// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3danimation_python.h"

// main header
#include "qt3danimation_qabstractchannelmapping_wrapper.h"

// Wrappers providing overrides
#include "qt3danimation_qmorphtarget_wrapper.h"

// Argument includes
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DAnimation;

// Native ---------------------------------------------------------

void QAbstractChannelMappingWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QAbstractChannelMappingWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QMorphTargetWrapper::sbk_o_childEvent("QAbstractChannelMapping", funcName, gil, pyOverride, event);
}

void QAbstractChannelMappingWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QMorphTargetWrapper::sbk_o_connectNotify("QAbstractChannelMapping", funcName, gil, pyOverride, signal);
}

void QAbstractChannelMappingWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QMorphTargetWrapper::sbk_o_customEvent("QAbstractChannelMapping", funcName, gil, pyOverride, event);
}

void QAbstractChannelMappingWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QMorphTargetWrapper::sbk_o_connectNotify("QAbstractChannelMapping", funcName, gil, pyOverride, signal);
}

bool QAbstractChannelMappingWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QMorphTargetWrapper::sbk_o_event("QAbstractChannelMapping", funcName, gil, pyOverride, event);
}

bool QAbstractChannelMappingWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QMorphTargetWrapper::sbk_o_eventFilter("QAbstractChannelMapping", funcName, gil, pyOverride, watched, event);
}

void QAbstractChannelMappingWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QMorphTargetWrapper::sbk_o_timerEvent("QAbstractChannelMapping", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstractChannelMappingWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DAnimation::QAbstractChannelMapping::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractChannelMappingWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DAnimation::QAbstractChannelMapping::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractChannelMappingWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractChannelMappingWrapper *>(this));
    return Qt3DAnimation::QAbstractChannelMapping::qt_metacast(_clname);
}

QAbstractChannelMappingWrapper::~QAbstractChannelMappingWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Qt3DAnimation_QAbstractChannelMapping_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QAbstractChannelMapping");
    return -1;
}


static const char *Sbk_Qt3DAnimation_QAbstractChannelMapping_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DAnimation_QAbstractChannelMapping_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DAnimation_QAbstractChannelMapping_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DAnimation::QAbstractChannelMapping *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractChannelMapping_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractChannelMappingWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DAnimation_QAbstractChannelMapping_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QAbstractChannelMapping_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DAnimation_QAbstractChannelMapping_Type = nullptr;
static PyTypeObject *Sbk_Qt3DAnimation_QAbstractChannelMapping_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QAbstractChannelMapping_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QAbstractChannelMapping_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAbstractChannelMapping_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAbstractChannelMapping_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAbstractChannelMapping_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAbstractChannelMapping_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAbstractChannelMapping_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QAbstractChannelMapping_spec = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QAbstractChannelMapping_slots
};

} //extern "C"

static void *Sbk_Qt3DAnimation_QAbstractChannelMapping_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DAnimation::QAbstractChannelMapping *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractChannelMapping_PythonToCpp_QAbstractChannelMapping_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QAbstractChannelMapping_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractChannelMapping_PythonToCpp_QAbstractChannelMapping_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DAnimation_QAbstractChannelMapping_TypeF()))
        return QAbstractChannelMapping_PythonToCpp_QAbstractChannelMapping_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractChannelMapping_PTR_CppToPython_QAbstractChannelMapping(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DAnimation::QAbstractChannelMapping *>(const_cast<void *>(cppIn)), Sbk_Qt3DAnimation_QAbstractChannelMapping_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DAnimation_QAbstractChannelMapping_SignatureStrings[] = {
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DAnimation_QAbstractChannelMapping_SignatureByteSize = 0;
static constexpr uint8_t Qt3DAnimation_QAbstractChannelMapping_SignatureBytes[1] = {
    0x00
};
#endif

PyTypeObject *init_Qt3DAnimation_QAbstractChannelMapping(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractChannelMapping_IDX].type != nullptr)
        return SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractChannelMapping_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DAnimation_QAbstractChannelMapping_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DAnimation_QAbstractChannelMapping_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAbstractChannelMapping",
        "Qt3DAnimation::QAbstractChannelMapping*",
        &Sbk_Qt3DAnimation_QAbstractChannelMapping_spec,
        &Shiboken::callCppDestructor< Qt3DAnimation::QAbstractChannelMapping >,
        Sbk_Qt3DAnimation_QAbstractChannelMapping_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DAnimation_QAbstractChannelMapping_TypeF(); // references _Sbk_Qt3DAnimation_QAbstractChannelMapping_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DAnimation_QAbstractChannelMapping_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DAnimation_QAbstractChannelMapping_SignatureBytes, Qt3DAnimation_QAbstractChannelMapping_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DAnimation_QAbstractChannelMapping_PropertyStrings);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractChannelMapping_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractChannelMapping_PythonToCpp_QAbstractChannelMapping_PTR,
        is_QAbstractChannelMapping_PythonToCpp_QAbstractChannelMapping_PTR_Convertible,
        QAbstractChannelMapping_PTR_CppToPython_QAbstractChannelMapping);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAbstractChannelMapping");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAbstractChannelMapping*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAbstractChannelMapping&");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractChannelMapping");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractChannelMapping*");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractChannelMapping&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QAbstractChannelMapping).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractChannelMappingWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DAnimation_QAbstractChannelMapping_TypeF(), &Sbk_Qt3DAnimation_QAbstractChannelMapping_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DAnimation::QAbstractChannelMapping::staticMetaObject, sizeof(QAbstractChannelMappingWrapper));

    return pyType;
}
