// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3danimation_python.h"

// main header
#include "qt3danimation_qchannelmapper_wrapper.h"

// Wrappers providing overrides
#include "qt3danimation_qmorphtarget_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DAnimation/qabstractchannelmapping.h>
#include <Qt3DCore/qnode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DAnimation;

// Native ---------------------------------------------------------

void QChannelMapperWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QChannelMapperWrapper::QChannelMapperWrapper(::Qt3DCore::QNode * parent) : Qt3DAnimation::QChannelMapper(parent)
{
}

void QChannelMapperWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QMorphTargetWrapper::sbk_o_childEvent("QChannelMapper", funcName, gil, pyOverride, event);
}

void QChannelMapperWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QMorphTargetWrapper::sbk_o_connectNotify("QChannelMapper", funcName, gil, pyOverride, signal);
}

void QChannelMapperWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QMorphTargetWrapper::sbk_o_customEvent("QChannelMapper", funcName, gil, pyOverride, event);
}

void QChannelMapperWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QMorphTargetWrapper::sbk_o_connectNotify("QChannelMapper", funcName, gil, pyOverride, signal);
}

bool QChannelMapperWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QMorphTargetWrapper::sbk_o_event("QChannelMapper", funcName, gil, pyOverride, event);
}

bool QChannelMapperWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QMorphTargetWrapper::sbk_o_eventFilter("QChannelMapper", funcName, gil, pyOverride, watched, event);
}

void QChannelMapperWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QMorphTargetWrapper::sbk_o_timerEvent("QChannelMapper", funcName, gil, pyOverride, event);
}

const QMetaObject *QChannelMapperWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DAnimation::QChannelMapper::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QChannelMapperWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DAnimation::QChannelMapper::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QChannelMapperWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QChannelMapperWrapper *>(this));
    return Qt3DAnimation::QChannelMapper::qt_metacast(_clname);
}

QChannelMapperWrapper::~QChannelMapperWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DAnimation_QChannelMapper_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DAnimation::QChannelMapper >()))
        return -1;

    QChannelMapperWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QChannelMapper", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QChannelMapper::QChannelMapper(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QChannelMapper(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QChannelMapper(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QChannelMapper(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QChannelMapperWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QChannelMapperWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DAnimation::QChannelMapper >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DAnimation_QChannelMapperFunc_addMapping(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChannelMapper::addMapping(Qt3DAnimation::QAbstractChannelMapping*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractChannelMapping_IDX]), (pyArg)))) {
        overloadId = 0; // addMapping(Qt3DAnimation::QAbstractChannelMapping*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addMapping", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DAnimation::QAbstractChannelMapping *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addMapping(Qt3DAnimation::QAbstractChannelMapping*)
            cppSelf->addMapping(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DAnimation_QChannelMapperFunc_mappings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mappings()const
        QList<Qt3DAnimation::QAbstractChannelMapping*> cppResult = const_cast<const ::Qt3DAnimation::QChannelMapper *>(cppSelf)->mappings();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DAnimationTypeConverters[SBK_Qt3DAnimation_QList_Qt3DAnimation_QAbstractChannelMappingPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DAnimation_QChannelMapperFunc_removeMapping(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChannelMapper::removeMapping(Qt3DAnimation::QAbstractChannelMapping*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractChannelMapping_IDX]), (pyArg)))) {
        overloadId = 0; // removeMapping(Qt3DAnimation::QAbstractChannelMapping*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeMapping", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DAnimation::QAbstractChannelMapping *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeMapping(Qt3DAnimation::QAbstractChannelMapping*)
            cppSelf->removeMapping(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Qt3DAnimation_QChannelMapper_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DAnimation_QChannelMapper_methods[] = {
    {"addMapping", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelMapperFunc_addMapping), METH_O, nullptr},
    {"mappings", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelMapperFunc_mappings), METH_NOARGS, nullptr},
    {"removeMapping", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelMapperFunc_removeMapping), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DAnimation_QChannelMapper_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DAnimation::QChannelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QChannelMapperWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DAnimation_QChannelMapper_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QChannelMapper_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DAnimation_QChannelMapper_Type = nullptr;
static PyTypeObject *Sbk_Qt3DAnimation_QChannelMapper_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QChannelMapper_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QChannelMapper_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelMapper_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelMapper_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelMapper_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelMapper_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelMapper_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QChannelMapper_spec = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QChannelMapper_slots
};

} //extern "C"

static void *Sbk_Qt3DAnimation_QChannelMapper_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DAnimation::QChannelMapper *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QChannelMapper_PythonToCpp_QChannelMapper_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QChannelMapper_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QChannelMapper_PythonToCpp_QChannelMapper_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DAnimation_QChannelMapper_TypeF()))
        return QChannelMapper_PythonToCpp_QChannelMapper_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QChannelMapper_PTR_CppToPython_QChannelMapper(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DAnimation::QChannelMapper *>(const_cast<void *>(cppIn)), Sbk_Qt3DAnimation_QChannelMapper_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DAnimation_QChannelMapper_SignatureStrings[] = {
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper.addMapping(self,mapping:PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper.mappings(self)->QList[PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping]",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper.removeMapping(self,mapping:PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping)",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DAnimation_QChannelMapper_SignatureByteSize = 145;
static constexpr uint8_t Qt3DAnimation_QChannelMapper_SignatureBytes[145] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x71, 0xcc,
    0xcb, 0xcc, 0x4d, 0x2c, 0xc9, 0xcc, 0xcf, 0x43, 0xe7, 0x39, 0x67, 0x24, 0xe6, 0xe5, 0xa5, 0xe6,
    0xf8, 0x26, 0x16, 0x14, 0xa4, 0x16, 0x69, 0x14, 0xa7, 0xe6, 0xa4, 0xe9, 0x14, 0x24, 0x16, 0xa5,
    0xe6, 0x95, 0x58, 0x05, 0x20, 0x69, 0x77, 0xce, 0x2f, 0x4a, 0x45, 0x62, 0xf8, 0xe5, 0xa7, 0xa4,
    0xda, 0xe6, 0x95, 0xe6, 0xe4, 0x14, 0x94, 0x14, 0x69, 0x72, 0x05, 0x90, 0x6c, 0x8f, 0x5e, 0x62,
    0x4a, 0x0a, 0x88, 0x95, 0x99, 0x97, 0x0e, 0xb1, 0x32, 0x17, 0xc2, 0xb1, 0x22, 0xca, 0x28, 0xc7,
    0xa4, 0xe2, 0x92, 0xa2, 0xc4, 0xe4, 0x12, 0x24, 0x23, 0x81, 0x7a, 0xc9, 0x72, 0x07, 0xd4, 0xde,
    0x62, 0xb0, 0x2b, 0x34, 0x75, 0xed, 0x02, 0x7d, 0x32, 0x8b, 0x4b, 0xa2, 0x29, 0x70, 0x45, 0x2c,
    0x39, 0xae, 0x28, 0x4a, 0xcd, 0xcd, 0x2f, 0x4b, 0xa5, 0x7e, 0x80, 0x00, 0x00, 0xa5, 0xe6, 0xb9,
    0xf2
};
#endif

PyTypeObject *init_Qt3DAnimation_QChannelMapper(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX].type != nullptr)
        return SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DAnimation_QChannelMapper_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DAnimation_QChannelMapper_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QChannelMapper",
        "Qt3DAnimation::QChannelMapper*",
        &Sbk_Qt3DAnimation_QChannelMapper_spec,
        &Shiboken::callCppDestructor< Qt3DAnimation::QChannelMapper >,
        Sbk_Qt3DAnimation_QChannelMapper_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DAnimation_QChannelMapper_TypeF(); // references _Sbk_Qt3DAnimation_QChannelMapper_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DAnimation_QChannelMapper_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DAnimation_QChannelMapper_SignatureBytes, Qt3DAnimation_QChannelMapper_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DAnimation_QChannelMapper_PropertyStrings);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QChannelMapper_PythonToCpp_QChannelMapper_PTR,
        is_QChannelMapper_PythonToCpp_QChannelMapper_PTR_Convertible,
        QChannelMapper_PTR_CppToPython_QChannelMapper);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QChannelMapper");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QChannelMapper*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QChannelMapper&");
    Shiboken::Conversions::registerConverterAlias(converter, "QChannelMapper");
    Shiboken::Conversions::registerConverterAlias(converter, "QChannelMapper*");
    Shiboken::Conversions::registerConverterAlias(converter, "QChannelMapper&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QChannelMapper).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QChannelMapperWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DAnimation_QChannelMapper_TypeF(), &Sbk_Qt3DAnimation_QChannelMapper_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DAnimation::QChannelMapper::staticMetaObject, sizeof(QChannelMapperWrapper));

    return pyType;
}
