// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dextras_python.h"

// main header
#include "qt3dextras_qphongmaterial_wrapper.h"

// Wrappers providing overrides
#include "qt3dextras_qt3dwindow_wrapper.h"

// Argument includes
#include <Qt3DCore/qnode.h>
#include <QtGui/qcolor.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DExtras;

// Native ---------------------------------------------------------

void QPhongMaterialWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPhongMaterialWrapper::QPhongMaterialWrapper(::Qt3DCore::QNode * parent) : Qt3DExtras::QPhongMaterial(parent)
{
}

void QPhongMaterialWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    Qt3DWindowWrapper::sbk_o_childEvent("QPhongMaterial", funcName, gil, pyOverride, event);
}

void QPhongMaterialWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    Qt3DWindowWrapper::sbk_o_connectNotify("QPhongMaterial", funcName, gil, pyOverride, signal);
}

void QPhongMaterialWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    Qt3DWindowWrapper::sbk_o_customEvent("QPhongMaterial", funcName, gil, pyOverride, event);
}

void QPhongMaterialWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    Qt3DWindowWrapper::sbk_o_connectNotify("QPhongMaterial", funcName, gil, pyOverride, signal);
}

bool QPhongMaterialWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return Qt3DWindowWrapper::sbk_o_event("QPhongMaterial", funcName, gil, pyOverride, event);
}

bool QPhongMaterialWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return Qt3DWindowWrapper::sbk_o_eventFilter("QPhongMaterial", funcName, gil, pyOverride, watched, event);
}

void QPhongMaterialWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    Qt3DWindowWrapper::sbk_o_timerEvent("QPhongMaterial", funcName, gil, pyOverride, event);
}

const QMetaObject *QPhongMaterialWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DExtras::QPhongMaterial::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPhongMaterialWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DExtras::QPhongMaterial::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPhongMaterialWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPhongMaterialWrapper *>(this));
    return Qt3DExtras::QPhongMaterial::qt_metacast(_clname);
}

QPhongMaterialWrapper::~QPhongMaterialWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DExtras_QPhongMaterial_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DExtras::QPhongMaterial >()))
        return -1;

    QPhongMaterialWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QPhongMaterial", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPhongMaterial::QPhongMaterial(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QPhongMaterial(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPhongMaterial(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPhongMaterial(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPhongMaterialWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPhongMaterialWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DExtras::QPhongMaterial >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_ambient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ambient()const
        QColor cppResult = const_cast<const ::Qt3DExtras::QPhongMaterial *>(cppSelf)->ambient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_diffuse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // diffuse()const
        QColor cppResult = const_cast<const ::Qt3DExtras::QPhongMaterial *>(cppSelf)->diffuse();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_setAmbient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPhongMaterial::setAmbient(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setAmbient(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAmbient", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAmbient(QColor)
            cppSelf->setAmbient(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_setDiffuse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPhongMaterial::setDiffuse(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setDiffuse(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDiffuse", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDiffuse(QColor)
            cppSelf->setDiffuse(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_setShininess(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPhongMaterial::setShininess(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setShininess(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShininess", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShininess(float)
            cppSelf->setShininess(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_setSpecular(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPhongMaterial::setSpecular(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSpecular(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpecular", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpecular(QColor)
            cppSelf->setSpecular(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_shininess(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shininess()const
        float cppResult = const_cast<const ::Qt3DExtras::QPhongMaterial *>(cppSelf)->shininess();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QPhongMaterialFunc_specular(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // specular()const
        QColor cppResult = const_cast<const ::Qt3DExtras::QPhongMaterial *>(cppSelf)->specular();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Qt3DExtras_QPhongMaterial_PropertyStrings[] = {
    "ambient::",
    "diffuse::",
    "shininess::",
    "specular::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DExtras_QPhongMaterial_methods[] = {
    {"ambient", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_ambient), METH_NOARGS, nullptr},
    {"diffuse", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_diffuse), METH_NOARGS, nullptr},
    {"setAmbient", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_setAmbient), METH_O, nullptr},
    {"setDiffuse", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_setDiffuse), METH_O, nullptr},
    {"setShininess", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_setShininess), METH_O, nullptr},
    {"setSpecular", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_setSpecular), METH_O, nullptr},
    {"shininess", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_shininess), METH_NOARGS, nullptr},
    {"specular", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QPhongMaterialFunc_specular), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DExtras_QPhongMaterial_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DExtras::QPhongMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPhongMaterialWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DExtras_QPhongMaterial_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DExtras_QPhongMaterial_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DExtras_QPhongMaterial_Type = nullptr;
static PyTypeObject *Sbk_Qt3DExtras_QPhongMaterial_TypeF(void)
{
    return _Sbk_Qt3DExtras_QPhongMaterial_Type;
}

static PyType_Slot Sbk_Qt3DExtras_QPhongMaterial_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QPhongMaterial_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QPhongMaterial_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DExtras_QPhongMaterial_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DExtras_QPhongMaterial_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DExtras_QPhongMaterial_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DExtras_QPhongMaterial_spec = {
    "2:PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DExtras_QPhongMaterial_slots
};

} //extern "C"

static void *Sbk_Qt3DExtras_QPhongMaterial_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DExtras::QPhongMaterial *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPhongMaterial_PythonToCpp_QPhongMaterial_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DExtras_QPhongMaterial_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPhongMaterial_PythonToCpp_QPhongMaterial_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DExtras_QPhongMaterial_TypeF()))
        return QPhongMaterial_PythonToCpp_QPhongMaterial_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPhongMaterial_PTR_CppToPython_QPhongMaterial(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DExtras::QPhongMaterial *>(const_cast<void *>(cppIn)), Sbk_Qt3DExtras_QPhongMaterial_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DExtras_QPhongMaterial_SignatureStrings[] = {
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,ambient:QColor=None,diffuse:QColor=None,specular:QColor=None,shininess:float=None)",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.ambient(self)->PySide6.QtGui.QColor",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.diffuse(self)->PySide6.QtGui.QColor",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.setAmbient(self,ambient:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.setDiffuse(self,diffuse:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.setShininess(self,shininess:float)",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.setSpecular(self,specular:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.shininess(self)->float",
    "PySide6.Qt3DExtras.Qt3DExtras.QPhongMaterial.specular(self)->PySide6.QtGui.QColor",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DExtras_QPhongMaterial_SignatureByteSize = 287;
static constexpr uint8_t Qt3DExtras_QPhongMaterial_SignatureBytes[287] = {
    0x78, 0xda, 0xd5, 0x53, 0x4d, 0x4b, 0xc4, 0x40, 0x0c, 0xbd, 0xfb, 0x2b, 0x7a, 0xb4, 0x52, 0x0b,
    0xa2, 0xec, 0xa1, 0xb0, 0x82, 0xec, 0xca, 0x1e, 0xd4, 0xb5, 0xb5, 0xe8, 0x45, 0x3c, 0x64, 0x6d,
    0xda, 0x0d, 0x8c, 0x99, 0x32, 0x93, 0xa2, 0xfd, 0xf7, 0xd6, 0x7e, 0xac, 0xd3, 0x45, 0x0f, 0x15,
    0x2f, 0x7b, 0x0b, 0x21, 0x79, 0xc9, 0x7b, 0x79, 0x89, 0xeb, 0x94, 0x32, 0x9c, 0x85, 0x89, 0x9c,
    0x2f, 0xaf, 0x3f, 0xc4, 0x80, 0x1d, 0x85, 0xf1, 0x56, 0x73, 0x71, 0x07, 0x82, 0x86, 0x40, 0x1d,
    0x5b, 0x54, 0x79, 0x50, 0x82, 0x41, 0x96, 0x28, 0x76, 0x1a, 0x17, 0xda, 0xa0, 0x13, 0xac, 0x75,
    0x86, 0x73, 0xae, 0x94, 0x2a, 0xc5, 0x04, 0x27, 0xd1, 0x0d, 0xd6, 0xef, 0xda, 0x64, 0xf7, 0xac,
    0xea, 0xf9, 0x5a, 0x33, 0x06, 0xf0, 0xb6, 0xa1, 0x2f, 0x88, 0x64, 0xa1, 0x95, 0x36, 0x5d, 0x2e,
    0xa3, 0x3c, 0xaf, 0x2c, 0x8e, 0x72, 0xb6, 0xc4, 0xd7, 0x4a, 0x81, 0x19, 0x27, 0xb7, 0xc4, 0xc4,
    0x68, 0x6d, 0x94, 0x2b, 0x0d, 0xd2, 0x26, 0xfd, 0xa3, 0x78, 0x02, 0x8d, 0xb0, 0x9f, 0xdf, 0xd2,
    0xf1, 0x4f, 0x2f, 0xbf, 0x7b, 0x57, 0x15, 0x85, 0xdd, 0xac, 0x69, 0x80, 0xfd, 0xf2, 0xff, 0x07,
    0x68, 0x51, 0xae, 0x9c, 0x25, 0x77, 0x8a, 0x49, 0x5d, 0x12, 0x17, 0xe1, 0x23, 0x93, 0xe6, 0xe7,
    0x9f, 0xc6, 0x04, 0x5e, 0x72, 0x0b, 0x42, 0x7c, 0x96, 0x8a, 0x69, 0x2a, 0x03, 0x6f, 0xaf, 0xe8,
    0xa1, 0xd8, 0xc0, 0xec, 0xa2, 0xa9, 0x7a, 0x82, 0x66, 0x10, 0x8b, 0x5b, 0xd0, 0x5f, 0x31, 0x5c,
    0x29, 0xbd, 0x01, 0x35, 0xc0, 0x0d, 0x40, 0x15, 0x5b, 0x2a, 0x18, 0x33, 0x8f, 0x58, 0x5e, 0xfc,
    0xc9, 0x74, 0x96, 0x8e, 0x44, 0xbb, 0x63, 0x1f, 0x2e, 0x9d, 0x74, 0x70, 0x61, 0x47, 0x68, 0xcf,
    0x94, 0x7f, 0xc0, 0xeb, 0xad, 0xde, 0xc3, 0x0d, 0xc6, 0x3f, 0x54, 0x81, 0x46, 0xea, 0x34, 0x1f,
    0xd1, 0xaa, 0x32, 0x11, 0xc3, 0x55, 0xe4, 0xb7, 0xa7, 0xfa, 0x04, 0x15, 0xaf, 0xb0, 0x61
};
#endif

PyTypeObject *init_Qt3DExtras_QPhongMaterial(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX].type != nullptr)
        return SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DExtras_QPhongMaterial_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QMaterial_IDX]))));

    _Sbk_Qt3DExtras_QPhongMaterial_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QPhongMaterial",
        "Qt3DExtras::QPhongMaterial*",
        &Sbk_Qt3DExtras_QPhongMaterial_spec,
        &Shiboken::callCppDestructor< Qt3DExtras::QPhongMaterial >,
        Sbk_Qt3DExtras_QPhongMaterial_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DExtras_QPhongMaterial_TypeF(); // references _Sbk_Qt3DExtras_QPhongMaterial_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DExtras_QPhongMaterial_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DExtras_QPhongMaterial_SignatureBytes, Qt3DExtras_QPhongMaterial_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DExtras_QPhongMaterial_PropertyStrings);
    SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QPhongMaterial_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPhongMaterial_PythonToCpp_QPhongMaterial_PTR,
        is_QPhongMaterial_PythonToCpp_QPhongMaterial_PTR_Convertible,
        QPhongMaterial_PTR_CppToPython_QPhongMaterial);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QPhongMaterial");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QPhongMaterial*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QPhongMaterial&");
    Shiboken::Conversions::registerConverterAlias(converter, "QPhongMaterial");
    Shiboken::Conversions::registerConverterAlias(converter, "QPhongMaterial*");
    Shiboken::Conversions::registerConverterAlias(converter, "QPhongMaterial&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DExtras::QPhongMaterial).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPhongMaterialWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DExtras_QPhongMaterial_TypeF(), &Sbk_Qt3DExtras_QPhongMaterial_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DExtras::QPhongMaterial::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DExtras::QPhongMaterial::staticMetaObject, sizeof(QPhongMaterialWrapper));

    return pyType;
}
