// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTPHYSICALDEVICEWRAPPER_H
#define SBK_QABSTRACTPHYSICALDEVICEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <Qt3DInput/qabstractphysicaldevice.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractPhysicalDeviceWrapper : public Qt3DInput::QAbstractPhysicalDevice
{
public:
    QAbstractPhysicalDeviceWrapper(::Qt3DCore::QNode * parent = nullptr);
    QAbstractPhysicalDeviceWrapper(const QAbstractPhysicalDeviceWrapper &) = delete;
    QAbstractPhysicalDeviceWrapper& operator=(const QAbstractPhysicalDeviceWrapper &) = delete;
    QAbstractPhysicalDeviceWrapper(QAbstractPhysicalDeviceWrapper &&) = delete;
    QAbstractPhysicalDeviceWrapper& operator=(QAbstractPhysicalDeviceWrapper &&) = delete;
    ~QAbstractPhysicalDeviceWrapper() override;

    int axisCount() const override;
    static int sbk_o_axisCount(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    int axisIdentifier(const ::QString & name) const override;
    static int sbk_o_axisIdentifier(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name);
    ::QStringList axisNames() const override;
    static ::QStringList sbk_o_axisNames(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    int buttonCount() const override;
    int buttonIdentifier(const ::QString & name) const override;
    ::QStringList buttonNames() const override;
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[13] = {false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTPHYSICALDEVICEWRAPPER_H
