// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dinput_python.h"

// main header
#include "qt3dinput_qinputsettings_wrapper.h"

// Wrappers providing overrides
#include "qt3dinput_qwheelevent_wrapper.h"

// Argument includes
#include <Qt3DCore/qnode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DInput;

// Native ---------------------------------------------------------

void QInputSettingsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QInputSettingsWrapper::QInputSettingsWrapper(::Qt3DCore::QNode * parent) : Qt3DInput::QInputSettings(parent)
{
}

void QInputSettingsWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWheelEventWrapper::sbk_o_childEvent("QInputSettings", funcName, gil, pyOverride, event);
}

void QInputSettingsWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWheelEventWrapper::sbk_o_connectNotify("QInputSettings", funcName, gil, pyOverride, signal);
}

void QInputSettingsWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWheelEventWrapper::sbk_o_customEvent("QInputSettings", funcName, gil, pyOverride, event);
}

void QInputSettingsWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWheelEventWrapper::sbk_o_connectNotify("QInputSettings", funcName, gil, pyOverride, signal);
}

bool QInputSettingsWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWheelEventWrapper::sbk_o_event("QInputSettings", funcName, gil, pyOverride, event);
}

bool QInputSettingsWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWheelEventWrapper::sbk_o_eventFilter("QInputSettings", funcName, gil, pyOverride, watched, event);
}

void QInputSettingsWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWheelEventWrapper::sbk_o_timerEvent("QInputSettings", funcName, gil, pyOverride, event);
}

const QMetaObject *QInputSettingsWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DInput::QInputSettings::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QInputSettingsWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DInput::QInputSettings::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QInputSettingsWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QInputSettingsWrapper *>(this));
    return Qt3DInput::QInputSettings::qt_metacast(_clname);
}

QInputSettingsWrapper::~QInputSettingsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DInput_QInputSettings_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DInput::QInputSettings >()))
        return -1;

    QInputSettingsWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QInputSettings", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QInputSettings::QInputSettings(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QInputSettings(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QInputSettings(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QInputSettings(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QInputSettingsWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QInputSettingsWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DInput::QInputSettings >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DInput_QInputSettingsFunc_eventSource(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QInputSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // eventSource()const
        QObject * cppResult = const_cast<const ::Qt3DInput::QInputSettings *>(cppSelf)->eventSource();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QInputSettingsFunc_setEventSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QInputSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputSettings::setEventSource(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setEventSource(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEventSource", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEventSource(QObject*)
            cppSelf->setEventSource(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Qt3DInput_QInputSettings_PropertyStrings[] = {
    "eventSource::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DInput_QInputSettings_methods[] = {
    {"eventSource", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QInputSettingsFunc_eventSource), METH_NOARGS, nullptr},
    {"setEventSource", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QInputSettingsFunc_setEventSource), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DInput_QInputSettings_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DInput::QInputSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QInputSettingsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DInput_QInputSettings_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DInput_QInputSettings_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DInput_QInputSettings_Type = nullptr;
static PyTypeObject *Sbk_Qt3DInput_QInputSettings_TypeF(void)
{
    return _Sbk_Qt3DInput_QInputSettings_Type;
}

static PyType_Slot Sbk_Qt3DInput_QInputSettings_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DInput_QInputSettings_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DInput_QInputSettings_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DInput_QInputSettings_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DInput_QInputSettings_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DInput_QInputSettings_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DInput_QInputSettings_spec = {
    "2:PySide6.Qt3DInput.Qt3DInput.QInputSettings",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DInput_QInputSettings_slots
};

} //extern "C"

static void *Sbk_Qt3DInput_QInputSettings_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DInput::QInputSettings *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QInputSettings_PythonToCpp_QInputSettings_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DInput_QInputSettings_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QInputSettings_PythonToCpp_QInputSettings_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DInput_QInputSettings_TypeF()))
        return QInputSettings_PythonToCpp_QInputSettings_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QInputSettings_PTR_CppToPython_QInputSettings(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DInput::QInputSettings *>(const_cast<void *>(cppIn)), Sbk_Qt3DInput_QInputSettings_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DInput_QInputSettings_SignatureStrings[] = {
    "PySide6.Qt3DInput.Qt3DInput.QInputSettings(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,eventSource:QObject=None)",
    "PySide6.Qt3DInput.Qt3DInput.QInputSettings.eventSource(self)->PySide6.QtCore.QObject",
    "PySide6.Qt3DInput.Qt3DInput.QInputSettings.setEventSource(self,eventSource:PySide6.QtCore.QObject)",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DInput_QInputSettings_SignatureByteSize = 146;
static constexpr uint8_t Qt3DInput_QInputSettings_SignatureBytes[146] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0xf1, 0xcc,
    0x2b, 0x28, 0x2d, 0x41, 0x66, 0x81, 0xa9, 0xe0, 0xd4, 0x92, 0x92, 0xcc, 0xbc, 0xf4, 0x62, 0x8d,
    0xe2, 0xd4, 0x9c, 0x34, 0x9d, 0x82, 0xc4, 0xa2, 0xd4, 0xbc, 0x12, 0xab, 0x00, 0x24, 0x6d, 0xce,
    0xf9, 0x45, 0xa9, 0x48, 0x0c, 0xbf, 0xfc, 0x94, 0x54, 0xdb, 0xbc, 0xd2, 0x9c, 0x9c, 0x82, 0x92,
    0x22, 0x1d, 0x2d, 0x2b, 0xef, 0xd4, 0xca, 0xf2, 0xfc, 0xa2, 0x14, 0xff, 0xbc, 0x9c, 0x4a, 0x5b,
    0xbf, 0xfc, 0xbc, 0x54, 0x9d, 0xd4, 0x32, 0xa0, 0x01, 0xc1, 0xf9, 0xa5, 0x45, 0xc9, 0xa9, 0x56,
    0x81, 0xfe, 0x49, 0x59, 0xa9, 0xc9, 0x25, 0x60, 0x09, 0x4d, 0xae, 0x00, 0xa2, 0xdd, 0xa2, 0x87,
    0x64, 0x08, 0xd8, 0x5d, 0x9a, 0xba, 0x76, 0x08, 0xdd, 0x10, 0x77, 0x40, 0x8c, 0x26, 0xc5, 0xd0,
    0xe2, 0xd4, 0x12, 0x57, 0x34, 0x73, 0x51, 0x5c, 0x8b, 0xdd, 0x06, 0x4d, 0x2e, 0x00, 0x0a, 0x1d,
    0x74, 0xd5
};
#endif

PyTypeObject *init_Qt3DInput_QInputSettings(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX].type != nullptr)
        return SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DInput_QInputSettings_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QComponent_IDX]))));

    _Sbk_Qt3DInput_QInputSettings_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QInputSettings",
        "Qt3DInput::QInputSettings*",
        &Sbk_Qt3DInput_QInputSettings_spec,
        &Shiboken::callCppDestructor< Qt3DInput::QInputSettings >,
        Sbk_Qt3DInput_QInputSettings_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DInput_QInputSettings_TypeF(); // references _Sbk_Qt3DInput_QInputSettings_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DInput_QInputSettings_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DInput_QInputSettings_SignatureBytes, Qt3DInput_QInputSettings_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DInput_QInputSettings_PropertyStrings);
    SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QInputSettings_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QInputSettings_PythonToCpp_QInputSettings_PTR,
        is_QInputSettings_PythonToCpp_QInputSettings_PTR_Convertible,
        QInputSettings_PTR_CppToPython_QInputSettings);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QInputSettings");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QInputSettings*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QInputSettings&");
    Shiboken::Conversions::registerConverterAlias(converter, "QInputSettings");
    Shiboken::Conversions::registerConverterAlias(converter, "QInputSettings*");
    Shiboken::Conversions::registerConverterAlias(converter, "QInputSettings&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DInput::QInputSettings).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QInputSettingsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DInput_QInputSettings_TypeF(), &Sbk_Qt3DInput_QInputSettings_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DInput::QInputSettings::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DInput::QInputSettings::staticMetaObject, sizeof(QInputSettingsWrapper));

    return pyType;
}
