// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QLEGENDWRAPPER_H
#define SBK_QLEGENDWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtCharts/qlegend.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QLegendWrapper : public QLegend
{
public:
    QLegendWrapper(const QLegendWrapper &) = delete;
    QLegendWrapper& operator=(const QLegendWrapper &) = delete;
    QLegendWrapper(QLegendWrapper &&) = delete;
    QLegendWrapper& operator=(QLegendWrapper &&) = delete;
    ~QLegendWrapper() override;

    void advance(int phase) override;
    static void sbk_o_advance(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int phase);
    ::QRectF boundingRect() const override;
    static ::QRectF sbk_o_boundingRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void changeEvent(::QEvent * event) override;
    static void sbk_o_changeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void childEvent(::QChildEvent * event) override;
    void closeEvent(::QCloseEvent * event) override;
    static void sbk_o_closeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QCloseEvent * event);
    bool collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    static bool sbk_o_collidesWithItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape);
    bool collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    static bool sbk_o_collidesWithPath(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPainterPath & path, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape);
    void connectNotify(const ::QMetaMethod & signal) override;
    bool contains(const ::QPointF & point) const override;
    static bool sbk_o_contains(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF & point);
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent * event) override;
    static void sbk_o_contextMenuEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneContextMenuEvent * event);
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dragEnterEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dragLeaveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    void dragMoveEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dragMoveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    void dropEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dropEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QVariant extension(const ::QVariant & variant) const override;
    static ::QVariant sbk_o_extension(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & variant);
    void focusInEvent(::QFocusEvent * event) override;
    static void sbk_o_focusInEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFocusEvent * event);
    bool focusNextPrevChild(bool next) override;
    static bool sbk_o_focusNextPrevChild(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, bool next);
    void focusOutEvent(::QFocusEvent * event) override;
    static void sbk_o_focusOutEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFocusEvent * event);
    void getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const override;
    static void sbk_o_getContentsMargins(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qreal * left, qreal * top, qreal * right, qreal * bottom);
    void grabKeyboardEvent(::QEvent * event) override;
    static void sbk_o_grabKeyboardEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void grabMouseEvent(::QEvent * event) override;
    static void sbk_o_grabMouseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void hideEvent(::QHideEvent * event) override;
    static void sbk_o_hideEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QHideEvent * event);
    void hoverEnterEvent(::QGraphicsSceneHoverEvent * event) override;
    static void sbk_o_hoverEnterEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneHoverEvent * event);
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent * event) override;
    static void sbk_o_hoverLeaveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneHoverEvent * event);
    void hoverMoveEvent(::QGraphicsSceneHoverEvent * event) override;
    static void sbk_o_hoverMoveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneHoverEvent * event);
    void initStyleOption(::QStyleOption * option) const override;
    static void sbk_o_initStyleOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyleOption * option);
    void inputMethodEvent(::QInputMethodEvent * event) override;
    static void sbk_o_inputMethodEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QInputMethodEvent * event);
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery query) const override;
    static ::QVariant sbk_o_inputMethodQuery(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::Qt::InputMethodQuery query);
    bool isEmpty() const override;
    static bool sbk_o_isEmpty(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isObscuredBy(const ::QGraphicsItem * item) const override;
    static bool sbk_o_isObscuredBy(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QGraphicsItem * item);
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value) override;
    static ::QVariant sbk_o_itemChange(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value);
    void keyPressEvent(::QKeyEvent * event) override;
    static void sbk_o_keyPressEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QKeyEvent * event);
    void keyReleaseEvent(::QKeyEvent * event) override;
    static void sbk_o_keyReleaseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QKeyEvent * event);
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mouseDoubleClickEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    void mouseMoveEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mouseMoveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    void mousePressEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mousePressEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mouseReleaseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    void moveEvent(::QGraphicsSceneMoveEvent * event) override;
    static void sbk_o_moveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMoveEvent * event);
    ::QPainterPath opaqueArea() const override;
    static ::QPainterPath sbk_o_opaqueArea(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr) override;
    static void sbk_o_paint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr);
    void paintWindowFrame(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr) override;
    static void sbk_o_paintWindowFrame(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr);
    void polishEvent() override;
    static void sbk_o_polishEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QVariant propertyChange(const ::QString & propertyName, const ::QVariant & value) override;
    static ::QVariant sbk_o_propertyChange(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & propertyName, const ::QVariant & value);
    void resizeEvent(::QGraphicsSceneResizeEvent * event) override;
    static void sbk_o_resizeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneResizeEvent * event);
    bool sceneEvent(::QEvent * event) override;
    static bool sbk_o_sceneEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    bool sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event) override;
    static bool sbk_o_sceneEventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsItem * watched, ::QEvent * event);
    void setGeometry(const ::QRectF & rect) override;
    static void sbk_o_setGeometry(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & rect);
    ::QPainterPath shape() const override;
    void showEvent(::QShowEvent * event) override;
    static void sbk_o_showEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QShowEvent * event);
    ::QSizeF sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint = QSizeF()) const override;
    static ::QSizeF sbk_o_sizeHint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::Qt::SizeHint which, const ::QSizeF & constraint = QSizeF());
    void timerEvent(::QTimerEvent * event) override;
    int type() const override;
    static int sbk_o_type(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void ungrabKeyboardEvent(::QEvent * event) override;
    static void sbk_o_ungrabKeyboardEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void ungrabMouseEvent(::QEvent * event) override;
    static void sbk_o_ungrabMouseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void updateGeometry() override;
    void wheelEvent(::QGraphicsSceneWheelEvent * event) override;
    static void sbk_o_wheelEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneWheelEvent * event);
    bool windowFrameEvent(::QEvent * e) override;
    static bool sbk_o_windowFrameEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * e);
    ::Qt::WindowFrameSection windowFrameSectionAt(const ::QPointF & pos) const override;
    static ::Qt::WindowFrameSection sbk_o_windowFrameSectionAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF & pos);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[62] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QLEGENDWRAPPER_H
