// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcharts_python.h"

// main header
#include "qpolarchart_wrapper.h"

// Wrappers providing overrides
#include "qlegend_wrapper.h"
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qpolarchart.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicssceneevent.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPolarChartWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPolarChartWrapper::QPolarChartWrapper(::QGraphicsItem * parent, ::QFlags<Qt::WindowType> wFlags) : QPolarChart(parent, wFlags)
{
}

void QPolarChartWrapper::advance(int phase)
{
    static const char *funcName = "advance";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::advance(phase);
    }
    QLegendWrapper::sbk_o_advance("QPolarChart", funcName, gil, pyOverride, phase);
}

::QRectF QPolarChartWrapper::boundingRect() const
{
    static const char *funcName = "boundingRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::boundingRect();
    }
    return QLegendWrapper::sbk_o_boundingRect("QPolarChart", funcName, gil, pyOverride);
}

void QPolarChartWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::changeEvent(event);
    }
    QLegendWrapper::sbk_o_changeEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::closeEvent(event);
    }
    QLegendWrapper::sbk_o_closeEvent("QPolarChart", funcName, gil, pyOverride, event);
}

bool QPolarChartWrapper::collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithItem(other, mode);
    }
    return QLegendWrapper::sbk_o_collidesWithItem("QPolarChart", funcName, gil, pyOverride, other, mode);
}

bool QPolarChartWrapper::collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithPath";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithPath(path, mode);
    }
    return QLegendWrapper::sbk_o_collidesWithPath("QPolarChart", funcName, gil, pyOverride, path, mode);
}

void QPolarChartWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QPolarChart", funcName, gil, pyOverride, signal);
}

bool QPolarChartWrapper::contains(const ::QPointF & point) const
{
    static const char *funcName = "contains";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contains(point);
    }
    return QLegendWrapper::sbk_o_contains("QPolarChart", funcName, gil, pyOverride, point);
}

void QPolarChartWrapper::contextMenuEvent(::QGraphicsSceneContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contextMenuEvent(event);
    }
    QLegendWrapper::sbk_o_contextMenuEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QPolarChart", funcName, gil, pyOverride, signal);
}

void QPolarChartWrapper::dragEnterEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragEnterEvent(event);
    }
    QLegendWrapper::sbk_o_dragEnterEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::dragLeaveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragLeaveEvent(event);
    }
    QLegendWrapper::sbk_o_dragLeaveEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::dragMoveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragMoveEvent(event);
    }
    QLegendWrapper::sbk_o_dragMoveEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::dropEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dropEvent(event);
    }
    QLegendWrapper::sbk_o_dropEvent("QPolarChart", funcName, gil, pyOverride, event);
}

bool QPolarChartWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QPolarChart", funcName, gil, pyOverride, event);
}

bool QPolarChartWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QPolarChart", funcName, gil, pyOverride, watched, event);
}

::QVariant QPolarChartWrapper::extension(const ::QVariant & variant) const
{
    static const char *funcName = "extension";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::extension(variant);
    }
    return QLegendWrapper::sbk_o_extension("QPolarChart", funcName, gil, pyOverride, variant);
}

void QPolarChartWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusInEvent(event);
    }
    QLegendWrapper::sbk_o_focusInEvent("QPolarChart", funcName, gil, pyOverride, event);
}

bool QPolarChartWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusNextPrevChild(next);
    }
    return QLegendWrapper::sbk_o_focusNextPrevChild("QPolarChart", funcName, gil, pyOverride, next);
}

void QPolarChartWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusOutEvent(event);
    }
    QLegendWrapper::sbk_o_focusOutEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const
{
    static const char *funcName = "getContentsMargins";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::getContentsMargins(left, top, right, bottom);
    }
    QLegendWrapper::sbk_o_getContentsMargins("QPolarChart", funcName, gil, pyOverride, left, top, right, bottom);
}

void QPolarChartWrapper::grabKeyboardEvent(::QEvent * event)
{
    static const char *funcName = "grabKeyboardEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::grabKeyboardEvent(event);
    }
    QLegendWrapper::sbk_o_grabKeyboardEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::grabMouseEvent(::QEvent * event)
{
    static const char *funcName = "grabMouseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::grabMouseEvent(event);
    }
    QLegendWrapper::sbk_o_grabMouseEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hideEvent(event);
    }
    QLegendWrapper::sbk_o_hideEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::hoverEnterEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverEnterEvent(event);
    }
    QLegendWrapper::sbk_o_hoverEnterEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::hoverLeaveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hoverLeaveEvent(event);
    }
    QLegendWrapper::sbk_o_hoverLeaveEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::hoverMoveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hoverMoveEvent(event);
    }
    QLegendWrapper::sbk_o_hoverMoveEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::initStyleOption(::QStyleOption * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::initStyleOption(option);
    }
    QLegendWrapper::sbk_o_initStyleOption("QPolarChart", funcName, gil, pyOverride, option);
}

void QPolarChartWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodEvent(event);
    }
    QLegendWrapper::sbk_o_inputMethodEvent("QPolarChart", funcName, gil, pyOverride, event);
}

::QVariant QPolarChartWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodQuery(query);
    }
    return QLegendWrapper::sbk_o_inputMethodQuery("QPolarChart", funcName, gil, pyOverride, query);
}

bool QPolarChartWrapper::isEmpty() const
{
    static const char *funcName = "isEmpty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayoutItem::isEmpty();
    }
    return QLegendWrapper::sbk_o_isEmpty("QPolarChart", funcName, gil, pyOverride);
}

bool QPolarChartWrapper::isObscuredBy(const ::QGraphicsItem * item) const
{
    static const char *funcName = "isObscuredBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::isObscuredBy(item);
    }
    return QLegendWrapper::sbk_o_isObscuredBy("QPolarChart", funcName, gil, pyOverride, item);
}

::QVariant QPolarChartWrapper::itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value)
{
    static const char *funcName = "itemChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::itemChange(change, value);
    }
    return QLegendWrapper::sbk_o_itemChange("QPolarChart", funcName, gil, pyOverride, change, value);
}

void QPolarChartWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyPressEvent(event);
    }
    QLegendWrapper::sbk_o_keyPressEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyReleaseEvent(event);
    }
    QLegendWrapper::sbk_o_keyReleaseEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseDoubleClickEvent(event);
    }
    QLegendWrapper::sbk_o_mouseDoubleClickEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::mouseMoveEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseMoveEvent(event);
    }
    QLegendWrapper::sbk_o_mouseMoveEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::mousePressEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mousePressEvent(event);
    }
    QLegendWrapper::sbk_o_mousePressEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::mouseReleaseEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseReleaseEvent(event);
    }
    QLegendWrapper::sbk_o_mouseReleaseEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::moveEvent(::QGraphicsSceneMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::moveEvent(event);
    }
    QLegendWrapper::sbk_o_moveEvent("QPolarChart", funcName, gil, pyOverride, event);
}

::QPainterPath QPolarChartWrapper::opaqueArea() const
{
    static const char *funcName = "opaqueArea";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::opaqueArea();
    }
    return QLegendWrapper::sbk_o_opaqueArea("QPolarChart", funcName, gil, pyOverride);
}

void QPolarChartWrapper::paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::paint(painter, option, widget);
    }
    QLegendWrapper::sbk_o_paint("QPolarChart", funcName, gil, pyOverride, painter, option, widget);
}

void QPolarChartWrapper::paintWindowFrame(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paintWindowFrame";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::paintWindowFrame(painter, option, widget);
    }
    QLegendWrapper::sbk_o_paintWindowFrame("QPolarChart", funcName, gil, pyOverride, painter, option, widget);
}

void QPolarChartWrapper::polishEvent()
{
    static const char *funcName = "polishEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::polishEvent();
    }
    QLegendWrapper::sbk_o_polishEvent("QPolarChart", funcName, gil, pyOverride);
}

::QVariant QPolarChartWrapper::propertyChange(const ::QString & propertyName, const ::QVariant & value)
{
    static const char *funcName = "propertyChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::propertyChange(propertyName, value);
    }
    return QLegendWrapper::sbk_o_propertyChange("QPolarChart", funcName, gil, pyOverride, propertyName, value);
}

void QPolarChartWrapper::resizeEvent(::QGraphicsSceneResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::resizeEvent(event);
    }
    QLegendWrapper::sbk_o_resizeEvent("QPolarChart", funcName, gil, pyOverride, event);
}

bool QPolarChartWrapper::sceneEvent(::QEvent * event)
{
    static const char *funcName = "sceneEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::sceneEvent(event);
    }
    return QLegendWrapper::sbk_o_sceneEvent("QPolarChart", funcName, gil, pyOverride, event);
}

bool QPolarChartWrapper::sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event)
{
    static const char *funcName = "sceneEventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::sceneEventFilter(watched, event);
    }
    return QLegendWrapper::sbk_o_sceneEventFilter("QPolarChart", funcName, gil, pyOverride, watched, event);
}

void QPolarChartWrapper::setGeometry(const ::QRectF & rect)
{
    // This method belongs to a property.
    static const char *funcName = "2:setGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::setGeometry(rect);
    }
    QLegendWrapper::sbk_o_setGeometry("QPolarChart", funcName, gil, pyOverride, rect);
}

::QPainterPath QPolarChartWrapper::shape() const
{
    static const char *funcName = "shape";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::shape();
    }
    return QLegendWrapper::sbk_o_opaqueArea("QPolarChart", funcName, gil, pyOverride);
}

void QPolarChartWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::showEvent(event);
    }
    QLegendWrapper::sbk_o_showEvent("QPolarChart", funcName, gil, pyOverride, event);
}

::QSizeF QPolarChartWrapper::sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint) const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::sizeHint(which, constraint);
    }
    return QLegendWrapper::sbk_o_sizeHint("QPolarChart", funcName, gil, pyOverride, which, constraint);
}

void QPolarChartWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QPolarChart", funcName, gil, pyOverride, event);
}

int QPolarChartWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::type();
    }
    return QLegendWrapper::sbk_o_type("QPolarChart", funcName, gil, pyOverride);
}

void QPolarChartWrapper::ungrabKeyboardEvent(::QEvent * event)
{
    static const char *funcName = "ungrabKeyboardEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::ungrabKeyboardEvent(event);
    }
    QLegendWrapper::sbk_o_ungrabKeyboardEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::ungrabMouseEvent(::QEvent * event)
{
    static const char *funcName = "ungrabMouseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::ungrabMouseEvent(event);
    }
    QLegendWrapper::sbk_o_ungrabMouseEvent("QPolarChart", funcName, gil, pyOverride, event);
}

void QPolarChartWrapper::updateGeometry()
{
    static const char *funcName = "updateGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::updateGeometry();
    }
    QLegendWrapper::sbk_o_polishEvent("QPolarChart", funcName, gil, pyOverride);
}

void QPolarChartWrapper::wheelEvent(::QGraphicsSceneWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[59], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::wheelEvent(event);
    }
    QLegendWrapper::sbk_o_wheelEvent("QPolarChart", funcName, gil, pyOverride, event);
}

bool QPolarChartWrapper::windowFrameEvent(::QEvent * e)
{
    static const char *funcName = "windowFrameEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[60], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::windowFrameEvent(e);
    }
    return QLegendWrapper::sbk_o_windowFrameEvent("QPolarChart", funcName, gil, pyOverride, e);
}

::Qt::WindowFrameSection QPolarChartWrapper::windowFrameSectionAt(const ::QPointF & pos) const
{
    static const char *funcName = "windowFrameSectionAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[61], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::windowFrameSectionAt(pos);
    }
    return QLegendWrapper::sbk_o_windowFrameSectionAt("QPolarChart", funcName, gil, pyOverride, pos);
}

const QMetaObject *QPolarChartWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPolarChart::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPolarChartWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPolarChart::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPolarChartWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPolarChartWrapper *>(this));
    return QPolarChart::qt_metacast(_clname);
}

QPolarChartWrapper::~QPolarChartWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPolarChart_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPolarChart >()))
        return -1;

    QPolarChartWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QPolarChart", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPolarChart::QPolarChart(QGraphicsItem*=,QFlags<Qt::WindowType>=)
    if (numArgs == 0) {
        overloadId = 0; // QPolarChart(QGraphicsItem*,QFlags<Qt::WindowType>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QPolarChart(QGraphicsItem*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QPolarChart(QGraphicsItem*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"parent", 0}, {"wFlags", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QGraphicsItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPolarChart(QGraphicsItem*,QFlags<Qt::WindowType>)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPolarChartWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPolarChartWrapper(cppArg0, cppArg1);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPolarChart >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPolarChartFunc_addAxis(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPolarChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addAxis", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPolarChart::addAxis(QAbstractAxis*,QPolarChart::PolarOrientation)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_PolarOrientation_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // addAxis(QAbstractAxis*,QPolarChart::PolarOrientation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addAxis", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractAxis *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QPolarChart::PolarOrientation cppArg1 = static_cast< ::QPolarChart::PolarOrientation>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAxis(QAbstractAxis*,QPolarChart::PolarOrientation)
            cppSelf->addAxis(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPolarChartFunc_axisPolarOrientation(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QPolarChart::axisPolarOrientation(QAbstractAxis*)->QPolarChart::PolarOrientation
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), (pyArg)))) {
        overloadId = 0; // axisPolarOrientation(QAbstractAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "axisPolarOrientation", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // axisPolarOrientation(QAbstractAxis*)
            QPolarChart::PolarOrientation cppResult = ::QPolarChart::axisPolarOrientation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_PolarOrientation_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QPolarChart_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPolarChart_EnumFlagInfo[] = {
    "PolarOrientation:Flag:PolarOrientations",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPolarChart_methods[] = {
    {"addAxis", reinterpret_cast<PyCFunction>(Sbk_QPolarChartFunc_addAxis), METH_VARARGS, nullptr},
    {"axisPolarOrientation", reinterpret_cast<PyCFunction>(Sbk_QPolarChartFunc_axisPolarOrientation), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPolarChart_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPolarChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPolarChartWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPolarChart_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPolarChart_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QPolarChartSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QPolarChart *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]))
        return static_cast< ::QChart *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]))
        return static_cast< ::QGraphicsWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX]))
        return static_cast< ::QGraphicsObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]))
        return static_cast< ::QGraphicsItem *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]))
        return static_cast< ::QGraphicsLayoutItem *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPolarChart_Type = nullptr;
static PyTypeObject *Sbk_QPolarChart_TypeF(void)
{
    return _Sbk_QPolarChart_Type;
}

static PyType_Slot Sbk_QPolarChart_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPolarChart_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPolarChart_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPolarChart_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPolarChart_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPolarChart_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPolarChart_spec = {
    "2:PySide6.QtCharts.QPolarChart",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPolarChart_slots
};

} //extern "C"

static void *Sbk_QPolarChart_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QGraphicsItem >())
        return dynamic_cast< ::QPolarChart *>(reinterpret_cast< ::QGraphicsItem *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPolarChart *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QGraphicsLayoutItem >())
        return dynamic_cast< ::QPolarChart *>(reinterpret_cast< ::QGraphicsLayoutItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPolarChart_PolarOrientation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPolarChart::PolarOrientation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPolarChart::PolarOrientation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPolarChart_PolarOrientation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_PolarOrientation_IDX])))
        return Enum_PythonToCpp_QPolarChart_PolarOrientation;
    return {};
}

static PyObject *QPolarChart_PolarOrientation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPolarChart::PolarOrientation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPolarChart::PolarOrientation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_PolarOrientation_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QPolarChart_PolarOrientation(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QPolarChart::PolarOrientation>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QPolarChart::PolarOrientation> *>(cppOut) = value;

}

static PyObject *QPolarChart_PolarOrientation_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QPolarChart::PolarOrientation> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_PolarOrientation_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPolarChart_PythonToCpp_QPolarChart_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPolarChart_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPolarChart_PythonToCpp_QPolarChart_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPolarChart_TypeF()))
        return QPolarChart_PythonToCpp_QPolarChart_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPolarChart_PTR_CppToPython_QPolarChart(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPolarChart *>(const_cast<void *>(cppIn)), Sbk_QPolarChart_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPolarChart_SignatureStrings[] = {
    "PySide6.QtCharts.QPolarChart(self,parent:PySide6.QtWidgets.QGraphicsItem=nullptr,wFlags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags())",
    "PySide6.QtCharts.QPolarChart.addAxis(self,axis:PySide6.QtCharts.QAbstractAxis,polarOrientation:PySide6.QtCharts.QPolarChart.PolarOrientation)",
    "PySide6.QtCharts.QPolarChart.axisPolarOrientation(axis:PySide6.QtCharts.QAbstractAxis)->PySide6.QtCharts.QPolarChart.PolarOrientation",
    nullptr}; // Sentinel
#else
static constexpr size_t QPolarChart_SignatureByteSize = 171;
static constexpr uint8_t QPolarChart_SignatureBytes[171] = {
    0x78, 0xda, 0x95, 0x8e, 0xc1, 0x0a, 0x82, 0x40, 0x10, 0x86, 0xef, 0x3d, 0x89, 0x82, 0xed, 0xb1,
    0x83, 0x60, 0x20, 0x42, 0xd1, 0xa9, 0x95, 0x02, 0xcf, 0x93, 0xbb, 0xe9, 0xc2, 0xb6, 0xbb, 0xcc,
    0x4e, 0x98, 0x6f, 0xdf, 0x6a, 0x20, 0x61, 0x60, 0x75, 0x9a, 0xf9, 0xe1, 0xfb, 0x67, 0x3e, 0xde,
    0x9f, 0x94, 0x90, 0x1b, 0x56, 0x52, 0xd1, 0x02, 0x92, 0x67, 0x25, 0xb7, 0x1a, 0x70, 0x0c, 0x91,
    0x97, 0xfa, 0x9a, 0x38, 0x40, 0x69, 0x28, 0xe5, 0x13, 0x58, 0x29, 0xd1, 0xc8, 0x81, 0xdc, 0x23,
    0xb8, 0x56, 0xd5, 0xfe, 0x40, 0xf2, 0x96, 0x99, 0xbb, 0xd6, 0x8e, 0x30, 0xe9, 0x76, 0x1a, 0x1a,
    0xff, 0x86, 0x17, 0x16, 0x65, 0x18, 0xac, 0x52, 0x46, 0xd8, 0xee, 0xdc, 0x3b, 0x99, 0x4d, 0x69,
    0x64, 0xa3, 0x38, 0x5e, 0xf1, 0x05, 0x0d, 0x06, 0x42, 0xe4, 0x0f, 0xe5, 0x5f, 0x3a, 0x10, 0xb6,
    0xf4, 0x13, 0xcf, 0x2f, 0x9e, 0x10, 0x6a, 0x1a, 0xc0, 0xc4, 0x0d, 0xdd, 0x23, 0xaa, 0xe0, 0x0d,
    0xa4, 0xac, 0x49, 0x17, 0xcf, 0xf3, 0x19, 0xfd, 0xcd, 0x26, 0x7c, 0x98, 0x57, 0xa2, 0x1f, 0xac,
    0xe2, 0xf5, 0xf6, 0x2f, 0x8d, 0xd5, 0x13, 0x46, 0x97, 0x97, 0x29
};
#endif

PyTypeObject *init_QPolarChart(PyObject *module)
{
    if (SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX].type != nullptr)
        return SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX].type;

    Shiboken::AutoDecRef Sbk_QPolarChart_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]))));

    _Sbk_QPolarChart_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPolarChart",
        "QPolarChart*",
        &Sbk_QPolarChart_spec,
        &Shiboken::callCppDestructor< QPolarChart >,
        Sbk_QPolarChart_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPolarChart_TypeF(); // references _Sbk_QPolarChart_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPolarChart_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPolarChart_SignatureBytes, QPolarChart_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPolarChart_PropertyStrings);
    SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPolarChart_PythonToCpp_QPolarChart_PTR,
        is_QPolarChart_PythonToCpp_QPolarChart_PTR_Convertible,
        QPolarChart_PTR_CppToPython_QPolarChart);

    Shiboken::Conversions::registerConverterName(converter, "QPolarChart");
    Shiboken::Conversions::registerConverterName(converter, "QPolarChart*");
    Shiboken::Conversions::registerConverterName(converter, "QPolarChart&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPolarChart).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPolarChartWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QPolarChart_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QPolarChart_TypeF(), &Sbk_QPolarChartSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPolarChart_TypeF(), &Sbk_QPolarChart_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPolarChart_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PolarOrientation'.
    const char *PolarOrientation_Initializer[] = {
        "PolarOrientationRadial",
        "PolarOrientationAngular",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PolarOrientation_InitializerValues[] = {
        uint8_t(QPolarChart::PolarOrientation::PolarOrientationRadial), //  0x01  1
        uint8_t(QPolarChart::PolarOrientation::PolarOrientationAngular) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPolarChart_TypeF(),
        "2:PySide6.QtCharts.QPolarChart.PolarOrientation",
        PolarOrientation_Initializer, PolarOrientation_InitializerValues);
    SbkPySide6_QtChartsTypeStructs[SBK_QPolarChart_PolarOrientation_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtChartsTypeStructs[SBK_QFlags_QPolarChart_PolarOrientation_IDX].type =
        EType;
    // Register converter for enum 'QPolarChart::PolarOrientation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPolarChart_PolarOrientation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPolarChart_PolarOrientation,
            is_Enum_PythonToCpp_QPolarChart_PolarOrientation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPolarChart::PolarOrientation");
        Shiboken::Conversions::registerConverterAlias(converter, "PolarOrientation");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QPolarChart_PolarOrientation_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QPolarChart_PolarOrientation,
            is_Enum_PythonToCpp_QPolarChart_PolarOrientation_Convertible);
        // Register converter for flag 'QFlags<QPolarChart::PolarOrientation>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QPolarChart::PolarOrientation>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QPolarChart::PolarOrientations");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PolarOrientation' enum/flags.

    qRegisterMetaType< ::QPolarChart::PolarOrientation >("QPolarChart::PolarOrientation");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPolarChart::staticMetaObject, sizeof(QPolarChartWrapper));

    return pyType;
}
