// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcharts_python.h"

// main header
#include "qvboxplotmodelmapper_wrapper.h"

// Wrappers providing overrides
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QtCharts/qboxplotseries.h>
#include <qabstractitemmodel.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QVBoxPlotModelMapperWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QVBoxPlotModelMapperWrapper::QVBoxPlotModelMapperWrapper(::QObject * parent) : QVBoxPlotModelMapper(parent)
{
}

void QVBoxPlotModelMapperWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QVBoxPlotModelMapper", funcName, gil, pyOverride, event);
}

void QVBoxPlotModelMapperWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QVBoxPlotModelMapper", funcName, gil, pyOverride, signal);
}

void QVBoxPlotModelMapperWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QVBoxPlotModelMapper", funcName, gil, pyOverride, event);
}

void QVBoxPlotModelMapperWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QVBoxPlotModelMapper", funcName, gil, pyOverride, signal);
}

bool QVBoxPlotModelMapperWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QVBoxPlotModelMapper", funcName, gil, pyOverride, event);
}

bool QVBoxPlotModelMapperWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QVBoxPlotModelMapper", funcName, gil, pyOverride, watched, event);
}

void QVBoxPlotModelMapperWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QVBoxPlotModelMapper", funcName, gil, pyOverride, event);
}

const QMetaObject *QVBoxPlotModelMapperWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QVBoxPlotModelMapper::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QVBoxPlotModelMapperWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QVBoxPlotModelMapper::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QVBoxPlotModelMapperWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QVBoxPlotModelMapperWrapper *>(this));
    return QVBoxPlotModelMapper::qt_metacast(_clname);
}

QVBoxPlotModelMapperWrapper::~QVBoxPlotModelMapperWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVBoxPlotModelMapper_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVBoxPlotModelMapper >()))
        return -1;

    QVBoxPlotModelMapperWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QVBoxPlotModelMapper", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QVBoxPlotModelMapper::QVBoxPlotModelMapper(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QVBoxPlotModelMapper(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QVBoxPlotModelMapper(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QVBoxPlotModelMapper(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QVBoxPlotModelMapperWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QVBoxPlotModelMapperWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QVBoxPlotModelMapper >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_firstBoxSetColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstBoxSetColumn()const
        int cppResult = const_cast<const ::QVBoxPlotModelMapper *>(cppSelf)->firstBoxSetColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_firstRow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstRow()const
        int cppResult = const_cast<const ::QVBoxPlotModelMapper *>(cppSelf)->firstRow();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_lastBoxSetColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastBoxSetColumn()const
        int cppResult = const_cast<const ::QVBoxPlotModelMapper *>(cppSelf)->lastBoxSetColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_model(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // model()const
        QAbstractItemModel * cppResult = const_cast<const ::QVBoxPlotModelMapper *>(cppSelf)->model();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_rowCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowCount()const
        int cppResult = const_cast<const ::QVBoxPlotModelMapper *>(cppSelf)->rowCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_series(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // series()const
        QBoxPlotSeries * cppResult = const_cast<const ::QVBoxPlotModelMapper *>(cppSelf)->series();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBoxPlotSeries_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_setFirstBoxSetColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVBoxPlotModelMapper::setFirstBoxSetColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFirstBoxSetColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFirstBoxSetColumn", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstBoxSetColumn(int)
            cppSelf->setFirstBoxSetColumn(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_setFirstRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVBoxPlotModelMapper::setFirstRow(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFirstRow(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFirstRow", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstRow(int)
            cppSelf->setFirstRow(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_setLastBoxSetColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVBoxPlotModelMapper::setLastBoxSetColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLastBoxSetColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastBoxSetColumn", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLastBoxSetColumn(int)
            cppSelf->setLastBoxSetColumn(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_setModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBoxPlotModelMapper::setModel(QAbstractItemModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg)))) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModel", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModel(QAbstractItemModel*)
            cppSelf->setModel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_setRowCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVBoxPlotModelMapper::setRowCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRowCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowCount", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowCount(int)
            cppSelf->setRowCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVBoxPlotModelMapperFunc_setSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBoxPlotModelMapper::setSeries(QBoxPlotSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBoxPlotSeries_IDX]), (pyArg)))) {
        overloadId = 0; // setSeries(QBoxPlotSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSeries", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBoxPlotSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSeries(QBoxPlotSeries*)
            cppSelf->setSeries(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QVBoxPlotModelMapper_PropertyStrings[] = {
    "firstBoxSetColumn::",
    "firstRow::",
    "lastBoxSetColumn::",
    "model::",
    "rowCount::",
    "series::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVBoxPlotModelMapper_methods[] = {
    {"firstBoxSetColumn", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_firstBoxSetColumn), METH_NOARGS, nullptr},
    {"firstRow", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_firstRow), METH_NOARGS, nullptr},
    {"lastBoxSetColumn", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_lastBoxSetColumn), METH_NOARGS, nullptr},
    {"model", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_model), METH_NOARGS, nullptr},
    {"rowCount", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_rowCount), METH_NOARGS, nullptr},
    {"series", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_series), METH_NOARGS, nullptr},
    {"setFirstBoxSetColumn", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_setFirstBoxSetColumn), METH_O, nullptr},
    {"setFirstRow", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_setFirstRow), METH_O, nullptr},
    {"setLastBoxSetColumn", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_setLastBoxSetColumn), METH_O, nullptr},
    {"setModel", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_setModel), METH_O, nullptr},
    {"setRowCount", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_setRowCount), METH_O, nullptr},
    {"setSeries", reinterpret_cast<PyCFunction>(Sbk_QVBoxPlotModelMapperFunc_setSeries), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QVBoxPlotModelMapper_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QVBoxPlotModelMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QVBoxPlotModelMapperWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QVBoxPlotModelMapper_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVBoxPlotModelMapper_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVBoxPlotModelMapper_Type = nullptr;
static PyTypeObject *Sbk_QVBoxPlotModelMapper_TypeF(void)
{
    return _Sbk_QVBoxPlotModelMapper_Type;
}

static PyType_Slot Sbk_QVBoxPlotModelMapper_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QVBoxPlotModelMapper_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVBoxPlotModelMapper_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVBoxPlotModelMapper_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVBoxPlotModelMapper_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVBoxPlotModelMapper_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVBoxPlotModelMapper_spec = {
    "2:PySide6.QtCharts.QVBoxPlotModelMapper",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVBoxPlotModelMapper_slots
};

} //extern "C"

static void *Sbk_QVBoxPlotModelMapper_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QVBoxPlotModelMapper *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QVBoxPlotModelMapper_PythonToCpp_QVBoxPlotModelMapper_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVBoxPlotModelMapper_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QVBoxPlotModelMapper_PythonToCpp_QVBoxPlotModelMapper_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVBoxPlotModelMapper_TypeF()))
        return QVBoxPlotModelMapper_PythonToCpp_QVBoxPlotModelMapper_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QVBoxPlotModelMapper_PTR_CppToPython_QVBoxPlotModelMapper(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QVBoxPlotModelMapper *>(const_cast<void *>(cppIn)), Sbk_QVBoxPlotModelMapper_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QVBoxPlotModelMapper_SignatureStrings[] = {
    "PySide6.QtCharts.QVBoxPlotModelMapper(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,series:QBoxPlotSeries=None,model:QAbstractItemModel=None,firstBoxSetColumn:int=None,lastBoxSetColumn:int=None,firstRow:int=None,rowCount:int=None)",
    "PySide6.QtCharts.QVBoxPlotModelMapper.firstBoxSetColumn(self)->int",
    "PySide6.QtCharts.QVBoxPlotModelMapper.firstRow(self)->int",
    "PySide6.QtCharts.QVBoxPlotModelMapper.lastBoxSetColumn(self)->int",
    "PySide6.QtCharts.QVBoxPlotModelMapper.model(self)->PySide6.QtCore.QAbstractItemModel",
    "PySide6.QtCharts.QVBoxPlotModelMapper.rowCount(self)->int",
    "PySide6.QtCharts.QVBoxPlotModelMapper.series(self)->PySide6.QtCharts.QBoxPlotSeries",
    "PySide6.QtCharts.QVBoxPlotModelMapper.setFirstBoxSetColumn(self,firstBoxSetColumn:int)",
    "PySide6.QtCharts.QVBoxPlotModelMapper.setFirstRow(self,firstRow:int)",
    "PySide6.QtCharts.QVBoxPlotModelMapper.setLastBoxSetColumn(self,lastBoxSetColumn:int)",
    "PySide6.QtCharts.QVBoxPlotModelMapper.setModel(self,model:PySide6.QtCore.QAbstractItemModel)",
    "PySide6.QtCharts.QVBoxPlotModelMapper.setRowCount(self,rowCount:int)",
    "PySide6.QtCharts.QVBoxPlotModelMapper.setSeries(self,series:PySide6.QtCharts.QBoxPlotSeries)",
    nullptr}; // Sentinel
#else
static constexpr size_t QVBoxPlotModelMapper_SignatureByteSize = 275;
static constexpr uint8_t QVBoxPlotModelMapper_SignatureBytes[275] = {
    0x78, 0xda, 0x95, 0x93, 0xdf, 0x4f, 0x83, 0x30, 0x10, 0xc7, 0xdf, 0xf7, 0x97, 0x88, 0x41, 0x1e,
    0x7d, 0x68, 0x32, 0x13, 0x5d, 0x62, 0x62, 0x14, 0x47, 0x47, 0xe2, 0x7b, 0x37, 0x6e, 0x19, 0xa6,
    0xb4, 0xe4, 0x7a, 0x04, 0xf9, 0xef, 0xad, 0x85, 0x8a, 0x6c, 0x98, 0xd1, 0xc7, 0xf6, 0xf2, 0xfd,
    0xdc, 0x8f, 0xef, 0x5d, 0xd6, 0xe5, 0x65, 0x01, 0xf7, 0x09, 0xa7, 0xcd, 0x49, 0x20, 0x99, 0x84,
    0x7f, 0x3c, 0xe9, 0xaf, 0x4c, 0x6a, 0x4a, 0x75, 0x01, 0x32, 0x15, 0x75, 0x0d, 0x78, 0x63, 0x40,
    0x1e, 0xe3, 0x5a, 0x20, 0x28, 0x62, 0xd9, 0xa8, 0xd0, 0x08, 0x09, 0xdf, 0xee, 0x3f, 0xe1, 0x40,
    0x6b, 0xd5, 0x48, 0x59, 0x13, 0xc6, 0xb7, 0xec, 0x15, 0xba, 0x56, 0x63, 0xb1, 0x55, 0xb2, 0x5b,
    0xbf, 0x6b, 0x05, 0xb1, 0x01, 0x2c, 0xc1, 0x30, 0x3e, 0x80, 0x73, 0xf7, 0xec, 0x43, 0xd5, 0x4f,
    0x12, 0xc6, 0x1f, 0xf7, 0x86, 0x50, 0x1c, 0xe8, 0x85, 0xa0, 0x72, 0x79, 0xfb, 0xe8, 0xb1, 0x44,
    0x43, 0x56, 0x95, 0x83, 0xcd, 0x25, 0x9b, 0x4a, 0xb1, 0x52, 0x51, 0x1f, 0x92, 0xe2, 0xbf, 0x88,
    0x13, 0xed, 0x74, 0x3b, 0xfe, 0xa0, 0x6e, 0x37, 0xba, 0xb1, 0xa5, 0xfb, 0x9f, 0x68, 0x95, 0x2d,
    0x69, 0x3b, 0xb9, 0xc8, 0xef, 0x06, 0x11, 0xdd, 0x3d, 0x58, 0x50, 0x08, 0xc2, 0x56, 0x13, 0xae,
    0x3c, 0xef, 0x30, 0x9c, 0xe0, 0x86, 0xeb, 0x65, 0xe7, 0xb6, 0x5d, 0x8c, 0x7c, 0x21, 0xd4, 0x0f,
    0x33, 0xbc, 0x9c, 0x7e, 0x0d, 0x66, 0xea, 0x19, 0x34, 0x93, 0xf5, 0x58, 0xcc, 0xa4, 0xe7, 0x59,
    0x93, 0xe6, 0x77, 0x27, 0x0a, 0xc4, 0x7a, 0xe3, 0x26, 0x4b, 0x15, 0x00, 0x79, 0x9b, 0xf3, 0x70,
    0x76, 0x77, 0x03, 0xa0, 0xe9, 0xaf, 0xad, 0xc3, 0xf9, 0x5c, 0xb5, 0x36, 0x00, 0xbe, 0xfb, 0x6b,
    0xef, 0xe4, 0x72, 0x02, 0x20, 0xf9, 0xe8, 0xb4, 0x3f, 0xfe, 0x2b, 0x76, 0x47, 0xab, 0x6f, 0x18,
    0xdd, 0xac, 0x9f
};
#endif

PyTypeObject *init_QVBoxPlotModelMapper(PyObject *module)
{
    if (SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX].type != nullptr)
        return SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX].type;

    Shiboken::AutoDecRef Sbk_QVBoxPlotModelMapper_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBoxPlotModelMapper_IDX]))));

    _Sbk_QVBoxPlotModelMapper_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QVBoxPlotModelMapper",
        "QVBoxPlotModelMapper*",
        &Sbk_QVBoxPlotModelMapper_spec,
        &Shiboken::callCppDestructor< QVBoxPlotModelMapper >,
        Sbk_QVBoxPlotModelMapper_Type_bases.object(),
        0);
    auto *pyType = Sbk_QVBoxPlotModelMapper_TypeF(); // references _Sbk_QVBoxPlotModelMapper_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QVBoxPlotModelMapper_SignatureStrings);
#else
    InitSignatureBytes(pyType, QVBoxPlotModelMapper_SignatureBytes, QVBoxPlotModelMapper_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVBoxPlotModelMapper_PropertyStrings);
    SbkPySide6_QtChartsTypeStructs[SBK_QVBoxPlotModelMapper_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QVBoxPlotModelMapper_PythonToCpp_QVBoxPlotModelMapper_PTR,
        is_QVBoxPlotModelMapper_PythonToCpp_QVBoxPlotModelMapper_PTR_Convertible,
        QVBoxPlotModelMapper_PTR_CppToPython_QVBoxPlotModelMapper);

    Shiboken::Conversions::registerConverterName(converter, "QVBoxPlotModelMapper");
    Shiboken::Conversions::registerConverterName(converter, "QVBoxPlotModelMapper*");
    Shiboken::Conversions::registerConverterName(converter, "QVBoxPlotModelMapper&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVBoxPlotModelMapper).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QVBoxPlotModelMapperWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QVBoxPlotModelMapper_TypeF(), &Sbk_QVBoxPlotModelMapper_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QVBoxPlotModelMapper::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QVBoxPlotModelMapper::staticMetaObject, sizeof(QVBoxPlotModelMapperWrapper));

    return pyType;
}
