// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTANIMATIONWRAPPER_H
#define SBK_QABSTRACTANIMATIONWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <qabstractanimation.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractAnimationWrapper : public QAbstractAnimation
{
public:
    QAbstractAnimationWrapper(::QObject * parent = nullptr);
    QAbstractAnimationWrapper(const QAbstractAnimationWrapper &) = delete;
    QAbstractAnimationWrapper& operator=(const QAbstractAnimationWrapper &) = delete;
    QAbstractAnimationWrapper(QAbstractAnimationWrapper &&) = delete;
    QAbstractAnimationWrapper& operator=(QAbstractAnimationWrapper &&) = delete;
    ~QAbstractAnimationWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    int duration() const override;
    static int sbk_o_duration(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void timerEvent(::QTimerEvent * event) override;
    void updateCurrentTime(int currentTime) override;
    static void sbk_o_updateCurrentTime(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int currentTime);
    void updateDirection(::QAbstractAnimation::Direction direction) override;
    static void sbk_o_updateDirection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractAnimation::Direction direction);
    void updateState(::QAbstractAnimation::State newState, ::QAbstractAnimation::State oldState) override;
    static void sbk_o_updateState(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractAnimation::State newState, ::QAbstractAnimation::State oldState);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[11] = {false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTANIMATIONWRAPPER_H
