// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QEVENTWRAPPER_H
#define SBK_QEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <qcoreevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QEventWrapper : public QEvent
{
public:
    QEventWrapper(::QEvent::Type type);
    QEventWrapper(const QEventWrapper &) = delete;
    QEventWrapper(const QEvent& self) : QEvent(self)
    {
    }
    QEventWrapper& operator=(const QEventWrapper &) = delete;
    QEventWrapper(QEventWrapper &&) = delete;
    QEventWrapper& operator=(QEventWrapper &&) = delete;
    ~QEventWrapper() override;

    ::QEvent * clone() const override;
    static ::QEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setAccepted(bool accepted) override;
    static void sbk_o_setAccepted(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, bool accepted);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[2] = {false, false};
};

#endif // SBK_QEVENTWRAPPER_H
