// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qfile_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qprocess_wrapper.h"
#include "qfiledevice_wrapper.h"
#include "qtranslator_wrapper.h"
#include "qiodevice_wrapper.h"

// Argument includes
#include <QString>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QFileWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QFileWrapper::QFileWrapper()
{
}

QFileWrapper::QFileWrapper(::QObject * parent) : QFile(parent)
{
}

QFileWrapper::QFileWrapper(const ::QString & name) : QFile(name)
{
    // ... middle
}

QFileWrapper::QFileWrapper(const ::QString & name, ::QObject * parent) : QFile(name, parent)
{
    // ... middle
}

bool QFileWrapper::atEnd() const
{
    static const char *funcName = "atEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::atEnd();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFile", funcName, gil, pyOverride);
}

qint64 QFileWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::bytesAvailable();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFile", funcName, gil, pyOverride);
}

qint64 QFileWrapper::bytesToWrite() const
{
    static const char *funcName = "bytesToWrite";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::bytesToWrite();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFile", funcName, gil, pyOverride);
}

bool QFileWrapper::canReadLine() const
{
    static const char *funcName = "canReadLine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::canReadLine();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFile", funcName, gil, pyOverride);
}

void QFileWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QFile", funcName, gil, pyOverride, event);
}

void QFileWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::close();
    }
    QProcessWrapper::sbk_o_close("QFile", funcName, gil, pyOverride);
}

void QFileWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QFile", funcName, gil, pyOverride, signal);
}

void QFileWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QFile", funcName, gil, pyOverride, event);
}

void QFileWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QFile", funcName, gil, pyOverride, signal);
}

bool QFileWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QFile", funcName, gil, pyOverride, event);
}

bool QFileWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QFile", funcName, gil, pyOverride, watched, event);
}

::QString QFileWrapper::fileName() const
{
    static const char *funcName = "fileName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFile::fileName();
    }
    return QFileDeviceWrapper::sbk_o_fileName("QFile", funcName, gil, pyOverride);
}

bool QFileWrapper::isSequential() const
{
    static const char *funcName = "isSequential";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::isSequential();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFile", funcName, gil, pyOverride);
}

bool QFileWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> flags)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFile::open(flags);
    }
    return QIODeviceWrapper::sbk_o_open("QFile", funcName, gil, pyOverride, flags);
}

::QFlags<QFileDevice::Permission> QFileWrapper::permissions() const
{
    static const char *funcName = "permissions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFile::permissions();
    }
    return QFileDeviceWrapper::sbk_o_permissions("QFile", funcName, gil, pyOverride);
}

qint64 QFileWrapper::pos() const
{
    static const char *funcName = "pos";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::pos();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFile", funcName, gil, pyOverride);
}

qint64 QFileWrapper::readData(char * data, qint64 maxlen)
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::readData(data, maxlen);
    }
    return QProcessWrapper::sbk_o_readData("QFile", funcName, gil, pyOverride, data, maxlen);
}

qint64 QFileWrapper::readLineData(char * data, qint64 maxlen)
{
    static const char *funcName = "readLineData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::readLineData(data, maxlen);
    }
    return QProcessWrapper::sbk_o_readLineData("QFile", funcName, gil, pyOverride, data, maxlen);
}

bool QFileWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::reset();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFile", funcName, gil, pyOverride);
}

bool QFileWrapper::resize(qint64 sz)
{
    static const char *funcName = "resize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFile::resize(sz);
    }
    return QFileDeviceWrapper::sbk_o_resize("QFile", funcName, gil, pyOverride, sz);
}

bool QFileWrapper::seek(qint64 offset)
{
    static const char *funcName = "seek";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::seek(offset);
    }
    return QProcessWrapper::sbk_o_seek("QFile", funcName, gil, pyOverride, offset);
}

bool QFileWrapper::setPermissions(::QFlags<QFileDevice::Permission> permissionSpec)
{
    static const char *funcName = "setPermissions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFile::setPermissions(permissionSpec);
    }
    return QFileDeviceWrapper::sbk_o_setPermissions("QFile", funcName, gil, pyOverride, permissionSpec);
}

qint64 QFileWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFile::size();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFile", funcName, gil, pyOverride);
}

qint64 QFileWrapper::skipData(qint64 maxSize)
{
    static const char *funcName = "skipData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::skipData(maxSize);
    }
    return QIODeviceWrapper::sbk_o_skipData("QFile", funcName, gil, pyOverride, maxSize);
}

void QFileWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QFile", funcName, gil, pyOverride, event);
}

bool QFileWrapper::waitForBytesWritten(int msecs)
{
    static const char *funcName = "waitForBytesWritten";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForBytesWritten(msecs);
    }
    return QFileDeviceWrapper::sbk_o_waitForBytesWritten("QFile", funcName, gil, pyOverride, msecs);
}

bool QFileWrapper::waitForReadyRead(int msecs)
{
    static const char *funcName = "waitForReadyRead";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForReadyRead(msecs);
    }
    return QProcessWrapper::sbk_o_waitForReadyRead("QFile", funcName, gil, pyOverride, msecs);
}

qint64 QFileWrapper::writeData(const char * data, qint64 len)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::writeData(data, len);
    }
    return QIODeviceWrapper::sbk_o_writeData("QFile", funcName, gil, pyOverride, data, len);
}

const QMetaObject *QFileWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QFile::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QFileWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QFile::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QFileWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QFileWrapper *>(this));
    return QFile::qt_metacast(_clname);
}

QFileWrapper::~QFileWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFile_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFile >()))
        return -1;

    QFileWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFile", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFile::QFile()
    // 1: QFile::QFile(QObject*)
    // 2: QFile::QFile(PyPathLike)
    // 3: QFile::QFile(PyPathLike,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QFile()
    } else if (numArgs >= 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QFile(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 3; // QFile(QString,QObject*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QFile(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFile()
        {

            // QFile()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QFileWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QFileWrapper();
            }

            break;
        }
        case 1: // QFile(QObject *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFile(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QFileWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QFileWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 2: // QFile(const QString &name)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFile(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QFileWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QFileWrapper(cppArg0);
                }

            }
            break;
        }
        case 3: // QFile(const QString &name, QObject *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFile(QString,QObject*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QFileWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QFileWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QFileFunc_copy(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "copy", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFile::copy(QString,QString)->bool
    // 1: QFile::copy(PyPathLike)->bool
    if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 1; // copy(QString)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // copy(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "copy", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // copy(const QString &fileName, const QString &newName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // copy(QString,QString)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QFile::copy(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // copy(const QString &newName)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // copy(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->copy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_decodeName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QFile::decodeName(QByteArray)->QString
    // 1: static QFile::decodeName(const char*)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 1; // decodeName(const char*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // decodeName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "decodeName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // decodeName(const QByteArray &localFileName)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // decodeName(QByteArray)
                QString cppResult = ::QFile::decodeName(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // decodeName(const char *localFileName)
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // decodeName(const char*)
                QString cppResult = ::QFile::decodeName(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_encodeName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QFile::encodeName(QString)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // encodeName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "encodeName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // encodeName(QString)
            QByteArray cppResult = ::QFile::encodeName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_exists(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "exists", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFile::exists()const->bool
    // 1: static QFile::exists(QString)->bool
    if (numArgs == 0) {
        overloadId = 0; // exists()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // exists(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exists", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // exists() const
        {

            // exists()const
            bool cppResult = const_cast<const ::QFile *>(cppSelf)->exists();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // exists(const QString &fileName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // exists(QString)
                bool cppResult = ::QFile::exists(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFile *>(cppSelf)->::QFile::fileName()
            : const_cast<const ::QFile *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_link(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "link", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFile::link(QString,QString)->bool
    // 1: QFile::link(PyPathLike)->bool
    if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 1; // link(QString)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // link(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "link", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // link(const QString &fileName, const QString &newName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // link(QString,QString)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QFile::link(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // link(const QString &newName)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // link(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->link(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_moveToTrash(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "moveToTrash", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    if (PyArg_ParseTuple(args, "|OO:moveToTrash", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFile::moveToTrash()->bool
    // 1: static QFile::moveToTrash(QString,QString*=)->bool
    if (numArgs == 0) {
        overloadId = 0; // moveToTrash()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // moveToTrash(QString,QString*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // moveToTrash(QString,QString*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "moveToTrash", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // moveToTrash()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "moveToTrash", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);
            }

            // moveToTrash()
            bool cppResult = cppSelf->moveToTrash();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // moveToTrash(const QString &fileName, QString *pathInTrash)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"pathInTrash", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "moveToTrash", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // moveToTrash(QString,QString*)
                bool cppResult = ::QFile::moveToTrash(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_open(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:open", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::open(QFlags<QIODeviceBase::OpenModeFlag>)->bool
    // 1: QFile::open(QFlags<QIODeviceBase::OpenModeFlag>,QFlags<QFileDevice::Permission>)->bool
    // 2: QFile::open(int,QFlags<QIODeviceBase::OpenModeFlag>,QFlags<QFileDevice::FileHandleFlag>=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // open(int,QFlags<QIODeviceBase::OpenModeFlag>,QFlags<QFileDevice::FileHandleFlag>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_FileHandleFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 2; // open(int,QFlags<QIODeviceBase::OpenModeFlag>,QFlags<QFileDevice::FileHandleFlag>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // open(QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // open(QFlags<QIODeviceBase::OpenModeFlag>,QFlags<QFileDevice::Permission>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // open(QFlags<QIODeviceBase::OpenModeFlag> flags)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);
            }
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg0 = QFlags<QIODeviceBase::OpenModeFlag>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QFlags<QIODeviceBase::OpenModeFlag>)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QFile::open(cppArg0)
                    : cppSelf->open(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // open(QFlags<QIODeviceBase::OpenModeFlag> flags, QFlags<QFileDevice::Permission> permissions)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);
            }
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg0 = QFlags<QIODeviceBase::OpenModeFlag>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QFileDevice::Permission> cppArg1 = QFlags<QFileDevice::Permission>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QFlags<QIODeviceBase::OpenModeFlag>,QFlags<QFileDevice::Permission>)
                bool cppResult = cppSelf->open(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // open(int fd, QFlags<QIODeviceBase::OpenModeFlag> ioFlags, QFlags<QFileDevice::FileHandleFlag> handleFlags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"handleFlags", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_FileHandleFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1 = QFlags<QIODeviceBase::OpenModeFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QFileDevice::FileHandleFlag> cppArg2(QFileDevice::FileHandleFlag::DontCloseHandle);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // open(int,QFlags<QIODeviceBase::OpenModeFlag>,QFlags<QFileDevice::FileHandleFlag>)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->open(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_permissions(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "permissions", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDevice::permissions()const->QFlags<QFileDevice::Permission>
    // 1: static QFile::permissions(PyPathLike)->QFlags<QFileDevice::Permission>
    if (numArgs == 0) {
        overloadId = 0; // permissions()const
    } else if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 1; // permissions(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "permissions", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // permissions() const
        {

            // permissions()const
            QFlags<QFileDevice::Permission> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QFile *>(cppSelf)->::QFile::permissions()
                : const_cast<const ::QFile *>(cppSelf)->permissions();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, &cppResult);
            break;
        }
        case 1: // permissions(const QString &filename)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // permissions(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                QFlags<QFileDevice::Permission> cppResult = ::QFile::permissions(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_remove(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "remove", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFile::remove()->bool
    // 1: static QFile::remove(QString)->bool
    if (numArgs == 0) {
        overloadId = 0; // remove()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // remove()
        {

            // remove()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->remove();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // remove(const QString &fileName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // remove(QString)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QFile::remove(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_rename(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rename", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFile::rename(PyPathLike)->bool
    // 1: static QFile::rename(QString,QString)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // rename(QString,QString)
    } else if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 0; // rename(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rename", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // rename(const QString &newName)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // rename(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->rename(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // rename(const QString &oldName, const QString &newName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // rename(QString,QString)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QFile::rename(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_resize(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resize", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDevice::resize(qint64)->bool
    // 1: static QFile::resize(QString,qint64)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 1; // resize(QString,qint64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 0; // resize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resize", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // resize(qint64 sz)
        {
            qint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resize(qint64)
                bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QFile::resize(cppArg0)
                    : cppSelf->resize(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // resize(const QString &filename, qint64 sz)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qint64 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resize(QString,qint64)
                bool cppResult = ::QFile::resize(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFile::setFileName(PyPathLike)
    if (Shiboken::String::checkPath(pyArg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            auto cppArg0 = PySide::pyPathToQString(pyArg);
            // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            // ========================================================================
            // End of code injection

            cppSelf->setFileName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFileFunc_setPermissions(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPermissions", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDevice::setPermissions(QFlags<QFileDevice::Permission>)->bool
    // 1: static QFile::setPermissions(PyPathLike,QFlags<QFileDevice::Permission>)->bool
    if (numArgs == 2
        && Shiboken::String::checkPath(pyArgs[0])
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 1; // setPermissions(QString,QFlags<QFileDevice::Permission>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // setPermissions(QFlags<QFileDevice::Permission>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPermissions", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setPermissions(QFlags<QFileDevice::Permission> permissionSpec)
        {
            ::QFlags<QFileDevice::Permission> cppArg0 = QFlags<QFileDevice::Permission>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPermissions(QFlags<QFileDevice::Permission>)
                bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QFile::setPermissions(cppArg0)
                    : cppSelf->setPermissions(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // setPermissions(const QString &filename, QFlags<QFileDevice::Permission> permissionSpec)
        {
            ::QFlags<QFileDevice::Permission> cppArg1 = QFlags<QFileDevice::Permission>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPermissions(QString,QFlags<QFileDevice::Permission>)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                bool cppResult = ::QFile::setPermissions(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFile *>(cppSelf)->::QFile::size()
            : const_cast<const ::QFile *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_supportsMoveToTrash(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsMoveToTrash()
        bool cppResult = ::QFile::supportsMoveToTrash();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileFunc_symLinkTarget(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFile *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "symLinkTarget", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFile::symLinkTarget()const->QString
    // 1: static QFile::symLinkTarget(QString)->QString
    if (numArgs == 0) {
        overloadId = 0; // symLinkTarget()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // symLinkTarget(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "symLinkTarget", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // symLinkTarget() const
        {

            // symLinkTarget()const
            QString cppResult = const_cast<const ::QFile *>(cppSelf)->symLinkTarget();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            break;
        }
        case 1: // symLinkTarget(const QString &fileName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // symLinkTarget(QString)
                QString cppResult = ::QFile::symLinkTarget(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyMethodDef Sbk_QFileMethod_copy = {"copy", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_copy), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_exists = {"exists", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_exists), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_link = {"link", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_link), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_moveToTrash = {"moveToTrash", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_moveToTrash), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_permissions = {"permissions", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_permissions), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_remove = {"remove", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_remove), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_rename = {"rename", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_rename), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_resize = {"resize", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_resize), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_setPermissions = {"setPermissions", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_setPermissions), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QFileMethod_symLinkTarget = {"symLinkTarget", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_symLinkTarget), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QFile_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFile_methods[] = {
    {"copy", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_copy), METH_VARARGS|METH_STATIC, nullptr},
    {"decodeName", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_decodeName), METH_O|METH_STATIC, nullptr},
    {"encodeName", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_encodeName), METH_O|METH_STATIC, nullptr},
    {"exists", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_exists), METH_VARARGS|METH_STATIC, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_fileName), METH_NOARGS, nullptr},
    {"link", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_link), METH_VARARGS|METH_STATIC, nullptr},
    {"moveToTrash", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_moveToTrash), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_open), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"permissions", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_permissions), METH_VARARGS|METH_STATIC, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_remove), METH_VARARGS|METH_STATIC, nullptr},
    {"rename", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_rename), METH_VARARGS|METH_STATIC, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_resize), METH_VARARGS|METH_STATIC, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_setFileName), METH_O, nullptr},
    {"setPermissions", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_setPermissions), METH_VARARGS|METH_STATIC, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_size), METH_NOARGS, nullptr},
    {"supportsMoveToTrash", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_supportsMoveToTrash), METH_NOARGS|METH_STATIC, nullptr},
    {"symLinkTarget", reinterpret_cast<PyCFunction>(Sbk_QFileFunc_symLinkTarget), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QFile_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PySide::getHiddenDataFromQObject(reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self))), self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QFileMethod_copy = {
        Sbk_QFileMethod_copy.ml_name,
        Sbk_QFileMethod_copy.ml_meth,
        Sbk_QFileMethod_copy.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_copy.ml_doc,
    };
    if (Shiboken::String::compare(name, "copy") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_copy, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_exists = {
        Sbk_QFileMethod_exists.ml_name,
        Sbk_QFileMethod_exists.ml_meth,
        Sbk_QFileMethod_exists.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_exists.ml_doc,
    };
    if (Shiboken::String::compare(name, "exists") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_exists, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_link = {
        Sbk_QFileMethod_link.ml_name,
        Sbk_QFileMethod_link.ml_meth,
        Sbk_QFileMethod_link.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_link.ml_doc,
    };
    if (Shiboken::String::compare(name, "link") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_link, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_moveToTrash = {
        Sbk_QFileMethod_moveToTrash.ml_name,
        Sbk_QFileMethod_moveToTrash.ml_meth,
        Sbk_QFileMethod_moveToTrash.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_moveToTrash.ml_doc,
    };
    if (Shiboken::String::compare(name, "moveToTrash") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_moveToTrash, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_permissions = {
        Sbk_QFileMethod_permissions.ml_name,
        Sbk_QFileMethod_permissions.ml_meth,
        Sbk_QFileMethod_permissions.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_permissions.ml_doc,
    };
    if (Shiboken::String::compare(name, "permissions") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_permissions, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_remove = {
        Sbk_QFileMethod_remove.ml_name,
        Sbk_QFileMethod_remove.ml_meth,
        Sbk_QFileMethod_remove.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_remove.ml_doc,
    };
    if (Shiboken::String::compare(name, "remove") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_remove, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_rename = {
        Sbk_QFileMethod_rename.ml_name,
        Sbk_QFileMethod_rename.ml_meth,
        Sbk_QFileMethod_rename.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_rename.ml_doc,
    };
    if (Shiboken::String::compare(name, "rename") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_rename, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_resize = {
        Sbk_QFileMethod_resize.ml_name,
        Sbk_QFileMethod_resize.ml_meth,
        Sbk_QFileMethod_resize.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_resize.ml_doc,
    };
    if (Shiboken::String::compare(name, "resize") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_resize, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_setPermissions = {
        Sbk_QFileMethod_setPermissions.ml_name,
        Sbk_QFileMethod_setPermissions.ml_meth,
        Sbk_QFileMethod_setPermissions.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_setPermissions.ml_doc,
    };
    if (Shiboken::String::compare(name, "setPermissions") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_setPermissions, self, 0);
    static PyMethodDef non_static_Sbk_QFileMethod_symLinkTarget = {
        Sbk_QFileMethod_symLinkTarget.ml_name,
        Sbk_QFileMethod_symLinkTarget.ml_meth,
        Sbk_QFileMethod_symLinkTarget.ml_flags & (~METH_STATIC),
        Sbk_QFileMethod_symLinkTarget.ml_doc,
    };
    if (Shiboken::String::compare(name, "symLinkTarget") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileMethod_symLinkTarget, self, 0);
    return PySide::getHiddenDataFromQObject(reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self))), self, name);
}

static int Sbk_QFile_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QFileWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QFile_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFile_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QFileSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QFile *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]))
        return static_cast< ::QFileDevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFile_Type = nullptr;
static PyTypeObject *Sbk_QFile_TypeF(void)
{
    return _Sbk_QFile_Type;
}

static PyType_Slot Sbk_QFile_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QFile_getattro)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QFile_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFile_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFile_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFile_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFile_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFile_spec = {
    "2:PySide6.QtCore.QFile",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFile_slots
};

} //extern "C"

static void *Sbk_QFile_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QFile *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFile_PythonToCpp_QFile_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFile_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFile_PythonToCpp_QFile_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFile_TypeF()))
        return QFile_PythonToCpp_QFile_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFile_PTR_CppToPython_QFile(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QFile *>(const_cast<void *>(cppIn)), Sbk_QFile_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFile_SignatureStrings[] = {
    "3:PySide6.QtCore.QFile(self)",
    "2:PySide6.QtCore.QFile(self,parent:PySide6.QtCore.QObject)",
    "1:PySide6.QtCore.QFile(self,name:PyPathLike)",
    "0:PySide6.QtCore.QFile(self,name:PyPathLike,parent:PySide6.QtCore.QObject)",
    "1:PySide6.QtCore.QFile.copy(fileName:QString,newName:QString)->bool",
    "0:PySide6.QtCore.QFile.copy(self,newName:PyPathLike)->bool",
    "1:PySide6.QtCore.QFile.decodeName(localFileName:typing.Union[PySide6.QtCore.QByteArray, char*])->QString",
    "0:PySide6.QtCore.QFile.decodeName(localFileName:char*)->QString",
    "PySide6.QtCore.QFile.encodeName(fileName:QString)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QFile.exists(self)->bool",
    "0:PySide6.QtCore.QFile.exists(fileName:QString)->bool",
    "PySide6.QtCore.QFile.fileName(self)->QString",
    "1:PySide6.QtCore.QFile.link(fileName:QString,newName:QString)->bool",
    "0:PySide6.QtCore.QFile.link(self,newName:PyPathLike)->bool",
    "1:PySide6.QtCore.QFile.moveToTrash(self)->bool",
    "0:PySide6.QtCore.QFile.moveToTrash(fileName:QString,pathInTrash:QString*=nullptr)->bool",
    "2:PySide6.QtCore.QFile.open(self,flags:PySide6.QtCore.QIODeviceBase.OpenModeFlag)->bool",
    "1:PySide6.QtCore.QFile.open(self,flags:PySide6.QtCore.QIODeviceBase.OpenModeFlag,permissions:PySide6.QtCore.QFileDevice.Permission)->bool",
    "0:PySide6.QtCore.QFile.open(self,fd:int,ioFlags:PySide6.QtCore.QIODeviceBase.OpenModeFlag,handleFlags:PySide6.QtCore.QFileDevice.FileHandleFlag=QFileDevice.FileHandleFlag.DontCloseHandle)->bool",
    "1:PySide6.QtCore.QFile.permissions(self)->PySide6.QtCore.QFileDevice.Permission",
    "0:PySide6.QtCore.QFile.permissions(filename:PyPathLike)->PySide6.QtCore.QFileDevice.Permission",
    "1:PySide6.QtCore.QFile.remove(self)->bool",
    "0:PySide6.QtCore.QFile.remove(fileName:QString)->bool",
    "1:PySide6.QtCore.QFile.rename(self,newName:PyPathLike)->bool",
    "0:PySide6.QtCore.QFile.rename(oldName:QString,newName:QString)->bool",
    "1:PySide6.QtCore.QFile.resize(self,sz:qint64)->bool",
    "0:PySide6.QtCore.QFile.resize(filename:QString,sz:qint64)->bool",
    "PySide6.QtCore.QFile.setFileName(self,name:PyPathLike)",
    "1:PySide6.QtCore.QFile.setPermissions(self,permissionSpec:PySide6.QtCore.QFileDevice.Permission)->bool",
    "0:PySide6.QtCore.QFile.setPermissions(filename:PyPathLike,permissionSpec:PySide6.QtCore.QFileDevice.Permission)->bool",
    "PySide6.QtCore.QFile.size(self)->qint64",
    "PySide6.QtCore.QFile.supportsMoveToTrash()->bool",
    "1:PySide6.QtCore.QFile.symLinkTarget(self)->QString",
    "0:PySide6.QtCore.QFile.symLinkTarget(fileName:QString)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QFile_SignatureByteSize = 505;
static constexpr uint8_t QFile_SignatureBytes[505] = {
    0x78, 0xda, 0xad, 0x55, 0x5d, 0x4f, 0xc2, 0x30, 0x14, 0x7d, 0xe7, 0x57, 0xf8, 0x08, 0x64, 0x2e,
    0xf8, 0x11, 0x1e, 0x48, 0x30, 0xf1, 0x23, 0x8b, 0x26, 0x2a, 0x10, 0xf0, 0xc9, 0xf8, 0x50, 0xb7,
    0x0b, 0x54, 0x4a, 0x5b, 0xdb, 0xfa, 0x31, 0x7e, 0xbd, 0x65, 0x5b, 0x49, 0xb3, 0xb5, 0x6c, 0xa2,
    0x6f, 0xdb, 0x7a, 0xce, 0x3d, 0xa7, 0x77, 0xe7, 0xb6, 0x67, 0x83, 0x71, 0x3a, 0xc5, 0x09, 0xf4,
    0xc3, 0x89, 0xba, 0x66, 0x02, 0xc2, 0x49, 0x84, 0x09, 0xb4, 0x25, 0x90, 0x79, 0xa7, 0x75, 0xea,
    0x5f, 0x0c, 0x38, 0x12, 0x40, 0x55, 0x05, 0x30, 0x7a, 0x7d, 0x83, 0x58, 0x75, 0x5a, 0x27, 0x7b,
    0xa8, 0x14, 0xad, 0x41, 0x2f, 0x8f, 0x91, 0x5a, 0xde, 0xe3, 0x15, 0x74, 0x5a, 0xbd, 0xe6, 0xe0,
    0xc3, 0x74, 0xc3, 0x98, 0xf1, 0xb4, 0x3d, 0xd7, 0x4f, 0x8f, 0xdb, 0x72, 0x93, 0xa9, 0x12, 0x98,
    0x2e, 0x02, 0x0a, 0x5f, 0xf6, 0x7b, 0xe7, 0xf8, 0xe2, 0x95, 0x31, 0xe2, 0xb1, 0x93, 0xd7, 0xc8,
    0x3d, 0x15, 0x3c, 0x6b, 0x0f, 0x05, 0xd5, 0x23, 0x9f, 0x40, 0xcc, 0x92, 0x4c, 0xbb, 0x4d, 0x58,
    0x8c, 0x48, 0x64, 0x9c, 0xa8, 0x94, 0x6b, 0xe1, 0xf0, 0x89, 0x62, 0x46, 0x9f, 0xcb, 0xd4, 0xab,
    0x54, 0xc1, 0xa5, 0x10, 0x28, 0x0d, 0x8e, 0xe2, 0x25, 0x12, 0xdd, 0x17, 0xad, 0x52, 0x58, 0xf5,
    0x79, 0xf4, 0x0a, 0x65, 0x05, 0x2c, 0xbe, 0x93, 0x0d, 0x74, 0xc7, 0x2e, 0xf7, 0x4a, 0x53, 0xbd,
    0xf6, 0x7c, 0xbb, 0x86, 0x6f, 0x2c, 0x95, 0xcc, 0xb3, 0xb4, 0xbf, 0xb5, 0x05, 0xd2, 0x21, 0x9a,
    0xb1, 0x9c, 0x1c, 0x03, 0x36, 0xf5, 0xcd, 0xce, 0x3c, 0x66, 0x08, 0xa6, 0xab, 0xbf, 0x26, 0x20,
    0xab, 0x71, 0x58, 0x02, 0xd6, 0xec, 0x13, 0x66, 0x6c, 0x26, 0x90, 0x5c, 0x36, 0x69, 0x88, 0x0d,
    0xaf, 0x98, 0xe6, 0x5a, 0xf2, 0x8e, 0x66, 0x8b, 0xe6, 0x5b, 0x77, 0x48, 0x3f, 0x08, 0xe1, 0x4a,
    0x98, 0xba, 0xee, 0xd1, 0x0d, 0x19, 0x07, 0x9a, 0xef, 0x60, 0x4e, 0xd0, 0x42, 0x56, 0x40, 0x77,
    0xa3, 0x1b, 0xf8, 0xc4, 0x31, 0x5c, 0x21, 0x09, 0xe1, 0x48, 0x83, 0x1f, 0x74, 0x20, 0x22, 0x0d,
    0xad, 0xd9, 0xde, 0xc1, 0x75, 0x03, 0x0e, 0x62, 0x8d, 0xa5, 0xd4, 0xf9, 0x97, 0xce, 0xd2, 0x39,
    0x2f, 0x1c, 0xef, 0x60, 0x35, 0x9d, 0xb3, 0x9c, 0x24, 0x03, 0x4c, 0x55, 0x80, 0x59, 0xf4, 0x4b,
    0x4b, 0x4b, 0x44, 0x13, 0x02, 0x6e, 0x96, 0x65, 0x69, 0xfb, 0x78, 0xbb, 0x83, 0x0e, 0xfd, 0x4b,
    0xe1, 0x0d, 0xa3, 0xea, 0x9a, 0x30, 0x59, 0x7c, 0xab, 0xe9, 0xa5, 0xd5, 0x11, 0x13, 0x95, 0x46,
    0x8d, 0xf1, 0x75, 0xc4, 0xae, 0xb7, 0xcd, 0x12, 0xad, 0x04, 0xb7, 0x59, 0x79, 0x8f, 0x5d, 0x01,
    0xdb, 0xb0, 0x36, 0x09, 0x75, 0x81, 0xf4, 0x4d, 0xb9, 0xb7, 0x3e, 0x35, 0x53, 0xbe, 0x67, 0xec,
    0x7a, 0x7b, 0xc9, 0x8c, 0x24, 0x4d, 0xc6, 0xde, 0xeb, 0x40, 0xe2, 0x4d, 0xe1, 0x40, 0x6e, 0x06,
    0xef, 0x3a, 0x55, 0xfd, 0xf3, 0x5a, 0xe1, 0x8c, 0xb3, 0xeb, 0xb7, 0x51, 0xae, 0xf0, 0x9d, 0x6c,
    0x09, 0x2a, 0xb2, 0x8f, 0xb7, 0xea, 0x95, 0xe9, 0xb1, 0xaa, 0x89, 0xe3, 0x52, 0x7c, 0xac, 0x09,
    0x9b, 0x72, 0x88, 0xff, 0x65, 0xc8, 0x4a, 0x32, 0x8e, 0x54, 0xfd, 0x49, 0xd5, 0xad, 0x69, 0xfe,
    0x81, 0x46, 0xe5, 0x2d, 0xf4, 0xe0, 0x3e, 0x38, 0x67, 0x42, 0xc9, 0x07, 0xeb, 0x08, 0xad, 0xf9,
    0xc1, 0x32, 0x5d, 0xdf, 0xeb, 0xa3, 0x7d, 0x86, 0xc4, 0x02, 0x54, 0xf9, 0x3e, 0xe9, 0x35, 0xe1,
    0x38, 0x32, 0x6d, 0xf8, 0x3f, 0xe5, 0xce, 0x4c, 0x1a
};
#endif

PyTypeObject *init_QFile(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX].type;

    Shiboken::AutoDecRef Sbk_QFile_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]))));

    _Sbk_QFile_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFile",
        "QFile*",
        &Sbk_QFile_spec,
        &Shiboken::callCppDestructor< QFile >,
        Sbk_QFile_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFile_TypeF(); // references _Sbk_QFile_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFile_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFile_SignatureBytes, QFile_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFile_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFile_PythonToCpp_QFile_PTR,
        is_QFile_PythonToCpp_QFile_PTR_Convertible,
        QFile_PTR_CppToPython_QFile);

    Shiboken::Conversions::registerConverterName(converter, "QFile");
    Shiboken::Conversions::registerConverterName(converter, "QFile*");
    Shiboken::Conversions::registerConverterName(converter, "QFile&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFile).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFileWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QFile_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QFile_TypeF(), &Sbk_QFileSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QFile_TypeF(), &Sbk_QFile_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QFile::staticMetaObject, sizeof(QFileWrapper));

    return pyType;
}
