// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QFILEDEVICEWRAPPER_H
#define SBK_QFILEDEVICEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <qfiledevice.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QFileDeviceWrapper : public QFileDevice
{
public:
    QFileDeviceWrapper();
    QFileDeviceWrapper(::QObject * parent);
    QFileDeviceWrapper(const QFileDeviceWrapper &) = delete;
    QFileDeviceWrapper& operator=(const QFileDeviceWrapper &) = delete;
    QFileDeviceWrapper(QFileDeviceWrapper &&) = delete;
    QFileDeviceWrapper& operator=(QFileDeviceWrapper &&) = delete;
    ~QFileDeviceWrapper() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(::QChildEvent * event) override;
    void close() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QString fileName() const override;
    static ::QString sbk_o_fileName(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isSequential() const override;
    bool open(::QFlags<QIODeviceBase::OpenModeFlag> mode) override;
    ::QFlags<QFileDevice::Permission> permissions() const override;
    static ::QFlags<QFileDevice::Permission> sbk_o_permissions(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    qint64 pos() const override;
    qint64 readData(char * data, qint64 maxlen) override;
    qint64 readLineData(char * data, qint64 maxlen) override;
    bool reset() override;
    bool resize(qint64 sz) override;
    static bool sbk_o_resize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 sz);
    bool seek(qint64 offset) override;
    bool setPermissions(::QFlags<QFileDevice::Permission> permissionSpec) override;
    static bool sbk_o_setPermissions(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QFileDevice::Permission> permissionSpec);
    qint64 size() const override;
    qint64 skipData(qint64 maxSize) override;
    void timerEvent(::QTimerEvent * event) override;
    bool waitForBytesWritten(int msecs) override;
    static bool sbk_o_waitForBytesWritten(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs);
    bool waitForReadyRead(int msecs) override;
    qint64 writeData(const char * data, qint64 len) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[28] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QFILEDEVICEWRAPPER_H
