// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QMIMEDATAWRAPPER_H
#define SBK_QMIMEDATAWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <qmimedata.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QMimeDataWrapper : public QMimeData
{
public:
    QMimeDataWrapper();
    QMimeDataWrapper(const QMimeDataWrapper &) = delete;
    QMimeDataWrapper& operator=(const QMimeDataWrapper &) = delete;
    QMimeDataWrapper(QMimeDataWrapper &&) = delete;
    QMimeDataWrapper& operator=(QMimeDataWrapper &&) = delete;
    ~QMimeDataWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QStringList formats() const override;
    static ::QStringList sbk_o_formats(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool hasFormat(const ::QString & mimetype) const override;
    static bool sbk_o_hasFormat(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & mimetype);
    ::QVariant retrieveData(const ::QString & mimetype, ::QMetaType preferredType) const override;
    static ::QVariant sbk_o_retrieveData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & mimetype, ::QMetaType preferredType);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[10] = {false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QMIMEDATAWRAPPER_H
