// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qoperatingsystemversion_wrapper.h"

// Argument includes
#include <qoperatingsystemversion.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOperatingSystemVersion_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOperatingSystemVersion >()))
        return -1;

    ::QOperatingSystemVersion *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QOperatingSystemVersion", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOperatingSystemVersion::QOperatingSystemVersion(QOperatingSystemVersion::OSType,int,int=,int=)
    // 1: QOperatingSystemVersion::QOperatingSystemVersion(QOperatingSystemVersion)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOperatingSystemVersion(QOperatingSystemVersion)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_OSType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // QOperatingSystemVersion(QOperatingSystemVersion::OSType,int,int,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // QOperatingSystemVersion(QOperatingSystemVersion::OSType,int,int,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 0; // QOperatingSystemVersion(QOperatingSystemVersion::OSType,int,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOperatingSystemVersion(QOperatingSystemVersion::OSType osType, int vmajor, int vminor, int vmicro)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"vminor", 2}, {"vmicro", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]);
                }
            }
            ::QOperatingSystemVersion::OSType cppArg0{QOperatingSystemVersion::Unknown};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOperatingSystemVersion(QOperatingSystemVersion::OSType,int,int,int)
                cptr = new ::QOperatingSystemVersion(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // QOperatingSystemVersion(const QOperatingSystemVersion &QOperatingSystemVersion)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOperatingSystemVersion cppArg0_local = ::QOperatingSystemVersion(QOperatingSystemVersion::Unknown, int(0));
            ::QOperatingSystemVersion *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOperatingSystemVersion(QOperatingSystemVersion)
                cptr = new ::QOperatingSystemVersion(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOperatingSystemVersion >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOperatingSystemVersionFunc_currentType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentType()
        QOperatingSystemVersion::OSType cppResult = ::QOperatingSystemVersion::currentType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_OSType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QOperatingSystemVersion::OSType cppResult = const_cast<const ::QOperatingSystemVersion *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_OSType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersion__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOperatingSystemVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOperatingSystemVersion_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOperatingSystemVersion_EnumFlagInfo[] = {
    "OSType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOperatingSystemVersion_methods[] = {
    {"currentType", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionFunc_currentType), METH_NOARGS|METH_STATIC, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersion__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOperatingSystemVersion_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOperatingSystemVersion_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QOperatingSystemVersion__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOperatingSystemVersion_Type = nullptr;
static PyTypeObject *Sbk_QOperatingSystemVersion_TypeF(void)
{
    return _Sbk_QOperatingSystemVersion_Type;
}

static PyType_Slot Sbk_QOperatingSystemVersion_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QOperatingSystemVersion__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOperatingSystemVersion_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOperatingSystemVersion_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOperatingSystemVersion_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOperatingSystemVersion_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOperatingSystemVersion_spec = {
    "2:PySide6.QtCore.QOperatingSystemVersion",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOperatingSystemVersion_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOperatingSystemVersion_OSType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOperatingSystemVersion::OSType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOperatingSystemVersion::OSType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOperatingSystemVersion_OSType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_OSType_IDX])))
        return Enum_PythonToCpp_QOperatingSystemVersion_OSType;
    return {};
}

static PyObject *QOperatingSystemVersion_OSType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOperatingSystemVersion::OSType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOperatingSystemVersion::OSType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_OSType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOperatingSystemVersion_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOperatingSystemVersion_TypeF()))
        return QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOperatingSystemVersion_PTR_CppToPython_QOperatingSystemVersion(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOperatingSystemVersion_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QOperatingSystemVersion_COPY_CppToPython_QOperatingSystemVersion(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOperatingSystemVersion *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOperatingSystemVersion_TypeF(), new ::QOperatingSystemVersion(*source), true, true);
}

// Python to C++ copy conversion.
static void QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOperatingSystemVersion *>(cppOut) = *reinterpret_cast< ::QOperatingSystemVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOperatingSystemVersion_TypeF()))
        return QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOperatingSystemVersion_SignatureStrings[] = {
    "1:PySide6.QtCore.QOperatingSystemVersion(self,osType:PySide6.QtCore.QOperatingSystemVersion.OSType,vmajor:int,vminor:int=-1,vmicro:int=-1)",
    "0:PySide6.QtCore.QOperatingSystemVersion(self,QOperatingSystemVersion:PySide6.QtCore.QOperatingSystemVersion)",
    "PySide6.QtCore.QOperatingSystemVersion.currentType()->PySide6.QtCore.QOperatingSystemVersion.OSType",
    "PySide6.QtCore.QOperatingSystemVersion.type(self)->PySide6.QtCore.QOperatingSystemVersion.OSType",
    "PySide6.QtCore.QOperatingSystemVersion.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QOperatingSystemVersion_SignatureByteSize = 153;
static constexpr uint8_t QOperatingSystemVersion_SignatureBytes[153] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0x2f, 0x48, 0x2d, 0x4a, 0x2c, 0xc9, 0xcc, 0x4b, 0x0f, 0xae, 0x2c,
    0x2e, 0x49, 0xcd, 0x0d, 0x4b, 0x2d, 0x2a, 0xce, 0xcc, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3,
    0xc9, 0x2f, 0x0e, 0xa9, 0x2c, 0x48, 0x25, 0x52, 0x8b, 0x9e, 0x7f, 0x30, 0x48, 0xb5, 0x4e, 0x59,
    0x6e, 0x62, 0x56, 0x7e, 0x91, 0x55, 0x66, 0x5e, 0x09, 0x90, 0x99, 0x99, 0x07, 0x61, 0xda, 0xea,
    0x1a, 0x82, 0x78, 0xc9, 0x45, 0xf9, 0x50, 0x9e, 0x26, 0x97, 0x01, 0x49, 0x4e, 0xc1, 0x21, 0x49,
    0xa4, 0x19, 0x9a, 0x5c, 0x44, 0xfa, 0x21, 0xb9, 0xb4, 0xa8, 0x28, 0x35, 0xaf, 0x04, 0xe4, 0x11,
    0x0d, 0x4d, 0x5d, 0x3b, 0x92, 0x7c, 0x4e, 0xac, 0x1d, 0x25, 0x20, 0xc3, 0x41, 0x9e, 0xa2, 0x95,
    0x05, 0xf1, 0xf1, 0xc9, 0xf9, 0x05, 0x95, 0xf1, 0xf1, 0x30, 0x4b, 0x80, 0x16, 0x02, 0xd5, 0xe8,
    0x05, 0x03, 0x79, 0x5c, 0x00, 0xf6, 0xfb, 0xbe, 0x3a
};
#endif

PyTypeObject *init_QOperatingSystemVersion(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX].type;

    Shiboken::AutoDecRef Sbk_QOperatingSystemVersion_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]))));

    _Sbk_QOperatingSystemVersion_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOperatingSystemVersion",
        "QOperatingSystemVersion",
        &Sbk_QOperatingSystemVersion_spec,
        &Shiboken::callCppDestructor< ::QOperatingSystemVersion >,
        Sbk_QOperatingSystemVersion_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOperatingSystemVersion_TypeF(); // references _Sbk_QOperatingSystemVersion_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOperatingSystemVersion_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOperatingSystemVersion_SignatureBytes, QOperatingSystemVersion_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOperatingSystemVersion_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_PTR,
        is_QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_PTR_Convertible,
        QOperatingSystemVersion_PTR_CppToPython_QOperatingSystemVersion,
        QOperatingSystemVersion_COPY_CppToPython_QOperatingSystemVersion);

    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersion");
    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersion*");
    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersion&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOperatingSystemVersion).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_COPY,
        is_QOperatingSystemVersion_PythonToCpp_QOperatingSystemVersion_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOperatingSystemVersion_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'OSType'.
    const char *OSType_Initializer[] = {
        "Unknown",
        "Windows",
        "MacOS",
        "IOS",
        "TvOS",
        "WatchOS",
        "Android",
        "VisionOS",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OSType_InitializerValues[] = {
        uint8_t(QOperatingSystemVersion::OSType::Unknown), //  0x00  0
        uint8_t(QOperatingSystemVersion::OSType::Windows), //  0x01  1
        uint8_t(QOperatingSystemVersion::OSType::MacOS),   //  0x02  2
        uint8_t(QOperatingSystemVersion::OSType::IOS),     //  0x03  3
        uint8_t(QOperatingSystemVersion::OSType::TvOS),    //  0x04  4
        uint8_t(QOperatingSystemVersion::OSType::WatchOS), //  0x05  5
        uint8_t(QOperatingSystemVersion::OSType::Android), //  0x06  6
        uint8_t(QOperatingSystemVersion::OSType::VisionOS) //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOperatingSystemVersion_TypeF(),
        "2:PySide6.QtCore.QOperatingSystemVersion.OSType",
        OSType_Initializer, OSType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_OSType_IDX].type = EType;
    // Register converter for enum 'QOperatingSystemVersion::OSType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOperatingSystemVersion_OSType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOperatingSystemVersion_OSType,
            is_Enum_PythonToCpp_QOperatingSystemVersion_OSType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersion::OSType");
        Shiboken::Conversions::registerConverterAlias(converter, "OSType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'OSType' enum.

    qRegisterMetaType< ::QOperatingSystemVersion::OSType >("QOperatingSystemVersion::OSType");

    return pyType;
}

PyTypeObject *init_QOperatingSystemVersionStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QOperatingSystemVersion");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "Windows7",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::Windows7));
    PyDict_SetItemString(dict, "Windows8",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::Windows8));
    PyDict_SetItemString(dict, "Windows8_1",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::Windows8_1));
    PyDict_SetItemString(dict, "Windows10",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::Windows10));
    PyDict_SetItemString(dict, "OSXMavericks",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::OSXMavericks));
    PyDict_SetItemString(dict, "OSXYosemite",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::OSXYosemite));
    PyDict_SetItemString(dict, "OSXElCapitan",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::OSXElCapitan));
    PyDict_SetItemString(dict, "MacOSSierra",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::MacOSSierra));
    PyDict_SetItemString(dict, "MacOSHighSierra",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::MacOSHighSierra));
    PyDict_SetItemString(dict, "MacOSMojave",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::MacOSMojave));
    PyDict_SetItemString(dict, "MacOSCatalina",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::MacOSCatalina));
    PyDict_SetItemString(dict, "MacOSBigSur",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::MacOSBigSur));
    PyDict_SetItemString(dict, "MacOSMonterey",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::MacOSMonterey));
    PyDict_SetItemString(dict, "AndroidJellyBean",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidJellyBean));
    PyDict_SetItemString(dict, "AndroidJellyBean_MR1",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidJellyBean_MR1));
    PyDict_SetItemString(dict, "AndroidJellyBean_MR2",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidJellyBean_MR2));
    PyDict_SetItemString(dict, "AndroidKitKat",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidKitKat));
    PyDict_SetItemString(dict, "AndroidLollipop",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidLollipop));
    PyDict_SetItemString(dict, "AndroidLollipop_MR1",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidLollipop_MR1));
    PyDict_SetItemString(dict, "AndroidMarshmallow",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidMarshmallow));
    PyDict_SetItemString(dict, "AndroidNougat",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidNougat));
    PyDict_SetItemString(dict, "AndroidNougat_MR1",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidNougat_MR1));
    PyDict_SetItemString(dict, "AndroidOreo",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidOreo));
    PyDict_SetItemString(dict, "AndroidOreo_MR1",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidOreo_MR1));
    PyDict_SetItemString(dict, "AndroidPie",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::AndroidPie));
    PyDict_SetItemString(dict, "Android10",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::Android10));
    PyDict_SetItemString(dict, "Android11",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersion_IDX]), &QOperatingSystemVersion::Android11));
    PyDict_SetItemString(dict, "Windows10_1809",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_1809));
    PyDict_SetItemString(dict, "Windows10_1903",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_1903));
    PyDict_SetItemString(dict, "Windows10_1909",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_1909));
    PyDict_SetItemString(dict, "Windows10_2004",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_2004));
    PyDict_SetItemString(dict, "Windows10_20H2",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_20H2));
    PyDict_SetItemString(dict, "Windows10_21H1",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_21H1));
    PyDict_SetItemString(dict, "Windows10_21H2",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_21H2));
    PyDict_SetItemString(dict, "Windows10_22H2",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows10_22H2));
    PyDict_SetItemString(dict, "Windows11",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows11));
    PyDict_SetItemString(dict, "Windows11_21H2",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows11_21H2));
    PyDict_SetItemString(dict, "Windows11_22H2",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Windows11_22H2));
    PyDict_SetItemString(dict, "Android12",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Android12));
    PyDict_SetItemString(dict, "Android12L",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Android12L));
    PyDict_SetItemString(dict, "Android13",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::Android13));
    PyDict_SetItemString(dict, "MacOSVentura",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &QOperatingSystemVersion::MacOSVentura));
    return type;
}
