// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qparallelanimationgroup_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qabstractanimation_wrapper.h"
#include "qtranslator_wrapper.h"

// Argument includes
#include <qabstractanimation.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QParallelAnimationGroupWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QParallelAnimationGroupWrapper::QParallelAnimationGroupWrapper(::QObject * parent) : QParallelAnimationGroup(parent)
{
}

void QParallelAnimationGroupWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QParallelAnimationGroup", funcName, gil, pyOverride, event);
}

void QParallelAnimationGroupWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QParallelAnimationGroup", funcName, gil, pyOverride, signal);
}

void QParallelAnimationGroupWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QParallelAnimationGroup", funcName, gil, pyOverride, event);
}

void QParallelAnimationGroupWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QParallelAnimationGroup", funcName, gil, pyOverride, signal);
}

int QParallelAnimationGroupWrapper::duration() const
{
    static const char *funcName = "duration";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QParallelAnimationGroup::duration();
    }
    return QAbstractAnimationWrapper::sbk_o_duration("QParallelAnimationGroup", funcName, gil, pyOverride);
}

bool QParallelAnimationGroupWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QParallelAnimationGroup::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QParallelAnimationGroup", funcName, gil, pyOverride, event);
}

bool QParallelAnimationGroupWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QParallelAnimationGroup", funcName, gil, pyOverride, watched, event);
}

void QParallelAnimationGroupWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QParallelAnimationGroup", funcName, gil, pyOverride, event);
}

void QParallelAnimationGroupWrapper::updateCurrentTime(int currentTime)
{
    static const char *funcName = "updateCurrentTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QParallelAnimationGroup::updateCurrentTime(currentTime);
    }
    QAbstractAnimationWrapper::sbk_o_updateCurrentTime("QParallelAnimationGroup", funcName, gil, pyOverride, currentTime);
}

void QParallelAnimationGroupWrapper::updateDirection(::QAbstractAnimation::Direction direction)
{
    static const char *funcName = "updateDirection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QParallelAnimationGroup::updateDirection(direction);
    }
    QAbstractAnimationWrapper::sbk_o_updateDirection("QParallelAnimationGroup", funcName, gil, pyOverride, direction);
}

void QParallelAnimationGroupWrapper::updateState(::QAbstractAnimation::State newState, ::QAbstractAnimation::State oldState)
{
    static const char *funcName = "updateState";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QParallelAnimationGroup::updateState(newState, oldState);
    }
    QAbstractAnimationWrapper::sbk_o_updateState("QParallelAnimationGroup", funcName, gil, pyOverride, newState, oldState);
}

const QMetaObject *QParallelAnimationGroupWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QParallelAnimationGroup::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QParallelAnimationGroupWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QParallelAnimationGroup::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QParallelAnimationGroupWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QParallelAnimationGroupWrapper *>(this));
    return QParallelAnimationGroup::qt_metacast(_clname);
}

QParallelAnimationGroupWrapper::~QParallelAnimationGroupWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QParallelAnimationGroup_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QParallelAnimationGroup >()))
        return -1;

    QParallelAnimationGroupWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QParallelAnimationGroup", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QParallelAnimationGroup::QParallelAnimationGroup(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QParallelAnimationGroup(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QParallelAnimationGroup(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QParallelAnimationGroup(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QParallelAnimationGroupWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QParallelAnimationGroupWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QParallelAnimationGroup >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QParallelAnimationGroupFunc_duration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QParallelAnimationGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // duration()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QParallelAnimationGroup *>(cppSelf)->::QParallelAnimationGroup::duration()
            : const_cast<const ::QParallelAnimationGroup *>(cppSelf)->duration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QParallelAnimationGroupFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QParallelAnimationGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QParallelAnimationGroup::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QParallelAnimationGroupFunc_updateCurrentTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QParallelAnimationGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractAnimation::updateCurrentTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // updateCurrentTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateCurrentTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateCurrentTime(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QParallelAnimationGroup::updateCurrentTime(cppArg0)
                : cppSelf->updateCurrentTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QParallelAnimationGroupFunc_updateDirection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QParallelAnimationGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractAnimation::updateDirection(QAbstractAnimation::Direction)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_Direction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // updateDirection(QAbstractAnimation::Direction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateDirection", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);

    // Call function/method
    {
        ::QAbstractAnimation::Direction cppArg0{QAbstractAnimation::Forward};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateDirection(QAbstractAnimation::Direction)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QParallelAnimationGroup::updateDirection(cppArg0)
                : cppSelf->updateDirection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QParallelAnimationGroupFunc_updateState(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QParallelAnimationGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateState", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractAnimation::updateState(QAbstractAnimation::State,QAbstractAnimation::State)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_State_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_State_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // updateState(QAbstractAnimation::State,QAbstractAnimation::State)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateState", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]);

    // Call function/method
    {
        ::QAbstractAnimation::State cppArg0{QAbstractAnimation::Stopped};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QAbstractAnimation::State cppArg1{QAbstractAnimation::Stopped};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateState(QAbstractAnimation::State,QAbstractAnimation::State)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QParallelAnimationGroup::updateState(cppArg0, cppArg1)
                : cppSelf->updateState(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QParallelAnimationGroup_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QParallelAnimationGroup_methods[] = {
    {"duration", reinterpret_cast<PyCFunction>(Sbk_QParallelAnimationGroupFunc_duration), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QParallelAnimationGroupFunc_event), METH_O, nullptr},
    {"updateCurrentTime", reinterpret_cast<PyCFunction>(Sbk_QParallelAnimationGroupFunc_updateCurrentTime), METH_O, nullptr},
    {"updateDirection", reinterpret_cast<PyCFunction>(Sbk_QParallelAnimationGroupFunc_updateDirection), METH_O, nullptr},
    {"updateState", reinterpret_cast<PyCFunction>(Sbk_QParallelAnimationGroupFunc_updateState), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QParallelAnimationGroup_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QParallelAnimationGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QParallelAnimationGroupWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QParallelAnimationGroup_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QParallelAnimationGroup_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QParallelAnimationGroup_Type = nullptr;
static PyTypeObject *Sbk_QParallelAnimationGroup_TypeF(void)
{
    return _Sbk_QParallelAnimationGroup_Type;
}

static PyType_Slot Sbk_QParallelAnimationGroup_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QParallelAnimationGroup_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QParallelAnimationGroup_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QParallelAnimationGroup_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QParallelAnimationGroup_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QParallelAnimationGroup_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QParallelAnimationGroup_spec = {
    "2:PySide6.QtCore.QParallelAnimationGroup",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QParallelAnimationGroup_slots
};

} //extern "C"

static void *Sbk_QParallelAnimationGroup_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QParallelAnimationGroup *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QParallelAnimationGroup_PythonToCpp_QParallelAnimationGroup_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QParallelAnimationGroup_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QParallelAnimationGroup_PythonToCpp_QParallelAnimationGroup_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QParallelAnimationGroup_TypeF()))
        return QParallelAnimationGroup_PythonToCpp_QParallelAnimationGroup_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QParallelAnimationGroup_PTR_CppToPython_QParallelAnimationGroup(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QParallelAnimationGroup *>(const_cast<void *>(cppIn)), Sbk_QParallelAnimationGroup_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QParallelAnimationGroup_SignatureStrings[] = {
    "PySide6.QtCore.QParallelAnimationGroup(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCore.QParallelAnimationGroup.duration(self)->int",
    "PySide6.QtCore.QParallelAnimationGroup.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QParallelAnimationGroup.updateCurrentTime(self,currentTime:int)",
    "PySide6.QtCore.QParallelAnimationGroup.updateDirection(self,direction:PySide6.QtCore.QAbstractAnimation.Direction)",
    "PySide6.QtCore.QParallelAnimationGroup.updateState(self,newState:PySide6.QtCore.QAbstractAnimation.State,oldState:PySide6.QtCore.QAbstractAnimation.State)",
    nullptr}; // Sentinel
#else
static constexpr size_t QParallelAnimationGroup_SignatureByteSize = 189;
static constexpr uint8_t QParallelAnimationGroup_SignatureBytes[189] = {
    0x78, 0xda, 0x95, 0x90, 0xc1, 0x0a, 0x83, 0x30, 0x10, 0x44, 0xef, 0x7e, 0x49, 0x05, 0xeb, 0xb1,
    0x07, 0xa1, 0x05, 0xb1, 0xa5, 0xc7, 0x46, 0xec, 0x0f, 0x44, 0xb3, 0x85, 0x94, 0x98, 0x84, 0x75,
    0xd3, 0xd2, 0xbf, 0x6f, 0x8c, 0x68, 0xa1, 0x5e, 0xe2, 0x25, 0x64, 0x96, 0xcc, 0x9b, 0xd9, 0xb0,
    0x4f, 0x23, 0x05, 0x1c, 0xf2, 0x9a, 0x2a, 0x83, 0x90, 0xd7, 0x8c, 0x23, 0x57, 0x0a, 0x54, 0xa9,
    0x65, 0xcf, 0x49, 0x1a, 0x7d, 0x45, 0xe3, 0xec, 0x6e, 0x00, 0xf5, 0xc8, 0x2c, 0x47, 0xd0, 0x54,
    0xb0, 0x3f, 0xcb, 0xad, 0x7d, 0x42, 0x47, 0x47, 0xed, 0x94, 0xb2, 0x84, 0x69, 0xc2, 0xa2, 0x90,
    0xb9, 0x70, 0x18, 0x54, 0x60, 0xa7, 0xfb, 0x93, 0xd4, 0x14, 0x6b, 0x85, 0x97, 0xef, 0x31, 0x75,
    0x0a, 0xd7, 0x55, 0xa5, 0xcb, 0x38, 0xf5, 0xcc, 0xd6, 0x18, 0x15, 0x0b, 0x75, 0x56, 0x70, 0x82,
    0xca, 0xe1, 0xb8, 0xe4, 0x5d, 0xf6, 0x30, 0x05, 0x74, 0xbf, 0x41, 0xe1, 0x2b, 0xa6, 0xdb, 0x70,
    0x67, 0x89, 0xfe, 0x6f, 0xe6, 0x2d, 0x33, 0x31, 0xcb, 0x55, 0xe3, 0xb2, 0x1d, 0x08, 0x79, 0x47,
    0x0b, 0x25, 0x5f, 0xac, 0x1b, 0x23, 0x1b, 0xf2, 0xc7, 0x14, 0xa7, 0xe1, 0x1d, 0x54, 0x44, 0x5a,
    0x78, 0x97, 0x19, 0x25, 0x36, 0x19, 0xd2, 0xe4, 0x0b, 0xba, 0xb8, 0xd5, 0x11
};
#endif

PyTypeObject *init_QParallelAnimationGroup(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX].type;

    Shiboken::AutoDecRef Sbk_QParallelAnimationGroup_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAnimationGroup_IDX]))));

    _Sbk_QParallelAnimationGroup_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QParallelAnimationGroup",
        "QParallelAnimationGroup*",
        &Sbk_QParallelAnimationGroup_spec,
        &Shiboken::callCppDestructor< QParallelAnimationGroup >,
        Sbk_QParallelAnimationGroup_Type_bases.object(),
        0);
    auto *pyType = Sbk_QParallelAnimationGroup_TypeF(); // references _Sbk_QParallelAnimationGroup_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QParallelAnimationGroup_SignatureStrings);
#else
    InitSignatureBytes(pyType, QParallelAnimationGroup_SignatureBytes, QParallelAnimationGroup_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QParallelAnimationGroup_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QParallelAnimationGroup_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QParallelAnimationGroup_PythonToCpp_QParallelAnimationGroup_PTR,
        is_QParallelAnimationGroup_PythonToCpp_QParallelAnimationGroup_PTR_Convertible,
        QParallelAnimationGroup_PTR_CppToPython_QParallelAnimationGroup);

    Shiboken::Conversions::registerConverterName(converter, "QParallelAnimationGroup");
    Shiboken::Conversions::registerConverterName(converter, "QParallelAnimationGroup*");
    Shiboken::Conversions::registerConverterName(converter, "QParallelAnimationGroup&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QParallelAnimationGroup).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QParallelAnimationGroupWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QParallelAnimationGroup_TypeF(), &Sbk_QParallelAnimationGroup_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QParallelAnimationGroup::staticMetaObject, sizeof(QParallelAnimationGroupWrapper));

    return pyType;
}
