// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qprocess_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qtranslator_wrapper.h"
#include "qiodevice_wrapper.h"

// inner classes
#include "qprocess_unixprocessparameters_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qprocess.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QProcessWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QProcessWrapper::QProcessWrapper(::QObject * parent) : QProcess(parent)
{
}

bool QProcessWrapper::atEnd() const
{
    static const char *funcName = "atEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::atEnd();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QProcess", funcName, gil, pyOverride);
}

qint64 QProcessWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::bytesAvailable();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QProcess", funcName, gil, pyOverride);
}

qint64 QProcessWrapper::bytesToWrite() const
{
    static const char *funcName = "bytesToWrite";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::bytesToWrite();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QProcess", funcName, gil, pyOverride);
}

bool QProcessWrapper::canReadLine() const
{
    static const char *funcName = "canReadLine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::canReadLine();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QProcess", funcName, gil, pyOverride);
}

void QProcessWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QProcess", funcName, gil, pyOverride, event);
}

void QProcessWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::close();
    }
    sbk_o_close("QProcess", funcName, gil, pyOverride);
}

void QProcessWrapper::sbk_o_close(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QProcessWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QProcess", funcName, gil, pyOverride, signal);
}

void QProcessWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QProcess", funcName, gil, pyOverride, event);
}

void QProcessWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QProcess", funcName, gil, pyOverride, signal);
}

bool QProcessWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QProcess", funcName, gil, pyOverride, event);
}

bool QProcessWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QProcess", funcName, gil, pyOverride, watched, event);
}

bool QProcessWrapper::isSequential() const
{
    static const char *funcName = "isSequential";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::isSequential();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QProcess", funcName, gil, pyOverride);
}

bool QProcessWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::open(mode);
    }
    return sbk_o_open("QProcess", funcName, gil, pyOverride, mode);
}

bool QProcessWrapper::sbk_o_open(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QProcessWrapper::pos() const
{
    static const char *funcName = "pos";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::pos();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QProcess", funcName, gil, pyOverride);
}

qint64 QProcessWrapper::readData(char * data, qint64 maxlen)
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::readData(data, maxlen);
    }
    return sbk_o_readData("QProcess", funcName, gil, pyOverride, data, maxlen);
}

qint64 QProcessWrapper::sbk_o_readData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxlen)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxlen
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

qint64 QProcessWrapper::readLineData(char * data, qint64 maxlen)
{
    static const char *funcName = "readLineData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::readLineData(data, maxlen);
    }
    return sbk_o_readLineData("QProcess", funcName, gil, pyOverride, data, maxlen);
}

qint64 QProcessWrapper::sbk_o_readLineData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxlen)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxlen
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

bool QProcessWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::reset();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QProcess", funcName, gil, pyOverride);
}

bool QProcessWrapper::seek(qint64 pos)
{
    static const char *funcName = "seek";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::seek(pos);
    }
    return sbk_o_seek("QProcess", funcName, gil, pyOverride, pos);
}

bool QProcessWrapper::sbk_o_seek(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 pos)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &pos)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        pos
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QProcessWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::size();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QProcess", funcName, gil, pyOverride);
}

qint64 QProcessWrapper::skipData(qint64 maxSize)
{
    static const char *funcName = "skipData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::skipData(maxSize);
    }
    return QIODeviceWrapper::sbk_o_skipData("QProcess", funcName, gil, pyOverride, maxSize);
}

void QProcessWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QProcess", funcName, gil, pyOverride, event);
}

bool QProcessWrapper::waitForBytesWritten(int msecs)
{
    static const char *funcName = "waitForBytesWritten";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::waitForBytesWritten(msecs);
    }
    return QIODeviceWrapper::sbk_o_waitForBytesWritten("QProcess", funcName, gil, pyOverride, msecs);
}

bool QProcessWrapper::waitForReadyRead(int msecs)
{
    static const char *funcName = "waitForReadyRead";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::waitForReadyRead(msecs);
    }
    return sbk_o_waitForReadyRead("QProcess", funcName, gil, pyOverride, msecs);
}

bool QProcessWrapper::sbk_o_waitForReadyRead(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QProcessWrapper::writeData(const char * data, qint64 len)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QProcess::writeData(data, len);
    }
    return QIODeviceWrapper::sbk_o_writeData("QProcess", funcName, gil, pyOverride, data, len);
}

const QMetaObject *QProcessWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QProcess::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QProcessWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QProcess::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QProcessWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QProcessWrapper *>(this));
    return QProcess::qt_metacast(_clname);
}

QProcessWrapper::~QProcessWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QProcess_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QProcess >()))
        return -1;

    QProcessWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QProcess", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QProcess::QProcess(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QProcess(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QProcess(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QProcess(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QProcessWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QProcessWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QProcess >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QProcessFunc_arguments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // arguments()const
        QStringList cppResult = const_cast<const ::QProcess *>(cppSelf)->arguments();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_bytesToWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesToWrite()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QProcess *>(cppSelf)->::QProcess::bytesToWrite()
            : const_cast<const ::QProcess *>(cppSelf)->bytesToWrite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QProcess::close()
            : cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_closeReadChannel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::closeReadChannel(QProcess::ProcessChannel)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // closeReadChannel(QProcess::ProcessChannel)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "closeReadChannel", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QProcess::ProcessChannel cppArg0{QProcess::StandardOutput};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // closeReadChannel(QProcess::ProcessChannel)
            cppSelf->closeReadChannel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_closeWriteChannel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // closeWriteChannel()
        cppSelf->closeWriteChannel();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_environment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // environment()const
        QStringList cppResult = const_cast<const ::QProcess *>(cppSelf)->environment();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QProcess::ProcessError cppResult = const_cast<const ::QProcess *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessError_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_execute(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "execute", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|OO:execute", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QProcess::execute(QString,const QStringList&=)->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // execute(QString,QStringList)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            overloadId = 0; // execute(QString,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "execute", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"arguments", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "execute", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStringList cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // execute(QString,QStringList)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = ::QProcess::execute(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_exitCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exitCode()const
        int cppResult = const_cast<const ::QProcess *>(cppSelf)->exitCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_exitStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exitStatus()const
        QProcess::ExitStatus cppResult = const_cast<const ::QProcess *>(cppSelf)->exitStatus();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ExitStatus_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_failChildProcessModifier(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "failChildProcessModifier", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|OO:failChildProcessModifier", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcess::failChildProcessModifier(const char*,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // failChildProcessModifier(const char*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // failChildProcessModifier(const char*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "failChildProcessModifier", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"error", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "failChildProcessModifier", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // failChildProcessModifier(const char*,int)
            cppSelf->failChildProcessModifier(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_inputChannelMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inputChannelMode()const
        QProcess::InputChannelMode cppResult = const_cast<const ::QProcess *>(cppSelf)->inputChannelMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_InputChannelMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_isSequential(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSequential()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QProcess *>(cppSelf)->::QProcess::isSequential()
            : const_cast<const ::QProcess *>(cppSelf)->isSequential();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_kill(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // kill()
        cppSelf->kill();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_nullDevice(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nullDevice()
        QString cppResult = ::QProcess::nullDevice();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_open(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|O:open", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::open(QFlags<QIODeviceBase::OpenModeFlag>=)->bool
    if (numArgs == 0) {
        overloadId = 0; // open(QFlags<QIODeviceBase::OpenModeFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // open(QFlags<QIODeviceBase::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg0(QIODeviceBase::OpenModeFlag::ReadWrite);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // open(QFlags<QIODeviceBase::OpenModeFlag>)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QProcess::open(cppArg0)
                : cppSelf->open(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_processChannelMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // processChannelMode()const
        QProcess::ProcessChannelMode cppResult = const_cast<const ::QProcess *>(cppSelf)->processChannelMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannelMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_processEnvironment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // processEnvironment()const
        QProcessEnvironment cppResult = const_cast<const ::QProcess *>(cppSelf)->processEnvironment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_processId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // processId()const
        qint64 cppResult = const_cast<const ::QProcess *>(cppSelf)->processId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_program(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // program()const
        QString cppResult = const_cast<const ::QProcess *>(cppSelf)->program();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_readAllStandardError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readAllStandardError()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        QByteArray cppResult = cppSelf->readAllStandardError();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_readAllStandardOutput(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readAllStandardOutput()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        QByteArray cppResult = cppSelf->readAllStandardOutput();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_readChannel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readChannel()const
        QProcess::ProcessChannel cppResult = const_cast<const ::QProcess *>(cppSelf)->readChannel();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannel_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_readData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QProcess::readData(ba.data(), qint64(cppArg0)) : cppSelf->readData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_setArguments(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setArguments(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setArguments(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setArguments", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setArguments(QStringList)
            cppSelf->setArguments(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setEnvironment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setEnvironment(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setEnvironment(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEnvironment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEnvironment(QStringList)
            cppSelf->setEnvironment(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setInputChannelMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setInputChannelMode(QProcess::InputChannelMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_InputChannelMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setInputChannelMode(QProcess::InputChannelMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInputChannelMode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QProcess::InputChannelMode cppArg0{QProcess::ManagedInputChannel};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInputChannelMode(QProcess::InputChannelMode)
            cppSelf->setInputChannelMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setProcessChannelMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setProcessChannelMode(QProcess::ProcessChannelMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannelMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setProcessChannelMode(QProcess::ProcessChannelMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProcessChannelMode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QProcess::ProcessChannelMode cppArg0{QProcess::SeparateChannels};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProcessChannelMode(QProcess::ProcessChannelMode)
            cppSelf->setProcessChannelMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setProcessEnvironment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setProcessEnvironment(QProcessEnvironment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), (pyArg)))) {
        overloadId = 0; // setProcessEnvironment(QProcessEnvironment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProcessEnvironment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QProcessEnvironment cppArg0_local;
        ::QProcessEnvironment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setProcessEnvironment(QProcessEnvironment)
            cppSelf->setProcessEnvironment(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setProcessState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setProcessState(QProcess::ProcessState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessState_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setProcessState(QProcess::ProcessState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProcessState", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QProcess::ProcessState cppArg0{QProcess::NotRunning};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProcessState(QProcess::ProcessState)
            cppSelf->setProcessState(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setProgram(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setProgram(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setProgram(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProgram", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProgram(QString)
            cppSelf->setProgram(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setReadChannel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setReadChannel(QProcess::ProcessChannel)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setReadChannel(QProcess::ProcessChannel)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadChannel", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QProcess::ProcessChannel cppArg0{QProcess::StandardOutput};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadChannel(QProcess::ProcessChannel)
            cppSelf->setReadChannel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setStandardErrorFile(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setStandardErrorFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setStandardErrorFile", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcess::setStandardErrorFile(QString,QFlags<QIODeviceBase::OpenModeFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setStandardErrorFile(QString,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // setStandardErrorFile(QString,QFlags<QIODeviceBase::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setStandardErrorFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setStandardErrorFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1(QIODeviceBase::OpenModeFlag::Truncate);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStandardErrorFile(QString,QFlags<QIODeviceBase::OpenModeFlag>)
            cppSelf->setStandardErrorFile(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setStandardInputFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setStandardInputFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setStandardInputFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStandardInputFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStandardInputFile(QString)
            cppSelf->setStandardInputFile(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setStandardOutputFile(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setStandardOutputFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setStandardOutputFile", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcess::setStandardOutputFile(QString,QFlags<QIODeviceBase::OpenModeFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setStandardOutputFile(QString,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // setStandardOutputFile(QString,QFlags<QIODeviceBase::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setStandardOutputFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setStandardOutputFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1(QIODeviceBase::OpenModeFlag::Truncate);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStandardOutputFile(QString,QFlags<QIODeviceBase::OpenModeFlag>)
            cppSelf->setStandardOutputFile(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setStandardOutputProcess(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setStandardOutputProcess(QProcess*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), (pyArg)))) {
        overloadId = 0; // setStandardOutputProcess(QProcess*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStandardOutputProcess", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QProcess *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStandardOutputProcess(QProcess*)
            cppSelf->setStandardOutputProcess(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setUnixProcessParameters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setUnixProcessParameters(QFlags<QProcess::UnixProcessFlag>)
    // 1: QProcess::setUnixProcessParameters(QProcess::UnixProcessParameters)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), (pyArg)))) {
        overloadId = 1; // setUnixProcessParameters(QProcess::UnixProcessParameters)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QProcess_UnixProcessFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setUnixProcessParameters(QFlags<QProcess::UnixProcessFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUnixProcessParameters", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setUnixProcessParameters(QFlags<QProcess::UnixProcessFlag> flagsOnly)
        {
            ::QFlags<QProcess::UnixProcessFlag> cppArg0 = QFlags<QProcess::UnixProcessFlag>(0);
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUnixProcessParameters(QFlags<QProcess::UnixProcessFlag>)
                cppSelf->setUnixProcessParameters(cppArg0);
            }
            break;
        }
        case 1: // setUnixProcessParameters(const QProcess::UnixProcessParameters &params)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QProcess::UnixProcessParameters cppArg0_local;
            ::QProcess::UnixProcessParameters *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUnixProcessParameters(QProcess::UnixProcessParameters)
                cppSelf->setUnixProcessParameters(*cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_setWorkingDirectory(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcess::setWorkingDirectory(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setWorkingDirectory(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWorkingDirectory", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWorkingDirectory(QString)
            cppSelf->setWorkingDirectory(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_splitCommand(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QProcess::splitCommand(QStringView)->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // splitCommand(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "splitCommand", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // splitCommand(QStringView)
            QStringList cppResult = ::QProcess::splitCommand(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_start(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:start", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcess::start(QFlags<QIODeviceBase::OpenModeFlag>=)
    // 1: QProcess::start(QString,const QStringList&=,QFlags<QIODeviceBase::OpenModeFlag>=)
    if (numArgs == 0) {
        overloadId = 0; // start(QFlags<QIODeviceBase::OpenModeFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // start(QString,QStringList,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // start(QString,QStringList,QFlags<QIODeviceBase::OpenModeFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // start(QString,QStringList,QFlags<QIODeviceBase::OpenModeFlag>)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // start(QFlags<QIODeviceBase::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // start(QFlags<QIODeviceBase::OpenModeFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 0}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
                }
            }
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg0(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // start(QFlags<QIODeviceBase::OpenModeFlag>)
                cppSelf->start(cppArg0);
            }
            break;
        }
        case 1: // start(const QString &program, const QStringList &arguments, QFlags<QIODeviceBase::OpenModeFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"arguments", 1}, {"mode", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QStringList cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg2(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // start(QString,QStringList,QFlags<QIODeviceBase::OpenModeFlag>)
                cppSelf->start(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_startCommand(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "startCommand", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|OO:startCommand", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcess::startCommand(QString,QFlags<QIODeviceBase::OpenModeFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // startCommand(QString,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // startCommand(QString,QFlags<QIODeviceBase::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startCommand", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "startCommand", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1(QIODeviceBase::OpenModeFlag::ReadWrite);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // startCommand(QString,QFlags<QIODeviceBase::OpenModeFlag>)
            cppSelf->startCommand(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_startDetached(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QProcess *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "startDetached", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:startDetached", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QProcess::startDetached(QString,const QStringList&=,const QString&=,qint64*=)->(retval, pid)
    // 1: QProcess::startDetached(qint64*=)->bool
    if (numArgs == 0) {
        overloadId = 1; // startDetached(qint64*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 1; // startDetached(qint64*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // startDetached(QString,QStringList,QString,qint64*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // startDetached(QString,QStringList,QString,qint64*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                overloadId = 0; // startDetached(QString,QStringList,QString,qint64*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startDetached", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // startDetached(const QString &program, const QStringList &arguments, const QString &workingDirectory, qint64 *pid)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"arguments", 1}, {"workingDirectory", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "startDetached", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QStringList cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            qint64* removed_cppArg3 = nullptr;
            SBK_UNUSED(removed_cppArg3)

            if (Shiboken::Errors::occurred() == nullptr) {
                // startDetached(QString,QStringList,QString,qint64*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qprocess-startdetached)]
                qint64 pid;
                bool retval = QProcess::startDetached(cppArg0, cppArg1, cppArg2, &pid);
                pyResult = PyTuple_New(2);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &retval));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &pid));
                // END of custom code block [file: ../glue/qtcore.cpp (qprocess-startdetached)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // startDetached(qint64 *pid)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"pid", 0}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "startDetached", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
                }
            }
            qint64 *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // startDetached(qint64*)
                bool cppResult = cppSelf->startDetached(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QProcess::ProcessState cppResult = const_cast<const ::QProcess *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessState_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_systemEnvironment(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemEnvironment()
        QStringList cppResult = ::QProcess::systemEnvironment();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_terminate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // terminate()
        cppSelf->terminate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QProcessFunc_unixProcessParameters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unixProcessParameters()const
        QProcess::UnixProcessParameters cppResult = const_cast<const ::QProcess *>(cppSelf)->unixProcessParameters();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_waitForBytesWritten(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForBytesWritten", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::waitForBytesWritten(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForBytesWritten(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"msecs", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForBytesWritten(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QProcess::waitForBytesWritten(cppArg0)
                : cppSelf->waitForBytesWritten(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_waitForFinished(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForFinished", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcess::waitForFinished(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForFinished(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForFinished(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"msecs", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForFinished(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->waitForFinished(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_waitForReadyRead(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForReadyRead", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::waitForReadyRead(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForReadyRead(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"msecs", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForReadyRead(int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QProcess::waitForReadyRead(cppArg0)
                : cppSelf->waitForReadyRead(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_waitForStarted(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForStarted", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForStarted", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcess::waitForStarted(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForStarted(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForStarted(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForStarted", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"msecs", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "waitForStarted", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForStarted(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->waitForStarted(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_workingDirectory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // workingDirectory()const
        QString cppResult = const_cast<const ::QProcess *>(cppSelf)->workingDirectory();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QProcessFunc_writeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::writeData(const char*,qint64)->qint64
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeData(const char*,qint64)
            qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QProcess::writeData(cppArg0, cppArg1)
                : cppSelf->writeData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyMethodDef Sbk_QProcessMethod_startDetached = {"startDetached", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_startDetached), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};


static const char *Sbk_QProcess_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QProcess_EnumFlagInfo[] = {
    "ExitStatus:Enum",
    "InputChannelMode:Enum",
    "ProcessChannel:Enum",
    "ProcessChannelMode:Enum",
    "ProcessError:Enum",
    "ProcessState:Enum",
    "UnixProcessFlag:Flag:UnixProcessFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QProcess_methods[] = {
    {"arguments", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_arguments), METH_NOARGS, nullptr},
    {"bytesToWrite", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_bytesToWrite), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_close), METH_NOARGS, nullptr},
    {"closeReadChannel", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_closeReadChannel), METH_O, nullptr},
    {"closeWriteChannel", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_closeWriteChannel), METH_NOARGS, nullptr},
    {"environment", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_environment), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_error), METH_NOARGS, nullptr},
    {"execute", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_execute), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"exitCode", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_exitCode), METH_NOARGS, nullptr},
    {"exitStatus", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_exitStatus), METH_NOARGS, nullptr},
    {"failChildProcessModifier", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_failChildProcessModifier), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"inputChannelMode", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_inputChannelMode), METH_NOARGS, nullptr},
    {"isSequential", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_isSequential), METH_NOARGS, nullptr},
    {"kill", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_kill), METH_NOARGS, nullptr},
    {"nullDevice", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_nullDevice), METH_NOARGS|METH_STATIC, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_open), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"processChannelMode", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_processChannelMode), METH_NOARGS, nullptr},
    {"processEnvironment", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_processEnvironment), METH_NOARGS, nullptr},
    {"processId", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_processId), METH_NOARGS, nullptr},
    {"program", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_program), METH_NOARGS, nullptr},
    {"readAllStandardError", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_readAllStandardError), METH_NOARGS, nullptr},
    {"readAllStandardOutput", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_readAllStandardOutput), METH_NOARGS, nullptr},
    {"readChannel", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_readChannel), METH_NOARGS, nullptr},
    {"readData", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_readData), METH_O, nullptr},
    {"setArguments", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setArguments), METH_O, nullptr},
    {"setEnvironment", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setEnvironment), METH_O, nullptr},
    {"setInputChannelMode", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setInputChannelMode), METH_O, nullptr},
    {"setProcessChannelMode", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setProcessChannelMode), METH_O, nullptr},
    {"setProcessEnvironment", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setProcessEnvironment), METH_O, nullptr},
    {"setProcessState", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setProcessState), METH_O, nullptr},
    {"setProgram", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setProgram), METH_O, nullptr},
    {"setReadChannel", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setReadChannel), METH_O, nullptr},
    {"setStandardErrorFile", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setStandardErrorFile), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setStandardInputFile", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setStandardInputFile), METH_O, nullptr},
    {"setStandardOutputFile", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setStandardOutputFile), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setStandardOutputProcess", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setStandardOutputProcess), METH_O, nullptr},
    {"setUnixProcessParameters", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setUnixProcessParameters), METH_O, nullptr},
    {"setWorkingDirectory", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_setWorkingDirectory), METH_O, nullptr},
    {"splitCommand", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_splitCommand), METH_O|METH_STATIC, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_start), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"startCommand", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_startCommand), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"startDetached", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_startDetached), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_state), METH_NOARGS, nullptr},
    {"systemEnvironment", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_systemEnvironment), METH_NOARGS|METH_STATIC, nullptr},
    {"terminate", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_terminate), METH_NOARGS, nullptr},
    {"unixProcessParameters", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_unixProcessParameters), METH_NOARGS, nullptr},
    {"waitForBytesWritten", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_waitForBytesWritten), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"waitForFinished", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_waitForFinished), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"waitForReadyRead", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_waitForReadyRead), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"waitForStarted", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_waitForStarted), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"workingDirectory", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_workingDirectory), METH_NOARGS, nullptr},
    {"writeData", reinterpret_cast<PyCFunction>(Sbk_QProcessFunc_writeData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QProcess_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PySide::getHiddenDataFromQObject(reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self))), self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QProcessMethod_startDetached = {
        Sbk_QProcessMethod_startDetached.ml_name,
        Sbk_QProcessMethod_startDetached.ml_meth,
        Sbk_QProcessMethod_startDetached.ml_flags & (~METH_STATIC),
        Sbk_QProcessMethod_startDetached.ml_doc,
    };
    if (Shiboken::String::compare(name, "startDetached") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QProcessMethod_startDetached, self, 0);
    return PySide::getHiddenDataFromQObject(reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self))), self, name);
}

static int Sbk_QProcess_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QProcess *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QProcessWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QProcess_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QProcess_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QProcessSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QProcess *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QProcess_Type = nullptr;
static PyTypeObject *Sbk_QProcess_TypeF(void)
{
    return _Sbk_QProcess_Type;
}

static PyType_Slot Sbk_QProcess_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QProcess_getattro)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QProcess_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QProcess_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QProcess_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QProcess_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QProcess_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QProcess_spec = {
    "2:PySide6.QtCore.QProcess",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QProcess_slots
};

} //extern "C"

static void *Sbk_QProcess_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QProcess *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QProcess_ProcessError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcess::ProcessError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcess::ProcessError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QProcess_ProcessError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessError_IDX])))
        return Enum_PythonToCpp_QProcess_ProcessError;
    return {};
}

static PyObject *QProcess_ProcessError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QProcess::ProcessError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QProcess::ProcessError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessError_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QProcess_ProcessState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcess::ProcessState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcess::ProcessState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QProcess_ProcessState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessState_IDX])))
        return Enum_PythonToCpp_QProcess_ProcessState;
    return {};
}

static PyObject *QProcess_ProcessState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QProcess::ProcessState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QProcess::ProcessState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QProcess_ProcessChannel(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcess::ProcessChannel>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcess::ProcessChannel *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QProcess_ProcessChannel_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannel_IDX])))
        return Enum_PythonToCpp_QProcess_ProcessChannel;
    return {};
}

static PyObject *QProcess_ProcessChannel_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QProcess::ProcessChannel>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QProcess::ProcessChannel *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannel_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QProcess_ProcessChannelMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcess::ProcessChannelMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcess::ProcessChannelMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QProcess_ProcessChannelMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannelMode_IDX])))
        return Enum_PythonToCpp_QProcess_ProcessChannelMode;
    return {};
}

static PyObject *QProcess_ProcessChannelMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QProcess::ProcessChannelMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QProcess::ProcessChannelMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannelMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QProcess_InputChannelMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcess::InputChannelMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcess::InputChannelMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QProcess_InputChannelMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_InputChannelMode_IDX])))
        return Enum_PythonToCpp_QProcess_InputChannelMode;
    return {};
}

static PyObject *QProcess_InputChannelMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QProcess::InputChannelMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QProcess::InputChannelMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_InputChannelMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QProcess_ExitStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcess::ExitStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcess::ExitStatus *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QProcess_ExitStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ExitStatus_IDX])))
        return Enum_PythonToCpp_QProcess_ExitStatus;
    return {};
}

static PyObject *QProcess_ExitStatus_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QProcess::ExitStatus>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QProcess::ExitStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ExitStatus_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QProcess_UnixProcessFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcess::UnixProcessFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcess::UnixProcessFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QProcess_UnixProcessFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessFlag_IDX])))
        return Enum_PythonToCpp_QProcess_UnixProcessFlag;
    return {};
}

static PyObject *QProcess_UnixProcessFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QProcess::UnixProcessFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QProcess::UnixProcessFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QProcess_UnixProcessFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QProcess::UnixProcessFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QProcess::UnixProcessFlag> *>(cppOut) = value;

}

static PyObject *QProcess_UnixProcessFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QProcess::UnixProcessFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QProcess_PythonToCpp_QProcess_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QProcess_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QProcess_PythonToCpp_QProcess_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QProcess_TypeF()))
        return QProcess_PythonToCpp_QProcess_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QProcess_PTR_CppToPython_QProcess(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QProcess *>(const_cast<void *>(cppIn)), Sbk_QProcess_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QProcess_SignatureStrings[] = {
    "PySide6.QtCore.QProcess(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCore.QProcess.arguments(self)->QStringList",
    "PySide6.QtCore.QProcess.bytesToWrite(self)->qint64",
    "PySide6.QtCore.QProcess.close(self)",
    "PySide6.QtCore.QProcess.closeReadChannel(self,channel:PySide6.QtCore.QProcess.ProcessChannel)",
    "PySide6.QtCore.QProcess.closeWriteChannel(self)",
    "PySide6.QtCore.QProcess.environment(self)->QStringList",
    "PySide6.QtCore.QProcess.error(self)->PySide6.QtCore.QProcess.ProcessError",
    "PySide6.QtCore.QProcess.execute(program:QString,arguments:QStringList={})->int",
    "PySide6.QtCore.QProcess.exitCode(self)->int",
    "PySide6.QtCore.QProcess.exitStatus(self)->PySide6.QtCore.QProcess.ExitStatus",
    "PySide6.QtCore.QProcess.failChildProcessModifier(self,description:char*,error:int=0)",
    "PySide6.QtCore.QProcess.inputChannelMode(self)->PySide6.QtCore.QProcess.InputChannelMode",
    "PySide6.QtCore.QProcess.isSequential(self)->bool",
    "PySide6.QtCore.QProcess.kill(self)",
    "PySide6.QtCore.QProcess.nullDevice()->QString",
    "PySide6.QtCore.QProcess.open(self,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)->bool",
    "PySide6.QtCore.QProcess.processChannelMode(self)->PySide6.QtCore.QProcess.ProcessChannelMode",
    "PySide6.QtCore.QProcess.processEnvironment(self)->PySide6.QtCore.QProcessEnvironment",
    "PySide6.QtCore.QProcess.processId(self)->qint64",
    "PySide6.QtCore.QProcess.program(self)->QString",
    "PySide6.QtCore.QProcess.readAllStandardError(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QProcess.readAllStandardOutput(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QProcess.readChannel(self)->PySide6.QtCore.QProcess.ProcessChannel",
    "PySide6.QtCore.QProcess.readData(self,maxlen:qint64)->PyObject",
    "PySide6.QtCore.QProcess.setArguments(self,arguments:QStringList)",
    "PySide6.QtCore.QProcess.setEnvironment(self,environment:QStringList)",
    "PySide6.QtCore.QProcess.setInputChannelMode(self,mode:PySide6.QtCore.QProcess.InputChannelMode)",
    "PySide6.QtCore.QProcess.setProcessChannelMode(self,mode:PySide6.QtCore.QProcess.ProcessChannelMode)",
    "PySide6.QtCore.QProcess.setProcessEnvironment(self,environment:typing.Union[PySide6.QtCore.QProcessEnvironment, PySide6.QtCore.QProcessEnvironment.Initialization])",
    "PySide6.QtCore.QProcess.setProcessState(self,state:PySide6.QtCore.QProcess.ProcessState)",
    "PySide6.QtCore.QProcess.setProgram(self,program:QString)",
    "PySide6.QtCore.QProcess.setReadChannel(self,channel:PySide6.QtCore.QProcess.ProcessChannel)",
    "PySide6.QtCore.QProcess.setStandardErrorFile(self,fileName:QString,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.Truncate)",
    "PySide6.QtCore.QProcess.setStandardInputFile(self,fileName:QString)",
    "PySide6.QtCore.QProcess.setStandardOutputFile(self,fileName:QString,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.Truncate)",
    "PySide6.QtCore.QProcess.setStandardOutputProcess(self,destination:PySide6.QtCore.QProcess)",
    "1:PySide6.QtCore.QProcess.setUnixProcessParameters(self,flagsOnly:PySide6.QtCore.QProcess.UnixProcessFlag)",
    "0:PySide6.QtCore.QProcess.setUnixProcessParameters(self,params:PySide6.QtCore.QProcess.UnixProcessParameters)",
    "PySide6.QtCore.QProcess.setWorkingDirectory(self,dir:QString)",
    "PySide6.QtCore.QProcess.splitCommand(command:QString)->QStringList",
    "1:PySide6.QtCore.QProcess.start(self,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "0:PySide6.QtCore.QProcess.start(self,program:QString,arguments:QStringList={},mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "PySide6.QtCore.QProcess.startCommand(self,command:QString,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "1:PySide6.QtCore.QProcess.startDetached(program:QString,arguments:QStringList={},workingDirectory:QString=QString())->Tuple[bool, int]",
    "0:PySide6.QtCore.QProcess.startDetached(self,pid:qint64*=nullptr)->bool",
    "PySide6.QtCore.QProcess.state(self)->PySide6.QtCore.QProcess.ProcessState",
    "PySide6.QtCore.QProcess.systemEnvironment()->QStringList",
    "PySide6.QtCore.QProcess.terminate(self)",
    "PySide6.QtCore.QProcess.unixProcessParameters(self)->PySide6.QtCore.QProcess.UnixProcessParameters",
    "PySide6.QtCore.QProcess.waitForBytesWritten(self,msecs:int=30000)->bool",
    "PySide6.QtCore.QProcess.waitForFinished(self,msecs:int=30000)->bool",
    "PySide6.QtCore.QProcess.waitForReadyRead(self,msecs:int=30000)->bool",
    "PySide6.QtCore.QProcess.waitForStarted(self,msecs:int=30000)->bool",
    "PySide6.QtCore.QProcess.workingDirectory(self)->QString",
    "PySide6.QtCore.QProcess.writeData(self,data:char*,len:qint64)->qint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QProcess_SignatureByteSize = 857;
static constexpr uint8_t QProcess_SignatureBytes[857] = {
    0x78, 0xda, 0xcd, 0x57, 0x51, 0x4f, 0xdb, 0x30, 0x10, 0x7e, 0xe7, 0x57, 0xf0, 0xd8, 0xa2, 0xac,
    0x62, 0xda, 0xc4, 0x43, 0xa4, 0x4e, 0x02, 0xda, 0x4a, 0x95, 0xc6, 0x5a, 0x56, 0x26, 0x1e, 0x10,
    0x0f, 0x26, 0xb9, 0x16, 0x0f, 0xc7, 0x0e, 0xb6, 0x03, 0x64, 0x13, 0xff, 0x7d, 0xe7, 0xc4, 0x4d,
    0x9b, 0xb6, 0x8e, 0x33, 0x58, 0xa5, 0xf1, 0x40, 0x93, 0xf6, 0xee, 0xf3, 0xf9, 0xbb, 0xbb, 0xcf,
    0xe7, 0x69, 0x3e, 0xa3, 0x31, 0x9c, 0xf4, 0x2e, 0xf5, 0xb9, 0x90, 0xd0, 0xbb, 0x9c, 0x4a, 0x11,
    0x81, 0x52, 0x1d, 0x05, 0x6c, 0x1e, 0xa4, 0x44, 0x02, 0xd7, 0xe1, 0x74, 0xc3, 0x66, 0x72, 0xf7,
    0x13, 0x22, 0xdd, 0xe7, 0x19, 0x63, 0xa9, 0x96, 0xdd, 0x83, 0xe9, 0x6e, 0x8c, 0x1e, 0x91, 0x8b,
    0x2c, 0x41, 0x80, 0x12, 0xad, 0xfb, 0xe1, 0xcb, 0xe5, 0x4c, 0x4b, 0xca, 0x17, 0x5f, 0xa9, 0xd2,
    0x4e, 0xa7, 0xbb, 0x5c, 0x83, 0xba, 0x12, 0xd7, 0x92, 0x6a, 0x58, 0xfa, 0x3d, 0x52, 0xae, 0x4f,
    0x3e, 0x3b, 0x5d, 0x22, 0x26, 0x94, 0xb5, 0x6d, 0xb6, 0xf9, 0x0e, 0x24, 0x3e, 0xbf, 0x27, 0x9c,
    0x03, 0x2b, 0x37, 0x18, 0x95, 0x2f, 0xa1, 0xcb, 0xcb, 0x7e, 0x5a, 0x1f, 0x0f, 0x7a, 0x11, 0xf2,
    0x3a, 0xbc, 0xdb, 0x1e, 0xf8, 0x13, 0x95, 0x82, 0x1b, 0x72, 0xfe, 0x86, 0x1b, 0x90, 0x52, 0xc8,
    0xa5, 0x83, 0x27, 0xe6, 0xa1, 0xb1, 0x75, 0x23, 0xbd, 0x40, 0x94, 0x21, 0xc1, 0xa9, 0x14, 0x0b,
    0x49, 0x92, 0xd0, 0xae, 0x1e, 0x54, 0x29, 0x0b, 0xd7, 0xe2, 0xe9, 0xff, 0x7e, 0xc5, 0xf5, 0x30,
    0x07, 0x0d, 0x70, 0x14, 0xbf, 0x89, 0xab, 0x84, 0xf9, 0x6c, 0x67, 0x9a, 0xe8, 0x4c, 0xf9, 0x76,
    0x32, 0xac, 0x2c, 0x9d, 0x60, 0x73, 0x42, 0xd9, 0xf9, 0x3d, 0x65, 0xb1, 0xfd, 0xe2, 0x42, 0xc4,
    0x74, 0x4e, 0xa1, 0x24, 0x29, 0x88, 0x41, 0x45, 0x92, 0xa6, 0x9a, 0x0a, 0x1e, 0x62, 0xaa, 0xe5,
    0x51, 0x50, 0x30, 0x18, 0x62, 0x78, 0xfd, 0x63, 0x77, 0x76, 0x28, 0x4f, 0x33, 0x6d, 0x13, 0x79,
    0xb1, 0xb6, 0x2b, 0x97, 0xfd, 0x78, 0xc3, 0xde, 0x0d, 0xac, 0x66, 0xf0, 0x98, 0x21, 0xbd, 0x94,
    0xb0, 0x25, 0xe8, 0x9d, 0x10, 0xcc, 0xe9, 0xf0, 0x40, 0x99, 0xaf, 0x94, 0x4c, 0x17, 0x0e, 0xe0,
    0x89, 0x46, 0xd0, 0x59, 0x55, 0x91, 0xd3, 0x5a, 0xa4, 0xc0, 0x4b, 0x6e, 0x12, 0x0c, 0x74, 0xab,
    0xee, 0xc7, 0x93, 0x12, 0xea, 0x8c, 0x28, 0xe8, 0x4d, 0xd0, 0xd6, 0x6c, 0x67, 0xc4, 0xc8, 0xa2,
    0xef, 0xfe, 0xa9, 0x67, 0xba, 0xaa, 0xa8, 0x7d, 0xdf, 0x6e, 0xd2, 0x5a, 0x37, 0xb5, 0x61, 0x76,
    0xba, 0xe5, 0xe1, 0x03, 0x1f, 0x6e, 0x77, 0x96, 0xc3, 0x63, 0xcd, 0xd2, 0x07, 0x3a, 0x8e, 0x5b,
    0x2a, 0x91, 0x6d, 0xa7, 0x8d, 0x9e, 0x76, 0x9a, 0x4b, 0x64, 0xee, 0x94, 0x31, 0xac, 0x71, 0x1e,
    0x13, 0x19, 0x0f, 0x9b, 0xda, 0xfb, 0x0c, 0x75, 0xf1, 0x54, 0x4a, 0x92, 0xb7, 0x45, 0x9b, 0x64,
    0x1a, 0xcb, 0xf2, 0x7d, 0x70, 0x35, 0x35, 0x6b, 0x9b, 0xa6, 0x46, 0xc4, 0x01, 0xd1, 0xc4, 0x16,
    0x20, 0x79, 0x61, 0xc0, 0xc3, 0x92, 0xd1, 0x02, 0xbc, 0x3c, 0x57, 0x9c, 0xee, 0x0a, 0xf4, 0x69,
    0xed, 0x44, 0xd9, 0xad, 0x56, 0xdd, 0x26, 0x80, 0xcd, 0xf2, 0x08, 0xd6, 0x94, 0xb8, 0x35, 0xc8,
    0x78, 0x97, 0x3e, 0xec, 0x6e, 0x28, 0x97, 0x44, 0x34, 0xe2, 0x4f, 0x77, 0xf7, 0x49, 0xf3, 0x0a,
    0xdb, 0x4e, 0x6d, 0xd6, 0x68, 0xe4, 0x43, 0xe7, 0x29, 0xd2, 0xd1, 0xfb, 0xc1, 0x51, 0x3f, 0x6f,
    0xfc, 0x5d, 0x14, 0x1c, 0xfa, 0x6d, 0x90, 0x08, 0x6a, 0xd4, 0x8f, 0xfe, 0x22, 0x46, 0x95, 0x6f,
    0xdb, 0xc4, 0x68, 0x8e, 0x00, 0xcb, 0x80, 0x32, 0x8f, 0x3e, 0x0a, 0x0a, 0x7b, 0x1f, 0x70, 0xd5,
    0xa6, 0xc1, 0xc6, 0x11, 0xd8, 0xe8, 0xb8, 0xb7, 0x01, 0x02, 0xb1, 0x6b, 0x2a, 0x30, 0xa2, 0xcc,
    0x6e, 0x79, 0x8e, 0x4f, 0xdf, 0x48, 0x02, 0xd5, 0x11, 0xfd, 0xef, 0x84, 0xfb, 0x4a, 0x66, 0x3c,
    0xf2, 0x71, 0xb5, 0x0c, 0xab, 0xa8, 0x60, 0x77, 0x58, 0xad, 0x30, 0x4a, 0x49, 0xfa, 0xff, 0xf6,
    0x56, 0xc6, 0x55, 0x1b, 0x7d, 0x71, 0x74, 0xd0, 0x94, 0x17, 0x45, 0xea, 0x4a, 0x6e, 0xf7, 0xe0,
    0x63, 0xd8, 0x00, 0x8e, 0x6d, 0xf3, 0x62, 0x5f, 0xa7, 0x04, 0x0b, 0x0c, 0x34, 0x48, 0x0b, 0x3e,
    0xc7, 0x08, 0xd5, 0x84, 0xb3, 0xdc, 0xe9, 0xbf, 0xe6, 0x6c, 0xb6, 0xd3, 0x3d, 0x38, 0x7e, 0xe3,
    0x52, 0xa9, 0x79, 0x57, 0x6d, 0xd6, 0x59, 0x79, 0x36, 0x72, 0x76, 0x2d, 0xe4, 0x03, 0xa6, 0x6a,
    0x40, 0x25, 0x6a, 0xb5, 0x90, 0xb9, 0xa5, 0x8b, 0xca, 0x16, 0x95, 0x90, 0x32, 0x33, 0x26, 0x26,
    0x09, 0xb2, 0xde, 0x89, 0xca, 0xcf, 0xca, 0xab, 0x3e, 0x01, 0x37, 0x30, 0xab, 0x89, 0xd4, 0xfb,
    0x1b, 0x61, 0x9a, 0x88, 0x5e, 0xad, 0xdc, 0x76, 0x6c, 0xde, 0x4f, 0x88, 0x8d, 0x01, 0x2e, 0xf9,
    0x2d, 0xe5, 0xa9, 0x4e, 0xf2, 0x7e, 0xc2, 0xf1, 0xe4, 0x6a, 0x00, 0x9a, 0x44, 0xf7, 0x10, 0xb7,
    0xbe, 0x6b, 0x04, 0xcf, 0x1b, 0x25, 0xb6, 0xfc, 0xbd, 0x6f, 0x3f, 0x3b, 0x5d, 0xac, 0x96, 0xab,
    0x2c, 0x65, 0x70, 0x63, 0xe6, 0xcd, 0xe0, 0x10, 0x47, 0x88, 0x5b, 0x5f, 0xe2, 0xaa, 0x30, 0xca,
    0x04, 0xd2, 0xd8, 0x4e, 0x1e, 0x47, 0xd5, 0x3d, 0xd6, 0x33, 0xbd, 0xaa, 0xea, 0x18, 0xf2, 0x4f,
    0x42, 0xc5, 0x11, 0xe4, 0x46, 0xca, 0x95, 0x86, 0x64, 0xfd, 0xe8, 0x6d, 0x79, 0xff, 0xc3, 0xe6,
    0x4c, 0x8c, 0x28, 0xf9, 0x2e, 0xbb, 0x99, 0x53, 0x0f, 0x1a, 0x42, 0xdf, 0x29, 0x05, 0xce, 0x25,
    0x9e, 0x09, 0xd5, 0x23, 0x21, 0xcd, 0x18, 0xa9, 0x4c, 0x1d, 0xe8, 0xea, 0x5e, 0xa1, 0x20, 0x52,
    0xc5, 0x0d, 0xeb, 0xd3, 0x31, 0xfe, 0xf9, 0x58, 0xb5, 0x38, 0x23, 0xca, 0xa9, 0xaa, 0xb2, 0xf3,
    0x36, 0x0c, 0x53, 0x92, 0xb9, 0xf9, 0xf7, 0x1e, 0x90, 0x99, 0xa9, 0x95, 0xb7, 0xc6, 0xb1, 0x4b,
    0x1a, 0x5b, 0x5c, 0x03, 0x9e, 0x4d, 0x1f, 0xad, 0x06, 0xe3, 0x18, 0x9f, 0xec, 0x75, 0xb5, 0x36,
    0x20, 0xdb, 0xbb, 0xc7, 0x1f, 0xa8, 0xfa, 0x6c, 0x0f
};
#endif

PyTypeObject *init_QProcess(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX].type;

    Shiboken::AutoDecRef Sbk_QProcess_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))));

    _Sbk_QProcess_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QProcess",
        "QProcess*",
        &Sbk_QProcess_spec,
        &Shiboken::callCppDestructor< QProcess >,
        Sbk_QProcess_Type_bases.object(),
        0);
    auto *pyType = Sbk_QProcess_TypeF(); // references _Sbk_QProcess_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QProcess_SignatureStrings);
#else
    InitSignatureBytes(pyType, QProcess_SignatureBytes, QProcess_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QProcess_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QProcess_PythonToCpp_QProcess_PTR,
        is_QProcess_PythonToCpp_QProcess_PTR_Convertible,
        QProcess_PTR_CppToPython_QProcess);

    Shiboken::Conversions::registerConverterName(converter, "QProcess");
    Shiboken::Conversions::registerConverterName(converter, "QProcess*");
    Shiboken::Conversions::registerConverterName(converter, "QProcess&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QProcess).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QProcessWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QProcess_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QProcess_TypeF(), &Sbk_QProcessSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QProcess_TypeF(), &Sbk_QProcess_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QProcess_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ProcessError'.
    const char *ProcessError_Initializer[] = {
        "FailedToStart",
        "Crashed",
        "Timedout",
        "ReadError",
        "WriteError",
        "UnknownError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ProcessError_InitializerValues[] = {
        uint8_t(QProcess::ProcessError::FailedToStart), //  0x00  0
        uint8_t(QProcess::ProcessError::Crashed),       //  0x01  1
        uint8_t(QProcess::ProcessError::Timedout),      //  0x02  2
        uint8_t(QProcess::ProcessError::ReadError),     //  0x03  3
        uint8_t(QProcess::ProcessError::WriteError),    //  0x04  4
        uint8_t(QProcess::ProcessError::UnknownError)   //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcess_TypeF(),
        "2:PySide6.QtCore.QProcess.ProcessError",
        ProcessError_Initializer, ProcessError_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessError_IDX].type = EType;
    // Register converter for enum 'QProcess::ProcessError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcess_ProcessError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QProcess_ProcessError,
            is_Enum_PythonToCpp_QProcess_ProcessError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QProcess::ProcessError");
        Shiboken::Conversions::registerConverterAlias(converter, "ProcessError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ProcessError' enum.

    // Initialization of enum 'ProcessState'.
    const char *ProcessState_Initializer[] = {
        "NotRunning",
        "Starting",
        "Running",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ProcessState_InitializerValues[] = {
        uint8_t(QProcess::ProcessState::NotRunning), //  0x00  0
        uint8_t(QProcess::ProcessState::Starting),   //  0x01  1
        uint8_t(QProcess::ProcessState::Running)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcess_TypeF(),
        "2:PySide6.QtCore.QProcess.ProcessState",
        ProcessState_Initializer, ProcessState_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessState_IDX].type = EType;
    // Register converter for enum 'QProcess::ProcessState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcess_ProcessState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QProcess_ProcessState,
            is_Enum_PythonToCpp_QProcess_ProcessState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QProcess::ProcessState");
        Shiboken::Conversions::registerConverterAlias(converter, "ProcessState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ProcessState' enum.

    // Initialization of enum 'ProcessChannel'.
    const char *ProcessChannel_Initializer[] = {
        "StandardOutput",
        "StandardError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ProcessChannel_InitializerValues[] = {
        uint8_t(QProcess::ProcessChannel::StandardOutput), //  0x00  0
        uint8_t(QProcess::ProcessChannel::StandardError)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcess_TypeF(),
        "2:PySide6.QtCore.QProcess.ProcessChannel",
        ProcessChannel_Initializer, ProcessChannel_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannel_IDX].type = EType;
    // Register converter for enum 'QProcess::ProcessChannel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcess_ProcessChannel_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QProcess_ProcessChannel,
            is_Enum_PythonToCpp_QProcess_ProcessChannel_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QProcess::ProcessChannel");
        Shiboken::Conversions::registerConverterAlias(converter, "ProcessChannel");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ProcessChannel' enum.

    // Initialization of enum 'ProcessChannelMode'.
    const char *ProcessChannelMode_Initializer[] = {
        "SeparateChannels",
        "MergedChannels",
        "ForwardedChannels",
        "ForwardedOutputChannel",
        "ForwardedErrorChannel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ProcessChannelMode_InitializerValues[] = {
        uint8_t(QProcess::ProcessChannelMode::SeparateChannels),       //  0x00  0
        uint8_t(QProcess::ProcessChannelMode::MergedChannels),         //  0x01  1
        uint8_t(QProcess::ProcessChannelMode::ForwardedChannels),      //  0x02  2
        uint8_t(QProcess::ProcessChannelMode::ForwardedOutputChannel), //  0x03  3
        uint8_t(QProcess::ProcessChannelMode::ForwardedErrorChannel)   //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcess_TypeF(),
        "2:PySide6.QtCore.QProcess.ProcessChannelMode",
        ProcessChannelMode_Initializer, ProcessChannelMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ProcessChannelMode_IDX].type = EType;
    // Register converter for enum 'QProcess::ProcessChannelMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcess_ProcessChannelMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QProcess_ProcessChannelMode,
            is_Enum_PythonToCpp_QProcess_ProcessChannelMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QProcess::ProcessChannelMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ProcessChannelMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ProcessChannelMode' enum.

    // Initialization of enum 'InputChannelMode'.
    const char *InputChannelMode_Initializer[] = {
        "ManagedInputChannel",
        "ForwardedInputChannel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InputChannelMode_InitializerValues[] = {
        uint8_t(QProcess::InputChannelMode::ManagedInputChannel),  //  0x00  0
        uint8_t(QProcess::InputChannelMode::ForwardedInputChannel) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcess_TypeF(),
        "2:PySide6.QtCore.QProcess.InputChannelMode",
        InputChannelMode_Initializer, InputChannelMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_InputChannelMode_IDX].type = EType;
    // Register converter for enum 'QProcess::InputChannelMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcess_InputChannelMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QProcess_InputChannelMode,
            is_Enum_PythonToCpp_QProcess_InputChannelMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QProcess::InputChannelMode");
        Shiboken::Conversions::registerConverterAlias(converter, "InputChannelMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InputChannelMode' enum.

    // Initialization of enum 'ExitStatus'.
    const char *ExitStatus_Initializer[] = {
        "NormalExit",
        "CrashExit",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ExitStatus_InitializerValues[] = {
        uint8_t(QProcess::ExitStatus::NormalExit), //  0x00  0
        uint8_t(QProcess::ExitStatus::CrashExit)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcess_TypeF(),
        "2:PySide6.QtCore.QProcess.ExitStatus",
        ExitStatus_Initializer, ExitStatus_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_ExitStatus_IDX].type = EType;
    // Register converter for enum 'QProcess::ExitStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcess_ExitStatus_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QProcess_ExitStatus,
            is_Enum_PythonToCpp_QProcess_ExitStatus_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QProcess::ExitStatus");
        Shiboken::Conversions::registerConverterAlias(converter, "ExitStatus");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ExitStatus' enum.

    // Initialization of enum 'UnixProcessFlag'.
    const char *UnixProcessFlag_Initializer[] = {
        "ResetSignalHandlers",
        "IgnoreSigPipe",
        "CloseFileDescriptors",
        "UseVFork",
        "CreateNewSession",
        "DisconnectControllingTerminal",
        "ResetIds",
        "DisableCoreDumps",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t UnixProcessFlag_InitializerValues[] = {
        uint16_t(QProcess::UnixProcessFlag::ResetSignalHandlers),           //  0x0001  1
        uint16_t(QProcess::UnixProcessFlag::IgnoreSigPipe),                 //  0x0002  2
        uint16_t(QProcess::UnixProcessFlag::CloseFileDescriptors),          //  0x0010  16
        uint16_t(QProcess::UnixProcessFlag::UseVFork),                      //  0x0020  32
        uint16_t(QProcess::UnixProcessFlag::CreateNewSession),              //  0x0040  64
        uint16_t(QProcess::UnixProcessFlag::DisconnectControllingTerminal), //  0x0080  128
        uint16_t(QProcess::UnixProcessFlag::ResetIds),                      //  0x0100  256
        uint16_t(QProcess::UnixProcessFlag::DisableCoreDumps)               //  0x0200  512
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcess_TypeF(),
        "2:PySide6.QtCore.QProcess.UnixProcessFlag",
        UnixProcessFlag_Initializer, UnixProcessFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QProcess_UnixProcessFlag_IDX].type =
        EType;
    // Register converter for enum 'QProcess::UnixProcessFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcess_UnixProcessFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QProcess_UnixProcessFlag,
            is_Enum_PythonToCpp_QProcess_UnixProcessFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QProcess::UnixProcessFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "UnixProcessFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QProcess_UnixProcessFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QProcess_UnixProcessFlag,
            is_Enum_PythonToCpp_QProcess_UnixProcessFlag_Convertible);
        // Register converter for flag 'QFlags<QProcess::UnixProcessFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QProcess::UnixProcessFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QProcess::UnixProcessFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'UnixProcessFlag' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QProcess::staticMetaObject);
    qRegisterMetaType< ::QProcess::ProcessError >("QProcess::ProcessError");
    qRegisterMetaType< ::QProcess::ProcessState >("QProcess::ProcessState");
    qRegisterMetaType< ::QProcess::ProcessChannel >("QProcess::ProcessChannel");
    qRegisterMetaType< ::QProcess::ProcessChannelMode >("QProcess::ProcessChannelMode");
    qRegisterMetaType< ::QProcess::InputChannelMode >("QProcess::InputChannelMode");
    qRegisterMetaType< ::QProcess::ExitStatus >("QProcess::ExitStatus");
    qRegisterMetaType< ::QProcess::UnixProcessFlag >("QProcess::UnixProcessFlag");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QProcess::staticMetaObject, sizeof(QProcessWrapper));

    return pyType;
}
