// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsavefile_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qprocess_wrapper.h"
#include "qfiledevice_wrapper.h"
#include "qtranslator_wrapper.h"
#include "qiodevice_wrapper.h"

// Argument includes
#include <QString>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSaveFileWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSaveFileWrapper::QSaveFileWrapper(::QObject * parent) : QSaveFile(parent)
{
}

QSaveFileWrapper::QSaveFileWrapper(const ::QString & name) : QSaveFile(name)
{
}

QSaveFileWrapper::QSaveFileWrapper(const ::QString & name, ::QObject * parent) : QSaveFile(name, parent)
{
}

bool QSaveFileWrapper::atEnd() const
{
    static const char *funcName = "atEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::atEnd();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QSaveFile", funcName, gil, pyOverride);
}

qint64 QSaveFileWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::bytesAvailable();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QSaveFile", funcName, gil, pyOverride);
}

qint64 QSaveFileWrapper::bytesToWrite() const
{
    static const char *funcName = "bytesToWrite";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::bytesToWrite();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QSaveFile", funcName, gil, pyOverride);
}

bool QSaveFileWrapper::canReadLine() const
{
    static const char *funcName = "canReadLine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::canReadLine();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QSaveFile", funcName, gil, pyOverride);
}

void QSaveFileWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QSaveFile", funcName, gil, pyOverride, event);
}

void QSaveFileWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QSaveFile", funcName, gil, pyOverride, signal);
}

void QSaveFileWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QSaveFile", funcName, gil, pyOverride, event);
}

void QSaveFileWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QSaveFile", funcName, gil, pyOverride, signal);
}

bool QSaveFileWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QSaveFile", funcName, gil, pyOverride, event);
}

bool QSaveFileWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QSaveFile", funcName, gil, pyOverride, watched, event);
}

::QString QSaveFileWrapper::fileName() const
{
    static const char *funcName = "fileName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSaveFile::fileName();
    }
    return QFileDeviceWrapper::sbk_o_fileName("QSaveFile", funcName, gil, pyOverride);
}

bool QSaveFileWrapper::isSequential() const
{
    static const char *funcName = "isSequential";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::isSequential();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QSaveFile", funcName, gil, pyOverride);
}

bool QSaveFileWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> flags)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSaveFile::open(flags);
    }
    return QProcessWrapper::sbk_o_open("QSaveFile", funcName, gil, pyOverride, flags);
}

::QFlags<QFileDevice::Permission> QSaveFileWrapper::permissions() const
{
    static const char *funcName = "permissions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::permissions();
    }
    return QFileDeviceWrapper::sbk_o_permissions("QSaveFile", funcName, gil, pyOverride);
}

qint64 QSaveFileWrapper::pos() const
{
    static const char *funcName = "pos";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::pos();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QSaveFile", funcName, gil, pyOverride);
}

qint64 QSaveFileWrapper::readData(char * data, qint64 maxlen)
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::readData(data, maxlen);
    }
    return QProcessWrapper::sbk_o_readData("QSaveFile", funcName, gil, pyOverride, data, maxlen);
}

qint64 QSaveFileWrapper::readLineData(char * data, qint64 maxlen)
{
    static const char *funcName = "readLineData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::readLineData(data, maxlen);
    }
    return QProcessWrapper::sbk_o_readLineData("QSaveFile", funcName, gil, pyOverride, data, maxlen);
}

bool QSaveFileWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::reset();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QSaveFile", funcName, gil, pyOverride);
}

bool QSaveFileWrapper::resize(qint64 sz)
{
    static const char *funcName = "resize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::resize(sz);
    }
    return QFileDeviceWrapper::sbk_o_resize("QSaveFile", funcName, gil, pyOverride, sz);
}

bool QSaveFileWrapper::seek(qint64 offset)
{
    static const char *funcName = "seek";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::seek(offset);
    }
    return QProcessWrapper::sbk_o_seek("QSaveFile", funcName, gil, pyOverride, offset);
}

bool QSaveFileWrapper::setPermissions(::QFlags<QFileDevice::Permission> permissionSpec)
{
    static const char *funcName = "setPermissions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::setPermissions(permissionSpec);
    }
    return QFileDeviceWrapper::sbk_o_setPermissions("QSaveFile", funcName, gil, pyOverride, permissionSpec);
}

qint64 QSaveFileWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::size();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QSaveFile", funcName, gil, pyOverride);
}

qint64 QSaveFileWrapper::skipData(qint64 maxSize)
{
    static const char *funcName = "skipData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::skipData(maxSize);
    }
    return QIODeviceWrapper::sbk_o_skipData("QSaveFile", funcName, gil, pyOverride, maxSize);
}

void QSaveFileWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QSaveFile", funcName, gil, pyOverride, event);
}

bool QSaveFileWrapper::waitForBytesWritten(int msecs)
{
    static const char *funcName = "waitForBytesWritten";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForBytesWritten(msecs);
    }
    return QFileDeviceWrapper::sbk_o_waitForBytesWritten("QSaveFile", funcName, gil, pyOverride, msecs);
}

bool QSaveFileWrapper::waitForReadyRead(int msecs)
{
    static const char *funcName = "waitForReadyRead";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForReadyRead(msecs);
    }
    return QProcessWrapper::sbk_o_waitForReadyRead("QSaveFile", funcName, gil, pyOverride, msecs);
}

qint64 QSaveFileWrapper::writeData(const char * data, qint64 len)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSaveFile::writeData(data, len);
    }
    return QIODeviceWrapper::sbk_o_writeData("QSaveFile", funcName, gil, pyOverride, data, len);
}

const QMetaObject *QSaveFileWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSaveFile::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSaveFileWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSaveFile::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSaveFileWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSaveFileWrapper *>(this));
    return QSaveFile::qt_metacast(_clname);
}

QSaveFileWrapper::~QSaveFileWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSaveFile_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSaveFile >()))
        return -1;

    QSaveFileWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSaveFile", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSaveFile::QSaveFile(QObject*=)
    // 1: QSaveFile::QSaveFile(QString)
    // 2: QSaveFile::QSaveFile(QString,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSaveFile(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSaveFile(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSaveFile(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QSaveFile(QString,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSaveFile(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSaveFile(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSaveFileWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSaveFileWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QSaveFile(const QString &name)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSaveFile(QString)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSaveFileWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSaveFileWrapper(cppArg0);
                }

            }
            break;
        }
        case 2: // QSaveFile(const QString &name, QObject *parent)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSaveFile(QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSaveFileWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSaveFileWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSaveFile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSaveFileFunc_cancelWriting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancelWriting()
        cppSelf->cancelWriting();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSaveFileFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("close()");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSaveFileFunc_commit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // commit()
        bool cppResult = cppSelf->commit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSaveFileFunc_directWriteFallback(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // directWriteFallback()const
        bool cppResult = const_cast<const ::QSaveFile *>(cppSelf)->directWriteFallback();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSaveFileFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSaveFile *>(cppSelf)->::QSaveFile::fileName()
            : const_cast<const ::QSaveFile *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSaveFileFunc_open(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::open(QFlags<QIODeviceBase::OpenModeFlag>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // open(QFlags<QIODeviceBase::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);

    // Call function/method
    {
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg0 = QFlags<QIODeviceBase::OpenModeFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // open(QFlags<QIODeviceBase::OpenModeFlag>)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSaveFile::open(cppArg0)
                : cppSelf->open(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSaveFileFunc_setDirectWriteFallback(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSaveFile::setDirectWriteFallback(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDirectWriteFallback(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirectWriteFallback", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirectWriteFallback(bool)
            cppSelf->setDirectWriteFallback(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSaveFileFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSaveFile::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            cppSelf->setFileName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSaveFileFunc_writeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::writeData(const char*,qint64)->qint64
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeData(const char*,qint64)
            qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSaveFile::writeData(cppArg0, cppArg1)
                : cppSelf->writeData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSaveFile_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSaveFile_methods[] = {
    {"cancelWriting", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_cancelWriting), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_close), METH_NOARGS, nullptr},
    {"commit", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_commit), METH_NOARGS, nullptr},
    {"directWriteFallback", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_directWriteFallback), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_fileName), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_open), METH_O, nullptr},
    {"setDirectWriteFallback", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_setDirectWriteFallback), METH_O, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_setFileName), METH_O, nullptr},
    {"writeData", reinterpret_cast<PyCFunction>(Sbk_QSaveFileFunc_writeData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSaveFile_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSaveFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSaveFileWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSaveFile_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSaveFile_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QSaveFileSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QSaveFile *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]))
        return static_cast< ::QFileDevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSaveFile_Type = nullptr;
static PyTypeObject *Sbk_QSaveFile_TypeF(void)
{
    return _Sbk_QSaveFile_Type;
}

static PyType_Slot Sbk_QSaveFile_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSaveFile_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSaveFile_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSaveFile_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSaveFile_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSaveFile_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSaveFile_spec = {
    "2:PySide6.QtCore.QSaveFile",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSaveFile_slots
};

} //extern "C"

static void *Sbk_QSaveFile_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSaveFile *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSaveFile_PythonToCpp_QSaveFile_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSaveFile_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSaveFile_PythonToCpp_QSaveFile_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSaveFile_TypeF()))
        return QSaveFile_PythonToCpp_QSaveFile_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSaveFile_PTR_CppToPython_QSaveFile(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSaveFile *>(const_cast<void *>(cppIn)), Sbk_QSaveFile_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSaveFile_SignatureStrings[] = {
    "2:PySide6.QtCore.QSaveFile(self,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtCore.QSaveFile(self,name:QString)",
    "0:PySide6.QtCore.QSaveFile(self,name:QString,parent:PySide6.QtCore.QObject)",
    "PySide6.QtCore.QSaveFile.cancelWriting(self)",
    "PySide6.QtCore.QSaveFile.close(self)",
    "PySide6.QtCore.QSaveFile.commit(self)->bool",
    "PySide6.QtCore.QSaveFile.directWriteFallback(self)->bool",
    "PySide6.QtCore.QSaveFile.fileName(self)->QString",
    "PySide6.QtCore.QSaveFile.open(self,flags:PySide6.QtCore.QIODeviceBase.OpenModeFlag)->bool",
    "PySide6.QtCore.QSaveFile.setDirectWriteFallback(self,enabled:bool)",
    "PySide6.QtCore.QSaveFile.setFileName(self,name:QString)",
    "PySide6.QtCore.QSaveFile.writeData(self,data:char*,len:qint64)->qint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QSaveFile_SignatureByteSize = 243;
static constexpr uint8_t QSaveFile_SignatureBytes[243] = {
    0x78, 0xda, 0x95, 0x92, 0x41, 0x4f, 0x84, 0x30, 0x10, 0x85, 0xef, 0xfc, 0x12, 0x31, 0x48, 0xd4,
    0x98, 0x3d, 0x34, 0xd1, 0x83, 0x12, 0x12, 0x0f, 0x8a, 0x84, 0x83, 0xe7, 0xa1, 0x3c, 0xd6, 0xea,
    0xd0, 0x62, 0x5b, 0xd7, 0xf8, 0xef, 0x2d, 0xa2, 0x89, 0x71, 0x53, 0x58, 0x2f, 0xcd, 0x1c, 0xbe,
    0xf7, 0xe6, 0xbd, 0x49, 0xcf, 0xc5, 0xc3, 0x47, 0xa3, 0x3a, 0x6c, 0xf2, 0xda, 0xdf, 0x18, 0x8b,
    0xbc, 0x6e, 0x68, 0x87, 0x52, 0x31, 0x8e, 0x1c, 0xb8, 0xcf, 0x46, 0xb2, 0xd0, 0x7e, 0x0f, 0xaa,
    0xda, 0x67, 0x48, 0x7f, 0xa9, 0xdf, 0x98, 0x47, 0x6f, 0xd3, 0xe4, 0x6c, 0xc5, 0x46, 0xd3, 0x00,
    0x51, 0x37, 0xde, 0x2a, 0xbd, 0x4d, 0x93, 0xd3, 0x7f, 0xd0, 0xcb, 0x09, 0xd2, 0x24, 0xe6, 0x94,
    0x4b, 0xd2, 0x12, 0xfc, 0x68, 0x95, 0x0f, 0x2e, 0x5f, 0xbe, 0x4b, 0x30, 0x1b, 0x87, 0x55, 0xc8,
    0x0c, 0x83, 0xf2, 0x33, 0x75, 0x72, 0xd5, 0x1a, 0xc3, 0x71, 0xb6, 0x53, 0x36, 0xc4, 0x9b, 0xb6,
    0xa3, 0x24, 0xe6, 0x96, 0xe4, 0xcb, 0x61, 0xc2, 0x3e, 0x3c, 0xf7, 0xa1, 0xff, 0x0f, 0xfd, 0x7d,
    0x86, 0xb8, 0xc0, 0x8c, 0xd0, 0xf3, 0xd9, 0x7a, 0xa6, 0xad, 0xdb, 0x3b, 0xd4, 0x6d, 0x55, 0x60,
    0xa7, 0x24, 0xae, 0xc9, 0x21, 0xaf, 0x02, 0x7c, 0x67, 0x3a, 0x94, 0x01, 0x5d, 0x8d, 0xe2, 0xe0,
    0x8b, 0x48, 0x8d, 0x0c, 0x9a, 0x5a, 0x46, 0x27, 0x26, 0x87, 0x74, 0xd1, 0xa2, 0xfc, 0x5d, 0xe8,
    0xcf, 0x47, 0x88, 0xea, 0xde, 0xa7, 0x8d, 0x05, 0x79, 0x9a, 0x55, 0x5d, 0x98, 0x84, 0x7c, 0x22,
    0x7b, 0x9c, 0x31, 0xb4, 0x78, 0x55, 0xda, 0x6f, 0x2e, 0x42, 0xfe, 0x79, 0x48, 0x3e, 0x01, 0xf3,
    0x30, 0xf9, 0x9e
};
#endif

PyTypeObject *init_QSaveFile(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX].type;

    Shiboken::AutoDecRef Sbk_QSaveFile_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]))));

    _Sbk_QSaveFile_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSaveFile",
        "QSaveFile*",
        &Sbk_QSaveFile_spec,
        &Shiboken::callCppDestructor< QSaveFile >,
        Sbk_QSaveFile_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSaveFile_TypeF(); // references _Sbk_QSaveFile_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSaveFile_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSaveFile_SignatureBytes, QSaveFile_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSaveFile_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSaveFile_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSaveFile_PythonToCpp_QSaveFile_PTR,
        is_QSaveFile_PythonToCpp_QSaveFile_PTR_Convertible,
        QSaveFile_PTR_CppToPython_QSaveFile);

    Shiboken::Conversions::registerConverterName(converter, "QSaveFile");
    Shiboken::Conversions::registerConverterName(converter, "QSaveFile*");
    Shiboken::Conversions::registerConverterName(converter, "QSaveFile&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSaveFile).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSaveFileWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QSaveFile_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QSaveFile_TypeF(), &Sbk_QSaveFileSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSaveFile_TypeF(), &Sbk_QSaveFile_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSaveFile::staticMetaObject, sizeof(QSaveFileWrapper));

    return pyType;
}
