// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsignalmapper_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qtranslator_wrapper.h"

// Argument includes
#include <QString>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSignalMapperWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSignalMapperWrapper::QSignalMapperWrapper(::QObject * parent) : QSignalMapper(parent)
{
}

void QSignalMapperWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QSignalMapper", funcName, gil, pyOverride, event);
}

void QSignalMapperWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QSignalMapper", funcName, gil, pyOverride, signal);
}

void QSignalMapperWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QSignalMapper", funcName, gil, pyOverride, event);
}

void QSignalMapperWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QSignalMapper", funcName, gil, pyOverride, signal);
}

bool QSignalMapperWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QSignalMapper", funcName, gil, pyOverride, event);
}

bool QSignalMapperWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QSignalMapper", funcName, gil, pyOverride, watched, event);
}

void QSignalMapperWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QSignalMapper", funcName, gil, pyOverride, event);
}

const QMetaObject *QSignalMapperWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSignalMapper::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSignalMapperWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSignalMapper::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSignalMapperWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSignalMapperWrapper *>(this));
    return QSignalMapper::qt_metacast(_clname);
}

QSignalMapperWrapper::~QSignalMapperWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSignalMapper_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSignalMapper >()))
        return -1;

    QSignalMapperWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QSignalMapper", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSignalMapper::QSignalMapper(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSignalMapper(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSignalMapper(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSignalMapper(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QSignalMapperWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QSignalMapperWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSignalMapper >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSignalMapperFunc_map(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "map", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSignalMapper::map()
    // 1: QSignalMapper::map(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // map()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // map(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "map", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // map()
        {

            // map()
            cppSelf->map();
            break;
        }
        case 1: // map(QObject *sender)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QObject*)
                cppSelf->map(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSignalMapperFunc_mapping(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSignalMapper::mapping(QObject*)const->QObject*
    // 1: QSignalMapper::mapping(QString)const->QObject*
    // 2: QSignalMapper::mapping(int)const->QObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 2; // mapping(int)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // mapping(QObject*)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // mapping(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapping", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mapping(QObject *object) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QObject *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapping(QObject*)const
                QObject * cppResult = const_cast<const ::QSignalMapper *>(cppSelf)->mapping(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // mapping(const QString &text) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapping(QString)const
                QObject * cppResult = const_cast<const ::QSignalMapper *>(cppSelf)->mapping(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 2: // mapping(int id) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapping(int)const
                QObject * cppResult = const_cast<const ::QSignalMapper *>(cppSelf)->mapping(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSignalMapperFunc_removeMappings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSignalMapper::removeMappings(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // removeMappings(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeMappings", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeMappings(QObject*)
            cppSelf->removeMappings(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSignalMapperFunc_setMapping(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMapping", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSignalMapper::setMapping(QObject*,QObject*)
    // 1: QSignalMapper::setMapping(QObject*,QString)
    // 2: QSignalMapper::setMapping(QObject*,int)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 2; // setMapping(QObject*,int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setMapping(QObject*,QObject*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // setMapping(QObject*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMapping", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setMapping(QObject *sender, QObject *object)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setMapping(QObject*,QObject*)
                cppSelf->setMapping(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setMapping(QObject *sender, const QString &text)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setMapping(QObject*,QString)
                cppSelf->setMapping(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // setMapping(QObject *sender, int id)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setMapping(QObject*,int)
                cppSelf->setMapping(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QSignalMapper_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSignalMapper_methods[] = {
    {"map", reinterpret_cast<PyCFunction>(Sbk_QSignalMapperFunc_map), METH_VARARGS, nullptr},
    {"mapping", reinterpret_cast<PyCFunction>(Sbk_QSignalMapperFunc_mapping), METH_O, nullptr},
    {"removeMappings", reinterpret_cast<PyCFunction>(Sbk_QSignalMapperFunc_removeMappings), METH_O, nullptr},
    {"setMapping", reinterpret_cast<PyCFunction>(Sbk_QSignalMapperFunc_setMapping), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSignalMapper_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSignalMapper *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSignalMapperWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSignalMapper_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSignalMapper_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSignalMapper_Type = nullptr;
static PyTypeObject *Sbk_QSignalMapper_TypeF(void)
{
    return _Sbk_QSignalMapper_Type;
}

static PyType_Slot Sbk_QSignalMapper_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSignalMapper_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSignalMapper_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSignalMapper_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSignalMapper_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSignalMapper_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSignalMapper_spec = {
    "2:PySide6.QtCore.QSignalMapper",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSignalMapper_slots
};

} //extern "C"

static void *Sbk_QSignalMapper_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSignalMapper *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSignalMapper_PythonToCpp_QSignalMapper_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSignalMapper_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSignalMapper_PythonToCpp_QSignalMapper_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSignalMapper_TypeF()))
        return QSignalMapper_PythonToCpp_QSignalMapper_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSignalMapper_PTR_CppToPython_QSignalMapper(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSignalMapper *>(const_cast<void *>(cppIn)), Sbk_QSignalMapper_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSignalMapper_SignatureStrings[] = {
    "PySide6.QtCore.QSignalMapper(self,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtCore.QSignalMapper.map(self)",
    "0:PySide6.QtCore.QSignalMapper.map(self,sender:PySide6.QtCore.QObject)",
    "2:PySide6.QtCore.QSignalMapper.mapping(self,object:PySide6.QtCore.QObject)->PySide6.QtCore.QObject",
    "1:PySide6.QtCore.QSignalMapper.mapping(self,text:QString)->PySide6.QtCore.QObject",
    "0:PySide6.QtCore.QSignalMapper.mapping(self,id:int)->PySide6.QtCore.QObject",
    "PySide6.QtCore.QSignalMapper.removeMappings(self,sender:PySide6.QtCore.QObject)",
    "2:PySide6.QtCore.QSignalMapper.setMapping(self,sender:PySide6.QtCore.QObject,object:PySide6.QtCore.QObject)",
    "1:PySide6.QtCore.QSignalMapper.setMapping(self,sender:PySide6.QtCore.QObject,text:QString)",
    "0:PySide6.QtCore.QSignalMapper.setMapping(self,sender:PySide6.QtCore.QObject,id:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QSignalMapper_SignatureByteSize = 183;
static constexpr uint8_t QSignalMapper_SignatureBytes[183] = {
    0x78, 0xda, 0xad, 0x91, 0xcb, 0x0e, 0x82, 0x30, 0x10, 0x45, 0xf7, 0xfd, 0x12, 0x49, 0x90, 0xa0,
    0x0b, 0x17, 0x4d, 0x74, 0xe3, 0x9a, 0x08, 0xe1, 0x0b, 0xaa, 0x8c, 0xa4, 0xa6, 0xb4, 0xcd, 0x74,
    0x34, 0xfa, 0xf7, 0x1a, 0x30, 0x11, 0x1f, 0x50, 0x9a, 0xb8, 0x6d, 0x6f, 0xcf, 0x9d, 0x39, 0xcd,
    0x6f, 0xa5, 0xac, 0x60, 0x95, 0x14, 0xb4, 0x35, 0x08, 0x49, 0x51, 0xca, 0x5a, 0x0b, 0x95, 0x09,
    0x6b, 0x01, 0x67, 0x0e, 0xd4, 0x31, 0xb6, 0x02, 0x41, 0x13, 0xcf, 0x3f, 0x82, 0xbb, 0xfd, 0x09,
    0x0e, 0xb4, 0xd6, 0x67, 0xa5, 0x2c, 0x61, 0xc4, 0x16, 0x5f, 0x89, 0x3e, 0x2a, 0x69, 0x84, 0x6d,
    0x71, 0x11, 0x4b, 0xa7, 0x05, 0x63, 0x07, 0xba, 0x02, 0x1c, 0xe8, 0x8d, 0xd8, 0xd2, 0x8b, 0xb1,
    0x52, 0xd7, 0x1d, 0xca, 0xb4, 0x6f, 0x86, 0x50, 0xf3, 0xcd, 0xef, 0x8b, 0x09, 0x2b, 0xbd, 0x2a,
    0x08, 0xae, 0xc4, 0x8b, 0x92, 0xf0, 0x71, 0x32, 0x4c, 0x4c, 0x03, 0x88, 0xb2, 0xe2, 0x52, 0x8f,
    0x4c, 0x37, 0x4a, 0x42, 0x68, 0xcc, 0x05, 0xb2, 0x8e, 0xe7, 0xfe, 0x21, 0xd4, 0x01, 0x65, 0xfd,
    0xf1, 0x46, 0x69, 0x1e, 0xe3, 0x3e, 0xb3, 0x61, 0x5d, 0x6f, 0xea, 0x7d, 0x8a, 0xc3, 0xd0, 0xcf,
    0x3f, 0x60, 0x77, 0xe1, 0x9b, 0x1d, 0xf0
};
#endif

PyTypeObject *init_QSignalMapper(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX].type;

    Shiboken::AutoDecRef Sbk_QSignalMapper_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QSignalMapper_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSignalMapper",
        "QSignalMapper*",
        &Sbk_QSignalMapper_spec,
        &Shiboken::callCppDestructor< QSignalMapper >,
        Sbk_QSignalMapper_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSignalMapper_TypeF(); // references _Sbk_QSignalMapper_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSignalMapper_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSignalMapper_SignatureBytes, QSignalMapper_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSignalMapper_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSignalMapper_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSignalMapper_PythonToCpp_QSignalMapper_PTR,
        is_QSignalMapper_PythonToCpp_QSignalMapper_PTR_Convertible,
        QSignalMapper_PTR_CppToPython_QSignalMapper);

    Shiboken::Conversions::registerConverterName(converter, "QSignalMapper");
    Shiboken::Conversions::registerConverterName(converter, "QSignalMapper*");
    Shiboken::Conversions::registerConverterName(converter, "QSignalMapper&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSignalMapper).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSignalMapperWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSignalMapper_TypeF(), &Sbk_QSignalMapper_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QSignalMapper::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSignalMapper::staticMetaObject, sizeof(QSignalMapperWrapper));

    return pyType;
}
