// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qtimezone_wrapper.h"

// inner classes
#include "qtimezone_offsetdata_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qdatetime.h>
#include <qlocale.h>
#include <qnamespace.h>
#include <qtimezone.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTimeZone_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTimeZone >()))
        return -1;

    ::QTimeZone *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:QTimeZone", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTimeZone::QTimeZone()
    // 1: QTimeZone::QTimeZone(QTimeZone::Initialization)
    // 2: QTimeZone::QTimeZone(QByteArray)
    // 3: QTimeZone::QTimeZone(QByteArray,int,QString,QString,QLocale::Country=,const QString&=)
    // 4: QTimeZone::QTimeZone(QTimeZone)
    // 5: QTimeZone::QTimeZone(int)
    if (numArgs == 0) {
        overloadId = 0; // QTimeZone()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QTimeZone(QByteArray)
        } else if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 3; // QTimeZone(QByteArray,int,QString,QString,QLocale::Country,QString)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 3; // QTimeZone(QByteArray,int,QString,QString,QLocale::Country,QString)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
                    overloadId = 3; // QTimeZone(QByteArray,int,QString,QString,QLocale::Country,QString)
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_Initialization_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QTimeZone(QTimeZone::Initialization)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QTimeZone(QTimeZone)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 5; // QTimeZone(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTimeZone()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
            }

            // QTimeZone()
            cptr = new ::QTimeZone();
            break;
        }
        case 1: // QTimeZone(QTimeZone::Initialization spec)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
            }
            ::QTimeZone::Initialization cppArg0{QTimeZone::LocalTime};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTimeZone(QTimeZone::Initialization)
                cptr = new ::QTimeZone(cppArg0);
            }
            break;
        }
        case 2: // QTimeZone(const QByteArray &ianaId)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTimeZone(QByteArray)
                cptr = new ::QTimeZone(*cppArg0);
            }
            break;
        }
        case 3: // QTimeZone(const QByteArray &zoneId, int offsetSeconds, const QString &name, const QString &abbreviation, QLocale::Country territory, const QString &comment)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"territory", 4}, {"comment", 5}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QLocale::Country cppArg4(QLocale::AnyTerritory);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5 = QString();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTimeZone(QByteArray,int,QString,QString,QLocale::Country,QString)
                cptr = new ::QTimeZone(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 4: // QTimeZone(const QTimeZone &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTimeZone cppArg0_local;
            ::QTimeZone *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTimeZone(QTimeZone)
                cptr = new ::QTimeZone(*cppArg0);
            }
            break;
        }
        case 5: // QTimeZone(int offsetSeconds)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTimeZone(int)
                cptr = new ::QTimeZone(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTimeZone >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTimeZoneFunc_abbreviation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::abbreviation(QDateTime)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // abbreviation(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "abbreviation", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // abbreviation(QDateTime)const
            QString cppResult = const_cast<const ::QTimeZone *>(cppSelf)->abbreviation(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_asBackendZone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // asBackendZone()const
        QTimeZone cppResult = const_cast<const ::QTimeZone *>(cppSelf)->asBackendZone();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_availableTimeZoneIds(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "availableTimeZoneIds", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTimeZone::availableTimeZoneIds()->QList<QByteArray>
    // 1: static QTimeZone::availableTimeZoneIds(QLocale::Country)->QList<QByteArray>
    // 2: static QTimeZone::availableTimeZoneIds(int)->QList<QByteArray>
    if (numArgs == 0) {
        overloadId = 0; // availableTimeZoneIds()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // availableTimeZoneIds(QLocale::Country)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // availableTimeZoneIds(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "availableTimeZoneIds", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // availableTimeZoneIds()
        {

            // availableTimeZoneIds()
            QList<QByteArray> cppResult = ::QTimeZone::availableTimeZoneIds();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
            break;
        }
        case 1: // availableTimeZoneIds(QLocale::Country territory)
        {
            ::QLocale::Country cppArg0{QLocale::AnyCountry};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // availableTimeZoneIds(QLocale::Country)
                QList<QByteArray> cppResult = ::QTimeZone::availableTimeZoneIds(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
            }
            break;
        }
        case 2: // availableTimeZoneIds(int offsetSeconds)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // availableTimeZoneIds(int)
                QList<QByteArray> cppResult = ::QTimeZone::availableTimeZoneIds(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_comment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comment()const
        QString cppResult = const_cast<const ::QTimeZone *>(cppSelf)->comment();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_country(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QTimeZone", "country() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // country()const
        QLocale::Country cppResult = const_cast<const ::QTimeZone *>(cppSelf)->country();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_daylightTimeOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::daylightTimeOffset(QDateTime)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // daylightTimeOffset(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "daylightTimeOffset", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // daylightTimeOffset(QDateTime)const
            int cppResult = const_cast<const ::QTimeZone *>(cppSelf)->daylightTimeOffset(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_displayName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "displayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:displayName", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTimeZone::displayName(QTimeZone::TimeType,QTimeZone::NameType=,const QLocale&=)const->QString
    // 1: QTimeZone::displayName(QDateTime,QTimeZone::NameType=,const QLocale&=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // displayName(QDateTime,QTimeZone::NameType,QLocale)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_NameType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // displayName(QDateTime,QTimeZone::NameType,QLocale)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[2])))) {
                overloadId = 1; // displayName(QDateTime,QTimeZone::NameType,QLocale)const
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_TimeType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // displayName(QTimeZone::TimeType,QTimeZone::NameType,QLocale)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_NameType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // displayName(QTimeZone::TimeType,QTimeZone::NameType,QLocale)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[2])))) {
                overloadId = 0; // displayName(QTimeZone::TimeType,QTimeZone::NameType,QLocale)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "displayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // displayName(QTimeZone::TimeType timeType, QTimeZone::NameType nameType, const QLocale &locale) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"nameType", 1}, {"locale", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_NameType_IDX])))->converter, (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "displayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
                }
            }
            ::QTimeZone::TimeType cppArg0{QTimeZone::StandardTime};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QTimeZone::NameType cppArg1(QTimeZone::NameType::DefaultName);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QLocale cppArg2_local = QLocale();
            ::QLocale *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // displayName(QTimeZone::TimeType,QTimeZone::NameType,QLocale)const
                QString cppResult = const_cast<const ::QTimeZone *>(cppSelf)->displayName(cppArg0, cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // displayName(const QDateTime &atDateTime, QTimeZone::NameType nameType, const QLocale &locale) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"nameType", 1}, {"locale", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_NameType_IDX])))->converter, (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "displayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QTimeZone::NameType cppArg1(QTimeZone::NameType::DefaultName);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QLocale cppArg2_local = QLocale();
            ::QLocale *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // displayName(QDateTime,QTimeZone::NameType,QLocale)const
                QString cppResult = const_cast<const ::QTimeZone *>(cppSelf)->displayName(*cppArg0, cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_fixedSecondsAheadOfUtc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fixedSecondsAheadOfUtc()const
        int cppResult = const_cast<const ::QTimeZone *>(cppSelf)->fixedSecondsAheadOfUtc();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_fromDurationAheadOfUtc(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTimeZone::fromDurationAheadOfUtc(std::chrono::seconds)->QTimeZone
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_std_chrono_seconds_IDX], (pyArg)))) {
        overloadId = 0; // fromDurationAheadOfUtc(std::chrono::seconds)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromDurationAheadOfUtc", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        std::chrono::seconds cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromDurationAheadOfUtc(std::chrono::seconds)
            QTimeZone cppResult = ::QTimeZone::fromDurationAheadOfUtc(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_fromSecondsAheadOfUtc(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTimeZone::fromSecondsAheadOfUtc(int)->QTimeZone
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // fromSecondsAheadOfUtc(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromSecondsAheadOfUtc", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromSecondsAheadOfUtc(int)
            QTimeZone cppResult = ::QTimeZone::fromSecondsAheadOfUtc(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_hasAlternativeName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::hasAlternativeName(QByteArrayView)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // hasAlternativeName(QByteArrayView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasAlternativeName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasAlternativeName(QByteArrayView)const
            bool cppResult = const_cast<const ::QTimeZone *>(cppSelf)->hasAlternativeName(QByteArrayView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_hasDaylightTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasDaylightTime()const
        bool cppResult = const_cast<const ::QTimeZone *>(cppSelf)->hasDaylightTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_hasTransitions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasTransitions()const
        bool cppResult = const_cast<const ::QTimeZone *>(cppSelf)->hasTransitions();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_ianaIdToWindowsId(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTimeZone::ianaIdToWindowsId(QByteArray)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // ianaIdToWindowsId(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ianaIdToWindowsId", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ianaIdToWindowsId(QByteArray)
            QByteArray cppResult = ::QTimeZone::ianaIdToWindowsId(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // id()const
        QByteArray cppResult = const_cast<const ::QTimeZone *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_isDaylightTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::isDaylightTime(QDateTime)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // isDaylightTime(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isDaylightTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isDaylightTime(QDateTime)const
            bool cppResult = const_cast<const ::QTimeZone *>(cppSelf)->isDaylightTime(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_isTimeZoneIdAvailable(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTimeZone::isTimeZoneIdAvailable(QByteArray)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // isTimeZoneIdAvailable(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isTimeZoneIdAvailable", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isTimeZoneIdAvailable(QByteArray)
            bool cppResult = ::QTimeZone::isTimeZoneIdAvailable(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_isUtcOrFixedOffset(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QTimeZone *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isUtcOrFixedOffset", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTimeZone::isUtcOrFixedOffset()const->bool
    // 1: static QTimeZone::isUtcOrFixedOffset(Qt::TimeSpec)->bool
    if (numArgs == 0) {
        overloadId = 0; // isUtcOrFixedOffset()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimeSpec_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // isUtcOrFixedOffset(Qt::TimeSpec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isUtcOrFixedOffset", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isUtcOrFixedOffset() const
        {

            // isUtcOrFixedOffset()const
            bool cppResult = const_cast<const ::QTimeZone *>(cppSelf)->isUtcOrFixedOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // isUtcOrFixedOffset(Qt::TimeSpec spec)
        {
            ::Qt::TimeSpec cppArg0{Qt::LocalTime};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isUtcOrFixedOffset(Qt::TimeSpec)
                bool cppResult = ::QTimeZone::isUtcOrFixedOffset(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTimeZone *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_nextTransition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::nextTransition(QDateTime)const->QTimeZone::OffsetData
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // nextTransition(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "nextTransition", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // nextTransition(QDateTime)const
            QTimeZone::OffsetData cppResult = const_cast<const ::QTimeZone *>(cppSelf)->nextTransition(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_OffsetData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_offsetData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::offsetData(QDateTime)const->QTimeZone::OffsetData
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // offsetData(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "offsetData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // offsetData(QDateTime)const
            QTimeZone::OffsetData cppResult = const_cast<const ::QTimeZone *>(cppSelf)->offsetData(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_OffsetData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_offsetFromUtc(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::offsetFromUtc(QDateTime)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // offsetFromUtc(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "offsetFromUtc", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // offsetFromUtc(QDateTime)const
            int cppResult = const_cast<const ::QTimeZone *>(cppSelf)->offsetFromUtc(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_previousTransition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::previousTransition(QDateTime)const->QTimeZone::OffsetData
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // previousTransition(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "previousTransition", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // previousTransition(QDateTime)const
            QTimeZone::OffsetData cppResult = const_cast<const ::QTimeZone *>(cppSelf)->previousTransition(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_OffsetData_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_standardTimeOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::standardTimeOffset(QDateTime)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // standardTimeOffset(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "standardTimeOffset", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // standardTimeOffset(QDateTime)const
            int cppResult = const_cast<const ::QTimeZone *>(cppSelf)->standardTimeOffset(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTimeZone::swap(QTimeZone&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QTimeZone&)
            cppSelf->swap(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTimeZoneFunc_systemTimeZone(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemTimeZone()
        QTimeZone cppResult = ::QTimeZone::systemTimeZone();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_systemTimeZoneId(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemTimeZoneId()
        QByteArray cppResult = ::QTimeZone::systemTimeZoneId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_territory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // territory()const
        QLocale::Country cppResult = const_cast<const ::QTimeZone *>(cppSelf)->territory();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_timeSpec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timeSpec()const
        Qt::TimeSpec cppResult = const_cast<const ::QTimeZone *>(cppSelf)->timeSpec();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimeSpec_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_transitions(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "transitions", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTimeZone::transitions(QDateTime,QDateTime)const->QList<QTimeZone::OffsetData>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // transitions(QDateTime,QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "transitions", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // transitions(QDateTime,QDateTime)const
            QList<QTimeZone::OffsetData> cppResult = const_cast<const ::QTimeZone *>(cppSelf)->transitions(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QTimeZone_OffsetData_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_utc(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // utc()
        QTimeZone cppResult = ::QTimeZone::utc();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_windowsIdToDefaultIanaId(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "windowsIdToDefaultIanaId", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTimeZone::windowsIdToDefaultIanaId(QByteArray)->QByteArray
    // 1: static QTimeZone::windowsIdToDefaultIanaId(QByteArray,QLocale::Country)->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // windowsIdToDefaultIanaId(QByteArray)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // windowsIdToDefaultIanaId(QByteArray,QLocale::Country)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "windowsIdToDefaultIanaId", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // windowsIdToDefaultIanaId(const QByteArray &windowsId)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // windowsIdToDefaultIanaId(QByteArray)
                QByteArray cppResult = ::QTimeZone::windowsIdToDefaultIanaId(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // windowsIdToDefaultIanaId(const QByteArray &windowsId, QLocale::Country territory)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QLocale::Country cppArg1{QLocale::AnyCountry};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // windowsIdToDefaultIanaId(QByteArray,QLocale::Country)
                QByteArray cppResult = ::QTimeZone::windowsIdToDefaultIanaId(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZoneFunc_windowsIdToIanaIds(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "windowsIdToIanaIds", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTimeZone::windowsIdToIanaIds(QByteArray)->QList<QByteArray>
    // 1: static QTimeZone::windowsIdToIanaIds(QByteArray,QLocale::Country)->QList<QByteArray>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // windowsIdToIanaIds(QByteArray)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // windowsIdToIanaIds(QByteArray,QLocale::Country)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "windowsIdToIanaIds", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // windowsIdToIanaIds(const QByteArray &windowsId)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // windowsIdToIanaIds(QByteArray)
                QList<QByteArray> cppResult = ::QTimeZone::windowsIdToIanaIds(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
            }
            break;
        }
        case 1: // windowsIdToIanaIds(const QByteArray &windowsId, QLocale::Country territory)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QLocale::Country cppArg1{QLocale::AnyCountry};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // windowsIdToIanaIds(QByteArray,QLocale::Country)
                QList<QByteArray> cppResult = ::QTimeZone::windowsIdToIanaIds(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTimeZone__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QTimeZoneMethod_isUtcOrFixedOffset = {"isUtcOrFixedOffset", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_isUtcOrFixedOffset), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QTimeZone_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTimeZone_EnumFlagInfo[] = {
    "Initialization:Enum",
    "NameType:Enum",
    "TimeType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTimeZone_methods[] = {
    {"abbreviation", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_abbreviation), METH_O, nullptr},
    {"asBackendZone", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_asBackendZone), METH_NOARGS, nullptr},
    {"availableTimeZoneIds", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_availableTimeZoneIds), METH_VARARGS|METH_STATIC, nullptr},
    {"comment", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_comment), METH_NOARGS, nullptr},
    {"country", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_country), METH_NOARGS, nullptr},
    {"daylightTimeOffset", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_daylightTimeOffset), METH_O, nullptr},
    {"displayName", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_displayName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fixedSecondsAheadOfUtc", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_fixedSecondsAheadOfUtc), METH_NOARGS, nullptr},
    {"fromDurationAheadOfUtc", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_fromDurationAheadOfUtc), METH_O|METH_STATIC, nullptr},
    {"fromSecondsAheadOfUtc", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_fromSecondsAheadOfUtc), METH_O|METH_STATIC, nullptr},
    {"hasAlternativeName", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_hasAlternativeName), METH_O, nullptr},
    {"hasDaylightTime", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_hasDaylightTime), METH_NOARGS, nullptr},
    {"hasTransitions", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_hasTransitions), METH_NOARGS, nullptr},
    {"ianaIdToWindowsId", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_ianaIdToWindowsId), METH_O|METH_STATIC, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_id), METH_NOARGS, nullptr},
    {"isDaylightTime", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_isDaylightTime), METH_O, nullptr},
    {"isTimeZoneIdAvailable", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_isTimeZoneIdAvailable), METH_O|METH_STATIC, nullptr},
    {"isUtcOrFixedOffset", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_isUtcOrFixedOffset), METH_VARARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_isValid), METH_NOARGS, nullptr},
    {"nextTransition", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_nextTransition), METH_O, nullptr},
    {"offsetData", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_offsetData), METH_O, nullptr},
    {"offsetFromUtc", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_offsetFromUtc), METH_O, nullptr},
    {"previousTransition", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_previousTransition), METH_O, nullptr},
    {"standardTimeOffset", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_standardTimeOffset), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_swap), METH_O, nullptr},
    {"systemTimeZone", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_systemTimeZone), METH_NOARGS|METH_STATIC, nullptr},
    {"systemTimeZoneId", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_systemTimeZoneId), METH_NOARGS|METH_STATIC, nullptr},
    {"territory", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_territory), METH_NOARGS, nullptr},
    {"timeSpec", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_timeSpec), METH_NOARGS, nullptr},
    {"transitions", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_transitions), METH_VARARGS, nullptr},
    {"utc", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_utc), METH_NOARGS|METH_STATIC, nullptr},
    {"windowsIdToDefaultIanaId", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_windowsIdToDefaultIanaId), METH_VARARGS|METH_STATIC, nullptr},
    {"windowsIdToIanaIds", reinterpret_cast<PyCFunction>(Sbk_QTimeZoneFunc_windowsIdToIanaIds), METH_VARARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTimeZone__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTimeZone_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QTimeZoneMethod_isUtcOrFixedOffset = {
        Sbk_QTimeZoneMethod_isUtcOrFixedOffset.ml_name,
        Sbk_QTimeZoneMethod_isUtcOrFixedOffset.ml_meth,
        Sbk_QTimeZoneMethod_isUtcOrFixedOffset.ml_flags & (~METH_STATIC),
        Sbk_QTimeZoneMethod_isUtcOrFixedOffset.ml_doc,
    };
    if (Shiboken::String::compare(name, "isUtcOrFixedOffset") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QTimeZoneMethod_isUtcOrFixedOffset, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject * Sbk_QTimeZone_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
                // operator!=(const QTimeZone &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTimeZone cppArg0_local;
                ::QTimeZone *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
                // operator==(const QTimeZone &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTimeZone cppArg0_local;
                ::QTimeZone *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTimeZone_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTimeZone_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QTimeZone__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTimeZone_Type = nullptr;
static PyTypeObject *Sbk_QTimeZone_TypeF(void)
{
    return _Sbk_QTimeZone_Type;
}

static PyType_Slot Sbk_QTimeZone_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QTimeZone__repr__)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QTimeZone_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTimeZone_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTimeZone_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTimeZone_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTimeZone_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTimeZone_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTimeZone_spec = {
    "2:PySide6.QtCore.QTimeZone",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTimeZone_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTimeZone_Initialization(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTimeZone::Initialization>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTimeZone::Initialization *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTimeZone_Initialization_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_Initialization_IDX])))
        return Enum_PythonToCpp_QTimeZone_Initialization;
    return {};
}

static PyObject *QTimeZone_Initialization_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTimeZone::Initialization>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTimeZone::Initialization *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_Initialization_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTimeZone_TimeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTimeZone::TimeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTimeZone::TimeType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTimeZone_TimeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_TimeType_IDX])))
        return Enum_PythonToCpp_QTimeZone_TimeType;
    return {};
}

static PyObject *QTimeZone_TimeType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTimeZone::TimeType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTimeZone::TimeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_TimeType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTimeZone_NameType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTimeZone::NameType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTimeZone::NameType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTimeZone_NameType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_NameType_IDX])))
        return Enum_PythonToCpp_QTimeZone_NameType;
    return {};
}

static PyObject *QTimeZone_NameType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTimeZone::NameType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTimeZone::NameType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_NameType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTimeZone_PythonToCpp_QTimeZone_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTimeZone_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTimeZone_PythonToCpp_QTimeZone_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTimeZone_TypeF()))
        return QTimeZone_PythonToCpp_QTimeZone_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTimeZone_PTR_CppToPython_QTimeZone(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTimeZone_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTimeZone_COPY_CppToPython_QTimeZone(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTimeZone *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTimeZone_TypeF(), new ::QTimeZone(*source), true, true);
}

// Python to C++ copy conversion.
static void QTimeZone_PythonToCpp_QTimeZone_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTimeZone *>(cppOut) = *reinterpret_cast< ::QTimeZone *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTimeZone_PythonToCpp_QTimeZone_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTimeZone_TypeF()))
        return QTimeZone_PythonToCpp_QTimeZone_COPY;
    return {};
}

// Implicit conversions.
static void QTimeZone_Initialization_PythonToCpp_QTimeZone(PyObject *pyIn, void *cppOut)
{
    ::QTimeZone::Initialization cppIn{QTimeZone::LocalTime};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_Initialization_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QTimeZone *>(cppOut) = ::QTimeZone(cppIn);
}
static PythonToCppFunc is_QTimeZone_Initialization_PythonToCpp_QTimeZone_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_Initialization_IDX]), pyIn))
        return QTimeZone_Initialization_PythonToCpp_QTimeZone;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTimeZone_SignatureStrings[] = {
    "5:PySide6.QtCore.QTimeZone(self)",
    "4:PySide6.QtCore.QTimeZone(self,spec:PySide6.QtCore.QTimeZone.Initialization)",
    "3:PySide6.QtCore.QTimeZone(self,ianaId:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "2:PySide6.QtCore.QTimeZone(self,zoneId:typing.Union[PySide6.QtCore.QByteArray, char*],offsetSeconds:int,name:QString,abbreviation:QString,territory:PySide6.QtCore.QLocale.Country=QLocale.AnyTerritory,comment:QString=QString())",
    "1:PySide6.QtCore.QTimeZone(self,other:PySide6.QtCore.QTimeZone)",
    "0:PySide6.QtCore.QTimeZone(self,offsetSeconds:int)",
    "PySide6.QtCore.QTimeZone.abbreviation(self,atDateTime:PySide6.QtCore.QDateTime)->QString",
    "PySide6.QtCore.QTimeZone.asBackendZone(self)->PySide6.QtCore.QTimeZone",
    "2:PySide6.QtCore.QTimeZone.availableTimeZoneIds()->QList[PySide6.QtCore.QByteArray]",
    "1:PySide6.QtCore.QTimeZone.availableTimeZoneIds(territory:PySide6.QtCore.QLocale.Country)->QList[PySide6.QtCore.QByteArray]",
    "0:PySide6.QtCore.QTimeZone.availableTimeZoneIds(offsetSeconds:int)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtCore.QTimeZone.comment(self)->QString",
    "PySide6.QtCore.QTimeZone.country(self)->PySide6.QtCore.QLocale.Country",
    "PySide6.QtCore.QTimeZone.daylightTimeOffset(self,atDateTime:PySide6.QtCore.QDateTime)->int",
    "1:PySide6.QtCore.QTimeZone.displayName(self,timeType:PySide6.QtCore.QTimeZone.TimeType,nameType:PySide6.QtCore.QTimeZone.NameType=QTimeZone.NameType.DefaultName,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language]=QLocale())->QString",
    "0:PySide6.QtCore.QTimeZone.displayName(self,atDateTime:PySide6.QtCore.QDateTime,nameType:PySide6.QtCore.QTimeZone.NameType=QTimeZone.NameType.DefaultName,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language]=QLocale())->QString",
    "PySide6.QtCore.QTimeZone.fixedSecondsAheadOfUtc(self)->int",
    "PySide6.QtCore.QTimeZone.fromDurationAheadOfUtc(offset:std.chrono.seconds)->PySide6.QtCore.QTimeZone",
    "PySide6.QtCore.QTimeZone.fromSecondsAheadOfUtc(offset:int)->PySide6.QtCore.QTimeZone",
    "PySide6.QtCore.QTimeZone.hasAlternativeName(self,alias:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtCore.QTimeZone.hasDaylightTime(self)->bool",
    "PySide6.QtCore.QTimeZone.hasTransitions(self)->bool",
    "PySide6.QtCore.QTimeZone.ianaIdToWindowsId(ianaId:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QTimeZone.id(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QTimeZone.isDaylightTime(self,atDateTime:PySide6.QtCore.QDateTime)->bool",
    "PySide6.QtCore.QTimeZone.isTimeZoneIdAvailable(ianaId:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "1:PySide6.QtCore.QTimeZone.isUtcOrFixedOffset(self)->bool",
    "0:PySide6.QtCore.QTimeZone.isUtcOrFixedOffset(spec:PySide6.QtCore.Qt.TimeSpec)->bool",
    "PySide6.QtCore.QTimeZone.isValid(self)->bool",
    "PySide6.QtCore.QTimeZone.nextTransition(self,afterDateTime:PySide6.QtCore.QDateTime)->PySide6.QtCore.QTimeZone.OffsetData",
    "PySide6.QtCore.QTimeZone.offsetData(self,forDateTime:PySide6.QtCore.QDateTime)->PySide6.QtCore.QTimeZone.OffsetData",
    "PySide6.QtCore.QTimeZone.offsetFromUtc(self,atDateTime:PySide6.QtCore.QDateTime)->int",
    "PySide6.QtCore.QTimeZone.previousTransition(self,beforeDateTime:PySide6.QtCore.QDateTime)->PySide6.QtCore.QTimeZone.OffsetData",
    "PySide6.QtCore.QTimeZone.standardTimeOffset(self,atDateTime:PySide6.QtCore.QDateTime)->int",
    "PySide6.QtCore.QTimeZone.swap(self,other:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "PySide6.QtCore.QTimeZone.systemTimeZone()->PySide6.QtCore.QTimeZone",
    "PySide6.QtCore.QTimeZone.systemTimeZoneId()->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QTimeZone.territory(self)->PySide6.QtCore.QLocale.Country",
    "PySide6.QtCore.QTimeZone.timeSpec(self)->PySide6.QtCore.Qt.TimeSpec",
    "PySide6.QtCore.QTimeZone.transitions(self,fromDateTime:PySide6.QtCore.QDateTime,toDateTime:PySide6.QtCore.QDateTime)->QList[PySide6.QtCore.QTimeZone.OffsetData]",
    "PySide6.QtCore.QTimeZone.utc()->PySide6.QtCore.QTimeZone",
    "1:PySide6.QtCore.QTimeZone.windowsIdToDefaultIanaId(windowsId:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QTimeZone.windowsIdToDefaultIanaId(windowsId:typing.Union[PySide6.QtCore.QByteArray, char*],territory:PySide6.QtCore.QLocale.Country)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QTimeZone.windowsIdToIanaIds(windowsId:typing.Union[PySide6.QtCore.QByteArray, char*])->QList[PySide6.QtCore.QByteArray]",
    "0:PySide6.QtCore.QTimeZone.windowsIdToIanaIds(windowsId:typing.Union[PySide6.QtCore.QByteArray, char*],territory:PySide6.QtCore.QLocale.Country)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtCore.QTimeZone.__copy__(self)->typing.Self",
    "PySide6.QtCore.QTimeZone.__ne__(self,rhs:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->bool",
    "PySide6.QtCore.QTimeZone.__eq__(self,rhs:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTimeZone_SignatureByteSize = 812;
static constexpr uint8_t QTimeZone_SignatureBytes[812] = {
    0x78, 0xda, 0xd5, 0x57, 0x5b, 0x6f, 0xda, 0x30, 0x14, 0x7e, 0xe7, 0x57, 0xf4, 0x91, 0x4c, 0x69,
    0xc4, 0xae, 0x0f, 0x48, 0xad, 0x44, 0x8b, 0x2a, 0x21, 0x55, 0xed, 0x2a, 0xe8, 0x26, 0x6d, 0x42,
    0xe8, 0x10, 0x9f, 0x80, 0xb5, 0x60, 0x33, 0xdb, 0xb4, 0x4d, 0x7f, 0x7d, 0x9d, 0x8b, 0x81, 0x12,
    0xec, 0x24, 0x94, 0x55, 0xda, 0x13, 0xc4, 0x3e, 0xf7, 0xcb, 0x77, 0x8e, 0xbf, 0x76, 0xbf, 0x27,
    0x43, 0x4a, 0xf0, 0x5b, 0x70, 0xa7, 0x2e, 0xb9, 0xc0, 0xe0, 0x6e, 0x44, 0x17, 0xf8, 0x8b, 0x33,
    0x6c, 0x4b, 0x8c, 0x23, 0xaf, 0xf5, 0xc5, 0x4d, 0xe0, 0xcb, 0x25, 0x86, 0x56, 0x92, 0x60, 0xc0,
    0xa8, 0xa2, 0x10, 0xd3, 0x67, 0x50, 0x94, 0x33, 0xaf, 0xf5, 0xb9, 0x42, 0x1a, 0x05, 0x06, 0x03,
    0xd2, 0x55, 0xc9, 0x92, 0xb2, 0x59, 0x70, 0xcf, 0x34, 0xd3, 0xef, 0x5d, 0x8e, 0x8b, 0x44, 0x61,
    0x4f, 0x08, 0x48, 0xfc, 0x93, 0x70, 0x0e, 0xe2, 0xc3, 0xd8, 0x6b, 0x7d, 0xaa, 0x10, 0xfb, 0xac,
    0xff, 0x35, 0x16, 0xeb, 0xf3, 0x28, 0x92, 0xa8, 0x86, 0x18, 0x72, 0x46, 0x64, 0x97, 0x32, 0xe5,
    0x33, 0x58, 0x60, 0xf7, 0x6e, 0xa8, 0x84, 0x16, 0xe3, 0xc3, 0x74, 0x2a, 0xf0, 0x81, 0x66, 0x9e,
    0xad, 0x0f, 0x15, 0x0a, 0x41, 0x15, 0x17, 0x49, 0xc9, 0xa2, 0x6b, 0x1e, 0x42, 0x8c, 0xc1, 0x25,
    0x5f, 0x31, 0x25, 0x92, 0x33, 0xf3, 0xdd, 0x63, 0xc9, 0xc8, 0xf0, 0xf8, 0x21, 0x5f, 0x2c, 0x90,
    0x29, 0x23, 0xed, 0xac, 0xf8, 0x6d, 0x7b, 0x5e, 0xeb, 0x63, 0x85, 0x8b, 0x5c, 0xcd, 0x51, 0x58,
    0x69, 0xbc, 0x56, 0xa7, 0x8a, 0x7f, 0xd7, 0x59, 0xaf, 0x65, 0xcd, 0xea, 0xb6, 0xe7, 0x39, 0x37,
    0xa8, 0x3e, 0x28, 0x4c, 0x09, 0x4a, 0x6a, 0xcc, 0x85, 0x77, 0x7a, 0x5e, 0xb8, 0xe3, 0x10, 0x2c,
    0x2f, 0x20, 0xfc, 0x83, 0x8c, 0x6c, 0x0a, 0xf0, 0xf4, 0xdc, 0x46, 0xed, 0xc8, 0x7a, 0x00, 0x0f,
    0x40, 0x63, 0x98, 0xc6, 0x68, 0x4e, 0x06, 0x44, 0xb6, 0x53, 0x0b, 0xae, 0xa9, 0x54, 0xf6, 0xd4,
    0x8f, 0x1d, 0x61, 0xde, 0x2f, 0xb3, 0x6e, 0xbe, 0xeb, 0xe8, 0xee, 0x34, 0xd4, 0x5d, 0x4e, 0x59,
    0x0d, 0x25, 0x56, 0x15, 0x45, 0xed, 0x99, 0xa8, 0x57, 0xe6, 0x2a, 0xcc, 0x1d, 0xb3, 0x65, 0xe9,
    0xb5, 0xfb, 0x76, 0x31, 0x04, 0x92, 0x98, 0xce, 0xe6, 0x2a, 0x3d, 0xb8, 0xcd, 0x1c, 0x6a, 0x52,
    0x51, 0xda, 0x69, 0x57, 0xca, 0x08, 0x95, 0xcb, 0x18, 0x92, 0x1b, 0xdd, 0xb6, 0xb9, 0x54, 0xa5,
    0x6f, 0x46, 0xc9, 0x12, 0xed, 0x2c, 0xa3, 0x82, 0x22, 0xeb, 0x75, 0x37, 0xe9, 0x4d, 0x41, 0x71,
    0x56, 0x3e, 0x0a, 0xfa, 0x18, 0xc1, 0x2a, 0x56, 0xe9, 0xb7, 0x1f, 0x67, 0xa1, 0x70, 0xa3, 0x4f,
    0x1e, 0x2e, 0xff, 0xc4, 0x12, 0xc6, 0x6b, 0x60, 0xb3, 0x15, 0xcc, 0x70, 0x6c, 0x70, 0x43, 0x43,
    0xc2, 0x26, 0x47, 0x9d, 0x06, 0x11, 0xa8, 0x11, 0xd7, 0xff, 0xc9, 0x75, 0xab, 0x85, 0x11, 0x7d,
    0x42, 0x52, 0xf4, 0x46, 0x6f, 0x8e, 0x40, 0x6e, 0xa3, 0x7b, 0x15, 0x9a, 0x6a, 0x4d, 0xeb, 0xc6,
    0xce, 0x2a, 0xf8, 0xa2, 0xbf, 0x12, 0x19, 0xbc, 0x6d, 0xb1, 0xe6, 0xed, 0xd6, 0x95, 0x8a, 0x04,
    0xe1, 0x5c, 0x70, 0xc6, 0x03, 0x99, 0x8b, 0x77, 0x61, 0x94, 0x53, 0x49, 0xd9, 0xbc, 0x42, 0x47,
    0xde, 0xcb, 0xcd, 0x85, 0xce, 0x41, 0xf6, 0x62, 0x0d, 0x49, 0x4c, 0xdb, 0xfe, 0x80, 0x5b, 0x49,
    0x8f, 0x29, 0xc8, 0xa6, 0x53, 0xf5, 0xf4, 0x7c, 0xca, 0x79, 0xec, 0x54, 0xd6, 0xdf, 0x6a, 0x5e,
    0x13, 0xda, 0x4a, 0xa6, 0x91, 0x00, 0x26, 0x69, 0x1a, 0x5c, 0x59, 0x8f, 0x27, 0x5f, 0x0a, 0x46,
    0xfc, 0x27, 0x65, 0x84, 0x3f, 0xca, 0x01, 0x69, 0x1f, 0xb6, 0x26, 0x94, 0x23, 0xba, 0xa6, 0x71,
    0x28, 0x27, 0x36, 0x84, 0xab, 0xc3, 0x5c, 0x8e, 0x50, 0x4d, 0x60, 0xab, 0x88, 0x88, 0xdc, 0xcc,
    0x81, 0x9e, 0x19, 0x0d, 0x07, 0x47, 0x25, 0xd3, 0xe5, 0x40, 0x51, 0x2a, 0x75, 0x69, 0xde, 0x8a,
    0xab, 0xb4, 0xa3, 0xb6, 0x20, 0xda, 0x70, 0x76, 0x9a, 0x71, 0xee, 0xdb, 0x17, 0x55, 0x06, 0xbb,
    0x43, 0x7d, 0x55, 0xc3, 0xf5, 0x1f, 0xba, 0x9a, 0x49, 0xbd, 0xca, 0x61, 0xf8, 0xa4, 0x36, 0xe5,
    0x56, 0xc4, 0x3f, 0xd2, 0x0d, 0x52, 0x27, 0x05, 0x56, 0xa9, 0xb9, 0x27, 0x9a, 0x12, 0xec, 0x9a,
    0xf9, 0x9a, 0x26, 0xd7, 0x1a, 0xf1, 0xf7, 0xd2, 0x79, 0xa5, 0x81, 0xc5, 0x20, 0x5d, 0x83, 0x29,
    0x6a, 0x95, 0xba, 0x4c, 0x57, 0x3d, 0xbe, 0x92, 0xbb, 0x71, 0x9c, 0xa2, 0xf6, 0x09, 0xff, 0xb9,
    0x53, 0x52, 0x01, 0x23, 0x20, 0xc8, 0xe1, 0xfb, 0x81, 0x5d, 0xf4, 0x23, 0x2c, 0xb7, 0x97, 0x67,
    0x67, 0xe3, 0x18, 0xae, 0xf2, 0x9c, 0xb2, 0x3c, 0x76, 0xc6, 0x8e, 0x05, 0x5a, 0x26, 0x52, 0xe1,
    0x62, 0xbd, 0x80, 0x1f, 0x84, 0xf5, 0xaf, 0x65, 0x68, 0x50, 0x3c, 0x0c, 0xa2, 0xd6, 0x0b, 0xec,
    0x5b, 0x17, 0x39, 0x55, 0x74, 0xb0, 0x4d, 0xce, 0xa6, 0xc7, 0x1d, 0x32, 0x76, 0x46, 0x83, 0x9f,
    0x8d, 0xe2, 0xca, 0x7d, 0x45, 0xf1, 0x5a, 0xaf, 0x8f, 0xbd, 0xab, 0xf1, 0x9e, 0x62, 0x74, 0x2c,
    0xc9, 0x2b, 0xdd, 0x58, 0xae, 0x6c, 0x39, 0x50, 0xf4, 0xd1, 0x4c, 0xaf, 0x11, 0x2f, 0x36, 0xa4,
    0x41, 0x86, 0xd7, 0xed, 0xf5, 0xc5, 0x31, 0xe7, 0x59, 0xe7, 0x1d, 0x0d, 0xf1, 0x1b, 0x3c, 0x82,
    0xec, 0x16, 0xd7, 0x0b, 0x5d, 0x6e, 0xaa, 0x7c, 0x4b, 0xd0, 0xde, 0xf2, 0x0e, 0x3b, 0xa2, 0x25,
    0xfe, 0x31, 0x9f, 0x8e, 0x56, 0x83, 0x27, 0x93, 0x90, 0x2f, 0x93, 0xc9, 0xc4, 0x74, 0x65, 0x61,
    0xe3, 0x50, 0x7f, 0xb9, 0x98, 0x18, 0x16, 0x2c, 0xbe, 0x98, 0xcb, 0xa3, 0x03, 0x63, 0xd5, 0xd8,
    0x9e, 0x4c, 0xf0, 0xef, 0x3b, 0xe8, 0x7f, 0x01, 0xcc, 0x65, 0xcc, 0xca
};
#endif

PyTypeObject *init_QTimeZone(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX].type;

    Shiboken::AutoDecRef Sbk_QTimeZone_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTimeZone_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTimeZone",
        "QTimeZone",
        &Sbk_QTimeZone_spec,
        &Shiboken::callCppDestructor< ::QTimeZone >,
        Sbk_QTimeZone_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTimeZone_TypeF(); // references _Sbk_QTimeZone_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTimeZone_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTimeZone_SignatureBytes, QTimeZone_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTimeZone_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTimeZone_PythonToCpp_QTimeZone_PTR,
        is_QTimeZone_PythonToCpp_QTimeZone_PTR_Convertible,
        QTimeZone_PTR_CppToPython_QTimeZone,
        QTimeZone_COPY_CppToPython_QTimeZone);

    Shiboken::Conversions::registerConverterName(converter, "QTimeZone");
    Shiboken::Conversions::registerConverterName(converter, "QTimeZone*");
    Shiboken::Conversions::registerConverterName(converter, "QTimeZone&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTimeZone).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTimeZone_PythonToCpp_QTimeZone_COPY,
        is_QTimeZone_PythonToCpp_QTimeZone_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTimeZone_Initialization_PythonToCpp_QTimeZone,
        is_QTimeZone_Initialization_PythonToCpp_QTimeZone_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTimeZone_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Initialization'.
    const char *Initialization_Initializer[] = {
        "LocalTime",
        "UTC",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Initialization_InitializerValues[] = {
        uint8_t(QTimeZone::Initialization::LocalTime), //  0x00  0
        uint8_t(QTimeZone::Initialization::UTC)        //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTimeZone_TypeF(),
        "2:PySide6.QtCore.QTimeZone.Initialization",
        Initialization_Initializer, Initialization_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_Initialization_IDX].type = EType;
    // Register converter for enum 'QTimeZone::Initialization'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTimeZone_Initialization_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTimeZone_Initialization,
            is_Enum_PythonToCpp_QTimeZone_Initialization_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTimeZone::Initialization");
        Shiboken::Conversions::registerConverterAlias(converter, "Initialization");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Initialization' enum.

    // Initialization of enum 'TimeType'.
    const char *TimeType_Initializer[] = {
        "StandardTime",
        "DaylightTime",
        "GenericTime",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TimeType_InitializerValues[] = {
        uint8_t(QTimeZone::TimeType::StandardTime), //  0x00  0
        uint8_t(QTimeZone::TimeType::DaylightTime), //  0x01  1
        uint8_t(QTimeZone::TimeType::GenericTime)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTimeZone_TypeF(),
        "2:PySide6.QtCore.QTimeZone.TimeType",
        TimeType_Initializer, TimeType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_TimeType_IDX].type = EType;
    // Register converter for enum 'QTimeZone::TimeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTimeZone_TimeType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTimeZone_TimeType,
            is_Enum_PythonToCpp_QTimeZone_TimeType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTimeZone::TimeType");
        Shiboken::Conversions::registerConverterAlias(converter, "TimeType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TimeType' enum.

    // Initialization of enum 'NameType'.
    const char *NameType_Initializer[] = {
        "DefaultName",
        "LongName",
        "ShortName",
        "OffsetName",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NameType_InitializerValues[] = {
        uint8_t(QTimeZone::NameType::DefaultName), //  0x00  0
        uint8_t(QTimeZone::NameType::LongName),    //  0x01  1
        uint8_t(QTimeZone::NameType::ShortName),   //  0x02  2
        uint8_t(QTimeZone::NameType::OffsetName)   //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTimeZone_TypeF(),
        "2:PySide6.QtCore.QTimeZone.NameType",
        NameType_Initializer, NameType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_NameType_IDX].type = EType;
    // Register converter for enum 'QTimeZone::NameType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTimeZone_NameType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTimeZone_NameType,
            is_Enum_PythonToCpp_QTimeZone_NameType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTimeZone::NameType");
        Shiboken::Conversions::registerConverterAlias(converter, "NameType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'NameType' enum.

    qRegisterMetaType< ::QTimeZone >("QTimeZone");
    qRegisterMetaType< ::QTimeZone::Initialization >("QTimeZone::Initialization");
    qRegisterMetaType< ::QTimeZone::TimeType >("QTimeZone::TimeType");
    qRegisterMetaType< ::QTimeZone::NameType >("QTimeZone::NameType");

    return pyType;
}

PyTypeObject *init_QTimeZoneStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QTimeZone");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "MinUtcOffsetSecs",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QTimeZone::MinUtcOffsetSecs));
    PyDict_SetItemString(dict, "MaxUtcOffsetSecs",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QTimeZone::MaxUtcOffsetSecs));
    return type;
}
