// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qvariantanimation_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qabstractanimation_wrapper.h"
#include "qtranslator_wrapper.h"

// Argument includes
#include <QList>
#include <qabstractanimation.h>
#include <qcoreevent.h>
#include <qeasingcurve.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QVariantAnimationWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QVariantAnimationWrapper::QVariantAnimationWrapper(::QObject * parent) : QVariantAnimation(parent)
{
}

void QVariantAnimationWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QVariantAnimation", funcName, gil, pyOverride, event);
}

void QVariantAnimationWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QVariantAnimation", funcName, gil, pyOverride, signal);
}

void QVariantAnimationWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QVariantAnimation", funcName, gil, pyOverride, event);
}

void QVariantAnimationWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QVariantAnimation", funcName, gil, pyOverride, signal);
}

int QVariantAnimationWrapper::duration() const
{
    // This method belongs to a property.
    static const char *funcName = "1:duration";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QVariantAnimation::duration();
    }
    return QAbstractAnimationWrapper::sbk_o_duration("QVariantAnimation", funcName, gil, pyOverride);
}

bool QVariantAnimationWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QVariantAnimation::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QVariantAnimation", funcName, gil, pyOverride, event);
}

bool QVariantAnimationWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QVariantAnimation", funcName, gil, pyOverride, watched, event);
}

::QVariant QVariantAnimationWrapper::interpolated(const ::QVariant & from, const ::QVariant & to, qreal progress) const
{
    static const char *funcName = "interpolated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QVariantAnimation::interpolated(from, to, progress);
    }
    return sbk_o_interpolated("QVariantAnimation", funcName, gil, pyOverride, from, to, progress);
}

::QVariant QVariantAnimationWrapper::sbk_o_interpolated(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & from, const ::QVariant & to, qreal progress)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &from),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &to),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &progress)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNd)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &from),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &to),
        progress
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QVariantAnimationWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QVariantAnimation", funcName, gil, pyOverride, event);
}

void QVariantAnimationWrapper::updateCurrentTime(int arg__1)
{
    static const char *funcName = "updateCurrentTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QVariantAnimation::updateCurrentTime(arg__1);
    }
    QAbstractAnimationWrapper::sbk_o_updateCurrentTime("QVariantAnimation", funcName, gil, pyOverride, arg__1);
}

void QVariantAnimationWrapper::updateCurrentValue(const ::QVariant & value)
{
    static const char *funcName = "updateCurrentValue";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QVariantAnimation::updateCurrentValue(value);
    }
    sbk_o_updateCurrentValue("QVariantAnimation", funcName, gil, pyOverride, value);
}

void QVariantAnimationWrapper::sbk_o_updateCurrentValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & value)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QVariantAnimationWrapper::updateDirection(::QAbstractAnimation::Direction direction)
{
    static const char *funcName = "updateDirection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractAnimation::updateDirection(direction);
    }
    QAbstractAnimationWrapper::sbk_o_updateDirection("QVariantAnimation", funcName, gil, pyOverride, direction);
}

void QVariantAnimationWrapper::updateState(::QAbstractAnimation::State newState, ::QAbstractAnimation::State oldState)
{
    static const char *funcName = "updateState";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QVariantAnimation::updateState(newState, oldState);
    }
    QAbstractAnimationWrapper::sbk_o_updateState("QVariantAnimation", funcName, gil, pyOverride, newState, oldState);
}

const QMetaObject *QVariantAnimationWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QVariantAnimation::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QVariantAnimationWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QVariantAnimation::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QVariantAnimationWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QVariantAnimationWrapper *>(this));
    return QVariantAnimation::qt_metacast(_clname);
}

QVariantAnimationWrapper::~QVariantAnimationWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVariantAnimation_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVariantAnimation >()))
        return -1;

    QVariantAnimationWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QVariantAnimation", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QVariantAnimation::QVariantAnimation(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QVariantAnimation(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QVariantAnimation(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QVariantAnimation(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QVariantAnimationWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QVariantAnimationWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QVariantAnimation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QVariantAnimationFunc_currentValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentValue()const
        QVariant cppResult = const_cast<const ::QVariantAnimation *>(cppSelf)->currentValue();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_duration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // duration()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QVariantAnimation *>(cppSelf)->::QVariantAnimation::duration()
            : const_cast<const ::QVariantAnimation *>(cppSelf)->duration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_easingCurve(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // easingCurve()const
        QEasingCurve cppResult = const_cast<const ::QVariantAnimation *>(cppSelf)->easingCurve();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_endValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endValue()const
        QVariant cppResult = const_cast<const ::QVariantAnimation *>(cppSelf)->endValue();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QVariantAnimation::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_interpolated(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "interpolated", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QVariantAnimation::interpolated(QVariant,QVariant,qreal)const->QVariant
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
        overloadId = 0; // interpolated(QVariant,QVariant,qreal)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "interpolated", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        qreal cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interpolated(QVariant,QVariant,qreal)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QVariantAnimation *>(cppSelf)->::QVariantAnimation::interpolated(cppArg0, cppArg1, cppArg2)
                : const_cast<const ::QVariantAnimation *>(cppSelf)->interpolated(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_keyValueAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVariantAnimation::keyValueAt(qreal)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // keyValueAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyValueAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyValueAt(qreal)const
            QVariant cppResult = const_cast<const ::QVariantAnimation *>(cppSelf)->keyValueAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_keyValues(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyValues()const
        QList<std::pair<double,QVariant>> cppResult = const_cast<const ::QVariantAnimation *>(cppSelf)->keyValues();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_double_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_setDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVariantAnimation::setDuration(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDuration(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDuration", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDuration(int)
            cppSelf->setDuration(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_setEasingCurve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVariantAnimation::setEasingCurve(QEasingCurve)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArg)))) {
        overloadId = 0; // setEasingCurve(QEasingCurve)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEasingCurve", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEasingCurve cppArg0_local;
        ::QEasingCurve *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setEasingCurve(QEasingCurve)
            cppSelf->setEasingCurve(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_setEndValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVariantAnimation::setEndValue(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setEndValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEndValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEndValue(QVariant)
            cppSelf->setEndValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_setKeyValueAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setKeyValueAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QVariantAnimation::setKeyValueAt(qreal,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setKeyValueAt(qreal,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setKeyValueAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeyValueAt(qreal,QVariant)
            cppSelf->setKeyValueAt(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_setKeyValues(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVariantAnimation::setKeyValues(QList<std::pair<double,QVariant>>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_double_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setKeyValues(QList<std::pair<double,QVariant>>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeyValues", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        ::QList<std::pair<double,QVariant>> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeyValues(QList<std::pair<double,QVariant>>)
            cppSelf->setKeyValues(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_setStartValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVariantAnimation::setStartValue(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setStartValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartValue(QVariant)
            cppSelf->setStartValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_startValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startValue()const
        QVariant cppResult = const_cast<const ::QVariantAnimation *>(cppSelf)->startValue();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QVariantAnimationFunc_updateCurrentTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractAnimation::updateCurrentTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // updateCurrentTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateCurrentTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateCurrentTime(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QVariantAnimation::updateCurrentTime(cppArg0)
                : cppSelf->updateCurrentTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_updateCurrentValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVariantAnimation::updateCurrentValue(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // updateCurrentValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateCurrentValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateCurrentValue(QVariant)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QVariantAnimation::updateCurrentValue(cppArg0)
                : cppSelf->updateCurrentValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QVariantAnimationFunc_updateState(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateState", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractAnimation::updateState(QAbstractAnimation::State,QAbstractAnimation::State)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_State_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_State_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // updateState(QAbstractAnimation::State,QAbstractAnimation::State)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateState", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]);

    // Call function/method
    {
        ::QAbstractAnimation::State cppArg0{QAbstractAnimation::Stopped};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QAbstractAnimation::State cppArg1{QAbstractAnimation::Stopped};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateState(QAbstractAnimation::State,QAbstractAnimation::State)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QVariantAnimation::updateState(cppArg0, cppArg1)
                : cppSelf->updateState(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QVariantAnimation_PropertyStrings[] = {
    "currentValue:",
    "duration::",
    "easingCurve::",
    "endValue::",
    "startValue::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVariantAnimation_methods[] = {
    {"currentValue", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_currentValue), METH_NOARGS, nullptr},
    {"duration", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_duration), METH_NOARGS, nullptr},
    {"easingCurve", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_easingCurve), METH_NOARGS, nullptr},
    {"endValue", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_endValue), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_event), METH_O, nullptr},
    {"interpolated", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_interpolated), METH_VARARGS, nullptr},
    {"keyValueAt", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_keyValueAt), METH_O, nullptr},
    {"keyValues", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_keyValues), METH_NOARGS, nullptr},
    {"setDuration", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_setDuration), METH_O, nullptr},
    {"setEasingCurve", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_setEasingCurve), METH_O, nullptr},
    {"setEndValue", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_setEndValue), METH_O, nullptr},
    {"setKeyValueAt", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_setKeyValueAt), METH_VARARGS, nullptr},
    {"setKeyValues", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_setKeyValues), METH_O, nullptr},
    {"setStartValue", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_setStartValue), METH_O, nullptr},
    {"startValue", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_startValue), METH_NOARGS, nullptr},
    {"updateCurrentTime", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_updateCurrentTime), METH_O, nullptr},
    {"updateCurrentValue", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_updateCurrentValue), METH_O, nullptr},
    {"updateState", reinterpret_cast<PyCFunction>(Sbk_QVariantAnimationFunc_updateState), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QVariantAnimation_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QVariantAnimation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QVariantAnimationWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QVariantAnimation_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVariantAnimation_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVariantAnimation_Type = nullptr;
static PyTypeObject *Sbk_QVariantAnimation_TypeF(void)
{
    return _Sbk_QVariantAnimation_Type;
}

static PyType_Slot Sbk_QVariantAnimation_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QVariantAnimation_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVariantAnimation_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVariantAnimation_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVariantAnimation_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVariantAnimation_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVariantAnimation_spec = {
    "2:PySide6.QtCore.QVariantAnimation",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVariantAnimation_slots
};

} //extern "C"

static void *Sbk_QVariantAnimation_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QVariantAnimation *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QVariantAnimation_PythonToCpp_QVariantAnimation_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVariantAnimation_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QVariantAnimation_PythonToCpp_QVariantAnimation_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVariantAnimation_TypeF()))
        return QVariantAnimation_PythonToCpp_QVariantAnimation_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QVariantAnimation_PTR_CppToPython_QVariantAnimation(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QVariantAnimation *>(const_cast<void *>(cppIn)), Sbk_QVariantAnimation_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QVariantAnimation_SignatureStrings[] = {
    "PySide6.QtCore.QVariantAnimation(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,startValue:QVariant=None,endValue:QVariant=None,currentValue:QVariant=None,duration:int=None,easingCurve:QEasingCurve=None)",
    "PySide6.QtCore.QVariantAnimation.currentValue(self)->QVariant",
    "PySide6.QtCore.QVariantAnimation.duration(self)->int",
    "PySide6.QtCore.QVariantAnimation.easingCurve(self)->PySide6.QtCore.QEasingCurve",
    "PySide6.QtCore.QVariantAnimation.endValue(self)->QVariant",
    "PySide6.QtCore.QVariantAnimation.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QVariantAnimation.interpolated(self,from:QVariant,to:QVariant,progress:qreal)->QVariant",
    "PySide6.QtCore.QVariantAnimation.keyValueAt(self,step:qreal)->QVariant",
    "PySide6.QtCore.QVariantAnimation.keyValues(self)->QList[std.pair[double, QVariant]]",
    "PySide6.QtCore.QVariantAnimation.setDuration(self,msecs:int)",
    "PySide6.QtCore.QVariantAnimation.setEasingCurve(self,easing:typing.Union[PySide6.QtCore.QEasingCurve, PySide6.QtCore.QEasingCurve.Type])",
    "PySide6.QtCore.QVariantAnimation.setEndValue(self,value:QVariant)",
    "PySide6.QtCore.QVariantAnimation.setKeyValueAt(self,step:qreal,value:QVariant)",
    "PySide6.QtCore.QVariantAnimation.setKeyValues(self,values:QList[std.pair[double, QVariant]])",
    "PySide6.QtCore.QVariantAnimation.setStartValue(self,value:QVariant)",
    "PySide6.QtCore.QVariantAnimation.startValue(self)->QVariant",
    "PySide6.QtCore.QVariantAnimation.updateCurrentTime(self,arg__1:int)",
    "PySide6.QtCore.QVariantAnimation.updateCurrentValue(self,value:QVariant)",
    "PySide6.QtCore.QVariantAnimation.updateState(self,newState:PySide6.QtCore.QAbstractAnimation.State,oldState:PySide6.QtCore.QAbstractAnimation.State)",
    nullptr}; // Sentinel
#else
static constexpr size_t QVariantAnimation_SignatureByteSize = 401;
static constexpr uint8_t QVariantAnimation_SignatureBytes[401] = {
    0x78, 0xda, 0xa5, 0x54, 0xcb, 0x6e, 0xc2, 0x30, 0x10, 0xbc, 0xf3, 0x15, 0x1c, 0x4b, 0xe5, 0x46,
    0xea, 0xa5, 0x87, 0x48, 0x54, 0x42, 0x94, 0x13, 0x55, 0x01, 0x41, 0xb9, 0x20, 0x84, 0x4c, 0xbc,
    0x20, 0xb7, 0x8e, 0xed, 0xae, 0x37, 0xa0, 0xfc, 0x7d, 0x43, 0x1e, 0x10, 0x1e, 0x25, 0xa1, 0x9c,
    0xe2, 0xd8, 0x3b, 0xe3, 0x19, 0xef, 0xd8, 0xc3, 0x78, 0x2c, 0x05, 0xbc, 0x78, 0x23, 0xea, 0x1a,
    0x04, 0x6f, 0x34, 0xe5, 0x28, 0xb9, 0xa6, 0x8e, 0x96, 0x21, 0x27, 0x69, 0xf4, 0x83, 0x03, 0xb5,
    0x62, 0x96, 0x23, 0x68, 0xf2, 0x87, 0x27, 0xc5, 0x83, 0xe5, 0x17, 0x04, 0xd4, 0xd6, 0x91, 0x52,
    0x96, 0x90, 0x3d, 0xfa, 0x7d, 0x88, 0xb7, 0x06, 0xc5, 0x40, 0xab, 0xb8, 0xfd, 0x61, 0x34, 0x30,
    0x47, 0x1c, 0x69, 0xca, 0x55, 0x04, 0x7e, 0x41, 0x9d, 0x2d, 0x80, 0x16, 0x97, 0xa6, 0x83, 0x08,
    0x77, 0x3b, 0x5d, 0x5a, 0x12, 0x11, 0xa6, 0x8a, 0x7c, 0xb9, 0xe7, 0xe0, 0x4e, 0xea, 0x75, 0x37,
    0xc2, 0x4d, 0x52, 0xdb, 0x3b, 0xfc, 0xa4, 0xab, 0xad, 0xc6, 0xb0, 0xc2, 0x9a, 0x57, 0xde, 0x2c,
    0xf5, 0xd9, 0x7a, 0x7a, 0x2d, 0xaa, 0xaa, 0xd1, 0x85, 0x9e, 0x02, 0x29, 0xeb, 0x80, 0x4a, 0x92,
    0x0b, 0xdc, 0x29, 0xa6, 0x64, 0xa4, 0x06, 0x5f, 0x7e, 0x8c, 0xb7, 0xcb, 0x87, 0x4d, 0x62, 0x3d,
    0xeb, 0x6e, 0x3a, 0x3c, 0x6b, 0x6e, 0x6f, 0x37, 0x9b, 0x50, 0x2e, 0x8d, 0x51, 0xd5, 0x74, 0x89,
    0x7b, 0x40, 0x6b, 0x14, 0x27, 0x10, 0x19, 0xeb, 0x0a, 0x4d, 0xb8, 0x6f, 0x21, 0x23, 0x73, 0x18,
    0x5b, 0x34, 0x6b, 0x04, 0xe7, 0xfc, 0x1f, 0x04, 0xae, 0x6e, 0x52, 0xfd, 0x0d, 0x71, 0xea, 0xb7,
    0x93, 0x4b, 0x77, 0x04, 0xf6, 0x0e, 0x1a, 0xb7, 0x3f, 0xb7, 0x77, 0xe9, 0x68, 0xe6, 0x48, 0x78,
    0x96, 0x4b, 0x9c, 0x09, 0x13, 0x2d, 0x15, 0xb0, 0x66, 0x81, 0x9c, 0xcf, 0xab, 0x39, 0x1d, 0xd0,
    0x5b, 0x39, 0x12, 0x2c, 0x74, 0x10, 0xb8, 0x5d, 0x5a, 0x5b, 0xb5, 0xc0, 0xbd, 0x93, 0x68, 0xe4,
    0xf1, 0xf6, 0x29, 0xb6, 0xc9, 0xc7, 0xfb, 0xd4, 0x49, 0xdd, 0xec, 0x4a, 0x58, 0x58, 0xf3, 0xca,
    0xa2, 0x37, 0x89, 0x2d, 0xcc, 0x6b, 0x0a, 0x29, 0x67, 0x8a, 0x6d, 0x8e, 0xae, 0x62, 0x3d, 0x86,
    0xfe, 0x9f, 0x5d, 0xba, 0x8b, 0xce, 0x95, 0x14, 0x39, 0xbf, 0xb2, 0x65, 0xf5, 0xc8, 0xc7, 0xfb,
    0x17, 0xea, 0xbf, 0x7e, 0x8f, 0x09, 0x6e, 0xca, 0x61, 0x64, 0x45, 0x72, 0x61, 0xba, 0xd9, 0x3b,
    0x34, 0x91, 0x61, 0xae, 0x81, 0xe3, 0x7a, 0xb1, 0x78, 0xae, 0x19, 0x9d, 0x23, 0x8e, 0x7b, 0x8c,
    0x64, 0x44, 0xc9, 0x79, 0x50, 0xce, 0xa0, 0x61, 0x9b, 0xfe, 0x9d, 0x3d, 0x0d, 0x9d, 0xa5, 0x23,
    0xe4, 0x41, 0x09, 0x9b, 0xd6, 0x31, 0xa3, 0xc4, 0x4d, 0x80, 0x56, 0xe3, 0x17, 0x1c, 0xe9, 0x63,
    0x8e
};
#endif

PyTypeObject *init_QVariantAnimation(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX].type;

    Shiboken::AutoDecRef Sbk_QVariantAnimation_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_IDX]))));

    _Sbk_QVariantAnimation_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QVariantAnimation",
        "QVariantAnimation*",
        &Sbk_QVariantAnimation_spec,
        &Shiboken::callCppDestructor< QVariantAnimation >,
        Sbk_QVariantAnimation_Type_bases.object(),
        0);
    auto *pyType = Sbk_QVariantAnimation_TypeF(); // references _Sbk_QVariantAnimation_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QVariantAnimation_SignatureStrings);
#else
    InitSignatureBytes(pyType, QVariantAnimation_SignatureBytes, QVariantAnimation_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVariantAnimation_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QVariantAnimation_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QVariantAnimation_PythonToCpp_QVariantAnimation_PTR,
        is_QVariantAnimation_PythonToCpp_QVariantAnimation_PTR_Convertible,
        QVariantAnimation_PTR_CppToPython_QVariantAnimation);

    Shiboken::Conversions::registerConverterName(converter, "QVariantAnimation");
    Shiboken::Conversions::registerConverterName(converter, "QVariantAnimation*");
    Shiboken::Conversions::registerConverterName(converter, "QVariantAnimation&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVariantAnimation).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QVariantAnimationWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QVariantAnimation_TypeF(), &Sbk_QVariantAnimation_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QVariantAnimation::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QVariantAnimation::staticMetaObject, sizeof(QVariantAnimationWrapper));

    return pyType;
}
