// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbuspendingcallwatcher_wrapper.h"

// Wrappers providing overrides
#include "qdbusvirtualobject_wrapper.h"

// Argument includes
#include <QtDBus/qdbuspendingcall.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDBusPendingCallWatcherWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDBusPendingCallWatcherWrapper::QDBusPendingCallWatcherWrapper(const ::QDBusPendingCall & call, ::QObject * parent) : QDBusPendingCallWatcher(call, parent)
{
}

void QDBusPendingCallWatcherWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QDBusVirtualObjectWrapper::sbk_o_childEvent("QDBusPendingCallWatcher", funcName, gil, pyOverride, event);
}

void QDBusPendingCallWatcherWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QDBusVirtualObjectWrapper::sbk_o_connectNotify("QDBusPendingCallWatcher", funcName, gil, pyOverride, signal);
}

void QDBusPendingCallWatcherWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QDBusVirtualObjectWrapper::sbk_o_customEvent("QDBusPendingCallWatcher", funcName, gil, pyOverride, event);
}

void QDBusPendingCallWatcherWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QDBusVirtualObjectWrapper::sbk_o_connectNotify("QDBusPendingCallWatcher", funcName, gil, pyOverride, signal);
}

bool QDBusPendingCallWatcherWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QDBusVirtualObjectWrapper::sbk_o_event("QDBusPendingCallWatcher", funcName, gil, pyOverride, event);
}

bool QDBusPendingCallWatcherWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QDBusVirtualObjectWrapper::sbk_o_eventFilter("QDBusPendingCallWatcher", funcName, gil, pyOverride, watched, event);
}

void QDBusPendingCallWatcherWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QDBusVirtualObjectWrapper::sbk_o_timerEvent("QDBusPendingCallWatcher", funcName, gil, pyOverride, event);
}

const QMetaObject *QDBusPendingCallWatcherWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDBusPendingCallWatcher::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDBusPendingCallWatcherWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDBusPendingCallWatcher::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDBusPendingCallWatcherWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDBusPendingCallWatcherWrapper *>(this));
    return QDBusPendingCallWatcher::qt_metacast(_clname);
}

QDBusPendingCallWatcherWrapper::~QDBusPendingCallWatcherWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusPendingCallWatcher_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]);
    if (type != myType)
        Shiboken::ObjectType::copyMultipleInheritance(type, myType);

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusPendingCallWatcher >()))
        return -1;

    QDBusPendingCallWatcherWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QDBusPendingCallWatcher", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusPendingCallWatcher::QDBusPendingCallWatcher(QDBusPendingCall,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDBusPendingCallWatcher(QDBusPendingCall,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QDBusPendingCallWatcher(QDBusPendingCall,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QDBusPendingCall *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDBusPendingCallWatcher(QDBusPendingCall,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QDBusPendingCallWatcherWrapper(*cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QDBusPendingCallWatcherWrapper(*cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDBusPendingCallWatcher >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDBusPendingCallWatcherFunc_waitForFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCallWatcher *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waitForFinished()
        cppSelf->waitForFinished();
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QDBusPendingCallWatcher_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusPendingCallWatcher_methods[] = {
    {"waitForFinished", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallWatcherFunc_waitForFinished), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDBusPendingCallWatcher_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDBusPendingCallWatcher *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDBusPendingCallWatcherWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDBusPendingCallWatcher_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusPendingCallWatcher_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_QDBusPendingCallWatcher_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QDBusPendingCallWatcher *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QDBusPendingCallWatcher *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QDBusPendingCall *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QDBusPendingCall *>(static_cast<const QDBusPendingCallWatcher *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QDBusPendingCallWatcherSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QDBusPendingCallWatcher *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]))
        return static_cast< ::QDBusPendingCall *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusPendingCallWatcher_Type = nullptr;
static PyTypeObject *Sbk_QDBusPendingCallWatcher_TypeF(void)
{
    return _Sbk_QDBusPendingCallWatcher_Type;
}

static PyType_Slot Sbk_QDBusPendingCallWatcher_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDBusPendingCallWatcher_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusPendingCallWatcher_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusPendingCallWatcher_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusPendingCallWatcher_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusPendingCallWatcher_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusPendingCallWatcher_spec = {
    "2:PySide6.QtDBus.QDBusPendingCallWatcher",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusPendingCallWatcher_slots
};

} //extern "C"

static void *Sbk_QDBusPendingCallWatcher_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDBusPendingCallWatcher *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusPendingCallWatcher_PythonToCpp_QDBusPendingCallWatcher_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusPendingCallWatcher_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusPendingCallWatcher_PythonToCpp_QDBusPendingCallWatcher_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusPendingCallWatcher_TypeF()))
        return QDBusPendingCallWatcher_PythonToCpp_QDBusPendingCallWatcher_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusPendingCallWatcher_PTR_CppToPython_QDBusPendingCallWatcher(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDBusPendingCallWatcher *>(const_cast<void *>(cppIn)), Sbk_QDBusPendingCallWatcher_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusPendingCallWatcher_SignatureStrings[] = {
    "PySide6.QtDBus.QDBusPendingCallWatcher(self,call:PySide6.QtDBus.QDBusPendingCall,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtDBus.QDBusPendingCallWatcher.waitForFinished(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusPendingCallWatcher_SignatureByteSize = 111;
static constexpr uint8_t QDBusPendingCallWatcher_SignatureBytes[111] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x71, 0x2a, 0x2d,
    0xd6, 0x0b, 0x04, 0x91, 0x01, 0xa9, 0x79, 0x29, 0x99, 0x79, 0xe9, 0xce, 0x89, 0x39, 0x39, 0xe1,
    0x89, 0x25, 0xc9, 0x19, 0xa9, 0x45, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x3a, 0xc9, 0x40, 0x01, 0xab,
    0x00, 0xfc, 0x1a, 0x74, 0x0a, 0x12, 0x8b, 0x52, 0xf3, 0x4a, 0x90, 0x94, 0x39, 0xe7, 0x17, 0xa5,
    0xea, 0x05, 0xfa, 0x27, 0x65, 0xa5, 0x26, 0x97, 0xd8, 0xe6, 0x95, 0xe6, 0xe4, 0x14, 0x94, 0x14,
    0x69, 0x72, 0x05, 0x10, 0x65, 0xaf, 0x5e, 0x79, 0x62, 0x66, 0x89, 0x5b, 0x7e, 0x91, 0x5b, 0x66,
    0x5e, 0x66, 0x71, 0x46, 0x6a, 0x0a, 0xd8, 0x1d, 0x9a, 0x5c, 0x00, 0x1b, 0x89, 0x41, 0x2a
};
#endif

PyTypeObject *init_QDBusPendingCallWatcher(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusPendingCallWatcher_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]))));

    _Sbk_QDBusPendingCallWatcher_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusPendingCallWatcher",
        "QDBusPendingCallWatcher*",
        &Sbk_QDBusPendingCallWatcher_spec,
        &Shiboken::callCppDestructor< QDBusPendingCallWatcher >,
        Sbk_QDBusPendingCallWatcher_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDBusPendingCallWatcher_TypeF(); // references _Sbk_QDBusPendingCallWatcher_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusPendingCallWatcher_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusPendingCallWatcher_SignatureBytes, QDBusPendingCallWatcher_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusPendingCallWatcher_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCallWatcher_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusPendingCallWatcher_PythonToCpp_QDBusPendingCallWatcher_PTR,
        is_QDBusPendingCallWatcher_PythonToCpp_QDBusPendingCallWatcher_PTR_Convertible,
        QDBusPendingCallWatcher_PTR_CppToPython_QDBusPendingCallWatcher);

    Shiboken::Conversions::registerConverterName(converter, "QDBusPendingCallWatcher");
    Shiboken::Conversions::registerConverterName(converter, "QDBusPendingCallWatcher*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusPendingCallWatcher&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusPendingCallWatcher).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDBusPendingCallWatcherWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QDBusPendingCallWatcher_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QDBusPendingCallWatcher_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QDBusPendingCallWatcher_TypeF(), &Sbk_QDBusPendingCallWatcherSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDBusPendingCallWatcher_TypeF(), &Sbk_QDBusPendingCallWatcher_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QDBusPendingCallWatcher::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDBusPendingCallWatcher::staticMetaObject, sizeof(QDBusPendingCallWatcherWrapper));

    return pyType;
}
