// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "q3dlight_wrapper.h"

// Wrappers providing overrides
#include "qabstract3dgraph_wrapper.h"
#include "q3dobject_wrapper.h"

// Argument includes
#include <QtDataVisualization/q3dobject.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void Q3DLightWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

Q3DLightWrapper::Q3DLightWrapper(::QObject * parent) : Q3DLight(parent)
{
}

void Q3DLightWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_childEvent("Q3DLight", funcName, gil, pyOverride, event);
}

void Q3DLightWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("Q3DLight", funcName, gil, pyOverride, signal);
}

void Q3DLightWrapper::copyValuesFrom(const ::Q3DObject & source)
{
    static const char *funcName = "copyValuesFrom";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Q3DObject::copyValuesFrom(source);
    }
    Q3DObjectWrapper::sbk_o_copyValuesFrom("Q3DLight", funcName, gil, pyOverride, source);
}

void Q3DLightWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_customEvent("Q3DLight", funcName, gil, pyOverride, event);
}

void Q3DLightWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("Q3DLight", funcName, gil, pyOverride, signal);
}

bool Q3DLightWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstract3DGraphWrapper::sbk_o_event("Q3DLight", funcName, gil, pyOverride, event);
}

bool Q3DLightWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstract3DGraphWrapper::sbk_o_eventFilter("Q3DLight", funcName, gil, pyOverride, watched, event);
}

void Q3DLightWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_timerEvent("Q3DLight", funcName, gil, pyOverride, event);
}

const QMetaObject *Q3DLightWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Q3DLight::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int Q3DLightWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Q3DLight::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *Q3DLightWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< Q3DLightWrapper *>(this));
    return Q3DLight::qt_metacast(_clname);
}

Q3DLightWrapper::~Q3DLightWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Q3DLight_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Q3DLight >()))
        return -1;

    Q3DLightWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:Q3DLight", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Q3DLight::Q3DLight(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // Q3DLight(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Q3DLight(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Q3DLight(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) Q3DLightWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new Q3DLightWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Q3DLight >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Q3DLightFunc_isAutoPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DLight *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAutoPosition()
        bool cppResult = cppSelf->isAutoPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Q3DLightFunc_setAutoPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DLight *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DLight::setAutoPosition(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoPosition(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoPosition", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoPosition(bool)
            cppSelf->setAutoPosition(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Q3DLight_PropertyStrings[] = {
    "autoPosition:isAutoPosition:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Q3DLight_methods[] = {
    {"isAutoPosition", reinterpret_cast<PyCFunction>(Sbk_Q3DLightFunc_isAutoPosition), METH_NOARGS, nullptr},
    {"setAutoPosition", reinterpret_cast<PyCFunction>(Sbk_Q3DLightFunc_setAutoPosition), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Q3DLight_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Q3DLight *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<Q3DLightWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Q3DLight_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Q3DLight_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Q3DLight_Type = nullptr;
static PyTypeObject *Sbk_Q3DLight_TypeF(void)
{
    return _Sbk_Q3DLight_Type;
}

static PyType_Slot Sbk_Q3DLight_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Q3DLight_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Q3DLight_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Q3DLight_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Q3DLight_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Q3DLight_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Q3DLight_spec = {
    "2:PySide6.QtDataVisualization.Q3DLight",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Q3DLight_slots
};

} //extern "C"

static void *Sbk_Q3DLight_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Q3DLight *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Q3DLight_PythonToCpp_Q3DLight_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Q3DLight_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Q3DLight_PythonToCpp_Q3DLight_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Q3DLight_TypeF()))
        return Q3DLight_PythonToCpp_Q3DLight_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Q3DLight_PTR_CppToPython_Q3DLight(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Q3DLight *>(const_cast<void *>(cppIn)), Sbk_Q3DLight_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Q3DLight_SignatureStrings[] = {
    "PySide6.QtDataVisualization.Q3DLight(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,autoPosition:bool=None)",
    "PySide6.QtDataVisualization.Q3DLight.isAutoPosition(self)->bool",
    "PySide6.QtDataVisualization.Q3DLight.setAutoPosition(self,enabled:bool)",
    nullptr}; // Sentinel
#else
static constexpr size_t Q3DLight_SignatureByteSize = 149;
static constexpr uint8_t Q3DLight_SignatureBytes[149] = {
    0x78, 0xda, 0x8d, 0x8e, 0xb1, 0x0a, 0xc2, 0x40, 0x10, 0x05, 0xfb, 0x7c, 0x89, 0x91, 0xf3, 0x1a,
    0xc1, 0x22, 0x10, 0x41, 0x4c, 0xa7, 0x98, 0x0b, 0x82, 0xfd, 0xc6, 0xac, 0xba, 0xb2, 0xdc, 0x86,
    0xbb, 0x0d, 0x72, 0x7e, 0xbd, 0x24, 0x85, 0x08, 0x36, 0x69, 0x1f, 0xcc, 0xbc, 0x71, 0xe9, 0x4c,
    0x1d, 0x6e, 0x6c, 0xa3, 0x15, 0x28, 0x5c, 0x28, 0x0e, 0xc0, 0xf4, 0x06, 0x25, 0xf1, 0xb6, 0x59,
    0x57, 0x47, 0xba, 0x3f, 0x74, 0x11, 0x91, 0x6f, 0xa6, 0x87, 0x80, 0x5e, 0x0b, 0xf7, 0x05, 0xf6,
    0x12, 0xd0, 0x36, 0x75, 0xfb, 0xc4, 0xab, 0x96, 0x7e, 0x60, 0xee, 0x35, 0x98, 0x65, 0x71, 0xc0,
    0xf4, 0x92, 0xd0, 0xd5, 0x9e, 0x53, 0x79, 0x12, 0x8f, 0x06, 0x06, 0x15, 0x27, 0x91, 0x46, 0x67,
    0xd1, 0x8a, 0xf0, 0x34, 0xe7, 0x99, 0x9b, 0x71, 0x6d, 0x29, 0xee, 0x7e, 0xf0, 0xa9, 0x24, 0x5f,
    0x6d, 0x47, 0xcb, 0x3c, 0x3e, 0xa2, 0xfe, 0x09, 0x0c, 0x7a, 0x68, 0x19, 0xbb, 0x29, 0x26, 0xcf,
    0x3e, 0x6a, 0xcb, 0x5f, 0x3c
};
#endif

PyTypeObject *init_Q3DLight(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX].type;

    Shiboken::AutoDecRef Sbk_Q3DLight_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DObject_IDX]))));

    _Sbk_Q3DLight_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Q3DLight",
        "Q3DLight*",
        &Sbk_Q3DLight_spec,
        &Shiboken::callCppDestructor< Q3DLight >,
        Sbk_Q3DLight_Type_bases.object(),
        0);
    auto *pyType = Sbk_Q3DLight_TypeF(); // references _Sbk_Q3DLight_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Q3DLight_SignatureStrings);
#else
    InitSignatureBytes(pyType, Q3DLight_SignatureBytes, Q3DLight_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Q3DLight_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DLight_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Q3DLight_PythonToCpp_Q3DLight_PTR,
        is_Q3DLight_PythonToCpp_Q3DLight_PTR_Convertible,
        Q3DLight_PTR_CppToPython_Q3DLight);

    Shiboken::Conversions::registerConverterName(converter, "Q3DLight");
    Shiboken::Conversions::registerConverterName(converter, "Q3DLight*");
    Shiboken::Conversions::registerConverterName(converter, "Q3DLight&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Q3DLight).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(Q3DLightWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Q3DLight_TypeF(), &Sbk_Q3DLight_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Q3DLight::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Q3DLight::staticMetaObject, sizeof(Q3DLightWrapper));

    return pyType;
}
