// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "q3dscatter_wrapper.h"

// Wrappers providing overrides
#include "qabstract3dgraph_wrapper.h"

// Argument includes
#include <QList>
#include <QtDataVisualization/qscatter3dseries.h>
#include <QtDataVisualization/qvalue3daxis.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qevent.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void Q3DScatterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

Q3DScatterWrapper::Q3DScatterWrapper(const ::QSurfaceFormat * format, ::QWindow * parent) : Q3DScatter(format, parent)
{
}

::QAccessibleInterface * Q3DScatterWrapper::accessibleRoot() const
{
    static const char *funcName = "accessibleRoot";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::accessibleRoot();
    }
    return QAbstract3DGraphWrapper::sbk_o_accessibleRoot("Q3DScatter", funcName, gil, pyOverride);
}

void Q3DScatterWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_childEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::closeEvent(::QCloseEvent * arg__1)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::closeEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_closeEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

void Q3DScatterWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("Q3DScatter", funcName, gil, pyOverride, signal);
}

void Q3DScatterWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_customEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("Q3DScatter", funcName, gil, pyOverride, signal);
}

bool Q3DScatterWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::event(event);
    }
    return QAbstract3DGraphWrapper::sbk_o_event("Q3DScatter", funcName, gil, pyOverride, event);
}

bool Q3DScatterWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstract3DGraphWrapper::sbk_o_eventFilter("Q3DScatter", funcName, gil, pyOverride, watched, event);
}

void Q3DScatterWrapper::exposeEvent(::QExposeEvent * event)
{
    static const char *funcName = "exposeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::exposeEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_exposeEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::focusInEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusInEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_focusInEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

::QObject * Q3DScatterWrapper::focusObject() const
{
    static const char *funcName = "focusObject";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusObject();
    }
    return QAbstract3DGraphWrapper::sbk_o_focusObject("Q3DScatter", funcName, gil, pyOverride);
}

void Q3DScatterWrapper::focusOutEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusOutEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_focusInEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

::QSurfaceFormat Q3DScatterWrapper::format() const
{
    static const char *funcName = "format";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::format();
    }
    return QAbstract3DGraphWrapper::sbk_o_format("Q3DScatter", funcName, gil, pyOverride);
}

void Q3DScatterWrapper::hideEvent(::QHideEvent * arg__1)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::hideEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_hideEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

void Q3DScatterWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::keyPressEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_keyPressEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

void Q3DScatterWrapper::keyReleaseEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::keyReleaseEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_keyPressEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

void Q3DScatterWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::mouseDoubleClickEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_mouseDoubleClickEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::mouseMoveEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_mouseDoubleClickEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::mousePressEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_mouseDoubleClickEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::mouseReleaseEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_mouseDoubleClickEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::moveEvent(::QMoveEvent * arg__1)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::moveEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_moveEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

bool Q3DScatterWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::nativeEvent(eventType, message, result);
    }
    return QAbstract3DGraphWrapper::sbk_o_nativeEvent("Q3DScatter", funcName, gil, pyOverride, eventType, message, result);
}

void Q3DScatterWrapper::paintEvent(::QPaintEvent * arg__1)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::paintEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_paintEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

void Q3DScatterWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::resizeEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_resizeEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

bool Q3DScatterWrapper::shadowsSupported() const
{
    static const char *funcName = "shadowsSupported";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::shadowsSupported();
    }
    return QAbstract3DGraphWrapper::sbk_o_shadowsSupported("Q3DScatter", funcName, gil, pyOverride);
}

void Q3DScatterWrapper::showEvent(::QShowEvent * arg__1)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::showEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_showEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

::QSize Q3DScatterWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::size();
    }
    return QAbstract3DGraphWrapper::sbk_o_size("Q3DScatter", funcName, gil, pyOverride);
}

::QSurface::SurfaceType Q3DScatterWrapper::surfaceType() const
{
    static const char *funcName = "surfaceType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::surfaceType();
    }
    return QAbstract3DGraphWrapper::sbk_o_surfaceType("Q3DScatter", funcName, gil, pyOverride);
}

void Q3DScatterWrapper::tabletEvent(::QTabletEvent * arg__1)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::tabletEvent(arg__1);
    }
    QAbstract3DGraphWrapper::sbk_o_tabletEvent("Q3DScatter", funcName, gil, pyOverride, arg__1);
}

void Q3DScatterWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_timerEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::touchEvent(::QTouchEvent * event)
{
    static const char *funcName = "touchEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::touchEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_touchEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

void Q3DScatterWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DGraph::wheelEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_wheelEvent("Q3DScatter", funcName, gil, pyOverride, event);
}

const QMetaObject *Q3DScatterWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Q3DScatter::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int Q3DScatterWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Q3DScatter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *Q3DScatterWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< Q3DScatterWrapper *>(this));
    return Q3DScatter::qt_metacast(_clname);
}

Q3DScatterWrapper::~Q3DScatterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Q3DScatter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Q3DScatter >()))
        return -1;

    Q3DScatterWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:Q3DScatter", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Q3DScatter::Q3DScatter(const QSurfaceFormat*=,QWindow*=)
    if (numArgs == 0) {
        overloadId = 0; // Q3DScatter(const QSurfaceFormat*,QWindow*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // Q3DScatter(const QSurfaceFormat*,QWindow*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[1])))) {
            overloadId = 0; // Q3DScatter(const QSurfaceFormat*,QWindow*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"format", 0}, {"parent", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QSurfaceFormat *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QWindow *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Q3DScatter(const QSurfaceFormat*,QWindow*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) Q3DScatterWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new Q3DScatterWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Q3DScatter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Q3DScatterFunc_addAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DScatter::addAxis(QValue3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // addAxis(QValue3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addAxis", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAxis(QValue3DAxis*)
            cppSelf->addAxis(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Q3DScatterFunc_addSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DScatter::addSeries(QScatter3DSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QScatter3DSeries_IDX]), (pyArg)))) {
        overloadId = 0; // addSeries(QScatter3DSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addSeries", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScatter3DSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSeries(QScatter3DSeries*)
            cppSelf->addSeries(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Q3DScatterFunc_axes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axes()const
        QList<QValue3DAxis*> cppResult = const_cast<const ::Q3DScatter *>(cppSelf)->axes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_QValue3DAxisPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Q3DScatterFunc_axisX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisX()const
        QValue3DAxis * cppResult = const_cast<const ::Q3DScatter *>(cppSelf)->axisX();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Q3DScatterFunc_axisY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisY()const
        QValue3DAxis * cppResult = const_cast<const ::Q3DScatter *>(cppSelf)->axisY();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Q3DScatterFunc_axisZ(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisZ()const
        QValue3DAxis * cppResult = const_cast<const ::Q3DScatter *>(cppSelf)->axisZ();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Q3DScatterFunc_releaseAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DScatter::releaseAxis(QValue3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // releaseAxis(QValue3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "releaseAxis", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseAxis(QValue3DAxis*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->releaseAxis(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "releaseAxis(QValue3DAxis*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Q3DScatterFunc_removeSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DScatter::removeSeries(QScatter3DSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QScatter3DSeries_IDX]), (pyArg)))) {
        overloadId = 0; // removeSeries(QScatter3DSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeSeries", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScatter3DSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeSeries(QScatter3DSeries*)
            cppSelf->removeSeries(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Q3DScatterFunc_selectedSeries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedSeries()const
        QScatter3DSeries * cppResult = const_cast<const ::Q3DScatter *>(cppSelf)->selectedSeries();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QScatter3DSeries_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Q3DScatterFunc_seriesList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // seriesList()const
        QList<QScatter3DSeries*> cppResult = const_cast<const ::Q3DScatter *>(cppSelf)->seriesList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_QScatter3DSeriesPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Q3DScatterFunc_setAxisX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DScatter::setAxisX(QValue3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisX(QValue3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisX", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisX(QValue3DAxis*)
            cppSelf->setAxisX(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Q3DScatterFunc_setAxisY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DScatter::setAxisY(QValue3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisY(QValue3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisY", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisY(QValue3DAxis*)
            cppSelf->setAxisY(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Q3DScatterFunc_setAxisZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DScatter::setAxisZ(QValue3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisZ(QValue3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisZ", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisZ(QValue3DAxis*)
            cppSelf->setAxisZ(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Q3DScatter_PropertyStrings[] = {
    "axisX::",
    "axisY::",
    "axisZ::",
    "selectedSeries:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Q3DScatter_methods[] = {
    {"addAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_addAxis), METH_O, nullptr},
    {"addSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_addSeries), METH_O, nullptr},
    {"axes", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_axes), METH_NOARGS, nullptr},
    {"axisX", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_axisX), METH_NOARGS, nullptr},
    {"axisY", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_axisY), METH_NOARGS, nullptr},
    {"axisZ", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_axisZ), METH_NOARGS, nullptr},
    {"releaseAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_releaseAxis), METH_O, nullptr},
    {"removeSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_removeSeries), METH_O, nullptr},
    {"selectedSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_selectedSeries), METH_NOARGS, nullptr},
    {"seriesList", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_seriesList), METH_NOARGS, nullptr},
    {"setAxisX", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_setAxisX), METH_O, nullptr},
    {"setAxisY", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_setAxisY), METH_O, nullptr},
    {"setAxisZ", reinterpret_cast<PyCFunction>(Sbk_Q3DScatterFunc_setAxisZ), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Q3DScatter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Q3DScatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<Q3DScatterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Q3DScatter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Q3DScatter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_Q3DScatterSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::Q3DScatter *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DGraph_IDX]))
        return static_cast< ::QAbstract3DGraph *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]))
        return static_cast< ::QWindow *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]))
        return static_cast< ::QSurface *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Q3DScatter_Type = nullptr;
static PyTypeObject *Sbk_Q3DScatter_TypeF(void)
{
    return _Sbk_Q3DScatter_Type;
}

static PyType_Slot Sbk_Q3DScatter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Q3DScatter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Q3DScatter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Q3DScatter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Q3DScatter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Q3DScatter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Q3DScatter_spec = {
    "2:PySide6.QtDataVisualization.Q3DScatter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Q3DScatter_slots
};

} //extern "C"

static void *Sbk_Q3DScatter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWindow >())
        return dynamic_cast< ::Q3DScatter *>(reinterpret_cast< ::QWindow *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Q3DScatter *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QSurface >())
        return dynamic_cast< ::Q3DScatter *>(reinterpret_cast< ::QSurface *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Q3DScatter_PythonToCpp_Q3DScatter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Q3DScatter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Q3DScatter_PythonToCpp_Q3DScatter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Q3DScatter_TypeF()))
        return Q3DScatter_PythonToCpp_Q3DScatter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Q3DScatter_PTR_CppToPython_Q3DScatter(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Q3DScatter *>(const_cast<void *>(cppIn)), Sbk_Q3DScatter_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Q3DScatter_SignatureStrings[] = {
    "PySide6.QtDataVisualization.Q3DScatter(self,format:typing.Union[PySide6.QtGui.QSurfaceFormat, PySide6.QtGui.QSurfaceFormat.FormatOption]=nullptr,parent:PySide6.QtGui.QWindow=nullptr,*:KeywordOnly=None,axisX:QValue3DAxis=None,axisY:QValue3DAxis=None,axisZ:QValue3DAxis=None,selectedSeries:QScatter3DSeries=None)",
    "PySide6.QtDataVisualization.Q3DScatter.addAxis(self,axis:PySide6.QtDataVisualization.QValue3DAxis)",
    "PySide6.QtDataVisualization.Q3DScatter.addSeries(self,series:PySide6.QtDataVisualization.QScatter3DSeries)",
    "PySide6.QtDataVisualization.Q3DScatter.axes(self)->QList[PySide6.QtDataVisualization.QValue3DAxis]",
    "PySide6.QtDataVisualization.Q3DScatter.axisX(self)->PySide6.QtDataVisualization.QValue3DAxis",
    "PySide6.QtDataVisualization.Q3DScatter.axisY(self)->PySide6.QtDataVisualization.QValue3DAxis",
    "PySide6.QtDataVisualization.Q3DScatter.axisZ(self)->PySide6.QtDataVisualization.QValue3DAxis",
    "PySide6.QtDataVisualization.Q3DScatter.releaseAxis(self,axis:PySide6.QtDataVisualization.QValue3DAxis)",
    "PySide6.QtDataVisualization.Q3DScatter.removeSeries(self,series:PySide6.QtDataVisualization.QScatter3DSeries)",
    "PySide6.QtDataVisualization.Q3DScatter.selectedSeries(self)->PySide6.QtDataVisualization.QScatter3DSeries",
    "PySide6.QtDataVisualization.Q3DScatter.seriesList(self)->QList[PySide6.QtDataVisualization.QScatter3DSeries]",
    "PySide6.QtDataVisualization.Q3DScatter.setAxisX(self,axis:PySide6.QtDataVisualization.QValue3DAxis)",
    "PySide6.QtDataVisualization.Q3DScatter.setAxisY(self,axis:PySide6.QtDataVisualization.QValue3DAxis)",
    "PySide6.QtDataVisualization.Q3DScatter.setAxisZ(self,axis:PySide6.QtDataVisualization.QValue3DAxis)",
    nullptr}; // Sentinel
#else
static constexpr size_t Q3DScatter_SignatureByteSize = 310;
static constexpr uint8_t Q3DScatter_SignatureBytes[310] = {
    0x78, 0xda, 0xbd, 0x93, 0x4d, 0x4b, 0xc4, 0x30, 0x10, 0x86, 0xef, 0xfe, 0x0a, 0x8f, 0xae, 0xd4,
    0x5c, 0x16, 0x3c, 0x04, 0x56, 0x58, 0x28, 0x7a, 0x50, 0xdc, 0x86, 0xe2, 0x6a, 0xbb, 0xf4, 0x10,
    0x9a, 0xa9, 0x04, 0xb2, 0x49, 0x49, 0x52, 0x77, 0xeb, 0xaf, 0xb7, 0x5f, 0x56, 0x2d, 0x5a, 0x52,
    0xa1, 0x7b, 0x0a, 0x9d, 0xce, 0xcc, 0x33, 0xf3, 0xe6, 0x4d, 0x50, 0x86, 0x9c, 0xc1, 0x35, 0x22,
    0xd6, 0xa7, 0x96, 0x6e, 0xb9, 0x29, 0xa8, 0xe0, 0xef, 0xd4, 0x72, 0x25, 0x11, 0x59, 0xfa, 0x61,
    0x4a, 0xad, 0x05, 0x7d, 0x61, 0x40, 0x64, 0x5e, 0xa6, 0xf4, 0x9e, 0x5a, 0x6c, 0xcb, 0x9c, 0xcb,
    0x57, 0xf4, 0x24, 0xab, 0x9c, 0x5d, 0xd0, 0xd7, 0xdf, 0x15, 0x1c, 0x91, 0xb0, 0xd0, 0x19, 0x4d,
    0xe1, 0xb6, 0xc9, 0xf4, 0xce, 0xc7, 0xfe, 0xa2, 0xf6, 0xd8, 0xe4, 0x35, 0x2b, 0x59, 0xc9, 0x42,
    0x88, 0xdc, 0x6a, 0x2f, 0xa7, 0x1a, 0xa4, 0xc5, 0x83, 0xca, 0x67, 0x2e, 0x99, 0x3a, 0xf4, 0x49,
    0x97, 0xf8, 0x1e, 0xca, 0x83, 0xd2, 0x6c, 0x23, 0x45, 0xb9, 0x7a, 0x54, 0x12, 0x3c, 0x7a, 0xe4,
    0xe6, 0x05, 0x93, 0x2d, 0x15, 0x05, 0x2c, 0xfd, 0x75, 0xf5, 0xf5, 0x15, 0x8f, 0xfe, 0x88, 0xc7,
    0xbf, 0xc4, 0xab, 0x4d, 0x21, 0xb5, 0xc0, 0x42, 0xd0, 0x1c, 0x0c, 0x26, 0x9d, 0x02, 0x95, 0x14,
    0x4d, 0xa0, 0x49, 0x5a, 0x9c, 0x05, 0x4e, 0xb2, 0x21, 0xca, 0x58, 0xdd, 0xb9, 0x95, 0xaf, 0x26,
    0xe2, 0xd1, 0xc2, 0x6f, 0xc3, 0x4c, 0x41, 0xb4, 0x93, 0xb5, 0x10, 0xd3, 0x8e, 0x3d, 0x5a, 0x3c,
    0x58, 0xc9, 0x1d, 0x75, 0xec, 0x28, 0x8b, 0xab, 0x1b, 0xf2, 0xc0, 0x8d, 0xdd, 0xb9, 0x6e, 0x93,
    0xb8, 0x23, 0xaa, 0x5b, 0xfc, 0x64, 0xb8, 0x76, 0x9f, 0xd2, 0x3c, 0x9a, 0xb3, 0x79, 0x3c, 0x57,
    0x73, 0x5d, 0x99, 0x92, 0x1a, 0x98, 0xdb, 0x4b, 0x1a, 0xf6, 0xea, 0x0d, 0x4e, 0x65, 0xa7, 0x9f,
    0x2f, 0xcd, 0x49, 0xba, 0x01, 0xca, 0x9d, 0x54, 0x67, 0xd7, 0x8e, 0x9d, 0x60, 0xdf, 0x01, 0x2b,
    0x71, 0x87, 0xd9, 0x75, 0xef, 0xe2, 0x99, 0x2e, 0xaa, 0x63, 0x44, 0x27, 0x60, 0xc4, 0xff, 0x62,
    0x7c, 0x00, 0xb0, 0xeb, 0x53, 0x85
};
#endif

PyTypeObject *init_Q3DScatter(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX].type;

    Shiboken::AutoDecRef Sbk_Q3DScatter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DGraph_IDX]))));

    _Sbk_Q3DScatter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Q3DScatter",
        "Q3DScatter*",
        &Sbk_Q3DScatter_spec,
        &Shiboken::callCppDestructor< Q3DScatter >,
        Sbk_Q3DScatter_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_Q3DScatter_TypeF(); // references _Sbk_Q3DScatter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Q3DScatter_SignatureStrings);
#else
    InitSignatureBytes(pyType, Q3DScatter_SignatureBytes, Q3DScatter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Q3DScatter_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DScatter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Q3DScatter_PythonToCpp_Q3DScatter_PTR,
        is_Q3DScatter_PythonToCpp_Q3DScatter_PTR_Convertible,
        Q3DScatter_PTR_CppToPython_Q3DScatter);

    Shiboken::Conversions::registerConverterName(converter, "Q3DScatter");
    Shiboken::Conversions::registerConverterName(converter, "Q3DScatter*");
    Shiboken::Conversions::registerConverterName(converter, "Q3DScatter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Q3DScatter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(Q3DScatterWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_Q3DScatter_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_Q3DScatter_TypeF(), &Sbk_Q3DScatterSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Q3DScatter_TypeF(), &Sbk_Q3DScatter_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Q3DScatter::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Q3DScatter::staticMetaObject, sizeof(Q3DScatterWrapper));

    return pyType;
}
