// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTFORMBUILDERWRAPPER_H
#define SBK_QABSTRACTFORMBUILDERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtDesigner/abstractformbuilder.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QAbstractFormBuilderWrapper : public QAbstractFormBuilder
{
public:
    QAbstractFormBuilderWrapper();
    QAbstractFormBuilderWrapper(const QAbstractFormBuilderWrapper &) = delete;
    QAbstractFormBuilderWrapper& operator=(const QAbstractFormBuilderWrapper &) = delete;
    QAbstractFormBuilderWrapper(QAbstractFormBuilderWrapper &&) = delete;
    QAbstractFormBuilderWrapper& operator=(QAbstractFormBuilderWrapper &&) = delete;
    ~QAbstractFormBuilderWrapper() override;

    void addMenuAction(::QAction * action) override;
    static void sbk_o_addMenuAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAction * action);
    bool checkProperty(::QObject * obj, const ::QString & prop) const override;
    static bool sbk_o_checkProperty(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * obj, const ::QString & prop);
    ::QAction * createAction(::QObject * parent, const ::QString & name) override;
    static ::QAction * sbk_o_createAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * parent, const ::QString & name);
    ::QActionGroup * createActionGroup(::QObject * parent, const ::QString & name) override;
    static ::QActionGroup * sbk_o_createActionGroup(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * parent, const ::QString & name);
    ::QLayout * createLayout(const ::QString & layoutName, ::QObject * parent, const ::QString & name) override;
    static ::QLayout * sbk_o_createLayout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & layoutName, ::QObject * parent, const ::QString & name);
    ::QWidget * createWidget(const ::QString & widgetName, ::QWidget * parentWidget, const ::QString & name) override;
    static ::QWidget * sbk_o_createWidget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & widgetName, ::QWidget * parentWidget, const ::QString & name);
    ::QWidget * load(::QIODevice * dev, ::QWidget * parentWidget = nullptr) override;
    static ::QWidget * sbk_o_load(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QIODevice * dev, ::QWidget * parentWidget = nullptr);
    void save(::QIODevice * dev, ::QWidget * widget) override;
    static void sbk_o_save(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QIODevice * dev, ::QWidget * widget);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[8] = {false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTFORMBUILDERWRAPPER_H
