// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesignerpropertyeditorinterface_wrapper.h"

// Wrappers providing overrides
#include "qdesignerpropertysheetextension_wrapper.h"
#include "qdesignerformwindowcursorinterface_wrapper.h"
#include "qdesignercustomwidgetinterface_wrapper.h"
#include "qdesignerwidgetboxinterface_wrapper.h"

// Argument includes
#include <QString>
#include <QtDesigner/abstractformeditor.h>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDesignerPropertyEditorInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDesignerPropertyEditorInterfaceWrapper::QDesignerPropertyEditorInterfaceWrapper(::QWidget * parent, ::QFlags<Qt::WindowType> flags) : QDesignerPropertyEditorInterface(parent, flags)
{
}

void QDesignerPropertyEditorInterfaceWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_actionEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_changeEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_childEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_closeEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, signal);
}

void QDesignerPropertyEditorInterfaceWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_contextMenuEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

::QDesignerFormEditorInterface * QDesignerPropertyEditorInterfaceWrapper::core() const
{
    static const char *funcName = "core";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDesignerPropertyEditorInterface::core();
    }
    return sbk_o_core("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

::QDesignerFormEditorInterface * QDesignerPropertyEditorInterfaceWrapper::sbk_o_core(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QDesignerFormEditorInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDesignerFormEditorInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QString QDesignerPropertyEditorInterfaceWrapper::currentPropertyName() const
{
    static const char *funcName = "currentPropertyName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.currentPropertyName");
        return ::QString();
    }
    return QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

void QDesignerPropertyEditorInterfaceWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_customEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

int QDesignerPropertyEditorInterfaceWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_count("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

void QDesignerPropertyEditorInterfaceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, signal);
}

void QDesignerPropertyEditorInterfaceWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragEnterEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragLeaveEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragMoveEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dropEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_enterEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerPropertyEditorInterfaceWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::event(event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_event("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerPropertyEditorInterfaceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_eventFilter("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, watched, event);
}

void QDesignerPropertyEditorInterfaceWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusInEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerPropertyEditorInterfaceWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusNextPrevChild("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, next);
}

void QDesignerPropertyEditorInterfaceWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusOutEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerPropertyEditorInterfaceWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QDesignerFormWindowCursorInterfaceWrapper::sbk_o_hasSelection("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

int QDesignerPropertyEditorInterfaceWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_heightForWidth("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, arg__1);
}

void QDesignerPropertyEditorInterfaceWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_hideEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_initPainter("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, painter);
}

void QDesignerPropertyEditorInterfaceWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_inputMethodEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

::QVariant QDesignerPropertyEditorInterfaceWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_inputMethodQuery("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, arg__1);
}

bool QDesignerPropertyEditorInterfaceWrapper::isReadOnly() const
{
    static const char *funcName = "isReadOnly";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.isReadOnly");
        return false;
    }
    return QDesignerFormWindowCursorInterfaceWrapper::sbk_o_hasSelection("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

void QDesignerPropertyEditorInterfaceWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_keyPressEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_keyReleaseEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_leaveEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

int QDesignerPropertyEditorInterfaceWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_metric("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, arg__1);
}

::QSize QDesignerPropertyEditorInterfaceWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_minimumSizeHint("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

void QDesignerPropertyEditorInterfaceWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseDoubleClickEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseMoveEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mousePressEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseReleaseEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_moveEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerPropertyEditorInterfaceWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_nativeEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, eventType, message, result);
}

::QObject * QDesignerPropertyEditorInterfaceWrapper::object() const
{
    static const char *funcName = "object";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.object");
        return nullptr;
    }
    return sbk_o_object("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

::QObject * QDesignerPropertyEditorInterfaceWrapper::sbk_o_object(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QObject >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QObject *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPaintEngine * QDesignerPropertyEditorInterfaceWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_paintEngine("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

void QDesignerPropertyEditorInterfaceWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_paintEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

::QPaintDevice * QDesignerPropertyEditorInterfaceWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_redirected("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, offset);
}

void QDesignerPropertyEditorInterfaceWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_resizeEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::setObject(::QObject * object)
{
    static const char *funcName = "setObject";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.setObject");
        return;
    }
    sbk_o_setObject("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, object);
}

void QDesignerPropertyEditorInterfaceWrapper::sbk_o_setObject(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * object)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), object)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), object)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QDesignerPropertyEditorInterfaceWrapper::setPropertyValue(const ::QString & name, const ::QVariant & value, bool changed)
{
    static const char *funcName = "setPropertyValue";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.setPropertyValue");
        return;
    }
    sbk_o_setPropertyValue("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, name, value, changed);
}

void QDesignerPropertyEditorInterfaceWrapper::sbk_o_setPropertyValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name, const ::QVariant & value, bool changed)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &changed)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &changed)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QDesignerPropertyEditorInterfaceWrapper::setReadOnly(bool readOnly)
{
    static const char *funcName = "setReadOnly";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.setReadOnly");
        return;
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_setVisible("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, readOnly);
}

void QDesignerPropertyEditorInterfaceWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_setVisible("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, visible);
}

::QPainter * QDesignerPropertyEditorInterfaceWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_sharedPainter("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

void QDesignerPropertyEditorInterfaceWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_showEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

::QSize QDesignerPropertyEditorInterfaceWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_minimumSizeHint("QDesignerPropertyEditorInterface", funcName, gil, pyOverride);
}

void QDesignerPropertyEditorInterfaceWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_tabletEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_timerEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerPropertyEditorInterfaceWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_wheelEvent("QDesignerPropertyEditorInterface", funcName, gil, pyOverride, event);
}

const QMetaObject *QDesignerPropertyEditorInterfaceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDesignerPropertyEditorInterface::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDesignerPropertyEditorInterfaceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDesignerPropertyEditorInterface::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDesignerPropertyEditorInterfaceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDesignerPropertyEditorInterfaceWrapper *>(this));
    return QDesignerPropertyEditorInterface::qt_metacast(_clname);
}

QDesignerPropertyEditorInterfaceWrapper::~QDesignerPropertyEditorInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerPropertyEditorInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QDesignerPropertyEditorInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesignerPropertyEditorInterface >()))
        return -1;

    QDesignerPropertyEditorInterfaceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QDesignerPropertyEditorInterface", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDesignerPropertyEditorInterface::QDesignerPropertyEditorInterface(QWidget*,QFlags<Qt::WindowType>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDesignerPropertyEditorInterface(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QDesignerPropertyEditorInterface(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"flags", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDesignerPropertyEditorInterface(QWidget*,QFlags<Qt::WindowType>)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QDesignerPropertyEditorInterfaceWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QDesignerPropertyEditorInterfaceWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDesignerPropertyEditorInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDesignerPropertyEditorInterfaceFunc_core(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // core()const
        QDesignerFormEditorInterface * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerPropertyEditorInterface *>(cppSelf)->::QDesignerPropertyEditorInterface::core()
            : const_cast<const ::QDesignerPropertyEditorInterface *>(cppSelf)->core();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerPropertyEditorInterfaceFunc_currentPropertyName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentPropertyName()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.currentPropertyName");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerPropertyEditorInterface *>(cppSelf)->currentPropertyName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerPropertyEditorInterfaceFunc_isReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadOnly()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.isReadOnly");
            return {};
        }
        bool cppResult = const_cast<const ::QDesignerPropertyEditorInterface *>(cppSelf)->isReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerPropertyEditorInterfaceFunc_object(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // object()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.object");
            return {};
        }
        QObject * cppResult = const_cast<const ::QDesignerPropertyEditorInterface *>(cppSelf)->object();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerPropertyEditorInterfaceFunc_setObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerPropertyEditorInterface::setObject(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setObject", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObject(QObject*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.setObject");
                return {};
            }
            cppSelf->setObject(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDesignerPropertyEditorInterfaceFunc_setPropertyValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPropertyValue", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setPropertyValue", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerPropertyEditorInterface::setPropertyValue(QString,QVariant,bool=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setPropertyValue(QString,QVariant,bool)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
            overloadId = 0; // setPropertyValue(QString,QVariant,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPropertyValue", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"changed", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setPropertyValue", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        bool cppArg2 = true;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPropertyValue(QString,QVariant,bool)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.setPropertyValue");
                return {};
            }
            cppSelf->setPropertyValue(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDesignerPropertyEditorInterfaceFunc_setReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerPropertyEditorInterface::setReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadOnly", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadOnly(bool)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerPropertyEditorInterface.setReadOnly");
                return {};
            }
            cppSelf->setReadOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QDesignerPropertyEditorInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerPropertyEditorInterface_methods[] = {
    {"core", reinterpret_cast<PyCFunction>(Sbk_QDesignerPropertyEditorInterfaceFunc_core), METH_NOARGS, nullptr},
    {"currentPropertyName", reinterpret_cast<PyCFunction>(Sbk_QDesignerPropertyEditorInterfaceFunc_currentPropertyName), METH_NOARGS, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_QDesignerPropertyEditorInterfaceFunc_isReadOnly), METH_NOARGS, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QDesignerPropertyEditorInterfaceFunc_object), METH_NOARGS, nullptr},
    {"setObject", reinterpret_cast<PyCFunction>(Sbk_QDesignerPropertyEditorInterfaceFunc_setObject), METH_O, nullptr},
    {"setPropertyValue", reinterpret_cast<PyCFunction>(Sbk_QDesignerPropertyEditorInterfaceFunc_setPropertyValue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setReadOnly", reinterpret_cast<PyCFunction>(Sbk_QDesignerPropertyEditorInterfaceFunc_setReadOnly), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerPropertyEditorInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDesignerPropertyEditorInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerPropertyEditorInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerPropertyEditorInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QDesignerPropertyEditorInterfaceSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QDesignerPropertyEditorInterface *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerPropertyEditorInterface_Type = nullptr;
static PyTypeObject *Sbk_QDesignerPropertyEditorInterface_TypeF(void)
{
    return _Sbk_QDesignerPropertyEditorInterface_Type;
}

static PyType_Slot Sbk_QDesignerPropertyEditorInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerPropertyEditorInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerPropertyEditorInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerPropertyEditorInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerPropertyEditorInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerPropertyEditorInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerPropertyEditorInterface_spec = {
    "2:PySide6.QtDesigner.QDesignerPropertyEditorInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerPropertyEditorInterface_slots
};

} //extern "C"

static void *Sbk_QDesignerPropertyEditorInterface_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QDesignerPropertyEditorInterface *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDesignerPropertyEditorInterface *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QDesignerPropertyEditorInterface *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerPropertyEditorInterface_PythonToCpp_QDesignerPropertyEditorInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerPropertyEditorInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerPropertyEditorInterface_PythonToCpp_QDesignerPropertyEditorInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerPropertyEditorInterface_TypeF()))
        return QDesignerPropertyEditorInterface_PythonToCpp_QDesignerPropertyEditorInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerPropertyEditorInterface_PTR_CppToPython_QDesignerPropertyEditorInterface(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDesignerPropertyEditorInterface *>(const_cast<void *>(cppIn)), Sbk_QDesignerPropertyEditorInterface_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDesignerPropertyEditorInterface_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface(self,parent:PySide6.QtWidgets.QWidget,flags:PySide6.QtCore.Qt.WindowType={})",
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface.core(self)->PySide6.QtDesigner.QDesignerFormEditorInterface",
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface.currentPropertyName(self)->QString",
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface.isReadOnly(self)->bool",
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface.object(self)->PySide6.QtCore.QObject",
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface.setObject(self,object:PySide6.QtCore.QObject)",
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface.setPropertyValue(self,name:QString,value:QVariant,changed:bool=true)",
    "PySide6.QtDesigner.QDesignerPropertyEditorInterface.setReadOnly(self,readOnly:bool)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDesignerPropertyEditorInterface_SignatureByteSize = 243;
static constexpr uint8_t QDesignerPropertyEditorInterface_SignatureBytes[243] = {
    0x78, 0xda, 0x9d, 0x92, 0xcb, 0x6a, 0xc3, 0x30, 0x10, 0x45, 0xf7, 0xf9, 0x92, 0x1a, 0x54, 0x2d,
    0xbb, 0x10, 0xa4, 0x9b, 0x3e, 0xa0, 0x9b, 0xd8, 0x6a, 0x42, 0xb2, 0x56, 0xac, 0xb1, 0xa2, 0xa2,
    0x48, 0x66, 0x34, 0x6e, 0x30, 0xa5, 0xff, 0x5e, 0x3f, 0xd3, 0x27, 0x85, 0x68, 0xa5, 0xd1, 0x5c,
    0xe6, 0xdc, 0xd1, 0x45, 0x45, 0xbb, 0xb6, 0x1a, 0x6e, 0xb8, 0xa4, 0x7b, 0x88, 0xd6, 0x78, 0x40,
    0x2e, 0xe7, 0xaa, 0xc0, 0x50, 0x03, 0x52, 0xfb, 0xa0, 0x2d, 0x05, 0x7c, 0xf2, 0x04, 0x58, 0xa9,
    0x12, 0xae, 0x22, 0xb8, 0x8a, 0xd5, 0x0a, 0xc1, 0x93, 0x28, 0xce, 0xf3, 0x3b, 0xab, 0x0d, 0x50,
    0xe4, 0x72, 0x2c, 0x58, 0xe5, 0x94, 0x89, 0x5f, 0xf4, 0xbb, 0x80, 0xd0, 0x1d, 0x7c, 0x67, 0xbd,
    0x0e, 0xa7, 0x4d, 0x5b, 0xc3, 0xf2, 0xed, 0x3d, 0x5b, 0x14, 0x97, 0x2f, 0xc0, 0xcb, 0x0e, 0x35,
    0x6c, 0x91, 0x5d, 0xdf, 0xfe, 0x37, 0xff, 0x18, 0xf0, 0xf8, 0x63, 0x36, 0xcd, 0xaf, 0xc1, 0xfe,
    0xb1, 0xb3, 0xbc, 0x52, 0xc7, 0xb3, 0xbd, 0x5c, 0x13, 0x5a, 0x6f, 0x92, 0xb0, 0x36, 0x3e, 0x83,
    0xd2, 0xb9, 0x77, 0xed, 0x4c, 0xdb, 0x87, 0xe0, 0x92, 0x50, 0x61, 0xff, 0x02, 0x25, 0xfd, 0xce,
    0x64, 0x0c, 0x3d, 0x1f, 0xd4, 0x24, 0x70, 0x04, 0xca, 0x3f, 0xd9, 0x6c, 0xf4, 0x11, 0x7f, 0x1b,
    0x64, 0xa9, 0x0e, 0xb3, 0xb4, 0x55, 0xae, 0x99, 0xbe, 0x97, 0xef, 0x32, 0x16, 0x53, 0xb8, 0xec,
    0xb5, 0xef, 0x0b, 0xb9, 0x55, 0x68, 0x95, 0x27, 0x56, 0x1e, 0x94, 0x37, 0xa0, 0x45, 0x9f, 0xd6,
    0x92, 0xb0, 0x81, 0x64, 0xe3, 0x6f, 0xf9, 0x33, 0x9c, 0x6e, 0x03, 0x38, 0x5b, 0x7c, 0x00, 0x89,
    0xd4, 0x29, 0x12
};
#endif

PyTypeObject *init_QDesignerPropertyEditorInterface(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesignerPropertyEditorInterface_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QDesignerPropertyEditorInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerPropertyEditorInterface",
        "QDesignerPropertyEditorInterface*",
        &Sbk_QDesignerPropertyEditorInterface_spec,
        &Shiboken::callCppDestructor< QDesignerPropertyEditorInterface >,
        Sbk_QDesignerPropertyEditorInterface_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QDesignerPropertyEditorInterface_TypeF(); // references _Sbk_QDesignerPropertyEditorInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDesignerPropertyEditorInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDesignerPropertyEditorInterface_SignatureBytes, QDesignerPropertyEditorInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerPropertyEditorInterface_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerPropertyEditorInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerPropertyEditorInterface_PythonToCpp_QDesignerPropertyEditorInterface_PTR,
        is_QDesignerPropertyEditorInterface_PythonToCpp_QDesignerPropertyEditorInterface_PTR_Convertible,
        QDesignerPropertyEditorInterface_PTR_CppToPython_QDesignerPropertyEditorInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerPropertyEditorInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerPropertyEditorInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerPropertyEditorInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerPropertyEditorInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDesignerPropertyEditorInterfaceWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QDesignerPropertyEditorInterface_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QDesignerPropertyEditorInterface_TypeF(), &Sbk_QDesignerPropertyEditorInterfaceSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDesignerPropertyEditorInterface_TypeF(), &Sbk_QDesignerPropertyEditorInterface_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QDesignerPropertyEditorInterface::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDesignerPropertyEditorInterface::staticMetaObject, sizeof(QDesignerPropertyEditorInterfaceWrapper));

    return pyType;
}
