// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qpydesignermembersheetextension_wrapper.h"

// Wrappers providing overrides
#include "qdesignermembersheetextension_wrapper.h"
#include "qdesignerpropertysheetextension_wrapper.h"
#include "qdesignerwidgetboxinterface_wrapper.h"

// Extra includes
#include <qpydesignerextensions.h>

// Argument includes
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPyDesignerMemberSheetExtensionWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPyDesignerMemberSheetExtensionWrapper::QPyDesignerMemberSheetExtensionWrapper(::QObject * parent) : QPyDesignerMemberSheetExtension(parent)
{
}

void QPyDesignerMemberSheetExtensionWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_childEvent("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, event);
}

void QPyDesignerMemberSheetExtensionWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, signal);
}

int QPyDesignerMemberSheetExtensionWrapper::count() const
{
    static const char *funcName = "count";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.count");
        return 0;
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_count("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride);
}

void QPyDesignerMemberSheetExtensionWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_customEvent("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, event);
}

::QString QPyDesignerMemberSheetExtensionWrapper::declaredInClass(int index) const
{
    static const char *funcName = "declaredInClass";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.declaredInClass");
        return ::QString();
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_propertyGroup("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

void QPyDesignerMemberSheetExtensionWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, signal);
}

bool QPyDesignerMemberSheetExtensionWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_event("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, event);
}

bool QPyDesignerMemberSheetExtensionWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_eventFilter("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, watched, event);
}

int QPyDesignerMemberSheetExtensionWrapper::indexOf(const ::QString & name) const
{
    static const char *funcName = "indexOf";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.indexOf");
        return 0;
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_indexOf("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, name);
}

bool QPyDesignerMemberSheetExtensionWrapper::inheritedFromWidget(int index) const
{
    static const char *funcName = "inheritedFromWidget";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.inheritedFromWidget");
        return false;
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_hasReset("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

bool QPyDesignerMemberSheetExtensionWrapper::isSignal(int index) const
{
    static const char *funcName = "isSignal";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.isSignal");
        return false;
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_hasReset("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

bool QPyDesignerMemberSheetExtensionWrapper::isSlot(int index) const
{
    static const char *funcName = "isSlot";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.isSlot");
        return false;
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_hasReset("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

bool QPyDesignerMemberSheetExtensionWrapper::isVisible(int index) const
{
    static const char *funcName = "isVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.isVisible");
        return false;
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_hasReset("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

::QString QPyDesignerMemberSheetExtensionWrapper::memberGroup(int index) const
{
    static const char *funcName = "memberGroup";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.memberGroup");
        return ::QString();
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_propertyGroup("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

::QString QPyDesignerMemberSheetExtensionWrapper::memberName(int index) const
{
    static const char *funcName = "memberName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.memberName");
        return ::QString();
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_propertyGroup("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

::QList<QByteArray> QPyDesignerMemberSheetExtensionWrapper::parameterNames(int index) const
{
    static const char *funcName = "parameterNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.parameterNames");
        return {};
    }
    return QDesignerMemberSheetExtensionWrapper::sbk_o_parameterNames("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

::QList<QByteArray> QPyDesignerMemberSheetExtensionWrapper::parameterTypes(int index) const
{
    static const char *funcName = "parameterTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.parameterTypes");
        return {};
    }
    return QDesignerMemberSheetExtensionWrapper::sbk_o_parameterNames("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

void QPyDesignerMemberSheetExtensionWrapper::setMemberGroup(int index, const ::QString & group)
{
    static const char *funcName = "setMemberGroup";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.setMemberGroup");
        return;
    }
    QDesignerPropertySheetExtensionWrapper::sbk_o_setPropertyGroup("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index, group);
}

void QPyDesignerMemberSheetExtensionWrapper::setVisible(int index, bool b)
{
    static const char *funcName = "setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.setVisible");
        return;
    }
    QDesignerPropertySheetExtensionWrapper::sbk_o_setAttribute("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index, b);
}

::QString QPyDesignerMemberSheetExtensionWrapper::signature(int index) const
{
    static const char *funcName = "signature";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyDesignerMemberSheetExtension.signature");
        return ::QString();
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_propertyGroup("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, index);
}

void QPyDesignerMemberSheetExtensionWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_timerEvent("QPyDesignerMemberSheetExtension", funcName, gil, pyOverride, event);
}

const QMetaObject *QPyDesignerMemberSheetExtensionWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPyDesignerMemberSheetExtension::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPyDesignerMemberSheetExtensionWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPyDesignerMemberSheetExtension::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPyDesignerMemberSheetExtensionWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPyDesignerMemberSheetExtensionWrapper *>(this));
    return QPyDesignerMemberSheetExtension::qt_metacast(_clname);
}

QPyDesignerMemberSheetExtensionWrapper::~QPyDesignerMemberSheetExtensionWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPyDesignerMemberSheetExtension_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QPyDesignerMemberSheetExtension");
        return -1;
    }

    Shiboken::ObjectType::copyMultipleInheritance(type, myType);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPyDesignerMemberSheetExtension >()))
        return -1;

    QPyDesignerMemberSheetExtensionWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QPyDesignerMemberSheetExtension", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPyDesignerMemberSheetExtension::QPyDesignerMemberSheetExtension(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QPyDesignerMemberSheetExtension(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPyDesignerMemberSheetExtension(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPyDesignerMemberSheetExtension(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPyDesignerMemberSheetExtensionWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPyDesignerMemberSheetExtensionWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPyDesignerMemberSheetExtension >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX]);
    };


    return 1;
}


static const char *Sbk_QPyDesignerMemberSheetExtension_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPyDesignerMemberSheetExtension_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPyDesignerMemberSheetExtension_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPyDesignerMemberSheetExtension *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPyDesignerMemberSheetExtensionWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPyDesignerMemberSheetExtension_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPyDesignerMemberSheetExtension_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_QPyDesignerMemberSheetExtension_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QPyDesignerMemberSheetExtension *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QPyDesignerMemberSheetExtension *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QDesignerMemberSheetExtension *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QDesignerMemberSheetExtension *>(static_cast<const QPyDesignerMemberSheetExtension *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QPyDesignerMemberSheetExtensionSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QPyDesignerMemberSheetExtension *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerMemberSheetExtension_IDX]))
        return static_cast< ::QDesignerMemberSheetExtension *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPyDesignerMemberSheetExtension_Type = nullptr;
static PyTypeObject *Sbk_QPyDesignerMemberSheetExtension_TypeF(void)
{
    return _Sbk_QPyDesignerMemberSheetExtension_Type;
}

static PyType_Slot Sbk_QPyDesignerMemberSheetExtension_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPyDesignerMemberSheetExtension_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPyDesignerMemberSheetExtension_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPyDesignerMemberSheetExtension_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPyDesignerMemberSheetExtension_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPyDesignerMemberSheetExtension_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPyDesignerMemberSheetExtension_spec = {
    "2:PySide6.QtDesigner.QPyDesignerMemberSheetExtension",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPyDesignerMemberSheetExtension_slots
};

} //extern "C"

static void *Sbk_QPyDesignerMemberSheetExtension_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPyDesignerMemberSheetExtension *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QDesignerMemberSheetExtension >())
        return dynamic_cast< ::QPyDesignerMemberSheetExtension *>(reinterpret_cast< ::QDesignerMemberSheetExtension *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPyDesignerMemberSheetExtension_PythonToCpp_QPyDesignerMemberSheetExtension_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPyDesignerMemberSheetExtension_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPyDesignerMemberSheetExtension_PythonToCpp_QPyDesignerMemberSheetExtension_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPyDesignerMemberSheetExtension_TypeF()))
        return QPyDesignerMemberSheetExtension_PythonToCpp_QPyDesignerMemberSheetExtension_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPyDesignerMemberSheetExtension_PTR_CppToPython_QPyDesignerMemberSheetExtension(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPyDesignerMemberSheetExtension *>(const_cast<void *>(cppIn)), Sbk_QPyDesignerMemberSheetExtension_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPyDesignerMemberSheetExtension_SignatureStrings[] = {
    "PySide6.QtDesigner.QPyDesignerMemberSheetExtension(self,parent:PySide6.QtCore.QObject=nullptr)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPyDesignerMemberSheetExtension_SignatureByteSize = 89;
static constexpr uint8_t QPyDesignerMemberSheetExtension_SignatureBytes[89] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x49, 0x2d, 0xce,
    0x4c, 0xcf, 0x4b, 0x2d, 0xd2, 0x0b, 0x0c, 0xa8, 0x84, 0xb1, 0x7d, 0x53, 0x73, 0x93, 0x52, 0x8b,
    0x82, 0x33, 0x52, 0x53, 0x4b, 0x5c, 0x2b, 0x4a, 0x52, 0xf3, 0x8a, 0x33, 0xf3, 0xf3, 0x34, 0x8a,
    0x53, 0x73, 0xd2, 0x74, 0x0a, 0x12, 0x8b, 0x52, 0xf3, 0x4a, 0xac, 0x02, 0xe0, 0xda, 0x9d, 0xf3,
    0x8b, 0x52, 0xf5, 0x02, 0xfd, 0x93, 0xb2, 0x52, 0x93, 0x4b, 0x6c, 0xf3, 0x4a, 0x73, 0x72, 0x0a,
    0x4a, 0x8a, 0x34, 0xb9, 0x00, 0xad, 0x6d, 0x23, 0x49
};
#endif

PyTypeObject *init_QPyDesignerMemberSheetExtension(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX].type;

    Shiboken::AutoDecRef Sbk_QPyDesignerMemberSheetExtension_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerMemberSheetExtension_IDX]))));

    _Sbk_QPyDesignerMemberSheetExtension_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPyDesignerMemberSheetExtension",
        "QPyDesignerMemberSheetExtension*",
        &Sbk_QPyDesignerMemberSheetExtension_spec,
        &Shiboken::callCppDestructor< QPyDesignerMemberSheetExtension >,
        Sbk_QPyDesignerMemberSheetExtension_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPyDesignerMemberSheetExtension_TypeF(); // references _Sbk_QPyDesignerMemberSheetExtension_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPyDesignerMemberSheetExtension_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPyDesignerMemberSheetExtension_SignatureBytes, QPyDesignerMemberSheetExtension_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPyDesignerMemberSheetExtension_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QPyDesignerMemberSheetExtension_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPyDesignerMemberSheetExtension_PythonToCpp_QPyDesignerMemberSheetExtension_PTR,
        is_QPyDesignerMemberSheetExtension_PythonToCpp_QPyDesignerMemberSheetExtension_PTR_Convertible,
        QPyDesignerMemberSheetExtension_PTR_CppToPython_QPyDesignerMemberSheetExtension);

    Shiboken::Conversions::registerConverterName(converter, "QPyDesignerMemberSheetExtension");
    Shiboken::Conversions::registerConverterName(converter, "QPyDesignerMemberSheetExtension*");
    Shiboken::Conversions::registerConverterName(converter, "QPyDesignerMemberSheetExtension&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPyDesignerMemberSheetExtension).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPyDesignerMemberSheetExtensionWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QPyDesignerMemberSheetExtension_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QPyDesignerMemberSheetExtension_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QPyDesignerMemberSheetExtension_TypeF(), &Sbk_QPyDesignerMemberSheetExtensionSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPyDesignerMemberSheetExtension_TypeF(), &Sbk_QPyDesignerMemberSheetExtension_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPyDesignerMemberSheetExtension::staticMetaObject, sizeof(QPyDesignerMemberSheetExtensionWrapper));

    return pyType;
}
