// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qabstractdataproxy_wrapper.h"

// Wrappers providing overrides
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QtGraphs/qabstractdataproxy.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractDataProxyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QAbstractDataProxyWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QAbstractDataProxy", funcName, gil, pyOverride, event);
}

void QAbstractDataProxyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QAbstractDataProxy", funcName, gil, pyOverride, signal);
}

void QAbstractDataProxyWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QAbstractDataProxy", funcName, gil, pyOverride, event);
}

void QAbstractDataProxyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QAbstractDataProxy", funcName, gil, pyOverride, signal);
}

bool QAbstractDataProxyWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QAbstractDataProxy", funcName, gil, pyOverride, event);
}

bool QAbstractDataProxyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QAbstractDataProxy", funcName, gil, pyOverride, watched, event);
}

void QAbstractDataProxyWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QAbstractDataProxy", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstractDataProxyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractDataProxy::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractDataProxyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractDataProxy::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractDataProxyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractDataProxyWrapper *>(this));
    return QAbstractDataProxy::qt_metacast(_clname);
}

QAbstractDataProxyWrapper::~QAbstractDataProxyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QAbstractDataProxy_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QAbstractDataProxy");
    return -1;
}

static PyObject *Sbk_QAbstractDataProxyFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAbstractDataProxy::DataType cppResult = const_cast<const ::QAbstractDataProxy *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_DataType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QAbstractDataProxy_PropertyStrings[] = {
    "type:",
    nullptr // Sentinel
};

static const char *Sbk_QAbstractDataProxy_EnumFlagInfo[] = {
    "DataType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractDataProxy_methods[] = {
    {"type", reinterpret_cast<PyCFunction>(Sbk_QAbstractDataProxyFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractDataProxy_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractDataProxyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractDataProxy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractDataProxy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractDataProxy_Type = nullptr;
static PyTypeObject *Sbk_QAbstractDataProxy_TypeF(void)
{
    return _Sbk_QAbstractDataProxy_Type;
}

static PyType_Slot Sbk_QAbstractDataProxy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractDataProxy_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractDataProxy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractDataProxy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractDataProxy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractDataProxy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractDataProxy_spec = {
    "2:PySide6.QtGraphs.QAbstractDataProxy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractDataProxy_slots
};

} //extern "C"

static void *Sbk_QAbstractDataProxy_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractDataProxy *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractDataProxy_DataType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractDataProxy::DataType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractDataProxy::DataType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractDataProxy_DataType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_DataType_IDX])))
        return Enum_PythonToCpp_QAbstractDataProxy_DataType;
    return {};
}

static PyObject *QAbstractDataProxy_DataType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractDataProxy::DataType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractDataProxy::DataType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_DataType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractDataProxy_PythonToCpp_QAbstractDataProxy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractDataProxy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractDataProxy_PythonToCpp_QAbstractDataProxy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractDataProxy_TypeF()))
        return QAbstractDataProxy_PythonToCpp_QAbstractDataProxy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractDataProxy_PTR_CppToPython_QAbstractDataProxy(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractDataProxy *>(const_cast<void *>(cppIn)), Sbk_QAbstractDataProxy_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractDataProxy_SignatureStrings[] = {
    "PySide6.QtGraphs.QAbstractDataProxy.type(self)->PySide6.QtGraphs.QAbstractDataProxy.DataType",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractDataProxy_SignatureByteSize = 65;
static constexpr uint8_t QAbstractDataProxy_SignatureBytes[65] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0x4a, 0x2c,
    0xc8, 0x28, 0xd6, 0x0b, 0x74, 0x4c, 0x2a, 0x2e, 0x29, 0x4a, 0x4c, 0x2e, 0x71, 0x49, 0x2c, 0x49,
    0x0c, 0x28, 0xca, 0xaf, 0xa8, 0xd4, 0x2b, 0xa9, 0x2c, 0x48, 0xd5, 0x28, 0x4e, 0xcd, 0x49, 0xd3,
    0xd4, 0xb5, 0x0b, 0x20, 0x42, 0x3d, 0x88, 0x15, 0x02, 0xd4, 0xc3, 0x05, 0x00, 0x3e, 0xd5, 0x22,
    0x01
};
#endif

PyTypeObject *init_QAbstractDataProxy(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractDataProxy_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAbstractDataProxy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractDataProxy",
        "QAbstractDataProxy*",
        &Sbk_QAbstractDataProxy_spec,
        &Shiboken::callCppDestructor< QAbstractDataProxy >,
        Sbk_QAbstractDataProxy_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractDataProxy_TypeF(); // references _Sbk_QAbstractDataProxy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractDataProxy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractDataProxy_SignatureBytes, QAbstractDataProxy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractDataProxy_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractDataProxy_PythonToCpp_QAbstractDataProxy_PTR,
        is_QAbstractDataProxy_PythonToCpp_QAbstractDataProxy_PTR_Convertible,
        QAbstractDataProxy_PTR_CppToPython_QAbstractDataProxy);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractDataProxy");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractDataProxy*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractDataProxy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractDataProxy).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractDataProxyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractDataProxy_TypeF(), &Sbk_QAbstractDataProxy_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractDataProxy_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DataType'.
    const char *DataType_Initializer[] = {
        "None_",
        "Bar",
        "Scatter",
        "Surface",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t DataType_InitializerValues[] = {
        int8_t(QAbstractDataProxy::DataType::None),    //  0x00  0
        int8_t(QAbstractDataProxy::DataType::Bar),     //  0x01  1
        int8_t(QAbstractDataProxy::DataType::Scatter), //  0x02  2
        int8_t(QAbstractDataProxy::DataType::Surface)  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractDataProxy_TypeF(),
        "2:PySide6.QtGraphs.QAbstractDataProxy.DataType",
        DataType_Initializer, DataType_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_DataType_IDX].type = EType;
    // Register converter for enum 'QAbstractDataProxy::DataType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractDataProxy_DataType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractDataProxy_DataType,
            is_Enum_PythonToCpp_QAbstractDataProxy_DataType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractDataProxy::DataType");
        Shiboken::Conversions::registerConverterAlias(converter, "DataType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DataType' enum.

    qRegisterMetaType< ::QAbstractDataProxy::DataType >("QAbstractDataProxy::DataType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractDataProxy::staticMetaObject, sizeof(QAbstractDataProxyWrapper));

    return pyType;
}
