// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qscatterdataproxy_wrapper.h"

// Wrappers providing overrides
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QList>
#include <QtGraphs/qscatter3dseries.h>
#include <QtGraphs/qscatterdataitem.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QScatterDataProxyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QScatterDataProxyWrapper::QScatterDataProxyWrapper(::QObject * parent) : QScatterDataProxy(parent)
{
}

void QScatterDataProxyWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QScatterDataProxy", funcName, gil, pyOverride, event);
}

void QScatterDataProxyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QScatterDataProxy", funcName, gil, pyOverride, signal);
}

void QScatterDataProxyWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QScatterDataProxy", funcName, gil, pyOverride, event);
}

void QScatterDataProxyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QScatterDataProxy", funcName, gil, pyOverride, signal);
}

bool QScatterDataProxyWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QScatterDataProxy", funcName, gil, pyOverride, event);
}

bool QScatterDataProxyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QScatterDataProxy", funcName, gil, pyOverride, watched, event);
}

void QScatterDataProxyWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QScatterDataProxy", funcName, gil, pyOverride, event);
}

const QMetaObject *QScatterDataProxyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QScatterDataProxy::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QScatterDataProxyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QScatterDataProxy::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QScatterDataProxyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QScatterDataProxyWrapper *>(this));
    return QScatterDataProxy::qt_metacast(_clname);
}

QScatterDataProxyWrapper::~QScatterDataProxyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScatterDataProxy_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScatterDataProxy >()))
        return -1;

    QScatterDataProxyWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QScatterDataProxy", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScatterDataProxy::QScatterDataProxy(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QScatterDataProxy(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QScatterDataProxy(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QScatterDataProxy(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QScatterDataProxyWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QScatterDataProxyWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QScatterDataProxy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QScatterDataProxyFunc_addItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataProxy::addItem(QScatterDataItem)->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), (pyArg)))) {
        overloadId = 0; // addItem(QScatterDataItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addItem", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScatterDataItem cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addItem(QScatterDataItem)
            qsizetype cppResult = cppSelf->addItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QScatterDataProxyFunc_addItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataProxy::addItems(QList<QScatterDataItem>)->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QScatterDataItem_IDX], (pyArg)))) {
        overloadId = 0; // addItems(QList<QScatterDataItem>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addItems", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        ::QList<QScatterDataItem> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addItems(QList<QScatterDataItem>)
            qsizetype cppResult = cppSelf->addItems(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QScatterDataProxyFunc_insertItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScatterDataProxy::insertItem(qsizetype,QScatterDataItem)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertItem(qsizetype,QScatterDataItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertItem", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QScatterDataItem cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertItem(qsizetype,QScatterDataItem)
            cppSelf->insertItem(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QScatterDataProxyFunc_insertItems(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertItems", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScatterDataProxy::insertItems(qsizetype,QList<QScatterDataItem>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QScatterDataItem_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertItems(qsizetype,QList<QScatterDataItem>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertItems", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<QScatterDataItem> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertItems(qsizetype,QList<QScatterDataItem>)
            cppSelf->insertItems(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QScatterDataProxyFunc_itemAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataProxy::itemAt(qsizetype)const->const QScatterDataItem&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // itemAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemAt", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemAt(qsizetype)const
            const QScatterDataItem & cppResult = const_cast<const ::QScatterDataProxy *>(cppSelf)->itemAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QScatterDataProxyFunc_itemCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemCount()const
        qsizetype cppResult = const_cast<const ::QScatterDataProxy *>(cppSelf)->itemCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QScatterDataProxyFunc_removeItems(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "removeItems", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScatterDataProxy::removeItems(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // removeItems(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeItems", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeItems(qsizetype,qsizetype)
            cppSelf->removeItems(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QScatterDataProxyFunc_resetArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resetArray", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScatterDataProxy::resetArray()
    // 1: QScatterDataProxy::resetArray(QList<QScatterDataItem>)
    if (numArgs == 0) {
        overloadId = 0; // resetArray()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QScatterDataItem_IDX], (pyArgs[0])))) {
        overloadId = 1; // resetArray(QList<QScatterDataItem>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resetArray", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // resetArray()
        {

            // resetArray()
            cppSelf->resetArray();
            break;
        }
        case 1: // resetArray(QList<QScatterDataItem> newArray)
        {
            ::QList<QScatterDataItem> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resetArray(QList<QScatterDataItem>)
                cppSelf->resetArray(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QScatterDataProxyFunc_series(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // series()const
        QScatter3DSeries * cppResult = const_cast<const ::QScatterDataProxy *>(cppSelf)->series();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatter3DSeries_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QScatterDataProxyFunc_setItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScatterDataProxy::setItem(qsizetype,QScatterDataItem)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setItem(qsizetype,QScatterDataItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItem", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QScatterDataItem cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItem(qsizetype,QScatterDataItem)
            cppSelf->setItem(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QScatterDataProxyFunc_setItems(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItems", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScatterDataProxy::setItems(qsizetype,QList<QScatterDataItem>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QScatterDataItem_IDX], (pyArgs[1])))) {
        overloadId = 0; // setItems(qsizetype,QList<QScatterDataItem>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItems", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<QScatterDataItem> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItems(qsizetype,QList<QScatterDataItem>)
            cppSelf->setItems(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QScatterDataProxy_PropertyStrings[] = {
    "itemCount:",
    "series:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScatterDataProxy_methods[] = {
    {"addItem", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_addItem), METH_O, nullptr},
    {"addItems", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_addItems), METH_O, nullptr},
    {"insertItem", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_insertItem), METH_VARARGS, nullptr},
    {"insertItems", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_insertItems), METH_VARARGS, nullptr},
    {"itemAt", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_itemAt), METH_O, nullptr},
    {"itemCount", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_itemCount), METH_NOARGS, nullptr},
    {"removeItems", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_removeItems), METH_VARARGS, nullptr},
    {"resetArray", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_resetArray), METH_VARARGS, nullptr},
    {"series", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_series), METH_NOARGS, nullptr},
    {"setItem", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_setItem), METH_VARARGS, nullptr},
    {"setItems", reinterpret_cast<PyCFunction>(Sbk_QScatterDataProxyFunc_setItems), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScatterDataProxy_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScatterDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QScatterDataProxyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScatterDataProxy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScatterDataProxy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScatterDataProxy_Type = nullptr;
static PyTypeObject *Sbk_QScatterDataProxy_TypeF(void)
{
    return _Sbk_QScatterDataProxy_Type;
}

static PyType_Slot Sbk_QScatterDataProxy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScatterDataProxy_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScatterDataProxy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScatterDataProxy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScatterDataProxy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScatterDataProxy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScatterDataProxy_spec = {
    "2:PySide6.QtGraphs.QScatterDataProxy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScatterDataProxy_slots
};

} //extern "C"

static void *Sbk_QScatterDataProxy_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QScatterDataProxy *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScatterDataProxy_PythonToCpp_QScatterDataProxy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScatterDataProxy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScatterDataProxy_PythonToCpp_QScatterDataProxy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScatterDataProxy_TypeF()))
        return QScatterDataProxy_PythonToCpp_QScatterDataProxy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScatterDataProxy_PTR_CppToPython_QScatterDataProxy(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QScatterDataProxy *>(const_cast<void *>(cppIn)), Sbk_QScatterDataProxy_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScatterDataProxy_SignatureStrings[] = {
    "PySide6.QtGraphs.QScatterDataProxy(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemCount:qsizetype=None,series:QScatter3DSeries=None)",
    "PySide6.QtGraphs.QScatterDataProxy.addItem(self,item:PySide6.QtGraphs.QScatterDataItem)->qsizetype",
    "PySide6.QtGraphs.QScatterDataProxy.addItems(self,items:QList[PySide6.QtGraphs.QScatterDataItem])->qsizetype",
    "PySide6.QtGraphs.QScatterDataProxy.insertItem(self,index:qsizetype,item:PySide6.QtGraphs.QScatterDataItem)",
    "PySide6.QtGraphs.QScatterDataProxy.insertItems(self,index:qsizetype,items:QList[PySide6.QtGraphs.QScatterDataItem])",
    "PySide6.QtGraphs.QScatterDataProxy.itemAt(self,index:qsizetype)->PySide6.QtGraphs.QScatterDataItem",
    "PySide6.QtGraphs.QScatterDataProxy.itemCount(self)->qsizetype",
    "PySide6.QtGraphs.QScatterDataProxy.removeItems(self,index:qsizetype,removeCount:qsizetype)",
    "1:PySide6.QtGraphs.QScatterDataProxy.resetArray(self)",
    "0:PySide6.QtGraphs.QScatterDataProxy.resetArray(self,newArray:QList[PySide6.QtGraphs.QScatterDataItem])",
    "PySide6.QtGraphs.QScatterDataProxy.series(self)->PySide6.QtGraphs.QScatter3DSeries",
    "PySide6.QtGraphs.QScatterDataProxy.setItem(self,index:qsizetype,item:PySide6.QtGraphs.QScatterDataItem)",
    "PySide6.QtGraphs.QScatterDataProxy.setItems(self,index:qsizetype,items:QList[PySide6.QtGraphs.QScatterDataItem])",
    nullptr}; // Sentinel
#else
static constexpr size_t QScatterDataProxy_SignatureByteSize = 278;
static constexpr uint8_t QScatterDataProxy_SignatureBytes[278] = {
    0x78, 0xda, 0xbd, 0x93, 0x51, 0x4b, 0xc3, 0x30, 0x10, 0xc7, 0xdf, 0xfb, 0x49, 0xac, 0xd4, 0x32,
    0x11, 0x7c, 0x08, 0x4c, 0x18, 0x1b, 0x88, 0x28, 0xae, 0xa5, 0x8f, 0xe2, 0x43, 0x5c, 0x4e, 0x16,
    0xe9, 0x92, 0x7a, 0xb9, 0xb9, 0xc5, 0x4f, 0x6f, 0xd6, 0xd8, 0x4d, 0x64, 0x5b, 0x13, 0x19, 0x3e,
    0x26, 0xb9, 0xbb, 0xdf, 0xff, 0xfe, 0xb9, 0x2b, 0x6c, 0x25, 0x05, 0x5c, 0xe7, 0x25, 0xdd, 0x22,
    0x6f, 0xe6, 0x26, 0x2f, 0xab, 0x19, 0x27, 0x02, 0x9c, 0x70, 0xe2, 0x05, 0xea, 0xb5, 0x3d, 0x33,
    0x50, 0xbf, 0x66, 0x0d, 0x47, 0x50, 0xc4, 0x8a, 0x6d, 0xf8, 0x58, 0x23, 0xe4, 0xe5, 0xf4, 0xe5,
    0x0d, 0x66, 0x34, 0x54, 0xcb, 0xba, 0x6e, 0x08, 0xb3, 0x73, 0x76, 0x0f, 0x76, 0xa5, 0x51, 0x4c,
    0x55, 0x6d, 0x87, 0x8f, 0x5a, 0x41, 0x26, 0x09, 0x16, 0x63, 0xbd, 0x74, 0xb9, 0xef, 0x46, 0x7e,
    0x02, 0xd9, 0x06, 0xfc, 0x83, 0x01, 0x94, 0x60, 0x58, 0xc7, 0xbb, 0x9a, 0x54, 0xed, 0x45, 0xfb,
    0x98, 0x26, 0x45, 0xaf, 0xae, 0x9c, 0x0b, 0x71, 0xe7, 0x8a, 0x7b, 0x7d, 0x1b, 0x0c, 0x3b, 0x9a,
    0xb4, 0x89, 0x4d, 0x2f, 0x6e, 0xb6, 0x2a, 0x22, 0x10, 0x66, 0xc7, 0x70, 0x82, 0x1f, 0xa4, 0xa1,
    0xa7, 0x5e, 0xd4, 0x73, 0x2c, 0x4b, 0x2a, 0xe7, 0x08, 0xfd, 0xe8, 0x48, 0x09, 0x58, 0xef, 0x4c,
    0x0b, 0xed, 0x30, 0x0e, 0x65, 0x0e, 0xb3, 0x22, 0x3a, 0x0d, 0x62, 0xba, 0xc8, 0x11, 0xed, 0xc5,
    0x39, 0xa7, 0x7a, 0x21, 0xa1, 0x88, 0x76, 0xd4, 0x5a, 0x4a, 0xac, 0xff, 0x08, 0x0b, 0xfd, 0x01,
    0x47, 0x4c, 0xf1, 0x01, 0xbf, 0x66, 0x39, 0x4d, 0x2e, 0x59, 0x50, 0x71, 0x03, 0x34, 0x42, 0xe4,
    0x7e, 0x9d, 0xd2, 0x64, 0xf0, 0x87, 0xac, 0x4c, 0xc1, 0xaa, 0x3d, 0x9d, 0xf6, 0x67, 0xfc, 0x22,
    0x76, 0x9e, 0x1d, 0x4c, 0xe8, 0x16, 0x34, 0xac, 0xe4, 0xff, 0x0c, 0xf2, 0x37, 0xe7, 0x44, 0x53,
    0xfc, 0x05, 0x73, 0xf1, 0xde, 0xe2
};
#endif

PyTypeObject *init_QScatterDataProxy(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX].type;

    Shiboken::AutoDecRef Sbk_QScatterDataProxy_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_IDX]))));

    _Sbk_QScatterDataProxy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScatterDataProxy",
        "QScatterDataProxy*",
        &Sbk_QScatterDataProxy_spec,
        &Shiboken::callCppDestructor< QScatterDataProxy >,
        Sbk_QScatterDataProxy_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScatterDataProxy_TypeF(); // references _Sbk_QScatterDataProxy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScatterDataProxy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScatterDataProxy_SignatureBytes, QScatterDataProxy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScatterDataProxy_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScatterDataProxy_PythonToCpp_QScatterDataProxy_PTR,
        is_QScatterDataProxy_PythonToCpp_QScatterDataProxy_PTR_Convertible,
        QScatterDataProxy_PTR_CppToPython_QScatterDataProxy);

    Shiboken::Conversions::registerConverterName(converter, "QScatterDataProxy");
    Shiboken::Conversions::registerConverterName(converter, "QScatterDataProxy*");
    Shiboken::Conversions::registerConverterName(converter, "QScatterDataProxy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScatterDataProxy).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QScatterDataProxyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QScatterDataProxy_TypeF(), &Sbk_QScatterDataProxy_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QScatterDataProxy::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QScatterDataProxy::staticMetaObject, sizeof(QScatterDataProxyWrapper));

    return pyType;
}
