// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qvalueaxis_wrapper.h"

// Wrappers providing overrides
#include "qabstractaxis_wrapper.h"
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QString>
#include <QtGraphs/qabstractaxis.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QValueAxisWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QValueAxisWrapper::QValueAxisWrapper(::QObject * parent) : QValueAxis(parent)
{
}

void QValueAxisWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QValueAxis", funcName, gil, pyOverride, event);
}

void QValueAxisWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QValueAxis", funcName, gil, pyOverride, signal);
}

void QValueAxisWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QValueAxis", funcName, gil, pyOverride, event);
}

void QValueAxisWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QValueAxis", funcName, gil, pyOverride, signal);
}

bool QValueAxisWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QValueAxis", funcName, gil, pyOverride, event);
}

bool QValueAxisWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QValueAxis", funcName, gil, pyOverride, watched, event);
}

void QValueAxisWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QValueAxis", funcName, gil, pyOverride, event);
}

::QAbstractAxis::AxisType QValueAxisWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QValueAxis::type();
    }
    return QAbstractAxisWrapper::sbk_o_type("QValueAxis", funcName, gil, pyOverride);
}

const QMetaObject *QValueAxisWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QValueAxis::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QValueAxisWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QValueAxis::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QValueAxisWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QValueAxisWrapper *>(this));
    return QValueAxis::qt_metacast(_clname);
}

QValueAxisWrapper::~QValueAxisWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QValueAxis_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QValueAxis >()))
        return -1;

    QValueAxisWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QValueAxis", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QValueAxis::QValueAxis(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QValueAxis(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QValueAxis(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QValueAxis(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QValueAxisWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QValueAxisWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QValueAxis >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QValueAxisFunc_labelDecimals(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelDecimals()const
        int cppResult = const_cast<const ::QValueAxis *>(cppSelf)->labelDecimals();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_labelFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelFormat()const
        QString cppResult = const_cast<const ::QValueAxis *>(cppSelf)->labelFormat();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_max(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // max()const
        qreal cppResult = const_cast<const ::QValueAxis *>(cppSelf)->max();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_min(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // min()const
        qreal cppResult = const_cast<const ::QValueAxis *>(cppSelf)->min();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_pan(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pan()const
        qreal cppResult = const_cast<const ::QValueAxis *>(cppSelf)->pan();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_setLabelDecimals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setLabelDecimals(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLabelDecimals(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelDecimals", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelDecimals(int)
            cppSelf->setLabelDecimals(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setLabelFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setLabelFormat(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setLabelFormat(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelFormat", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelFormat(QString)
            cppSelf->setLabelFormat(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setMax(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setMax(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMax(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMax", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMax(qreal)
            cppSelf->setMax(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setMin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setMin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMin", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMin(qreal)
            cppSelf->setMin(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setPan(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setPan(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setPan(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPan", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPan(qreal)
            cppSelf->setPan(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QValueAxis::setRange(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // setRange(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRange", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRange(qreal,qreal)
            cppSelf->setRange(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setSubTickCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setSubTickCount(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // setSubTickCount(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSubTickCount", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubTickCount(qsizetype)
            cppSelf->setSubTickCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setTickAnchor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setTickAnchor(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTickAnchor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTickAnchor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTickAnchor(qreal)
            cppSelf->setTickAnchor(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setTickInterval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setTickInterval(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTickInterval(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTickInterval", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTickInterval(qreal)
            cppSelf->setTickInterval(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_setZoom(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValueAxis::setZoom(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setZoom(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZoom", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoom(qreal)
            cppSelf->setZoom(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QValueAxisFunc_subTickCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subTickCount()const
        qsizetype cppResult = const_cast<const ::QValueAxis *>(cppSelf)->subTickCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_tickAnchor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tickAnchor()const
        qreal cppResult = const_cast<const ::QValueAxis *>(cppSelf)->tickAnchor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_tickInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tickInterval()const
        qreal cppResult = const_cast<const ::QValueAxis *>(cppSelf)->tickInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAbstractAxis::AxisType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QValueAxis *>(cppSelf)->::QValueAxis::type()
            : const_cast<const ::QValueAxis *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractAxis_AxisType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QValueAxisFunc_zoom(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zoom()const
        qreal cppResult = const_cast<const ::QValueAxis *>(cppSelf)->zoom();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QValueAxis_PropertyStrings[] = {
    "labelDecimals::",
    "labelFormat::",
    "max::",
    "min::",
    "pan::",
    "subTickCount::",
    "tickAnchor::",
    "tickInterval::",
    "zoom::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QValueAxis_methods[] = {
    {"labelDecimals", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_labelDecimals), METH_NOARGS, nullptr},
    {"labelFormat", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_labelFormat), METH_NOARGS, nullptr},
    {"max", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_max), METH_NOARGS, nullptr},
    {"min", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_min), METH_NOARGS, nullptr},
    {"pan", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_pan), METH_NOARGS, nullptr},
    {"setLabelDecimals", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setLabelDecimals), METH_O, nullptr},
    {"setLabelFormat", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setLabelFormat), METH_O, nullptr},
    {"setMax", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setMax), METH_O, nullptr},
    {"setMin", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setMin), METH_O, nullptr},
    {"setPan", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setPan), METH_O, nullptr},
    {"setRange", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setRange), METH_VARARGS, nullptr},
    {"setSubTickCount", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setSubTickCount), METH_O, nullptr},
    {"setTickAnchor", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setTickAnchor), METH_O, nullptr},
    {"setTickInterval", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setTickInterval), METH_O, nullptr},
    {"setZoom", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_setZoom), METH_O, nullptr},
    {"subTickCount", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_subTickCount), METH_NOARGS, nullptr},
    {"tickAnchor", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_tickAnchor), METH_NOARGS, nullptr},
    {"tickInterval", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_tickInterval), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_type), METH_NOARGS, nullptr},
    {"zoom", reinterpret_cast<PyCFunction>(Sbk_QValueAxisFunc_zoom), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QValueAxis_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QValueAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QValueAxisWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QValueAxis_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QValueAxis_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QValueAxis_Type = nullptr;
static PyTypeObject *Sbk_QValueAxis_TypeF(void)
{
    return _Sbk_QValueAxis_Type;
}

static PyType_Slot Sbk_QValueAxis_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QValueAxis_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QValueAxis_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QValueAxis_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QValueAxis_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QValueAxis_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QValueAxis_spec = {
    "2:PySide6.QtGraphs.QValueAxis",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QValueAxis_slots
};

} //extern "C"

static void *Sbk_QValueAxis_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QValueAxis *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QValueAxis_PythonToCpp_QValueAxis_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QValueAxis_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QValueAxis_PythonToCpp_QValueAxis_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QValueAxis_TypeF()))
        return QValueAxis_PythonToCpp_QValueAxis_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QValueAxis_PTR_CppToPython_QValueAxis(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QValueAxis *>(const_cast<void *>(cppIn)), Sbk_QValueAxis_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QValueAxis_SignatureStrings[] = {
    "PySide6.QtGraphs.QValueAxis(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,min:qreal=None,max:qreal=None,labelFormat:QString=None,labelDecimals:int=None,subTickCount:qsizetype=None,tickAnchor:qreal=None,tickInterval:qreal=None,zoom:qreal=None,pan:qreal=None)",
    "PySide6.QtGraphs.QValueAxis.labelDecimals(self)->int",
    "PySide6.QtGraphs.QValueAxis.labelFormat(self)->QString",
    "PySide6.QtGraphs.QValueAxis.max(self)->qreal",
    "PySide6.QtGraphs.QValueAxis.min(self)->qreal",
    "PySide6.QtGraphs.QValueAxis.pan(self)->qreal",
    "PySide6.QtGraphs.QValueAxis.setLabelDecimals(self,decimals:int)",
    "PySide6.QtGraphs.QValueAxis.setLabelFormat(self,format:QString)",
    "PySide6.QtGraphs.QValueAxis.setMax(self,max:qreal)",
    "PySide6.QtGraphs.QValueAxis.setMin(self,min:qreal)",
    "PySide6.QtGraphs.QValueAxis.setPan(self,pan:qreal)",
    "PySide6.QtGraphs.QValueAxis.setRange(self,min:qreal,max:qreal)",
    "PySide6.QtGraphs.QValueAxis.setSubTickCount(self,count:qsizetype)",
    "PySide6.QtGraphs.QValueAxis.setTickAnchor(self,anchor:qreal)",
    "PySide6.QtGraphs.QValueAxis.setTickInterval(self,interval:qreal)",
    "PySide6.QtGraphs.QValueAxis.setZoom(self,zoom:qreal)",
    "PySide6.QtGraphs.QValueAxis.subTickCount(self)->qsizetype",
    "PySide6.QtGraphs.QValueAxis.tickAnchor(self)->qreal",
    "PySide6.QtGraphs.QValueAxis.tickInterval(self)->qreal",
    "PySide6.QtGraphs.QValueAxis.type(self)->PySide6.QtGraphs.QAbstractAxis.AxisType",
    "PySide6.QtGraphs.QValueAxis.zoom(self)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QValueAxis_SignatureByteSize = 357;
static constexpr uint8_t QValueAxis_SignatureBytes[357] = {
    0x78, 0xda, 0x95, 0x53, 0x5d, 0x4f, 0xc2, 0x30, 0x14, 0x7d, 0xf7, 0x97, 0x88, 0x99, 0x7b, 0xf4,
    0x61, 0x09, 0x26, 0x04, 0xa3, 0x31, 0x7e, 0xb0, 0x09, 0xf1, 0xc1, 0xb7, 0xbb, 0x71, 0x81, 0x6a,
    0xd7, 0x8e, 0xf6, 0x4e, 0x19, 0xbf, 0xde, 0x42, 0x37, 0xd6, 0x41, 0xa4, 0xf3, 0x65, 0x49, 0xdb,
    0x73, 0xda, 0x73, 0xce, 0xce, 0x8d, 0xab, 0x29, 0x9b, 0xe3, 0x4d, 0x98, 0xd0, 0x83, 0x82, 0x62,
    0xa5, 0xc3, 0xe4, 0x1d, 0x78, 0x89, 0xa3, 0x0d, 0xd3, 0x97, 0x1a, 0xf9, 0x22, 0x28, 0x40, 0xa1,
    0xa0, 0x28, 0x3e, 0xe0, 0xc6, 0x52, 0x61, 0x98, 0x4c, 0xd2, 0x4f, 0xcc, 0x68, 0x28, 0x4a, 0xce,
    0x0b, 0x52, 0xc1, 0x55, 0xf4, 0x84, 0xd5, 0x8f, 0x54, 0xf3, 0x89, 0xe0, 0xd5, 0xf0, 0x55, 0x0a,
    0x0c, 0x72, 0x26, 0xa2, 0xb5, 0x42, 0xe0, 0xf5, 0x12, 0x36, 0xee, 0x92, 0x43, 0x8a, 0xfc, 0x5e,
    0xaa, 0x1c, 0x28, 0x4a, 0xa6, 0xa4, 0x98, 0x58, 0x3a, 0x07, 0x77, 0x98, 0xb1, 0x1c, 0xb8, 0x8e,
    0x98, 0x20, 0xbb, 0xad, 0xcb, 0x74, 0xc6, 0xb2, 0xaf, 0xb1, 0x2c, 0x8d, 0x98, 0xb5, 0x66, 0x5b,
    0xa4, 0xaa, 0x40, 0x7b, 0x46, 0xe6, 0x60, 0x24, 0xb2, 0x95, 0x54, 0xee, 0x0b, 0xbb, 0xdd, 0x47,
    0x41, 0xa8, 0xbe, 0x81, 0xbb, 0xfb, 0x5b, 0x29, 0x73, 0x77, 0x5d, 0x80, 0xab, 0x73, 0x70, 0x11,
    0xff, 0x9d, 0x48, 0xd8, 0x11, 0xb7, 0xcf, 0x67, 0x70, 0x7d, 0x6b, 0x34, 0xfa, 0x49, 0xd6, 0x6a,
    0x43, 0xa9, 0x1d, 0x9f, 0xa5, 0x99, 0xc0, 0x1a, 0xf8, 0x5e, 0xde, 0x79, 0x30, 0x13, 0xfd, 0xc1,
    0xc6, 0x71, 0x7f, 0xb0, 0x46, 0x7a, 0x3e, 0x71, 0x1d, 0xcc, 0x9d, 0x1f, 0x34, 0xe8, 0xc5, 0x77,
    0x02, 0x08, 0x16, 0x9d, 0xff, 0xee, 0xe5, 0xbf, 0xd4, 0x49, 0xb4, 0x1d, 0xf2, 0x53, 0xea, 0x3c,
    0xda, 0x16, 0x7a, 0x29, 0x71, 0x9d, 0x4a, 0x5b, 0x08, 0x2f, 0xe5, 0x0d, 0xc4, 0x12, 0x8f, 0xde,
    0xf9, 0x87, 0xc8, 0xa9, 0xd3, 0x69, 0x7b, 0x4b, 0xd6, 0xad, 0xb7, 0xf7, 0x86, 0xd9, 0xa1, 0xf9,
    0x96, 0x0f, 0xce, 0x14, 0xf4, 0x22, 0x37, 0x03, 0x62, 0xe9, 0xac, 0x33, 0x2e, 0xde, 0x0b, 0x3e,
    0xcc, 0x24, 0x59, 0x62, 0x3b, 0x53, 0x1e, 0xd2, 0xb1, 0xe3, 0x5d, 0x05, 0x1b, 0xb7, 0x67, 0x99,
    0xd4, 0x75, 0xda, 0xab, 0xba, 0x74, 0x6c, 0xb0, 0x1f, 0xcb, 0x48, 0x69, 0xd0, 0xa7, 0xb8, 0x51,
    0xaa, 0x49, 0x41, 0x46, 0x7b, 0xe8, 0xee, 0x33, 0xf3, 0x29, 0xdf, 0x36, 0x29, 0x1d, 0x5e, 0xff,
    0x05, 0xf7, 0x89, 0xfc, 0x3f
};
#endif

PyTypeObject *init_QValueAxis(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX].type;

    Shiboken::AutoDecRef Sbk_QValueAxis_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractAxis_IDX]))));

    _Sbk_QValueAxis_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QValueAxis",
        "QValueAxis*",
        &Sbk_QValueAxis_spec,
        &Shiboken::callCppDestructor< QValueAxis >,
        Sbk_QValueAxis_Type_bases.object(),
        0);
    auto *pyType = Sbk_QValueAxis_TypeF(); // references _Sbk_QValueAxis_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QValueAxis_SignatureStrings);
#else
    InitSignatureBytes(pyType, QValueAxis_SignatureBytes, QValueAxis_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QValueAxis_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QValueAxis_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QValueAxis_PythonToCpp_QValueAxis_PTR,
        is_QValueAxis_PythonToCpp_QValueAxis_PTR_Convertible,
        QValueAxis_PTR_CppToPython_QValueAxis);

    Shiboken::Conversions::registerConverterName(converter, "QValueAxis");
    Shiboken::Conversions::registerConverterName(converter, "QValueAxis*");
    Shiboken::Conversions::registerConverterName(converter, "QValueAxis&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QValueAxis).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QValueAxisWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QValueAxis_TypeF(), &Sbk_QValueAxis_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QValueAxis::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QValueAxis::staticMetaObject, sizeof(QValueAxisWrapper));

    return pyType;
}
