// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTTEXTDOCUMENTLAYOUTWRAPPER_H
#define SBK_QABSTRACTTEXTDOCUMENTLAYOUTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qabstracttextdocumentlayout.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractTextDocumentLayoutWrapper : public QAbstractTextDocumentLayout
{
public:
    QAbstractTextDocumentLayoutWrapper(::QTextDocument * doc);
    QAbstractTextDocumentLayoutWrapper(const QAbstractTextDocumentLayoutWrapper &) = delete;
    QAbstractTextDocumentLayoutWrapper& operator=(const QAbstractTextDocumentLayoutWrapper &) = delete;
    QAbstractTextDocumentLayoutWrapper(QAbstractTextDocumentLayoutWrapper &&) = delete;
    QAbstractTextDocumentLayoutWrapper& operator=(QAbstractTextDocumentLayoutWrapper &&) = delete;
    ~QAbstractTextDocumentLayoutWrapper() override;

    ::QRectF blockBoundingRect(const ::QTextBlock & block) const override;
    static ::QRectF sbk_o_blockBoundingRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QTextBlock & block);
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void documentChanged(int from, int charsRemoved, int charsAdded) override;
    ::QSizeF documentSize() const override;
    static ::QSizeF sbk_o_documentSize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void draw(::QPainter * painter, const ::QAbstractTextDocumentLayout::PaintContext & context) override;
    static void sbk_o_draw(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QAbstractTextDocumentLayout::PaintContext & context);
    void drawInlineObject(::QPainter * painter, const ::QRectF & rect, ::QTextInlineObject object, int posInDocument, const ::QTextFormat & format) override;
    static void sbk_o_drawInlineObject(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QRectF & rect, ::QTextInlineObject object, int posInDocument, const ::QTextFormat & format);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QRectF frameBoundingRect(::QTextFrame * frame) const override;
    static ::QRectF sbk_o_frameBoundingRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTextFrame * frame);
    int hitTest(const ::QPointF & point, ::Qt::HitTestAccuracy accuracy) const override;
    static int sbk_o_hitTest(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF & point, ::Qt::HitTestAccuracy accuracy);
    int pageCount() const override;
    void positionInlineObject(::QTextInlineObject item, int posInDocument, const ::QTextFormat & format) override;
    static void sbk_o_positionInlineObject(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTextInlineObject item, int posInDocument, const ::QTextFormat & format);
    void resizeInlineObject(::QTextInlineObject item, int posInDocument, const ::QTextFormat & format) override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[17] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTTEXTDOCUMENTLAYOUTWRAPPER_H
