// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibleobject_wrapper.h"

// Wrappers providing overrides
#include "qundocommand_wrapper.h"
#include "qaccessibleselectioninterface_wrapper.h"
#include "qaccessibletablecellinterface_wrapper.h"
#include "qaccessibleinterface_wrapper.h"
#include "qpaintengine_wrapper.h"
#include "qimageiohandler_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <QtGui/qcolor.h>
#include <QtGui/qwindow.h>
#include <qobject.h>
#include <qrect.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleObjectWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleObjectWrapper::QAccessibleObjectWrapper(::QObject * object) : QAccessibleObject(object)
{
}

::QColor QAccessibleObjectWrapper::backgroundColor() const
{
    static const char *funcName = "backgroundColor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleInterface::backgroundColor();
    }
    return QAccessibleInterfaceWrapper::sbk_o_backgroundColor("QAccessibleObject", funcName, gil, pyOverride);
}

::QAccessibleInterface * QAccessibleObjectWrapper::child(int index) const
{
    static const char *funcName = "child";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleObject.child");
        return nullptr;
    }
    return QAccessibleSelectionInterfaceWrapper::sbk_o_selectedItem("QAccessibleObject", funcName, gil, pyOverride, index);
}

::QAccessibleInterface * QAccessibleObjectWrapper::childAt(int x, int y) const
{
    static const char *funcName = "childAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleObject::childAt(x, y);
    }
    return QAccessibleInterfaceWrapper::sbk_o_childAt("QAccessibleObject", funcName, gil, pyOverride, x, y);
}

int QAccessibleObjectWrapper::childCount() const
{
    static const char *funcName = "childCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleObject.childCount");
        return 0;
    }
    return QUndoCommandWrapper::sbk_o_id("QAccessibleObject", funcName, gil, pyOverride);
}

::QAccessibleInterface * QAccessibleObjectWrapper::focusChild() const
{
    static const char *funcName = "focusChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleInterface::focusChild();
    }
    return QAccessibleTableCellInterfaceWrapper::sbk_o_table("QAccessibleObject", funcName, gil, pyOverride);
}

::QColor QAccessibleObjectWrapper::foregroundColor() const
{
    static const char *funcName = "foregroundColor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleInterface::foregroundColor();
    }
    return QAccessibleInterfaceWrapper::sbk_o_backgroundColor("QAccessibleObject", funcName, gil, pyOverride);
}

int QAccessibleObjectWrapper::indexOfChild(const ::QAccessibleInterface * arg__1) const
{
    static const char *funcName = "indexOfChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleObject.indexOfChild");
        return 0;
    }
    return QAccessibleInterfaceWrapper::sbk_o_indexOfChild("QAccessibleObject", funcName, gil, pyOverride, arg__1);
}

void * QAccessibleObjectWrapper::interface_cast(::QAccessible::InterfaceType arg__1)
{
    static const char *funcName = "interface_cast";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleInterface::interface_cast(arg__1);
    }
    return QAccessibleInterfaceWrapper::sbk_o_interface_cast("QAccessibleObject", funcName, gil, pyOverride, arg__1);
}

bool QAccessibleObjectWrapper::isValid() const
{
    static const char *funcName = "isValid";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleObject::isValid();
    }
    return QPaintEngineWrapper::sbk_o_end("QAccessibleObject", funcName, gil, pyOverride);
}

::QObject * QAccessibleObjectWrapper::object() const
{
    static const char *funcName = "object";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleObject::object();
    }
    return QAccessibleInterfaceWrapper::sbk_o_object("QAccessibleObject", funcName, gil, pyOverride);
}

::QAccessibleInterface * QAccessibleObjectWrapper::parent() const
{
    static const char *funcName = "parent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleObject.parent");
        return nullptr;
    }
    return QAccessibleTableCellInterfaceWrapper::sbk_o_table("QAccessibleObject", funcName, gil, pyOverride);
}

::QRect QAccessibleObjectWrapper::rect() const
{
    static const char *funcName = "rect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleObject::rect();
    }
    return QImageIOHandlerWrapper::sbk_o_currentImageRect("QAccessibleObject", funcName, gil, pyOverride);
}

::QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> QAccessibleObjectWrapper::relations(::QFlags<QAccessible::RelationFlag> match) const
{
    static const char *funcName = "relations";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleInterface::relations(match);
    }
    return QAccessibleInterfaceWrapper::sbk_o_relations("QAccessibleObject", funcName, gil, pyOverride, match);
}

::QAccessible::Role QAccessibleObjectWrapper::role() const
{
    static const char *funcName = "role";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleObject.role");
        return QAccessible::NoRole;
    }
    return QAccessibleInterfaceWrapper::sbk_o_role("QAccessibleObject", funcName, gil, pyOverride);
}

void QAccessibleObjectWrapper::setText(::QAccessible::Text t, const ::QString & text)
{
    static const char *funcName = "setText";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleObject::setText(t, text);
    }
    QAccessibleInterfaceWrapper::sbk_o_setText("QAccessibleObject", funcName, gil, pyOverride, t, text);
}

::QAccessible::State QAccessibleObjectWrapper::state() const
{
    static const char *funcName = "state";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleObject.state");
        return {};
    }
    return QAccessibleInterfaceWrapper::sbk_o_state("QAccessibleObject", funcName, gil, pyOverride);
}

::QString QAccessibleObjectWrapper::text(::QAccessible::Text t) const
{
    static const char *funcName = "text";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleObject.text");
        return ::QString();
    }
    return QAccessibleInterfaceWrapper::sbk_o_text("QAccessibleObject", funcName, gil, pyOverride, t);
}

void QAccessibleObjectWrapper::virtual_hook(int id, void * data)
{
    static const char *funcName = "virtual_hook";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleInterface::virtual_hook(id, data);
    }
    QAccessibleInterfaceWrapper::sbk_o_virtual_hook("QAccessibleObject", funcName, gil, pyOverride, id, data);
}

::QWindow * QAccessibleObjectWrapper::window() const
{
    static const char *funcName = "window";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAccessibleInterface::window();
    }
    return QAccessibleInterfaceWrapper::sbk_o_window("QAccessibleObject", funcName, gil, pyOverride);
}

QAccessibleObjectWrapper::~QAccessibleObjectWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleObject_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAccessibleObject");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleObject >()))
        return -1;

    QAccessibleObjectWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleObject", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleObject::QAccessibleObject(QObject*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAccessibleObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAccessibleObject(QObject*)
            cptr = new QAccessibleObjectWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleObjectFunc_childAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "childAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAccessibleInterface::childAt(int,int)const->QAccessibleInterface*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // childAt(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "childAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // childAt(int,int)const
            QAccessibleInterface * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAccessibleObject *>(cppSelf)->::QAccessibleObject::childAt(cppArg0, cppArg1)
                : const_cast<const ::QAccessibleObject *>(cppSelf)->childAt(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAccessibleObjectFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAccessibleObject *>(cppSelf)->::QAccessibleObject::isValid()
            : const_cast<const ::QAccessibleObject *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAccessibleObjectFunc_object(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // object()const
        QObject * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAccessibleObject *>(cppSelf)->::QAccessibleObject::object()
            : const_cast<const ::QAccessibleObject *>(cppSelf)->object();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAccessibleObjectFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        QRect cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAccessibleObject *>(cppSelf)->::QAccessibleObject::rect()
            : const_cast<const ::QAccessibleObject *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAccessibleObjectFunc_setText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAccessibleInterface::setText(QAccessible::Text,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Text_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setText(QAccessible::Text,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]);

    // Call function/method
    {
        ::QAccessible::Text cppArg0{QAccessible::Name};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setText(QAccessible::Text,QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAccessibleObject::setText(cppArg0, cppArg1)
                : cppSelf->setText(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QAccessibleObject_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleObject_methods[] = {
    {"childAt", reinterpret_cast<PyCFunction>(Sbk_QAccessibleObjectFunc_childAt), METH_VARARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QAccessibleObjectFunc_isValid), METH_NOARGS, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QAccessibleObjectFunc_object), METH_NOARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QAccessibleObjectFunc_rect), METH_NOARGS, nullptr},
    {"setText", reinterpret_cast<PyCFunction>(Sbk_QAccessibleObjectFunc_setText), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleObject_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleObjectWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleObject_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleObject_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleObject_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleObject_TypeF(void)
{
    return _Sbk_QAccessibleObject_Type;
}

static PyType_Slot Sbk_QAccessibleObject_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleObject_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleObject_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleObject_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleObject_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleObject_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleObject_spec = {
    "2:PySide6.QtGui.QAccessibleObject",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleObject_slots
};

} //extern "C"

static void *Sbk_QAccessibleObject_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QAccessibleInterface >())
        return dynamic_cast< ::QAccessibleObject *>(reinterpret_cast< ::QAccessibleInterface *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleObject_PythonToCpp_QAccessibleObject_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleObject_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleObject_PythonToCpp_QAccessibleObject_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleObject_TypeF()))
        return QAccessibleObject_PythonToCpp_QAccessibleObject_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleObject_PTR_CppToPython_QAccessibleObject(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleObject *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleObject_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleObject_SignatureStrings[] = {
    "PySide6.QtGui.QAccessibleObject(self,object:PySide6.QtCore.QObject)",
    "PySide6.QtGui.QAccessibleObject.childAt(self,x:int,y:int)->PySide6.QtGui.QAccessibleInterface",
    "PySide6.QtGui.QAccessibleObject.isValid(self)->bool",
    "PySide6.QtGui.QAccessibleObject.object(self)->PySide6.QtCore.QObject",
    "PySide6.QtGui.QAccessibleObject.rect(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QAccessibleObject.setText(self,t:PySide6.QtGui.QAccessible.Text,text:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleObject_SignatureByteSize = 163;
static constexpr uint8_t QAccessibleObject_SignatureBytes[163] = {
    0x78, 0xda, 0x8d, 0x90, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x12, 0x0b, 0x31, 0xa3,
    0x43, 0x06, 0xa1, 0x38, 0x88, 0x93, 0x4d, 0x2b, 0xee, 0x4d, 0x72, 0xd5, 0x93, 0x90, 0x40, 0x72,
    0x42, 0xfb, 0xef, 0x6d, 0x6b, 0xd1, 0x2a, 0xd8, 0xba, 0x3c, 0x6e, 0x78, 0xef, 0xe3, 0xde, 0xcb,
    0xdb, 0x12, 0x0d, 0x6c, 0xb8, 0xa4, 0xfd, 0x1d, 0xb9, 0xcc, 0xb4, 0x86, 0x18, 0x51, 0x59, 0x38,
    0xaa, 0x1b, 0x68, 0x5a, 0x45, 0xb0, 0x35, 0xf3, 0xc3, 0x2d, 0xf2, 0x97, 0x77, 0xe7, 0x03, 0x70,
    0xf9, 0xb4, 0xa4, 0x49, 0x3e, 0xcf, 0xe0, 0xfa, 0x8a, 0xd6, 0x64, 0x23, 0xab, 0x11, 0xe8, 0x88,
    0xb5, 0xbd, 0xa6, 0xeb, 0xed, 0xcf, 0xe8, 0xc1, 0x11, 0x84, 0xba, 0xd2, 0xb0, 0x48, 0xc7, 0x78,
    0xae, 0x2c, 0x9a, 0x81, 0xde, 0x11, 0x95, 0xf7, 0x76, 0x31, 0xe3, 0xdf, 0xe5, 0x3e, 0x9e, 0x98,
    0xf6, 0x5a, 0x84, 0x84, 0x19, 0x44, 0xf1, 0x0f, 0x20, 0x02, 0x9d, 0xa0, 0x19, 0x77, 0x99, 0xce,
    0xfb, 0x65, 0xe7, 0xbd, 0x8b, 0x51, 0x27, 0x42, 0x96, 0x14, 0xd0, 0x5d, 0xd2, 0xe4, 0x01, 0xd8,
    0x35, 0x9c, 0x64
};
#endif

PyTypeObject *init_QAccessibleObject(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleObject_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]))));

    _Sbk_QAccessibleObject_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleObject",
        "QAccessibleObject*",
        &Sbk_QAccessibleObject_spec,
        &Shiboken::callCppDestructor< QAccessibleObject >,
        Sbk_QAccessibleObject_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleObject_TypeF(); // references _Sbk_QAccessibleObject_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleObject_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleObject_SignatureBytes, QAccessibleObject_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleObject_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleObject_PythonToCpp_QAccessibleObject_PTR,
        is_QAccessibleObject_PythonToCpp_QAccessibleObject_PTR_Convertible,
        QAccessibleObject_PTR_CppToPython_QAccessibleObject);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleObject");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleObject*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleObject&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleObject).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleObjectWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleObject_TypeF(), &Sbk_QAccessibleObject_typeDiscovery);

    qRegisterMetaType< ::QAccessibleObject *>();

    return pyType;
}
