// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QENTEREVENTWRAPPER_H
#define SBK_QENTEREVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QEnterEventWrapper : public QEnterEvent
{
public:
    QEnterEventWrapper(const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QEnterEventWrapper(const QEnterEventWrapper &) = delete;
    QEnterEventWrapper(const QEnterEvent& self) : QEnterEvent(self)
    {
    }
    QEnterEventWrapper& operator=(const QEnterEventWrapper &) = delete;
    QEnterEventWrapper(QEnterEventWrapper &&) = delete;
    QEnterEventWrapper& operator=(QEnterEventWrapper &&) = delete;
    ~QEnterEventWrapper() override;

    ::QEnterEvent * clone() const override;
    static ::QEnterEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QENTEREVENTWRAPPER_H
