// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qfont_tag_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qfont.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtgui.cpp (qfont-tag-from-str-helper)]
using FontTagOptional = std::optional<QFont::Tag>;
static std::optional<QFont::Tag> qFontTagFromString(PyObject *unicode)
{
    FontTagOptional result;
    if (PyUnicode_GetLength(unicode) == 4)
        result = QFont::Tag::fromString(PySide::pyUnicodeToQString(unicode));
    if (!result.has_value())
        PyErr_SetString(PyExc_TypeError,
                        "QFont::Tag(): The tag name must be exactly 4 characters long.");
    return result;
}
// END of custom code block [file: ../glue/qtgui.cpp (qfont-tag-from-str-helper)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFont_Tag_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFont::Tag >()))
        return -1;

    ::QFont::Tag *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Tag", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Tag::Tag()
    // 1: Tag::Tag(QString)
    // 2: Tag::Tag(QFont::Tag)
    if (numArgs == 0) {
        overloadId = 0; // Tag()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // Tag(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArgs[0])))) {
        overloadId = 2; // Tag(QFont::Tag)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Tag()
        {

            // Tag()
            cptr = new ::QFont::Tag();
            break;
        }
        case 1: // Tag(QString name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // Tag(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qfont-tag-init-str)]
                const FontTagOptional tagO = qFontTagFromString(pyArgs[1-1]);
                if (tagO.has_value())
                    cptr = new QFont::Tag(tagO.value());
                // END of custom code block [file: ../glue/qtgui.cpp (qfont-tag-init-str)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // Tag(const QFont::Tag &Tag)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFont::Tag cppArg0_local;
            ::QFont::Tag *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Tag(QFont::Tag)
                cptr = new ::QFont::Tag(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFont::Tag >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFont_TagFunc_fromString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static Tag::fromString(QString)->QFont::Tag
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromString(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qfont-tag-fromString)]
            const FontTagOptional tagO = qFontTagFromString(pyArg);
            if (tagO.has_value()) {
                const auto &tag = tagO.value();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), &tag);
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qfont-tag-fromString)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFont_TagFunc_fromValue(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static Tag::fromValue(int)->QFont::Tag
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // fromValue(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromValue(int)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qfont-tag-fromValue)]
            const FontTagOptional tagO = QFont::Tag::fromValue(PyLong_AsUnsignedLong(pyArg));
            if (tagO.has_value()) {
                const auto &tag = tagO.value();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), &tag);
            } else {
                PyErr_SetString(PyExc_TypeError, "QFont::Tag::fromValue(): Invalid value passed.");
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qfont-tag-fromValue)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFont_TagFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont::Tag *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QFont::Tag *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFont_TagFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont::Tag *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QByteArray cppResult = const_cast<const ::QFont::Tag *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFont_TagFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont::Tag *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        quint32 cppResult = const_cast<const ::QFont::Tag *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFont_Tag__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFont::Tag *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFont_Tag_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFont_Tag_methods[] = {
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QFont_TagFunc_fromString), METH_O|METH_STATIC, nullptr},
    {"fromValue", reinterpret_cast<PyCFunction>(Sbk_QFont_TagFunc_fromValue), METH_O|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QFont_TagFunc_isValid), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QFont_TagFunc_toString), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QFont_TagFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFont_Tag__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QFont_Tag_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFont::Tag *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
                // operator!=(const QFont::Tag &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont::Tag cppArg0_local;
                ::QFont::Tag *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
                // operator<(const QFont::Tag &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont::Tag cppArg0_local;
                ::QFont::Tag *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
                // operator<=(const QFont::Tag &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont::Tag cppArg0_local;
                ::QFont::Tag *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
                // operator==(const QFont::Tag &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont::Tag cppArg0_local;
                ::QFont::Tag *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
                // operator>(const QFont::Tag &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont::Tag cppArg0_local;
                ::QFont::Tag *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
                // operator>=(const QFont::Tag &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont::Tag cppArg0_local;
                ::QFont::Tag *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QFont_Tag_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont::Tag *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QFont_Tag_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFont_Tag_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFont_Tag_Type = nullptr;
static PyTypeObject *Sbk_QFont_Tag_TypeF(void)
{
    return _Sbk_QFont_Tag_Type;
}

static PyType_Slot Sbk_QFont_Tag_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QFont_Tag_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFont_Tag_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFont_Tag_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QFont_Tag_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFont_Tag_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFont_Tag_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFont_Tag_spec = {
    "2:PySide6.QtGui.QFont.Tag",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFont_Tag_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Tag_PythonToCpp_Tag_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFont_Tag_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Tag_PythonToCpp_Tag_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFont_Tag_TypeF()))
        return Tag_PythonToCpp_Tag_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Tag_PTR_CppToPython_Tag(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFont_Tag_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Tag_COPY_CppToPython_Tag(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QFont::Tag *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFont_Tag_TypeF(), new ::QFont::Tag(*source), true, true);
}

// Python to C++ copy conversion.
static void Tag_PythonToCpp_Tag_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QFont::Tag *>(cppOut) = *reinterpret_cast< ::QFont::Tag *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Tag_PythonToCpp_Tag_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFont_Tag_TypeF()))
        return Tag_PythonToCpp_Tag_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFont_Tag_SignatureStrings[] = {
    "2:PySide6.QtGui.QFont.Tag(self)",
    "1:PySide6.QtGui.QFont.Tag(self,name:QString)",
    "0:PySide6.QtGui.QFont.Tag(self,Tag:PySide6.QtGui.QFont.Tag)",
    "PySide6.QtGui.QFont.Tag.fromString(name:QString)->PySide6.QtGui.QFont.Tag",
    "PySide6.QtGui.QFont.Tag.fromValue(value:int)->PySide6.QtGui.QFont.Tag",
    "PySide6.QtGui.QFont.Tag.isValid(self)->bool",
    "PySide6.QtGui.QFont.Tag.toString(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QFont.Tag.value(self)->quint32",
    "PySide6.QtGui.QFont.Tag.__copy__(self)->typing.Self",
    "PySide6.QtGui.QFont.Tag.__ne__(self,rhs:typing.Union[PySide6.QtGui.QFont.Tag, QString])->bool",
    "PySide6.QtGui.QFont.Tag.__lt__(self,rhs:typing.Union[PySide6.QtGui.QFont.Tag, QString])->bool",
    "PySide6.QtGui.QFont.Tag.__le__(self,rhs:typing.Union[PySide6.QtGui.QFont.Tag, QString])->bool",
    "PySide6.QtGui.QFont.Tag.__eq__(self,rhs:typing.Union[PySide6.QtGui.QFont.Tag, QString])->bool",
    "PySide6.QtGui.QFont.Tag.__gt__(self,rhs:typing.Union[PySide6.QtGui.QFont.Tag, QString])->bool",
    "PySide6.QtGui.QFont.Tag.__ge__(self,rhs:typing.Union[PySide6.QtGui.QFont.Tag, QString])->bool",
    "PySide6.QtGui.QFont.Tag.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QFont_Tag_SignatureByteSize = 229;
static constexpr uint8_t QFont_Tag_SignatureBytes[229] = {
    0x78, 0xda, 0xb5, 0x92, 0xc1, 0x0b, 0x82, 0x30, 0x14, 0xc6, 0xef, 0xfe, 0x15, 0x1d, 0x15, 0x74,
    0x94, 0x41, 0x07, 0x0f, 0x41, 0x05, 0x75, 0x4d, 0xac, 0x2e, 0x11, 0x63, 0xe5, 0xd4, 0x81, 0x6e,
    0x3a, 0x67, 0xb0, 0xff, 0xbe, 0x95, 0x13, 0xe9, 0x30, 0x83, 0x60, 0x97, 0xb1, 0xf1, 0xbe, 0xef,
    0xf7, 0x1e, 0xdf, 0x5e, 0x18, 0x1d, 0x65, 0x42, 0x52, 0xbc, 0x02, 0xb1, 0x38, 0x74, 0x04, 0xc4,
    0x7b, 0x46, 0x05, 0x38, 0xa1, 0xdc, 0x6d, 0x71, 0x99, 0x79, 0xce, 0x62, 0xb2, 0xee, 0x53, 0x54,
    0xe1, 0x28, 0x4e, 0x04, 0x27, 0x34, 0xf7, 0x9c, 0xf9, 0xb4, 0x58, 0x5d, 0x4c, 0x02, 0xcf, 0x31,
    0x14, 0x40, 0xc6, 0x59, 0xd5, 0xf3, 0xdd, 0xaf, 0x66, 0xc1, 0xda, 0xe0, 0x98, 0x24, 0x5d, 0x50,
    0xd9, 0x61, 0xf7, 0xf9, 0x3e, 0x23, 0x42, 0xc5, 0x1f, 0x14, 0xd2, 0x2a, 0x06, 0x49, 0xfb, 0x78,
    0x82, 0xf5, 0x9d, 0xb1, 0xd2, 0xa8, 0x15, 0x4c, 0x4f, 0xae, 0xc5, 0xa3, 0x6e, 0xc7, 0x38, 0x06,
    0xf1, 0x56, 0x0a, 0xbc, 0xe1, 0x1c, 0x49, 0x23, 0xe1, 0x33, 0xe9, 0x60, 0x6f, 0x3a, 0x35, 0xf2,
    0x32, 0x34, 0x8a, 0x21, 0x7c, 0xb0, 0x5a, 0x42, 0x38, 0xe8, 0x85, 0xac, 0x55, 0x73, 0x90, 0xa8,
    0xd7, 0x84, 0x87, 0x62, 0xed, 0xf0, 0x79, 0xd1, 0x46, 0xda, 0x73, 0xa6, 0x84, 0xd1, 0xab, 0xc1,
    0xe4, 0xcf, 0xf4, 0x27, 0xdc, 0x7e, 0x05, 0x00, 0x61, 0x29, 0xac, 0xd2, 0xad, 0xce, 0x8e, 0x1b,
    0x9b, 0xf4, 0xdc, 0x6a, 0x32, 0xb9, 0xd5, 0x64, 0x0a, 0xd4, 0x16, 0xe3, 0x9e, 0xa9, 0xad, 0x74,
    0x5e, 0x22, 0xdd, 0x7b, 0x83
};
#endif

PyTypeObject *init_QFont_Tag(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX].type;

    Shiboken::AutoDecRef Sbk_QFont_Tag_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFont_Tag_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Tag",
        "QFont::Tag",
        &Sbk_QFont_Tag_spec,
        &Shiboken::callCppDestructor< ::QFont::Tag >,
        Sbk_QFont_Tag_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFont_Tag_TypeF(); // references _Sbk_QFont_Tag_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFont_Tag_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFont_Tag_SignatureBytes, QFont_Tag_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFont_Tag_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Tag_PythonToCpp_Tag_PTR,
        is_Tag_PythonToCpp_Tag_PTR_Convertible,
        Tag_PTR_CppToPython_Tag,
        Tag_COPY_CppToPython_Tag);

    Shiboken::Conversions::registerConverterName(converter, "QFont::Tag");
    Shiboken::Conversions::registerConverterName(converter, "QFont::Tag*");
    Shiboken::Conversions::registerConverterName(converter, "QFont::Tag&");
    Shiboken::Conversions::registerConverterAlias(converter, "Tag");
    Shiboken::Conversions::registerConverterAlias(converter, "Tag*");
    Shiboken::Conversions::registerConverterAlias(converter, "Tag&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFont::Tag).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Tag_PythonToCpp_Tag_COPY,
        is_Tag_PythonToCpp_Tag_COPY_Convertible);



    qRegisterMetaType< ::QFont::Tag >("Tag");
    qRegisterMetaType< ::QFont::Tag >("QFont::Tag");

    return pyType;
}

