// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qfontvariableaxis_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qfont.h>
#include <QtGui/qfontvariableaxis.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFontVariableAxis_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFontVariableAxis >()))
        return -1;

    ::QFontVariableAxis *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFontVariableAxis", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFontVariableAxis::QFontVariableAxis()
    // 1: QFontVariableAxis::QFontVariableAxis(QFontVariableAxis)
    if (numArgs == 0) {
        overloadId = 0; // QFontVariableAxis()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QFontVariableAxis(QFontVariableAxis)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFontVariableAxis()
        {

            // QFontVariableAxis()
            cptr = new ::QFontVariableAxis();
            break;
        }
        case 1: // QFontVariableAxis(const QFontVariableAxis &axis)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFontVariableAxis cppArg0_local;
            ::QFontVariableAxis *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFontVariableAxis(QFontVariableAxis)
                cptr = new ::QFontVariableAxis(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFontVariableAxis >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFontVariableAxisFunc_defaultValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultValue()const
        qreal cppResult = const_cast<const ::QFontVariableAxis *>(cppSelf)->defaultValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFontVariableAxisFunc_maximumValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumValue()const
        qreal cppResult = const_cast<const ::QFontVariableAxis *>(cppSelf)->maximumValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFontVariableAxisFunc_minimumValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumValue()const
        qreal cppResult = const_cast<const ::QFontVariableAxis *>(cppSelf)->minimumValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFontVariableAxisFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QFontVariableAxis *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFontVariableAxisFunc_setDefaultValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontVariableAxis::setDefaultValue(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDefaultValue(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultValue(qreal)
            cppSelf->setDefaultValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFontVariableAxisFunc_setMaximumValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontVariableAxis::setMaximumValue(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMaximumValue(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumValue(qreal)
            cppSelf->setMaximumValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFontVariableAxisFunc_setMinimumValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontVariableAxis::setMinimumValue(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMinimumValue(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumValue(qreal)
            cppSelf->setMinimumValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFontVariableAxisFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontVariableAxis::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFontVariableAxisFunc_setTag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontVariableAxis::setTag(QFont::Tag)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // setTag(QFont::Tag)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTag", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTag(QFont::Tag)
            cppSelf->setTag(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFontVariableAxisFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontVariableAxis::swap(QFontVariableAxis&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFontVariableAxis&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFontVariableAxis cppArg0_local;
        ::QFontVariableAxis *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFontVariableAxis&)
            cppSelf->swap(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFontVariableAxisFunc_tag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tag()const
        QFont::Tag cppResult = const_cast<const ::QFontVariableAxis *>(cppSelf)->tag();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFontVariableAxis__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFontVariableAxis_PropertyStrings[] = {
    "defaultValue:",
    "maximumValue:",
    "minimumValue:",
    "name:",
    "tag:tagString",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFontVariableAxis_methods[] = {
    {"defaultValue", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_defaultValue), METH_NOARGS, nullptr},
    {"maximumValue", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_maximumValue), METH_NOARGS, nullptr},
    {"minimumValue", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_minimumValue), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_name), METH_NOARGS, nullptr},
    {"setDefaultValue", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_setDefaultValue), METH_O, nullptr},
    {"setMaximumValue", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_setMaximumValue), METH_O, nullptr},
    {"setMinimumValue", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_setMinimumValue), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_setName), METH_O, nullptr},
    {"setTag", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_setTag), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_swap), METH_O, nullptr},
    {"tag", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxisFunc_tag), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFontVariableAxis__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QFontVariableAxis_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFontVariableAxis_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFontVariableAxis_Type = nullptr;
static PyTypeObject *Sbk_QFontVariableAxis_TypeF(void)
{
    return _Sbk_QFontVariableAxis_Type;
}

static PyType_Slot Sbk_QFontVariableAxis_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFontVariableAxis_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFontVariableAxis_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFontVariableAxis_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFontVariableAxis_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFontVariableAxis_spec = {
    "2:PySide6.QtGui.QFontVariableAxis",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFontVariableAxis_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFontVariableAxis_PythonToCpp_QFontVariableAxis_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFontVariableAxis_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFontVariableAxis_PythonToCpp_QFontVariableAxis_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFontVariableAxis_TypeF()))
        return QFontVariableAxis_PythonToCpp_QFontVariableAxis_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFontVariableAxis_PTR_CppToPython_QFontVariableAxis(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFontVariableAxis_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QFontVariableAxis_COPY_CppToPython_QFontVariableAxis(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QFontVariableAxis *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFontVariableAxis_TypeF(), new ::QFontVariableAxis(*source), true, true);
}

// Python to C++ copy conversion.
static void QFontVariableAxis_PythonToCpp_QFontVariableAxis_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QFontVariableAxis *>(cppOut) = *reinterpret_cast< ::QFontVariableAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QFontVariableAxis_PythonToCpp_QFontVariableAxis_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFontVariableAxis_TypeF()))
        return QFontVariableAxis_PythonToCpp_QFontVariableAxis_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFontVariableAxis_SignatureStrings[] = {
    "1:PySide6.QtGui.QFontVariableAxis(self,*:KeywordOnly=None,tag:QByteArray=None,name:QString=None,minimumValue:qreal=None,maximumValue:qreal=None,defaultValue:qreal=None)",
    "0:PySide6.QtGui.QFontVariableAxis(self,axis:PySide6.QtGui.QFontVariableAxis,*:KeywordOnly=None,tag:QByteArray=None,name:QString=None,minimumValue:qreal=None,maximumValue:qreal=None,defaultValue:qreal=None)",
    "PySide6.QtGui.QFontVariableAxis.defaultValue(self)->qreal",
    "PySide6.QtGui.QFontVariableAxis.maximumValue(self)->qreal",
    "PySide6.QtGui.QFontVariableAxis.minimumValue(self)->qreal",
    "PySide6.QtGui.QFontVariableAxis.name(self)->QString",
    "PySide6.QtGui.QFontVariableAxis.setDefaultValue(self,defaultValue:qreal)",
    "PySide6.QtGui.QFontVariableAxis.setMaximumValue(self,maximumValue:qreal)",
    "PySide6.QtGui.QFontVariableAxis.setMinimumValue(self,minimumValue:qreal)",
    "PySide6.QtGui.QFontVariableAxis.setName(self,name:QString)",
    "PySide6.QtGui.QFontVariableAxis.setTag(self,tag:typing.Union[PySide6.QtGui.QFont.Tag, QString])",
    "PySide6.QtGui.QFontVariableAxis.swap(self,other:PySide6.QtGui.QFontVariableAxis)",
    "PySide6.QtGui.QFontVariableAxis.tag(self)->PySide6.QtGui.QFont.Tag",
    "PySide6.QtGui.QFontVariableAxis.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QFontVariableAxis_SignatureByteSize = 274;
static constexpr uint8_t QFontVariableAxis_SignatureBytes[274] = {
    0x78, 0xda, 0xcd, 0x93, 0xc1, 0x4b, 0xc3, 0x30, 0x14, 0xc6, 0xef, 0xfb, 0x2b, 0x3c, 0x5a, 0xa9,
    0x41, 0x2f, 0x1e, 0x02, 0x0a, 0x93, 0x31, 0x0f, 0xe2, 0xb4, 0x54, 0x77, 0x11, 0x29, 0x4f, 0xfb,
    0x56, 0x03, 0x69, 0x52, 0xd3, 0x94, 0x2d, 0xff, 0xbd, 0xd9, 0x9a, 0x42, 0x2d, 0x19, 0xc9, 0x6e,
    0x1e, 0xf3, 0x91, 0xdf, 0xc7, 0xfb, 0xbe, 0x97, 0x5c, 0xd3, 0x17, 0x93, 0xb3, 0x12, 0x6f, 0x48,
    0xa6, 0x1f, 0x3a, 0x46, 0xb2, 0xa5, 0x14, 0x7a, 0x0d, 0x8a, 0xc1, 0x27, 0xc7, 0xf9, 0x8e, 0xb5,
    0xe7, 0x2d, 0xf2, 0x4d, 0x7a, 0x41, 0x1f, 0xd1, 0x6c, 0xa5, 0x2a, 0x9f, 0x05, 0x37, 0xb7, 0x2b,
    0x29, 0x30, 0xd5, 0x50, 0xd1, 0xec, 0xde, 0x68, 0x9c, 0x2b, 0x05, 0x4e, 0x13, 0x50, 0x23, 0xcd,
    0x72, 0xad, 0x98, 0xa8, 0x7a, 0xa5, 0x66, 0x82, 0xd5, 0x5d, 0xbd, 0x06, 0xde, 0x21, 0xfd, 0x51,
    0x08, 0xdc, 0xe9, 0xb0, 0xf3, 0xea, 0x25, 0x6e, 0xa0, 0xe3, 0x7a, 0xaa, 0x27, 0xb3, 0xab, 0xb8,
    0x41, 0xad, 0x6d, 0x1b, 0xba, 0xf9, 0x0f, 0xd2, 0x04, 0x26, 0x24, 0x63, 0xf0, 0x10, 0x2c, 0xb9,
    0xbc, 0x3b, 0xf0, 0x41, 0x72, 0x3c, 0xca, 0x89, 0xe4, 0x28, 0xdc, 0x69, 0xe4, 0xbe, 0xa8, 0x81,
    0x70, 0x7d, 0x05, 0x99, 0x16, 0xf5, 0x62, 0x1a, 0xd2, 0xd3, 0x57, 0x12, 0x63, 0xf4, 0x34, 0xcd,
    0xec, 0x59, 0x48, 0x9c, 0xd1, 0xb4, 0x02, 0xcf, 0xc6, 0xa3, 0x8c, 0x56, 0x43, 0x23, 0x7f, 0x1e,
    0x51, 0x14, 0xfa, 0x0a, 0x55, 0x4f, 0xee, 0x9f, 0xa4, 0x36, 0x8d, 0xe5, 0xc8, 0x9b, 0x60, 0x52,
    0xbc, 0x7b, 0x60, 0x62, 0x6f, 0xa7, 0x67, 0xce, 0xfe, 0x23, 0xc2, 0x7f, 0x0b, 0x4d, 0xef, 0x2e,
    0xf5, 0x37, 0xaa, 0xd0, 0x4f, 0x09, 0x1b, 0x6a, 0x37, 0xad, 0xdd, 0xfc, 0x91, 0xf1, 0x82, 0x16,
    0x45, 0xf1, 0x25, 0x1b, 0x53, 0x14, 0x83, 0x8f, 0xcb, 0x9c, 0xdb, 0xd3, 0xec, 0x17, 0xf0, 0xb2,
    0xaf, 0x26
};
#endif

PyTypeObject *init_QFontVariableAxis(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX].type;

    Shiboken::AutoDecRef Sbk_QFontVariableAxis_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFontVariableAxis_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFontVariableAxis",
        "QFontVariableAxis",
        &Sbk_QFontVariableAxis_spec,
        &Shiboken::callCppDestructor< ::QFontVariableAxis >,
        Sbk_QFontVariableAxis_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFontVariableAxis_TypeF(); // references _Sbk_QFontVariableAxis_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFontVariableAxis_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFontVariableAxis_SignatureBytes, QFontVariableAxis_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFontVariableAxis_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QFontVariableAxis_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFontVariableAxis_PythonToCpp_QFontVariableAxis_PTR,
        is_QFontVariableAxis_PythonToCpp_QFontVariableAxis_PTR_Convertible,
        QFontVariableAxis_PTR_CppToPython_QFontVariableAxis,
        QFontVariableAxis_COPY_CppToPython_QFontVariableAxis);

    Shiboken::Conversions::registerConverterName(converter, "QFontVariableAxis");
    Shiboken::Conversions::registerConverterName(converter, "QFontVariableAxis*");
    Shiboken::Conversions::registerConverterName(converter, "QFontVariableAxis&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFontVariableAxis).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFontVariableAxis_PythonToCpp_QFontVariableAxis_COPY,
        is_QFontVariableAxis_PythonToCpp_QFontVariableAxis_COPY_Convertible);

    qRegisterMetaType< ::QFontVariableAxis >("QFontVariableAxis");

    return pyType;
}
