// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QMOUSEEVENTWRAPPER_H
#define SBK_QMOUSEEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QMouseEventWrapper : public QMouseEvent
{
public:
    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::MouseEventSource source, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(const QMouseEventWrapper &) = delete;
    QMouseEventWrapper(const QMouseEvent& self) : QMouseEvent(self)
    {
    }
    QMouseEventWrapper& operator=(const QMouseEventWrapper &) = delete;
    QMouseEventWrapper(QMouseEventWrapper &&) = delete;
    QMouseEventWrapper& operator=(QMouseEventWrapper &&) = delete;
    ~QMouseEventWrapper() override;

    ::QMouseEvent * clone() const override;
    static ::QMouseEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QMOUSEEVENTWRAPPER_H
