// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qopenglcontextgroup_wrapper.h"

// Wrappers providing overrides
#include "qwindow_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qopenglcontext.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOpenGLContextGroupWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QOpenGLContextGroupWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWindowWrapper::sbk_o_childEvent("QOpenGLContextGroup", funcName, gil, pyOverride, event);
}

void QOpenGLContextGroupWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QOpenGLContextGroup", funcName, gil, pyOverride, signal);
}

void QOpenGLContextGroupWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWindowWrapper::sbk_o_customEvent("QOpenGLContextGroup", funcName, gil, pyOverride, event);
}

void QOpenGLContextGroupWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QOpenGLContextGroup", funcName, gil, pyOverride, signal);
}

bool QOpenGLContextGroupWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWindowWrapper::sbk_o_event("QOpenGLContextGroup", funcName, gil, pyOverride, event);
}

bool QOpenGLContextGroupWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWindowWrapper::sbk_o_eventFilter("QOpenGLContextGroup", funcName, gil, pyOverride, watched, event);
}

void QOpenGLContextGroupWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWindowWrapper::sbk_o_timerEvent("QOpenGLContextGroup", funcName, gil, pyOverride, event);
}

const QMetaObject *QOpenGLContextGroupWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOpenGLContextGroup::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOpenGLContextGroupWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOpenGLContextGroup::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOpenGLContextGroupWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOpenGLContextGroupWrapper *>(this));
    return QOpenGLContextGroup::qt_metacast(_clname);
}

QOpenGLContextGroupWrapper::~QOpenGLContextGroupWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QOpenGLContextGroup_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QOpenGLContextGroup");
    return -1;
}

static PyObject *Sbk_QOpenGLContextGroupFunc_currentContextGroup(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentContextGroup()
        QOpenGLContextGroup * cppResult = ::QOpenGLContextGroup::currentContextGroup();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContextGroup_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOpenGLContextGroupFunc_shares(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLContextGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContextGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shares()const
        QList<QOpenGLContext*> cppResult = const_cast<const ::QOpenGLContextGroup *>(cppSelf)->shares();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QOpenGLContextPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QOpenGLContextGroup_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLContextGroup_methods[] = {
    {"currentContextGroup", reinterpret_cast<PyCFunction>(Sbk_QOpenGLContextGroupFunc_currentContextGroup), METH_NOARGS|METH_STATIC, nullptr},
    {"shares", reinterpret_cast<PyCFunction>(Sbk_QOpenGLContextGroupFunc_shares), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOpenGLContextGroup_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOpenGLContextGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContextGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOpenGLContextGroupWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOpenGLContextGroup_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLContextGroup_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QOpenGLContextGroup__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLContextGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContextGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLContextGroup_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLContextGroup_TypeF(void)
{
    return _Sbk_QOpenGLContextGroup_Type;
}

static PyType_Slot Sbk_QOpenGLContextGroup_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QOpenGLContextGroup__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOpenGLContextGroup_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLContextGroup_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLContextGroup_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLContextGroup_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLContextGroup_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLContextGroup_spec = {
    "2:PySide6.QtGui.QOpenGLContextGroup",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLContextGroup_slots
};

} //extern "C"

static void *Sbk_QOpenGLContextGroup_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOpenGLContextGroup *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLContextGroup_PythonToCpp_QOpenGLContextGroup_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLContextGroup_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLContextGroup_PythonToCpp_QOpenGLContextGroup_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLContextGroup_TypeF()))
        return QOpenGLContextGroup_PythonToCpp_QOpenGLContextGroup_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLContextGroup_PTR_CppToPython_QOpenGLContextGroup(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOpenGLContextGroup *>(const_cast<void *>(cppIn)), Sbk_QOpenGLContextGroup_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLContextGroup_SignatureStrings[] = {
    "PySide6.QtGui.QOpenGLContextGroup.currentContextGroup()->PySide6.QtGui.QOpenGLContextGroup",
    "PySide6.QtGui.QOpenGLContextGroup.shares(self)->QList[PySide6.QtGui.QOpenGLContext]",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLContextGroup_SignatureByteSize = 86;
static constexpr uint8_t QOpenGLContextGroup_SignatureBytes[86] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0xcd, 0xd4,
    0x0b, 0xf4, 0x2f, 0x48, 0xcd, 0x73, 0xf7, 0x71, 0xce, 0xcf, 0x2b, 0x49, 0xad, 0x28, 0x71, 0x2f,
    0xca, 0x2f, 0x2d, 0xd0, 0x4b, 0x2e, 0x2d, 0x2a, 0x4a, 0xcd, 0x2b, 0x41, 0x16, 0xd3, 0xd0, 0xd4,
    0xb5, 0x0b, 0x20, 0xa4, 0x91, 0x8b, 0xa0, 0x0a, 0xbd, 0xe2, 0x8c, 0xc4, 0xa2, 0xd4, 0x62, 0x8d,
    0xe2, 0xd4, 0x9c, 0x34, 0xa0, 0x89, 0x81, 0x3e, 0x99, 0xc5, 0x25, 0xd1, 0xf8, 0x74, 0xc5, 0x72,
    0x01, 0x00, 0xf5, 0xe6, 0x3f, 0x6e
};
#endif

PyTypeObject *init_QOpenGLContextGroup(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContextGroup_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContextGroup_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLContextGroup_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QOpenGLContextGroup_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLContextGroup",
        "QOpenGLContextGroup*",
        &Sbk_QOpenGLContextGroup_spec,
        &Shiboken::callCppDestructor< QOpenGLContextGroup >,
        Sbk_QOpenGLContextGroup_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLContextGroup_TypeF(); // references _Sbk_QOpenGLContextGroup_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLContextGroup_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLContextGroup_SignatureBytes, QOpenGLContextGroup_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLContextGroup_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContextGroup_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLContextGroup_PythonToCpp_QOpenGLContextGroup_PTR,
        is_QOpenGLContextGroup_PythonToCpp_QOpenGLContextGroup_PTR_Convertible,
        QOpenGLContextGroup_PTR_CppToPython_QOpenGLContextGroup);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLContextGroup");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLContextGroup*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLContextGroup&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLContextGroup).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOpenGLContextGroupWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOpenGLContextGroup_TypeF(), &Sbk_QOpenGLContextGroup_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOpenGLContextGroup::staticMetaObject, sizeof(QOpenGLContextGroupWrapper));

    return pyType;
}
