// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpdfwriter_wrapper.h"

// Wrappers providing overrides
#include "qwindow_wrapper.h"
#include "qundocommand_wrapper.h"
#include "qpagedpaintdevice_wrapper.h"
#include "qpaintengine_wrapper.h"
#include "qpaintdevice_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpageranges.h>
#include <QtGui/qpagesize.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpdfoutputintent.h>
#include <QtGui/qpdfwriter.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmargins.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <quuid.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPdfWriterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPdfWriterWrapper::QPdfWriterWrapper(::QIODevice * device) : QPdfWriter(device)
{
}

QPdfWriterWrapper::QPdfWriterWrapper(const ::QString & filename) : QPdfWriter(filename)
{
}

void QPdfWriterWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWindowWrapper::sbk_o_childEvent("QPdfWriter", funcName, gil, pyOverride, event);
}

void QPdfWriterWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QPdfWriter", funcName, gil, pyOverride, signal);
}

void QPdfWriterWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWindowWrapper::sbk_o_customEvent("QPdfWriter", funcName, gil, pyOverride, event);
}

int QPdfWriterWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::devType();
    }
    return QUndoCommandWrapper::sbk_o_id("QPdfWriter", funcName, gil, pyOverride);
}

void QPdfWriterWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QPdfWriter", funcName, gil, pyOverride, signal);
}

bool QPdfWriterWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWindowWrapper::sbk_o_event("QPdfWriter", funcName, gil, pyOverride, event);
}

bool QPdfWriterWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWindowWrapper::sbk_o_eventFilter("QPdfWriter", funcName, gil, pyOverride, watched, event);
}

void QPdfWriterWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::initPainter(painter);
    }
    QPaintDeviceWrapper::sbk_o_initPainter("QPdfWriter", funcName, gil, pyOverride, painter);
}

int QPdfWriterWrapper::metric(::QPaintDevice::PaintDeviceMetric id) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfWriter::metric(id);
    }
    return QPaintDeviceWrapper::sbk_o_metric("QPdfWriter", funcName, gil, pyOverride, id);
}

bool QPdfWriterWrapper::newPage()
{
    static const char *funcName = "newPage";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfWriter::newPage();
    }
    return QPaintEngineWrapper::sbk_o_end("QPdfWriter", funcName, gil, pyOverride);
}

::QPaintEngine * QPdfWriterWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfWriter::paintEngine();
    }
    return QPaintDeviceWrapper::sbk_o_paintEngine("QPdfWriter", funcName, gil, pyOverride);
}

::QPaintDevice * QPdfWriterWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::redirected(offset);
    }
    return QPaintDeviceWrapper::sbk_o_redirected("QPdfWriter", funcName, gil, pyOverride, offset);
}

bool QPdfWriterWrapper::setPageLayout(const ::QPageLayout & pageLayout)
{
    static const char *funcName = "setPageLayout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPagedPaintDevice::setPageLayout(pageLayout);
    }
    return QPagedPaintDeviceWrapper::sbk_o_setPageLayout("QPdfWriter", funcName, gil, pyOverride, pageLayout);
}

bool QPdfWriterWrapper::setPageMargins(const ::QMarginsF & margins, ::QPageLayout::Unit units)
{
    static const char *funcName = "setPageMargins";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPagedPaintDevice::setPageMargins(margins, units);
    }
    return QPagedPaintDeviceWrapper::sbk_o_setPageMargins("QPdfWriter", funcName, gil, pyOverride, margins, units);
}

bool QPdfWriterWrapper::setPageOrientation(::QPageLayout::Orientation orientation)
{
    static const char *funcName = "setPageOrientation";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPagedPaintDevice::setPageOrientation(orientation);
    }
    return QPagedPaintDeviceWrapper::sbk_o_setPageOrientation("QPdfWriter", funcName, gil, pyOverride, orientation);
}

void QPdfWriterWrapper::setPageRanges(const ::QPageRanges & ranges)
{
    static const char *funcName = "setPageRanges";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPagedPaintDevice::setPageRanges(ranges);
    }
    QPagedPaintDeviceWrapper::sbk_o_setPageRanges("QPdfWriter", funcName, gil, pyOverride, ranges);
}

bool QPdfWriterWrapper::setPageSize(const ::QPageSize & pageSize)
{
    static const char *funcName = "setPageSize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPagedPaintDevice::setPageSize(pageSize);
    }
    return QPagedPaintDeviceWrapper::sbk_o_setPageSize("QPdfWriter", funcName, gil, pyOverride, pageSize);
}

::QPainter * QPdfWriterWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::sharedPainter();
    }
    return QPaintDeviceWrapper::sbk_o_sharedPainter("QPdfWriter", funcName, gil, pyOverride);
}

void QPdfWriterWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWindowWrapper::sbk_o_timerEvent("QPdfWriter", funcName, gil, pyOverride, event);
}

const QMetaObject *QPdfWriterWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPdfWriter::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPdfWriterWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPdfWriter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPdfWriterWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPdfWriterWrapper *>(this));
    return QPdfWriter::qt_metacast(_clname);
}

QPdfWriterWrapper::~QPdfWriterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfWriter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);
    if (type != myType)
        Shiboken::ObjectType::copyMultipleInheritance(type, myType);

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfWriter >()))
        return -1;

    QPdfWriterWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPdfWriter", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfWriter::QPdfWriter(QIODevice*)
    // 1: QPdfWriter::QPdfWriter(QString)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPdfWriter(QIODevice*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QPdfWriter(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPdfWriter(QIODevice *device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPdfWriter(QIODevice*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QPdfWriterWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QPdfWriterWrapper(cppArg0);
                }

            }
            break;
        }
        case 1: // QPdfWriter(const QString &filename)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPdfWriter(QString)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QPdfWriterWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QPdfWriterWrapper(cppArg0);
                }

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPdfWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPdfWriterFunc_addFileAttachment(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addFileAttachment", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:addFileAttachment", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPdfWriter::addFileAttachment(QString,QByteArray,const QString&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // addFileAttachment(QString,QByteArray,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // addFileAttachment(QString,QByteArray,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addFileAttachment", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mimeType", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addFileAttachment", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addFileAttachment(QString,QByteArray,QString)
            cppSelf->addFileAttachment(cppArg0, *cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_author(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // author()const
        QString cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->author();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_colorModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorModel()const
        QPdfWriter::ColorModel cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->colorModel();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_ColorModel_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_creator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // creator()const
        QString cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->creator();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_documentId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentId()const
        QUuid cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->documentId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_documentXmpMetadata(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentXmpMetadata()const
        QByteArray cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->documentXmpMetadata();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_metric(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintDevice::metric(QPaintDevice::PaintDeviceMetric)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "metric", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        ::QPaintDevice::PaintDeviceMetric cppArg0 = static_cast< ::QPaintDevice::PaintDeviceMetric>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPdfWriter *>(cppSelf)->::QPdfWriter::metric(cppArg0)
                : const_cast<const ::QPdfWriter *>(cppSelf)->metric(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_newPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // newPage()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QPdfWriter::newPage()
            : cppSelf->newPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_outputIntent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputIntent()const
        QPdfOutputIntent cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->outputIntent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_paintEngine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // paintEngine()const
        QPaintEngine * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QPdfWriter *>(cppSelf)->::QPdfWriter::paintEngine()
            : const_cast<const ::QPdfWriter *>(cppSelf)->paintEngine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_pdfVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pdfVersion()const
        QPagedPaintDevice::PdfVersion cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->pdfVersion();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_PdfVersion_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_resolution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resolution()const
        int cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->resolution();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfWriterFunc_setAuthor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setAuthor(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setAuthor(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAuthor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAuthor(QString)
            cppSelf->setAuthor(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setColorModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setColorModel(QPdfWriter::ColorModel)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_ColorModel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorModel(QPdfWriter::ColorModel)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorModel", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        ::QPdfWriter::ColorModel cppArg0{QPdfWriter::ColorModel::RGB};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorModel(QPdfWriter::ColorModel)
            cppSelf->setColorModel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setCreator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setCreator(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCreator(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCreator", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCreator(QString)
            cppSelf->setCreator(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setDocumentId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setDocumentId(QUuid)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
        overloadId = 0; // setDocumentId(QUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocumentId", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUuid cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocumentId(QUuid)
            cppSelf->setDocumentId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setDocumentXmpMetadata(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setDocumentXmpMetadata(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setDocumentXmpMetadata(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocumentXmpMetadata", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocumentXmpMetadata(QByteArray)
            cppSelf->setDocumentXmpMetadata(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setOutputIntent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setOutputIntent(QPdfOutputIntent)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), (pyArg)))) {
        overloadId = 0; // setOutputIntent(QPdfOutputIntent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputIntent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPdfOutputIntent cppArg0_local;
        ::QPdfOutputIntent *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputIntent(QPdfOutputIntent)
            cppSelf->setOutputIntent(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setPdfVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setPdfVersion(QPagedPaintDevice::PdfVersion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_PdfVersion_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPdfVersion(QPagedPaintDevice::PdfVersion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPdfVersion", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        ::QPagedPaintDevice::PdfVersion cppArg0{QPagedPaintDevice::PdfVersion_1_4};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPdfVersion(QPagedPaintDevice::PdfVersion)
            cppSelf->setPdfVersion(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setResolution(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setResolution(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setResolution(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResolution", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setResolution(int)
            cppSelf->setResolution(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_setTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfWriter::setTitle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitle(QString)
            cppSelf->setTitle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfWriterFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // title()const
        QString cppResult = const_cast<const ::QPdfWriter *>(cppSelf)->title();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QPdfWriter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPdfWriter_EnumFlagInfo[] = {
    "ColorModel:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfWriter_methods[] = {
    {"addFileAttachment", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_addFileAttachment), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"author", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_author), METH_NOARGS, nullptr},
    {"colorModel", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_colorModel), METH_NOARGS, nullptr},
    {"creator", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_creator), METH_NOARGS, nullptr},
    {"documentId", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_documentId), METH_NOARGS, nullptr},
    {"documentXmpMetadata", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_documentXmpMetadata), METH_NOARGS, nullptr},
    {"metric", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_metric), METH_O, nullptr},
    {"newPage", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_newPage), METH_NOARGS, nullptr},
    {"outputIntent", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_outputIntent), METH_NOARGS, nullptr},
    {"paintEngine", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_paintEngine), METH_NOARGS, nullptr},
    {"pdfVersion", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_pdfVersion), METH_NOARGS, nullptr},
    {"resolution", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_resolution), METH_NOARGS, nullptr},
    {"setAuthor", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setAuthor), METH_O, nullptr},
    {"setColorModel", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setColorModel), METH_O, nullptr},
    {"setCreator", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setCreator), METH_O, nullptr},
    {"setDocumentId", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setDocumentId), METH_O, nullptr},
    {"setDocumentXmpMetadata", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setDocumentXmpMetadata), METH_O, nullptr},
    {"setOutputIntent", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setOutputIntent), METH_O, nullptr},
    {"setPdfVersion", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setPdfVersion), METH_O, nullptr},
    {"setResolution", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setResolution), METH_O, nullptr},
    {"setTitle", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_setTitle), METH_O, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QPdfWriterFunc_title), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPdfWriter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPdfWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPdfWriterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPdfWriter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfWriter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_QPdfWriter_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QPdfWriter *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QPdfWriter *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QPagedPaintDevice *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QPagedPaintDevice *>(static_cast<const QPdfWriter *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QPaintDevice *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QPaintDevice *>(static_cast<const QPagedPaintDevice *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QPdfWriterSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QPdfWriter *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_IDX]))
        return static_cast< ::QPagedPaintDevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfWriter_Type = nullptr;
static PyTypeObject *Sbk_QPdfWriter_TypeF(void)
{
    return _Sbk_QPdfWriter_Type;
}

static PyType_Slot Sbk_QPdfWriter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPdfWriter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfWriter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfWriter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfWriter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfWriter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfWriter_spec = {
    "2:PySide6.QtGui.QPdfWriter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfWriter_slots
};

} //extern "C"

static void *Sbk_QPdfWriter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPdfWriter *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QPdfWriter *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPdfWriter_ColorModel(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPdfWriter::ColorModel>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPdfWriter::ColorModel *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPdfWriter_ColorModel_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_ColorModel_IDX])))
        return Enum_PythonToCpp_QPdfWriter_ColorModel;
    return {};
}

static PyObject *QPdfWriter_ColorModel_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPdfWriter::ColorModel>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPdfWriter::ColorModel *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_ColorModel_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfWriter_PythonToCpp_QPdfWriter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfWriter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfWriter_PythonToCpp_QPdfWriter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfWriter_TypeF()))
        return QPdfWriter_PythonToCpp_QPdfWriter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfWriter_PTR_CppToPython_QPdfWriter(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPdfWriter *>(const_cast<void *>(cppIn)), Sbk_QPdfWriter_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPdfWriter_SignatureStrings[] = {
    "1:PySide6.QtGui.QPdfWriter(self,device:PySide6.QtCore.QIODevice)",
    "0:PySide6.QtGui.QPdfWriter(self,filename:QString)",
    "PySide6.QtGui.QPdfWriter.addFileAttachment(self,fileName:QString,data:typing.Union[PySide6.QtCore.QByteArray, char*],mimeType:QString=QString())",
    "PySide6.QtGui.QPdfWriter.author(self)->QString",
    "PySide6.QtGui.QPdfWriter.colorModel(self)->PySide6.QtGui.QPdfWriter.ColorModel",
    "PySide6.QtGui.QPdfWriter.creator(self)->QString",
    "PySide6.QtGui.QPdfWriter.documentId(self)->PySide6.QtCore.QUuid",
    "PySide6.QtGui.QPdfWriter.documentXmpMetadata(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QPdfWriter.metric(self,id:PySide6.QtGui.QPaintDevice.PaintDeviceMetric)->int",
    "PySide6.QtGui.QPdfWriter.newPage(self)->bool",
    "PySide6.QtGui.QPdfWriter.outputIntent(self)->PySide6.QtGui.QPdfOutputIntent",
    "PySide6.QtGui.QPdfWriter.paintEngine(self)->PySide6.QtGui.QPaintEngine",
    "PySide6.QtGui.QPdfWriter.pdfVersion(self)->PySide6.QtGui.QPagedPaintDevice.PdfVersion",
    "PySide6.QtGui.QPdfWriter.resolution(self)->int",
    "PySide6.QtGui.QPdfWriter.setAuthor(self,author:QString)",
    "PySide6.QtGui.QPdfWriter.setColorModel(self,model:PySide6.QtGui.QPdfWriter.ColorModel)",
    "PySide6.QtGui.QPdfWriter.setCreator(self,creator:QString)",
    "PySide6.QtGui.QPdfWriter.setDocumentId(self,documentId:PySide6.QtCore.QUuid)",
    "PySide6.QtGui.QPdfWriter.setDocumentXmpMetadata(self,xmpMetadata:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtGui.QPdfWriter.setOutputIntent(self,intent:PySide6.QtGui.QPdfOutputIntent)",
    "PySide6.QtGui.QPdfWriter.setPdfVersion(self,version:PySide6.QtGui.QPagedPaintDevice.PdfVersion)",
    "PySide6.QtGui.QPdfWriter.setResolution(self,resolution:int)",
    "PySide6.QtGui.QPdfWriter.setTitle(self,title:QString)",
    "PySide6.QtGui.QPdfWriter.title(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QPdfWriter_SignatureByteSize = 422;
static constexpr uint8_t QPdfWriter_SignatureBytes[422] = {
    0x78, 0xda, 0x95, 0x94, 0x4b, 0x6f, 0x82, 0x40, 0x10, 0x80, 0xef, 0xfe, 0x8a, 0x1e, 0xb5, 0xd9,
    0x92, 0xf6, 0xd2, 0x03, 0x49, 0x9b, 0x58, 0x6d, 0x1b, 0x0f, 0x56, 0xa8, 0xf6, 0x91, 0x34, 0x3d,
    0x6c, 0xd9, 0x01, 0x37, 0x81, 0x5d, 0xb2, 0x0c, 0xb6, 0xfc, 0xfb, 0x82, 0x28, 0x0f, 0x75, 0x17,
    0x3c, 0x39, 0xe2, 0xcc, 0xb7, 0xe3, 0xec, 0x37, 0xdc, 0xd8, 0x4e, 0xb6, 0xe4, 0x0c, 0x6e, 0x2d,
    0x17, 0x9f, 0x53, 0x6e, 0xb9, 0x0e, 0xf3, 0x3f, 0x14, 0x47, 0x50, 0xc3, 0x04, 0x42, 0x9f, 0x30,
    0xd8, 0x70, 0x0f, 0x1a, 0x49, 0x13, 0xa9, 0xc0, 0x72, 0x67, 0x8b, 0xe9, 0xf6, 0x87, 0xd1, 0xe0,
    0xba, 0x03, 0xe0, 0xf3, 0x10, 0x04, 0x8d, 0xc0, 0x76, 0x97, 0xa8, 0xb8, 0x08, 0x46, 0x03, 0x5d,
    0xbe, 0x45, 0x19, 0x7b, 0xca, 0xb3, 0xc7, 0x88, 0xd4, 0x5b, 0x47, 0x20, 0xb0, 0x26, 0xbc, 0x34,
    0x08, 0x84, 0x51, 0xa4, 0x36, 0x66, 0x71, 0x1e, 0x5b, 0x6f, 0x82, 0x4b, 0xf1, 0x75, 0xd8, 0xde,
    0x43, 0x86, 0x30, 0x56, 0x8a, 0x66, 0xe4, 0xc2, 0x5b, 0x53, 0x75, 0xf9, 0x4d, 0x22, 0x1e, 0xc1,
    0x2a, 0x8b, 0x2b, 0xc8, 0xdd, 0xee, 0x73, 0x38, 0x32, 0x35, 0x94, 0xe2, 0x5a, 0x96, 0xff, 0x63,
    0x74, 0x75, 0xbf, 0xab, 0xd0, 0xa7, 0x7b, 0x32, 0x94, 0x6a, 0x2e, 0x19, 0x84, 0xfb, 0x12, 0x6d,
    0xea, 0xa4, 0x4a, 0x35, 0xe0, 0x14, 0x50, 0x3c, 0xe3, 0x78, 0x26, 0xbd, 0xb4, 0x98, 0xda, 0x8c,
    0x1d, 0x1f, 0x5f, 0x8e, 0xe5, 0x2d, 0xe5, 0xac, 0xbb, 0xfe, 0x33, 0x8a, 0xe7, 0x80, 0xb4, 0x98,
    0xb2, 0x0e, 0x54, 0xcd, 0x57, 0x4f, 0x8b, 0x20, 0x6f, 0xd7, 0x2b, 0x6f, 0x90, 0xb3, 0x23, 0x49,
    0x28, 0x17, 0x58, 0x2a, 0x64, 0x35, 0xe2, 0xf9, 0xb6, 0x28, 0x3f, 0x30, 0x7f, 0xa2, 0x47, 0x0b,
    0xf8, 0x75, 0x68, 0x00, 0xfb, 0xe6, 0x7e, 0xa4, 0x34, 0x4c, 0x51, 0xa6, 0x18, 0xa7, 0x38, 0x13,
    0xb8, 0xf7, 0xe9, 0xe4, 0xb5, 0x2c, 0x1a, 0x59, 0x7a, 0x56, 0x5c, 0x74, 0xfa, 0x28, 0x02, 0x2e,
    0x40, 0x87, 0xaa, 0x33, 0x0c, 0x18, 0xe6, 0xbf, 0x83, 0x4a, 0x72, 0x71, 0xb5, 0x94, 0x00, 0x58,
    0x6b, 0x44, 0x55, 0x85, 0x9e, 0xaa, 0x20, 0x91, 0x61, 0x8a, 0x0d, 0xaa, 0x71, 0x88, 0x09, 0xe0,
    0xb8, 0xd6, 0x9b, 0x94, 0xaa, 0xf7, 0x58, 0xd2, 0xbc, 0x6e, 0xd2, 0xf6, 0x9c, 0x44, 0x45, 0x68,
    0xf7, 0x70, 0xbd, 0x03, 0xdb, 0xf0, 0x9d, 0xec, 0xe4, 0xef, 0xd7, 0xd0, 0xb4, 0x6d, 0x3e, 0xa9,
    0x37, 0xc1, 0x3e, 0xb5, 0x02, 0xfd, 0x60, 0x87, 0x6b, 0x40, 0xfe, 0xea, 0x07, 0x67, 0xbe, 0x7d,
    0xcc, 0x07, 0x2e, 0x0e, 0x0d, 0x25, 0x7c, 0x1b, 0xdb, 0x66, 0x4d, 0xcd, 0x50, 0xa7, 0xed, 0x18,
    0xd9, 0x94, 0x5f, 0xec, 0xfe, 0xa6, 0x99, 0xf9, 0xaf, 0x6d, 0xdb, 0x48, 0x6d, 0x9f, 0xcd, 0xbb,
    0x7a, 0x5b, 0x71, 0x0c, 0xcb, 0x05, 0x22, 0x58, 0x84, 0x3d, 0x2e, 0x19, 0xab, 0x92, 0xc6, 0x9b,
    0xf0, 0x1f, 0x2a, 0x8e, 0x6c, 0x68
};
#endif

PyTypeObject *init_QPdfWriter(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfWriter_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_IDX]))));

    _Sbk_QPdfWriter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfWriter",
        "QPdfWriter*",
        &Sbk_QPdfWriter_spec,
        &Shiboken::callCppDestructor< QPdfWriter >,
        Sbk_QPdfWriter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPdfWriter_TypeF(); // references _Sbk_QPdfWriter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPdfWriter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPdfWriter_SignatureBytes, QPdfWriter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfWriter_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfWriter_PythonToCpp_QPdfWriter_PTR,
        is_QPdfWriter_PythonToCpp_QPdfWriter_PTR_Convertible,
        QPdfWriter_PTR_CppToPython_QPdfWriter);

    Shiboken::Conversions::registerConverterName(converter, "QPdfWriter");
    Shiboken::Conversions::registerConverterName(converter, "QPdfWriter*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfWriter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfWriter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPdfWriterWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QPdfWriter_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QPdfWriter_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QPdfWriter_TypeF(), &Sbk_QPdfWriterSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPdfWriter_TypeF(), &Sbk_QPdfWriter_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPdfWriter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ColorModel'.
    const char *ColorModel_Initializer[] = {
        "RGB",
        "Grayscale",
        "CMYK",
        "Auto",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ColorModel_InitializerValues[] = {
        int8_t(QPdfWriter::ColorModel::RGB),       //  0x00  0
        int8_t(QPdfWriter::ColorModel::Grayscale), //  0x01  1
        int8_t(QPdfWriter::ColorModel::CMYK),      //  0x02  2
        int8_t(QPdfWriter::ColorModel::Auto)       //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPdfWriter_TypeF(),
        "2:PySide6.QtGui.QPdfWriter.ColorModel",
        ColorModel_Initializer, ColorModel_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPdfWriter_ColorModel_IDX].type = EType;
    // Register converter for enum 'QPdfWriter::ColorModel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPdfWriter_ColorModel_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPdfWriter_ColorModel,
            is_Enum_PythonToCpp_QPdfWriter_ColorModel_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPdfWriter::ColorModel");
        Shiboken::Conversions::registerConverterAlias(converter, "ColorModel");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ColorModel' enum.

    qRegisterMetaType< ::QPdfWriter::ColorModel >("QPdfWriter::ColorModel");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPdfWriter::staticMetaObject, sizeof(QPdfWriterWrapper));

    return pyType;
}
