// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPICTUREWRAPPER_H
#define SBK_QPICTUREWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qpicture.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QPictureWrapper : public QPicture
{
public:
    QPictureWrapper(int formatVersion = -1);
    QPictureWrapper(const QPictureWrapper &) = delete;
    QPictureWrapper(const QPicture& self) : QPicture(self)
    {
    }
    QPictureWrapper& operator=(const QPictureWrapper &) = delete;
    QPictureWrapper(QPictureWrapper &&) = delete;
    QPictureWrapper& operator=(QPictureWrapper &&) = delete;
    ~QPictureWrapper() override;

    int devType() const override;
    void initPainter(::QPainter * painter) const override;
    int metric(::QPaintDevice::PaintDeviceMetric m) const override;
    ::QPaintEngine * paintEngine() const override;
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    void setData(const char * data, uint size) override;
    static void sbk_o_setData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * data, uint size);
    ::QPainter * sharedPainter() const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[7] = {false, false, false, false, false, false, false};
};

#endif // SBK_QPICTUREWRAPPER_H
