// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPIXMAPWRAPPER_H
#define SBK_QPIXMAPWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qpixmap.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QPixmapWrapper : public QPixmap
{
public:
    QPixmapWrapper();
    QPixmapWrapper(const ::QSize & arg__1);
    QPixmapWrapper(const ::QString & fileName, const char * format = nullptr, ::QFlags<Qt::ImageConversionFlag> flags = Qt::AutoColor);
    QPixmapWrapper(const char *const xpm[]);
    QPixmapWrapper(int w, int h);
    QPixmapWrapper(const QPixmapWrapper &) = delete;
    QPixmapWrapper(const QPixmap& self) : QPixmap(self)
    {
    }
    QPixmapWrapper& operator=(const QPixmapWrapper &) = delete;
    QPixmapWrapper(QPixmapWrapper &&) = delete;
    QPixmapWrapper& operator=(QPixmapWrapper &&) = delete;
    ~QPixmapWrapper() override;

    int devType() const override;
    void initPainter(::QPainter * painter) const override;
    int metric(::QPaintDevice::PaintDeviceMetric arg__1) const override;
    ::QPaintEngine * paintEngine() const override;
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    ::QPainter * sharedPainter() const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QPIXMAPWRAPPER_H
