// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPOINTEREVENTWRAPPER_H
#define SBK_QPOINTEREVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QPointerEventWrapper : public QPointerEvent
{
public:
    QPointerEventWrapper(::QEvent::Type type, const ::QPointingDevice * dev, ::QFlags<Qt::KeyboardModifier> modifiers = Qt::NoModifier, const ::QList<QEventPoint> & points = {});
    QPointerEventWrapper(const QPointerEventWrapper &) = delete;
    QPointerEventWrapper(const QPointerEvent& self) : QPointerEvent(self)
    {
    }
    QPointerEventWrapper& operator=(const QPointerEventWrapper &) = delete;
    QPointerEventWrapper(QPointerEventWrapper &&) = delete;
    QPointerEventWrapper& operator=(QPointerEventWrapper &&) = delete;
    ~QPointerEventWrapper() override;

    ::QPointerEvent * clone() const override;
    static ::QPointerEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QPOINTEREVENTWRAPPER_H
