// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QRHISWAPCHAINWRAPPER_H
#define SBK_QRHISWAPCHAINWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <rhi/qrhi.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QRhiSwapChainWrapper : public QRhiSwapChain
{
public:
    QRhiSwapChainWrapper(const QRhiSwapChainWrapper &) = delete;
    QRhiSwapChainWrapper& operator=(const QRhiSwapChainWrapper &) = delete;
    QRhiSwapChainWrapper(QRhiSwapChainWrapper &&) = delete;
    QRhiSwapChainWrapper& operator=(QRhiSwapChainWrapper &&) = delete;
    ~QRhiSwapChainWrapper() override;

    bool createOrResize() override;
    ::QRhiCommandBuffer * currentFrameCommandBuffer() override;
    static ::QRhiCommandBuffer * sbk_o_currentFrameCommandBuffer(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QRhiRenderTarget * currentFrameRenderTarget() override;
    static ::QRhiRenderTarget * sbk_o_currentFrameRenderTarget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QRhiRenderTarget * currentFrameRenderTarget(::QRhiSwapChain::StereoTargetBuffer targetBuffer) override;
    static ::QRhiRenderTarget * sbk_o_currentFrameRenderTarget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QRhiSwapChain::StereoTargetBuffer targetBuffer);
    void destroy() override;
    bool isFormatSupported(::QRhiSwapChain::Format f) override;
    static bool sbk_o_isFormatSupported(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QRhiSwapChain::Format f);
    ::QRhiRenderPassDescriptor * newCompatibleRenderPassDescriptor() override;
    ::QRhiResource::Type resourceType() const override;
    ::QSize surfacePixelSize() override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[9] = {false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QRHISWAPCHAINWRAPPER_H
