// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextblockgroup_wrapper.h"

// Wrappers providing overrides
#include "qwindow_wrapper.h"
#include "qtextblockgroup_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextobject.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QTextBlockGroupWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTextBlockGroupWrapper::QTextBlockGroupWrapper(::QTextDocument * doc) : QTextBlockGroup(doc)
{
}

void QTextBlockGroupWrapper::blockFormatChanged(const ::QTextBlock & block)
{
    static const char *funcName = "blockFormatChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTextBlockGroup::blockFormatChanged(block);
    }
    sbk_o_blockFormatChanged("QTextBlockGroup", funcName, gil, pyOverride, block);
}

void QTextBlockGroupWrapper::sbk_o_blockFormatChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QTextBlock & block)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &block)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &block)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QTextBlockGroupWrapper::blockInserted(const ::QTextBlock & block)
{
    static const char *funcName = "blockInserted";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTextBlockGroup::blockInserted(block);
    }
    QTextBlockGroupWrapper::sbk_o_blockFormatChanged("QTextBlockGroup", funcName, gil, pyOverride, block);
}

void QTextBlockGroupWrapper::blockRemoved(const ::QTextBlock & block)
{
    static const char *funcName = "blockRemoved";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTextBlockGroup::blockRemoved(block);
    }
    QTextBlockGroupWrapper::sbk_o_blockFormatChanged("QTextBlockGroup", funcName, gil, pyOverride, block);
}

void QTextBlockGroupWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWindowWrapper::sbk_o_childEvent("QTextBlockGroup", funcName, gil, pyOverride, event);
}

void QTextBlockGroupWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QTextBlockGroup", funcName, gil, pyOverride, signal);
}

void QTextBlockGroupWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWindowWrapper::sbk_o_customEvent("QTextBlockGroup", funcName, gil, pyOverride, event);
}

void QTextBlockGroupWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QTextBlockGroup", funcName, gil, pyOverride, signal);
}

bool QTextBlockGroupWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWindowWrapper::sbk_o_event("QTextBlockGroup", funcName, gil, pyOverride, event);
}

bool QTextBlockGroupWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWindowWrapper::sbk_o_eventFilter("QTextBlockGroup", funcName, gil, pyOverride, watched, event);
}

void QTextBlockGroupWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWindowWrapper::sbk_o_timerEvent("QTextBlockGroup", funcName, gil, pyOverride, event);
}

const QMetaObject *QTextBlockGroupWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QTextBlockGroup::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTextBlockGroupWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QTextBlockGroup::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTextBlockGroupWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTextBlockGroupWrapper *>(this));
    return QTextBlockGroup::qt_metacast(_clname);
}

QTextBlockGroupWrapper::~QTextBlockGroupWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextBlockGroup_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextBlockGroup >()))
        return -1;

    QTextBlockGroupWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextBlockGroup", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextBlockGroup::QTextBlockGroup(QTextDocument*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTextBlockGroup(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QTextDocument *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QTextBlockGroup(QTextDocument*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QTextBlockGroupWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QTextBlockGroupWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QTextBlockGroup >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QTextBlockGroupFunc_blockFormatChanged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockGroup::blockFormatChanged(QTextBlock)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
        overloadId = 0; // blockFormatChanged(QTextBlock)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "blockFormatChanged", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlock cppArg0_local;
        ::QTextBlock *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // blockFormatChanged(QTextBlock)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTextBlockGroup::blockFormatChanged(*cppArg0)
                : cppSelf->blockFormatChanged(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextBlockGroupFunc_blockInserted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockGroup::blockInserted(QTextBlock)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
        overloadId = 0; // blockInserted(QTextBlock)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "blockInserted", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlock cppArg0_local;
        ::QTextBlock *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // blockInserted(QTextBlock)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTextBlockGroup::blockInserted(*cppArg0)
                : cppSelf->blockInserted(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextBlockGroupFunc_blockList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockList()const
        QList<QTextBlock> cppResult = const_cast<const ::QTextBlockGroup *>(cppSelf)->blockList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextBlock_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextBlockGroupFunc_blockRemoved(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockGroup::blockRemoved(QTextBlock)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
        overloadId = 0; // blockRemoved(QTextBlock)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "blockRemoved", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlock cppArg0_local;
        ::QTextBlock *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // blockRemoved(QTextBlock)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTextBlockGroup::blockRemoved(*cppArg0)
                : cppSelf->blockRemoved(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QTextBlockGroup_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextBlockGroup_methods[] = {
    {"blockFormatChanged", reinterpret_cast<PyCFunction>(Sbk_QTextBlockGroupFunc_blockFormatChanged), METH_O, nullptr},
    {"blockInserted", reinterpret_cast<PyCFunction>(Sbk_QTextBlockGroupFunc_blockInserted), METH_O, nullptr},
    {"blockList", reinterpret_cast<PyCFunction>(Sbk_QTextBlockGroupFunc_blockList), METH_NOARGS, nullptr},
    {"blockRemoved", reinterpret_cast<PyCFunction>(Sbk_QTextBlockGroupFunc_blockRemoved), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QTextBlockGroup_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QTextBlockGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTextBlockGroupWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QTextBlockGroup_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextBlockGroup_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextBlockGroup_Type = nullptr;
static PyTypeObject *Sbk_QTextBlockGroup_TypeF(void)
{
    return _Sbk_QTextBlockGroup_Type;
}

static PyType_Slot Sbk_QTextBlockGroup_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QTextBlockGroup_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextBlockGroup_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextBlockGroup_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextBlockGroup_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextBlockGroup_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextBlockGroup_spec = {
    "2:PySide6.QtGui.QTextBlockGroup",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextBlockGroup_slots
};

} //extern "C"

static void *Sbk_QTextBlockGroup_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QTextBlockGroup *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextBlockGroup_PythonToCpp_QTextBlockGroup_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextBlockGroup_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextBlockGroup_PythonToCpp_QTextBlockGroup_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBlockGroup_TypeF()))
        return QTextBlockGroup_PythonToCpp_QTextBlockGroup_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextBlockGroup_PTR_CppToPython_QTextBlockGroup(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QTextBlockGroup *>(const_cast<void *>(cppIn)), Sbk_QTextBlockGroup_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextBlockGroup_SignatureStrings[] = {
    "PySide6.QtGui.QTextBlockGroup(self,doc:PySide6.QtGui.QTextDocument)",
    "PySide6.QtGui.QTextBlockGroup.blockFormatChanged(self,block:PySide6.QtGui.QTextBlock)",
    "PySide6.QtGui.QTextBlockGroup.blockInserted(self,block:PySide6.QtGui.QTextBlock)",
    "PySide6.QtGui.QTextBlockGroup.blockList(self)->QList[PySide6.QtGui.QTextBlock]",
    "PySide6.QtGui.QTextBlockGroup.blockRemoved(self,block:PySide6.QtGui.QTextBlock)",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextBlockGroup_SignatureByteSize = 125;
static constexpr uint8_t QTextBlockGroup_SignatureBytes[125] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0xcd, 0xd4,
    0x0b, 0x0c, 0x49, 0xad, 0x28, 0x71, 0xca, 0xc9, 0x4f, 0xce, 0x76, 0x2f, 0xca, 0x2f, 0x2d, 0xd0,
    0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x49, 0xc9, 0x4f, 0xb6, 0x0a, 0xc0, 0x54, 0xe6, 0x92, 0x9f, 0x5c,
    0x9a, 0x9b, 0x9a, 0x57, 0xa2, 0xc9, 0x15, 0x80, 0xcf, 0x0c, 0xbd, 0x24, 0x10, 0xd3, 0x2d, 0xbf,
    0x28, 0x37, 0xb1, 0xc4, 0x39, 0x23, 0x31, 0x2f, 0x3d, 0x35, 0x05, 0x62, 0x2c, 0x58, 0xdc, 0x0a,
    0x97, 0x5e, 0xa2, 0x4c, 0xf5, 0xcc, 0x2b, 0x4e, 0x2d, 0x2a, 0xa1, 0xa2, 0x81, 0x3e, 0x99, 0xc5,
    0x25, 0x60, 0xc3, 0x34, 0x75, 0xed, 0x02, 0x41, 0x9c, 0x68, 0x5c, 0x9a, 0x62, 0x89, 0x31, 0x2e,
    0x28, 0x35, 0x37, 0xbf, 0x8c, 0x58, 0xe7, 0x01, 0x00, 0xd4, 0x58, 0x8d, 0xff
};
#endif

PyTypeObject *init_QTextBlockGroup(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextBlockGroup_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextObject_IDX]))));

    _Sbk_QTextBlockGroup_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextBlockGroup",
        "QTextBlockGroup*",
        &Sbk_QTextBlockGroup_spec,
        &Shiboken::callCppDestructor< QTextBlockGroup >,
        Sbk_QTextBlockGroup_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTextBlockGroup_TypeF(); // references _Sbk_QTextBlockGroup_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextBlockGroup_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextBlockGroup_SignatureBytes, QTextBlockGroup_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextBlockGroup_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockGroup_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextBlockGroup_PythonToCpp_QTextBlockGroup_PTR,
        is_QTextBlockGroup_PythonToCpp_QTextBlockGroup_PTR_Convertible,
        QTextBlockGroup_PTR_CppToPython_QTextBlockGroup);

    Shiboken::Conversions::registerConverterName(converter, "QTextBlockGroup");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlockGroup*");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlockGroup&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextBlockGroup).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTextBlockGroupWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QTextBlockGroup_TypeF(), &Sbk_QTextBlockGroup_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QTextBlockGroup::staticMetaObject, sizeof(QTextBlockGroupWrapper));

    return pyType;
}
