// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextframe_iterator_wrapper.h"

// Argument includes
#include <QTextFrame>
#include <QtGui/qtextobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextFrame_iterator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextFrame::iterator >()))
        return -1;

    ::QTextFrame::iterator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "iterator", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: iterator::iterator()
    // 1: iterator::iterator(QTextFrame::iterator)
    if (numArgs == 0) {
        overloadId = 0; // iterator()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), (pyArgs[0])))) {
        overloadId = 1; // iterator(QTextFrame::iterator)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // iterator()
        {

            // iterator()
            cptr = new ::QTextFrame::iterator();
            break;
        }
        case 1: // iterator(const QTextFrame::iterator &iterator)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFrame::iterator cppArg0_local;
            ::QTextFrame::iterator *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // iterator(QTextFrame::iterator)
                cptr = new ::QTextFrame::iterator(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextFrame::iterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextFrame_iteratorFunc___iter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __iter__()
        // Begin code injection
        // TEMPLATE - __iter__ - START
        Py_INCREF(self);
        pyResult = self;
        // TEMPLATE - __iter__ - END
        // End of code injection

    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextFrame_iteratorFunc___next__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __next__()
        // Begin code injection
        // TEMPLATE - __next__ - START
        if (!cppSelf->atEnd()) {
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), &*cppSelf);
            ++(*cppSelf);
        }
        // TEMPLATE - __next__ - END
        // End of code injection

    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextFrame_iteratorFunc_atEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atEnd()const
        bool cppResult = const_cast<const ::QTextFrame::iterator *>(cppSelf)->atEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextFrame_iteratorFunc_currentBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentBlock()const
        QTextBlock cppResult = const_cast<const ::QTextFrame::iterator *>(cppSelf)->currentBlock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextFrame_iteratorFunc_currentFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentFrame()const
        QTextFrame * cppResult = const_cast<const ::QTextFrame::iterator *>(cppSelf)->currentFrame();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextFrame_iteratorFunc_parentFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parentFrame()const
        QTextFrame * cppResult = const_cast<const ::QTextFrame::iterator *>(cppSelf)->parentFrame();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextFrame_iterator__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextFrame_iterator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextFrame_iterator_methods[] = {
    {"atEnd", reinterpret_cast<PyCFunction>(Sbk_QTextFrame_iteratorFunc_atEnd), METH_NOARGS, nullptr},
    {"currentBlock", reinterpret_cast<PyCFunction>(Sbk_QTextFrame_iteratorFunc_currentBlock), METH_NOARGS, nullptr},
    {"currentFrame", reinterpret_cast<PyCFunction>(Sbk_QTextFrame_iteratorFunc_currentFrame), METH_NOARGS, nullptr},
    {"parentFrame", reinterpret_cast<PyCFunction>(Sbk_QTextFrame_iteratorFunc_parentFrame), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextFrame_iterator__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTextFrame_iteratorFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: iterator::operator++(int)->QTextFrame::iterator
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // operator++(int)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator++", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator++(int)

            for (int i = 0; i < cppArg0; ++i, ++(*cppSelf));
            QTextFrame::iterator cppResult = (*cppSelf);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextFrame_iteratorFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: iterator::operator--(int)->QTextFrame::iterator
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // operator--(int)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator--", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator--(int)

            for (int i = 0; i < cppArg0; ++i, --(*cppSelf));
            QTextFrame::iterator cppResult = (*cppSelf);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_QTextFrame_iterator_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), (pyArg)))) {
                // operator!=(const QTextFrame::iterator &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextFrame::iterator cppArg0_local;
                ::QTextFrame::iterator *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), (pyArg)))) {
                // operator==(const QTextFrame::iterator &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextFrame::iterator cppArg0_local;
                ::QTextFrame::iterator *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTextFrame_iterator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextFrame_iterator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextFrame_iterator_Type = nullptr;
static PyTypeObject *Sbk_QTextFrame_iterator_TypeF(void)
{
    return _Sbk_QTextFrame_iterator_Type;
}

static PyType_Slot Sbk_QTextFrame_iterator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextFrame_iterator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextFrame_iterator_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextFrame_iterator_richcompare)},
    {Py_tp_iter,        reinterpret_cast<void *>(Sbk_QTextFrame_iteratorFunc___iter__)},
    {Py_tp_iternext,    reinterpret_cast<void *>(Sbk_QTextFrame_iteratorFunc___next__)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextFrame_iterator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextFrame_iterator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QTextFrame_iteratorFunc___isub__)},
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QTextFrame_iteratorFunc___iadd__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextFrame_iterator_spec = {
    "2:PySide6.QtGui.QTextFrame.iterator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextFrame_iterator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void iterator_PythonToCpp_iterator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextFrame_iterator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_iterator_PythonToCpp_iterator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextFrame_iterator_TypeF()))
        return iterator_PythonToCpp_iterator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *iterator_PTR_CppToPython_iterator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextFrame_iterator_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *iterator_COPY_CppToPython_iterator(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextFrame::iterator *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextFrame_iterator_TypeF(), new ::QTextFrame::iterator(*source), true, true);
}

// Python to C++ copy conversion.
static void iterator_PythonToCpp_iterator_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextFrame::iterator *>(cppOut) = *reinterpret_cast< ::QTextFrame::iterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_iterator_PythonToCpp_iterator_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextFrame_iterator_TypeF()))
        return iterator_PythonToCpp_iterator_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextFrame_iterator_SignatureStrings[] = {
    "1:PySide6.QtGui.QTextFrame.iterator(self)",
    "0:PySide6.QtGui.QTextFrame.iterator(self,iterator:PySide6.QtGui.QTextFrame.iterator)",
    "PySide6.QtGui.QTextFrame.iterator.__iter__(self)->PyObject",
    "PySide6.QtGui.QTextFrame.iterator.__next__(self)->PyObject",
    "PySide6.QtGui.QTextFrame.iterator.atEnd(self)->bool",
    "PySide6.QtGui.QTextFrame.iterator.currentBlock(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextFrame.iterator.currentFrame(self)->PySide6.QtGui.QTextFrame",
    "PySide6.QtGui.QTextFrame.iterator.parentFrame(self)->PySide6.QtGui.QTextFrame",
    "PySide6.QtGui.QTextFrame.iterator.__copy__(self)->typing.Self",
    "PySide6.QtGui.QTextFrame.iterator.__iadd__(self,arg__1:int)->PySide6.QtGui.QTextFrame.iterator",
    "PySide6.QtGui.QTextFrame.iterator.__isub__(self,arg__1:int)->PySide6.QtGui.QTextFrame.iterator",
    "PySide6.QtGui.QTextFrame.iterator.__ne__(self,o:PySide6.QtGui.QTextFrame.iterator)->bool",
    "PySide6.QtGui.QTextFrame.iterator.__eq__(self,o:PySide6.QtGui.QTextFrame.iterator)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextFrame_iterator_SignatureByteSize = 196;
static constexpr uint8_t QTextFrame_iterator_SignatureBytes[196] = {
    0x78, 0xda, 0xb5, 0x92, 0xbd, 0x0e, 0x82, 0x30, 0x10, 0x80, 0x77, 0x9e, 0x44, 0x13, 0x6c, 0x64,
    0x71, 0x60, 0x70, 0x30, 0x51, 0x47, 0x21, 0xb8, 0x5f, 0x0a, 0x9c, 0xa4, 0x8a, 0x2d, 0x96, 0x23,
    0x91, 0xb7, 0x17, 0x51, 0x64, 0x30, 0x81, 0x0b, 0xd1, 0xad, 0xf7, 0xf3, 0x7d, 0xbd, 0xb4, 0xe7,
    0xf9, 0x41, 0x1d, 0xa9, 0x14, 0x57, 0x22, 0xa4, 0x7d, 0xa5, 0x44, 0x78, 0xc4, 0x3b, 0xed, 0xac,
    0xbc, 0xa2, 0x50, 0x84, 0x56, 0x92, 0xb1, 0xb3, 0x12, 0xf3, 0xd3, 0xdc, 0x59, 0x32, 0x3b, 0xdd,
    0x2e, 0x1a, 0xef, 0x9f, 0x3b, 0xa3, 0x2d, 0x02, 0xe0, 0x79, 0x04, 0x78, 0x4d, 0xb1, 0x58, 0x07,
    0xf5, 0x21, 0x3e, 0x63, 0x42, 0x2c, 0x54, 0x37, 0xc9, 0x49, 0xa8, 0xa4, 0xad, 0x4e, 0x3b, 0x2e,
    0x36, 0x26, 0x67, 0x30, 0x49, 0x65, 0x2d, 0x6a, 0xda, 0xe4, 0x26, 0xb9, 0xf4, 0x57, 0x7e, 0x51,
    0x6d, 0x9d, 0xaf, 0x6b, 0xb3, 0x03, 0xba, 0xb6, 0xce, 0xd0, 0x15, 0xf2, 0x97, 0x36, 0x80, 0xc4,
    0x14, 0x75, 0xff, 0xb4, 0x54, 0x17, 0x4a, 0x67, 0x22, 0x6a, 0x22, 0xde, 0x9f, 0xca, 0x34, 0x7d,
    0xd3, 0xae, 0xb4, 0x19, 0x80, 0xe7, 0x2b, 0x4d, 0x03, 0x33, 0x7d, 0x60, 0x9e, 0xbe, 0xac, 0xe2,
    0x3f, 0xea, 0x35, 0x76, 0x72, 0xc3, 0x58, 0x72, 0xf6, 0x02, 0x01, 0xe0, 0x6d, 0x82, 0xf8, 0x01,
    0x57, 0x13, 0x59, 0xf2
};
#endif

PyTypeObject *init_QTextFrame_iterator(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextFrame_iterator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextFrame_iterator_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "iterator",
        "QTextFrame::iterator",
        &Sbk_QTextFrame_iterator_spec,
        &Shiboken::callCppDestructor< ::QTextFrame::iterator >,
        Sbk_QTextFrame_iterator_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextFrame_iterator_TypeF(); // references _Sbk_QTextFrame_iterator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextFrame_iterator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextFrame_iterator_SignatureBytes, QTextFrame_iterator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextFrame_iterator_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        iterator_PythonToCpp_iterator_PTR,
        is_iterator_PythonToCpp_iterator_PTR_Convertible,
        iterator_PTR_CppToPython_iterator,
        iterator_COPY_CppToPython_iterator);

    Shiboken::Conversions::registerConverterName(converter, "QTextFrame::iterator");
    Shiboken::Conversions::registerConverterName(converter, "QTextFrame::iterator*");
    Shiboken::Conversions::registerConverterName(converter, "QTextFrame::iterator&");
    Shiboken::Conversions::registerConverterAlias(converter, "iterator");
    Shiboken::Conversions::registerConverterAlias(converter, "iterator*");
    Shiboken::Conversions::registerConverterAlias(converter, "iterator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextFrame::iterator).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        iterator_PythonToCpp_iterator_COPY,
        is_iterator_PythonToCpp_iterator_COPY_Convertible);

    qRegisterMetaType< ::QTextFrame::iterator >("iterator");
    qRegisterMetaType< ::QTextFrame::iterator >("QTextFrame::iterator");

    return pyType;
}
