// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextinlineobject_wrapper.h"

// Argument includes
#include <QtGui/qtextformat.h>
#include <qnamespace.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextInlineObject_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextInlineObject >()))
        return -1;

    ::QTextInlineObject *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextInlineObject", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextInlineObject::QTextInlineObject()
    // 1: QTextInlineObject::QTextInlineObject(QTextInlineObject)
    if (numArgs == 0) {
        overloadId = 0; // QTextInlineObject()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextInlineObject(QTextInlineObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextInlineObject()
        {

            // QTextInlineObject()
            cptr = new ::QTextInlineObject();
            break;
        }
        case 1: // QTextInlineObject(const QTextInlineObject &QTextInlineObject)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextInlineObject cppArg0_local;
            ::QTextInlineObject *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextInlineObject(QTextInlineObject)
                cptr = new ::QTextInlineObject(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextInlineObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextInlineObjectFunc_ascent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ascent()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->ascent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_descent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // descent()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->descent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QTextFormat cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_formatIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // formatIndex()const
        int cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->formatIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        QRectF cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_setAscent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextInlineObject::setAscent(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAscent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAscent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAscent(qreal)
            cppSelf->setAscent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextInlineObjectFunc_setDescent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextInlineObject::setDescent(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDescent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDescent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescent(qreal)
            cppSelf->setDescent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextInlineObjectFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextInlineObject::setWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(qreal)
            cppSelf->setWidth(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextInlineObjectFunc_textDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->textDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_textPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textPosition()const
        int cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->textPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObjectFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextInlineObject__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextInlineObject_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextInlineObject_methods[] = {
    {"ascent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_ascent), METH_NOARGS, nullptr},
    {"descent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_descent), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_format), METH_NOARGS, nullptr},
    {"formatIndex", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_formatIndex), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_height), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_isValid), METH_NOARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_rect), METH_NOARGS, nullptr},
    {"setAscent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_setAscent), METH_O, nullptr},
    {"setDescent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_setDescent), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_setWidth), METH_O, nullptr},
    {"textDirection", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_textDirection), METH_NOARGS, nullptr},
    {"textPosition", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_textPosition), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_width), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObject__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextInlineObject_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextInlineObject_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextInlineObject_Type = nullptr;
static PyTypeObject *Sbk_QTextInlineObject_TypeF(void)
{
    return _Sbk_QTextInlineObject_Type;
}

static PyType_Slot Sbk_QTextInlineObject_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextInlineObject_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextInlineObject_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextInlineObject_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextInlineObject_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextInlineObject_spec = {
    "2:PySide6.QtGui.QTextInlineObject",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextInlineObject_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextInlineObject_PythonToCpp_QTextInlineObject_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextInlineObject_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextInlineObject_PythonToCpp_QTextInlineObject_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextInlineObject_TypeF()))
        return QTextInlineObject_PythonToCpp_QTextInlineObject_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextInlineObject_PTR_CppToPython_QTextInlineObject(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextInlineObject_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextInlineObject_COPY_CppToPython_QTextInlineObject(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextInlineObject *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextInlineObject_TypeF(), new ::QTextInlineObject(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextInlineObject_PythonToCpp_QTextInlineObject_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextInlineObject *>(cppOut) = *reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextInlineObject_PythonToCpp_QTextInlineObject_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextInlineObject_TypeF()))
        return QTextInlineObject_PythonToCpp_QTextInlineObject_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextInlineObject_SignatureStrings[] = {
    "1:PySide6.QtGui.QTextInlineObject(self)",
    "0:PySide6.QtGui.QTextInlineObject(self,QTextInlineObject:PySide6.QtGui.QTextInlineObject)",
    "PySide6.QtGui.QTextInlineObject.ascent(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.descent(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.format(self)->PySide6.QtGui.QTextFormat",
    "PySide6.QtGui.QTextInlineObject.formatIndex(self)->int",
    "PySide6.QtGui.QTextInlineObject.height(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.isValid(self)->bool",
    "PySide6.QtGui.QTextInlineObject.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QTextInlineObject.setAscent(self,a:qreal)",
    "PySide6.QtGui.QTextInlineObject.setDescent(self,d:qreal)",
    "PySide6.QtGui.QTextInlineObject.setWidth(self,w:qreal)",
    "PySide6.QtGui.QTextInlineObject.textDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QTextInlineObject.textPosition(self)->int",
    "PySide6.QtGui.QTextInlineObject.width(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextInlineObject_SignatureByteSize = 229;
static constexpr uint8_t QTextInlineObject_SignatureBytes[229] = {
    0x78, 0xda, 0x9d, 0x91, 0x4b, 0x0b, 0xc2, 0x30, 0x10, 0x84, 0xef, 0xfd, 0x25, 0x16, 0x6a, 0xd0,
    0x8b, 0x07, 0x0f, 0x82, 0x58, 0x2a, 0x05, 0x41, 0xab, 0xa2, 0xc7, 0x92, 0x36, 0x6b, 0xbb, 0x52,
    0x13, 0x6d, 0x22, 0xda, 0x7f, 0x6f, 0x7d, 0xf4, 0x01, 0x2a, 0x89, 0x1e, 0xb3, 0x99, 0x6f, 0xd8,
    0xd9, 0xe9, 0x0f, 0x17, 0xc5, 0x0a, 0x19, 0x0c, 0x48, 0xa0, 0xa6, 0x67, 0x24, 0xc1, 0x1a, 0xae,
    0xca, 0xe7, 0x19, 0x72, 0x98, 0x47, 0x7b, 0x88, 0x55, 0x47, 0x42, 0xb6, 0xb3, 0xad, 0x9e, 0x91,
    0xce, 0x79, 0x1b, 0xeb, 0x30, 0xdb, 0xd2, 0x08, 0x08, 0x95, 0x31, 0xf0, 0xd7, 0x1a, 0xdd, 0xd1,
    0x29, 0x07, 0x9a, 0x69, 0x19, 0x06, 0x7f, 0x40, 0x3b, 0x91, 0x1f, 0x68, 0xcd, 0x7c, 0x50, 0x7b,
    0x0f, 0x81, 0xa1, 0x8f, 0xcf, 0x19, 0x5c, 0x2b, 0x33, 0xe4, 0x7a, 0x2c, 0x05, 0x4c, 0xd2, 0x1f,
    0x57, 0x46, 0xb9, 0xa1, 0x19, 0xb2, 0x0a, 0x8a, 0x84, 0xd0, 0x33, 0x79, 0x5d, 0x6a, 0x3b, 0xe4,
    0x44, 0xe4, 0x40, 0x82, 0x65, 0xf9, 0xe7, 0x69, 0x1d, 0x24, 0xa8, 0x71, 0x73, 0x5f, 0x87, 0x0e,
    0x1f, 0xcb, 0xda, 0x26, 0x9c, 0xdb, 0x2a, 0xc6, 0x61, 0x3f, 0x80, 0x5b, 0x64, 0x2a, 0x7d, 0x62,
    0x17, 0x53, 0x4c, 0x95, 0x03, 0x17, 0xef, 0x79, 0x51, 0xf0, 0x6f, 0x91, 0x15, 0x99, 0xd1, 0x42,
    0x9c, 0x1b, 0xa1, 0x91, 0xed, 0x42, 0x48, 0x6c, 0xbb, 0x9a, 0x14, 0x7c, 0xa9, 0x23, 0x18, 0xf7,
    0x1b, 0x86, 0xb1, 0x38, 0x16, 0x61, 0x58, 0x51, 0xaa, 0x38, 0x22, 0x4f, 0xc8, 0xaa, 0x7c, 0x59,
    0x37, 0xde, 0xc1, 0x56, 0xcc
};
#endif

PyTypeObject *init_QTextInlineObject(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextInlineObject_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextInlineObject_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextInlineObject",
        "QTextInlineObject",
        &Sbk_QTextInlineObject_spec,
        &Shiboken::callCppDestructor< ::QTextInlineObject >,
        Sbk_QTextInlineObject_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextInlineObject_TypeF(); // references _Sbk_QTextInlineObject_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextInlineObject_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextInlineObject_SignatureBytes, QTextInlineObject_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextInlineObject_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextInlineObject_PythonToCpp_QTextInlineObject_PTR,
        is_QTextInlineObject_PythonToCpp_QTextInlineObject_PTR_Convertible,
        QTextInlineObject_PTR_CppToPython_QTextInlineObject,
        QTextInlineObject_COPY_CppToPython_QTextInlineObject);

    Shiboken::Conversions::registerConverterName(converter, "QTextInlineObject");
    Shiboken::Conversions::registerConverterName(converter, "QTextInlineObject*");
    Shiboken::Conversions::registerConverterName(converter, "QTextInlineObject&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextInlineObject).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextInlineObject_PythonToCpp_QTextInlineObject_COPY,
        is_QTextInlineObject_PythonToCpp_QTextInlineObject_COPY_Convertible);

    qRegisterMetaType< ::QTextInlineObject >("QTextInlineObject");

    return pyType;
}
