// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextline_wrapper.h"

// Argument includes
#include <QList>
#include <QTextLayout>
#include <QtGui/qglyphrun.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextlayout.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextLine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextLine >()))
        return -1;

    ::QTextLine *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextLine", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextLine::QTextLine()
    // 1: QTextLine::QTextLine(QTextLine)
    if (numArgs == 0) {
        overloadId = 0; // QTextLine()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextLine(QTextLine)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextLine()
        {

            // QTextLine()
            cptr = new ::QTextLine();
            break;
        }
        case 1: // QTextLine(const QTextLine &QTextLine)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextLine cppArg0_local;
            ::QTextLine *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextLine(QTextLine)
                cptr = new ::QTextLine(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextLine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextLineFunc_ascent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ascent()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->ascent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_cursorToX(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "cursorToX", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:cursorToX", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextLine::cursorToX(int,QTextLine::Edge=)const->PyObject
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // cursorToX(int,QTextLine::Edge)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_Edge_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // cursorToX(int,QTextLine::Edge)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "cursorToX", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"edge", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_Edge_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "cursorToX", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QTextLine::Edge cppArg1(QTextLine::Edge::Leading);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // cursorToX(int,QTextLine::Edge)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qtextline-cursortox)]
            qreal cppResult = cppSelf->::QTextLine::cursorToX(&cppArg0, cppArg1);
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg0));
            // END of custom code block [file: ../glue/qtgui.cpp (qtextline-cursortox)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_descent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // descent()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->descent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_draw(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "draw", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextLine::draw(QPainter*,QPointF)const
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // draw(QPainter*,QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPointF cppArg1_local;
        ::QPointF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // draw(QPainter*,QPointF)const
            const_cast<const ::QTextLine *>(cppSelf)->draw(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextLineFunc_glyphRuns(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:glyphRuns", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextLine::glyphRuns(int=,int=)const->QList<QGlyphRun>
    // 1: QTextLine::glyphRuns(int,int,QFlags<QTextLayout::GlyphRunRetrievalFlag>)const->QList<QGlyphRun>
    if (numArgs == 0) {
        overloadId = 0; // glyphRuns(int,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // glyphRuns(int,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // glyphRuns(int,int)const
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextLayout_GlyphRunRetrievalFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // glyphRuns(int,int,QFlags<QTextLayout::GlyphRunRetrievalFlag>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // glyphRuns(int from, int length) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"from", 0}, {"length", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);
                }
            }
            int cppArg0 = -1;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // glyphRuns(int,int)const
                QList<QGlyphRun> cppResult = const_cast<const ::QTextLine *>(cppSelf)->glyphRuns(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QGlyphRun_IDX], &cppResult);
            }
            break;
        }
        case 1: // glyphRuns(int from, int length, QFlags<QTextLayout::GlyphRunRetrievalFlag> flags) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QTextLayout::GlyphRunRetrievalFlag> cppArg2 = QFlags<QTextLayout::GlyphRunRetrievalFlag>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // glyphRuns(int,int,QFlags<QTextLayout::GlyphRunRetrievalFlag>)const
                QList<QGlyphRun> cppResult = const_cast<const ::QTextLine *>(cppSelf)->glyphRuns(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QGlyphRun_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_horizontalAdvance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // horizontalAdvance()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->horizontalAdvance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextLine *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_leading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leading()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->leading();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_leadingIncluded(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leadingIncluded()const
        bool cppResult = const_cast<const ::QTextLine *>(cppSelf)->leadingIncluded();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_lineNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineNumber()const
        int cppResult = const_cast<const ::QTextLine *>(cppSelf)->lineNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_naturalTextRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // naturalTextRect()const
        QRectF cppResult = const_cast<const ::QTextLine *>(cppSelf)->naturalTextRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_naturalTextWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // naturalTextWidth()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->naturalTextWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QPointF cppResult = const_cast<const ::QTextLine *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        QRectF cppResult = const_cast<const ::QTextLine *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_setLeadingIncluded(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextLine::setLeadingIncluded(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLeadingIncluded(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLeadingIncluded", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLeadingIncluded(bool)
            cppSelf->setLeadingIncluded(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextLineFunc_setLineWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextLine::setLineWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setLineWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLineWidth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineWidth(qreal)
            cppSelf->setLineWidth(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextLineFunc_setNumColumns(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setNumColumns", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextLine::setNumColumns(int)
    // 1: QTextLine::setNumColumns(int,qreal)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setNumColumns(int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
            overloadId = 1; // setNumColumns(int,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setNumColumns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setNumColumns(int columns)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNumColumns(int)
                cppSelf->setNumColumns(cppArg0);
            }
            break;
        }
        case 1: // setNumColumns(int columns, qreal alignmentWidth)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNumColumns(int,qreal)
                cppSelf->setNumColumns(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextLineFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextLine::setPosition(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QPointF)
            cppSelf->setPosition(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTextLineFunc_textLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textLength()const
        int cppResult = const_cast<const ::QTextLine *>(cppSelf)->textLength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_textStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textStart()const
        int cppResult = const_cast<const ::QTextLine *>(cppSelf)->textStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_xToCursor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "xToCursor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:xToCursor", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextLine::xToCursor(qreal,QTextLine::CursorPosition=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // xToCursor(qreal,QTextLine::CursorPosition)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_CursorPosition_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // xToCursor(qreal,QTextLine::CursorPosition)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "xToCursor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"edge", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_CursorPosition_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "xToCursor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]);
            }
        }
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QTextLine::CursorPosition cppArg1(QTextLine::CursorPosition::CursorBetweenCharacters);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // xToCursor(qreal,QTextLine::CursorPosition)const
            int cppResult = const_cast<const ::QTextLine *>(cppSelf)->xToCursor(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLineFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        qreal cppResult = const_cast<const ::QTextLine *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTextLine__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextLine_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextLine_EnumFlagInfo[] = {
    "CursorPosition:Enum",
    "Edge:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextLine_methods[] = {
    {"ascent", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_ascent), METH_NOARGS, nullptr},
    {"cursorToX", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_cursorToX), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"descent", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_descent), METH_NOARGS, nullptr},
    {"draw", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_draw), METH_VARARGS, nullptr},
    {"glyphRuns", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_glyphRuns), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_height), METH_NOARGS, nullptr},
    {"horizontalAdvance", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_horizontalAdvance), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_isValid), METH_NOARGS, nullptr},
    {"leading", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_leading), METH_NOARGS, nullptr},
    {"leadingIncluded", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_leadingIncluded), METH_NOARGS, nullptr},
    {"lineNumber", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_lineNumber), METH_NOARGS, nullptr},
    {"naturalTextRect", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_naturalTextRect), METH_NOARGS, nullptr},
    {"naturalTextWidth", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_naturalTextWidth), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_position), METH_NOARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_rect), METH_NOARGS, nullptr},
    {"setLeadingIncluded", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_setLeadingIncluded), METH_O, nullptr},
    {"setLineWidth", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_setLineWidth), METH_O, nullptr},
    {"setNumColumns", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_setNumColumns), METH_VARARGS, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_setPosition), METH_O, nullptr},
    {"textLength", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_textLength), METH_NOARGS, nullptr},
    {"textStart", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_textStart), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_width), METH_NOARGS, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_x), METH_NOARGS, nullptr},
    {"xToCursor", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_xToCursor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QTextLineFunc_y), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextLine__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextLine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextLine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextLine_Type = nullptr;
static PyTypeObject *Sbk_QTextLine_TypeF(void)
{
    return _Sbk_QTextLine_Type;
}

static PyType_Slot Sbk_QTextLine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextLine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextLine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextLine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextLine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextLine_spec = {
    "2:PySide6.QtGui.QTextLine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextLine_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextLine_Edge(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextLine::Edge>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextLine::Edge *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextLine_Edge_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_Edge_IDX])))
        return Enum_PythonToCpp_QTextLine_Edge;
    return {};
}

static PyObject *QTextLine_Edge_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextLine::Edge>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextLine::Edge *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_Edge_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextLine_CursorPosition(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextLine::CursorPosition>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextLine::CursorPosition *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextLine_CursorPosition_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_CursorPosition_IDX])))
        return Enum_PythonToCpp_QTextLine_CursorPosition;
    return {};
}

static PyObject *QTextLine_CursorPosition_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextLine::CursorPosition>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextLine::CursorPosition *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_CursorPosition_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextLine_PythonToCpp_QTextLine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextLine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextLine_PythonToCpp_QTextLine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextLine_TypeF()))
        return QTextLine_PythonToCpp_QTextLine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextLine_PTR_CppToPython_QTextLine(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextLine_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextLine_COPY_CppToPython_QTextLine(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextLine *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextLine_TypeF(), new ::QTextLine(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextLine_PythonToCpp_QTextLine_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextLine *>(cppOut) = *reinterpret_cast< ::QTextLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextLine_PythonToCpp_QTextLine_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextLine_TypeF()))
        return QTextLine_PythonToCpp_QTextLine_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextLine_SignatureStrings[] = {
    "1:PySide6.QtGui.QTextLine(self)",
    "0:PySide6.QtGui.QTextLine(self,QTextLine:PySide6.QtGui.QTextLine)",
    "PySide6.QtGui.QTextLine.ascent(self)->qreal",
    "PySide6.QtGui.QTextLine.cursorToX(self,cursorPos:int,edge:PySide6.QtGui.QTextLine.Edge=QTextLine.Edge.Leading)->PyObject",
    "PySide6.QtGui.QTextLine.descent(self)->qreal",
    "PySide6.QtGui.QTextLine.draw(self,painter:PySide6.QtGui.QPainter,position:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "1:PySide6.QtGui.QTextLine.glyphRuns(self,from:int=-1,length:int=-1)->QList[PySide6.QtGui.QGlyphRun]",
    "0:PySide6.QtGui.QTextLine.glyphRuns(self,from:int,length:int,flags:PySide6.QtGui.QTextLayout.GlyphRunRetrievalFlag)->QList[PySide6.QtGui.QGlyphRun]",
    "PySide6.QtGui.QTextLine.height(self)->qreal",
    "PySide6.QtGui.QTextLine.horizontalAdvance(self)->qreal",
    "PySide6.QtGui.QTextLine.isValid(self)->bool",
    "PySide6.QtGui.QTextLine.leading(self)->qreal",
    "PySide6.QtGui.QTextLine.leadingIncluded(self)->bool",
    "PySide6.QtGui.QTextLine.lineNumber(self)->int",
    "PySide6.QtGui.QTextLine.naturalTextRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QTextLine.naturalTextWidth(self)->qreal",
    "PySide6.QtGui.QTextLine.position(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QTextLine.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QTextLine.setLeadingIncluded(self,included:bool)",
    "PySide6.QtGui.QTextLine.setLineWidth(self,width:qreal)",
    "1:PySide6.QtGui.QTextLine.setNumColumns(self,columns:int)",
    "0:PySide6.QtGui.QTextLine.setNumColumns(self,columns:int,alignmentWidth:qreal)",
    "PySide6.QtGui.QTextLine.setPosition(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtGui.QTextLine.textLength(self)->int",
    "PySide6.QtGui.QTextLine.textStart(self)->int",
    "PySide6.QtGui.QTextLine.width(self)->qreal",
    "PySide6.QtGui.QTextLine.x(self)->qreal",
    "PySide6.QtGui.QTextLine.xToCursor(self,x:qreal,edge:PySide6.QtGui.QTextLine.CursorPosition=QTextLine.CursorPosition.CursorBetweenCharacters)->int",
    "PySide6.QtGui.QTextLine.y(self)->qreal",
    "PySide6.QtGui.QTextLine.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextLine_SignatureByteSize = 513;
static constexpr uint8_t QTextLine_SignatureBytes[513] = {
    0x78, 0xda, 0xb5, 0x55, 0x4d, 0x8b, 0xdb, 0x30, 0x10, 0xbd, 0xe7, 0x57, 0xf4, 0xd8, 0x80, 0xd6,
    0x34, 0x97, 0x1e, 0x0c, 0x29, 0xb4, 0x66, 0xb3, 0x14, 0x42, 0xeb, 0x7c, 0xb4, 0x5b, 0x58, 0x96,
    0xa0, 0xd8, 0x13, 0x5b, 0x45, 0x91, 0x5c, 0x69, 0xbc, 0x89, 0xfb, 0xeb, 0x2b, 0x45, 0x76, 0xd7,
    0x0d, 0x91, 0xa3, 0x5d, 0xe8, 0x25, 0xf1, 0x48, 0x6f, 0xe6, 0xbd, 0x19, 0xcd, 0x48, 0x93, 0x38,
    0x6d, 0x56, 0x2c, 0x87, 0xf7, 0xd1, 0x02, 0xef, 0x6a, 0x16, 0x2d, 0xd6, 0x70, 0xc4, 0x39, 0x13,
    0xf0, 0x56, 0x03, 0xdf, 0x8d, 0x47, 0xef, 0x06, 0xf7, 0xc9, 0x5f, 0xd3, 0x07, 0x1b, 0x8f, 0x3c,
    0x1b, 0x11, 0xd5, 0x19, 0x08, 0x74, 0x34, 0x37, 0x1f, 0x7e, 0x29, 0xa0, 0xdc, 0x8b, 0xcd, 0x6a,
    0xa5, 0xa5, 0x5a, 0xcb, 0x1f, 0x8e, 0xd5, 0x99, 0xa9, 0xd4, 0x31, 0x13, 0x48, 0x20, 0x2f, 0xbc,
    0xf4, 0xd1, 0xad, 0xd9, 0x9c, 0xfe, 0x6b, 0x46, 0x73, 0xa0, 0x39, 0x13, 0x85, 0x61, 0x4d, 0x9b,
    0xaf, 0xdb, 0x9f, 0x90, 0xa1, 0x97, 0x38, 0x87, 0x17, 0xa8, 0xcc, 0x15, 0x3d, 0x38, 0x81, 0x15,
    0x35, 0xc2, 0x40, 0x9d, 0xab, 0x4a, 0xdd, 0x32, 0xa9, 0xa4, 0x66, 0xc8, 0xa4, 0x88, 0xb1, 0xa9,
    0x8c, 0x90, 0xe8, 0x9b, 0x30, 0xc6, 0xc3, 0x33, 0x38, 0x91, 0x0a, 0x0c, 0x5a, 0x1a, 0xf4, 0x8c,
    0xbc, 0xb9, 0xb8, 0xde, 0x5f, 0xee, 0xc7, 0x4e, 0x29, 0x96, 0xd1, 0x2d, 0x87, 0xbd, 0x51, 0xfd,
    0x38, 0x1e, 0x4d, 0xbc, 0x85, 0x29, 0x78, 0x53, 0x95, 0xcb, 0x5a, 0x68, 0xa7, 0x78, 0xa7, 0xe4,
    0xde, 0x56, 0x73, 0x7a, 0x33, 0x21, 0x1c, 0x44, 0x81, 0x65, 0x6b, 0x99, 0xac, 0x17, 0x73, 0xa6,
    0xf1, 0xe1, 0x2c, 0xd0, 0x5d, 0xeb, 0xff, 0xe8, 0x6f, 0x11, 0x1f, 0x47, 0x8f, 0x80, 0xec, 0x38,
    0x2d, 0xf4, 0xc5, 0x00, 0xb4, 0x91, 0x35, 0x46, 0x1d, 0xcd, 0x12, 0x50, 0x31, 0x78, 0xa2, 0x7c,
    0x66, 0x1c, 0xae, 0x6b, 0xf2, 0x29, 0x2a, 0x81, 0x15, 0x65, 0xe0, 0x71, 0x96, 0x52, 0xb1, 0xdf,
    0x52, 0x20, 0xe5, 0x1f, 0xf3, 0x27, 0x2a, 0x32, 0x08, 0x73, 0x63, 0xfa, 0x3b, 0xe5, 0x2c, 0xef,
    0xc0, 0x5b, 0x29, 0xfd, 0x58, 0xee, 0x3a, 0x31, 0x2c, 0x70, 0x0b, 0xfe, 0x2c, 0x32, 0x5e, 0xe7,
    0x10, 0x48, 0x60, 0x7e, 0xbe, 0xd4, 0xfb, 0x2d, 0xa8, 0x0e, 0x6e, 0x8a, 0xee, 0x45, 0x0b, 0x8a,
    0xb5, 0xa2, 0xdc, 0xda, 0x4b, 0x33, 0x15, 0x9d, 0xcb, 0x79, 0x03, 0xda, 0xbd, 0x59, 0x48, 0x90,
    0x7b, 0x96, 0x63, 0x19, 0x96, 0x5c, 0x37, 0x12, 0x3e, 0x4e, 0x37, 0x0c, 0x5e, 0x77, 0xf5, 0x6a,
    0xb9, 0x1a, 0x70, 0x7e, 0xa1, 0xb0, 0x84, 0xb5, 0x56, 0x6c, 0xeb, 0x3b, 0x1e, 0x74, 0x37, 0xff,
    0xcf, 0x99, 0x92, 0x83, 0xfd, 0x8c, 0x4f, 0xd9, 0x0e, 0xcd, 0x9f, 0x71, 0x34, 0x07, 0x93, 0x48,
    0x5e, 0xef, 0xbb, 0xf9, 0xc8, 0x9c, 0x61, 0xe7, 0x62, 0xe0, 0xe2, 0xbd, 0xe2, 0x49, 0x4c, 0xf3,
    0x15, 0xc2, 0x8e, 0xff, 0x7d, 0x5f, 0xc8, 0x40, 0xb0, 0xb4, 0x5f, 0x7a, 0x7b, 0x37, 0xfd, 0xff,
    0x6b, 0xc9, 0xa7, 0x06, 0xed, 0xc7, 0xe9, 0x72, 0x08, 0x69, 0x57, 0x8b, 0x5e, 0x21, 0x55, 0x18,
    0x02, 0x3e, 0x84, 0xf7, 0xe2, 0x31, 0x10, 0xb6, 0x96, 0xc9, 0xe9, 0x21, 0x72, 0x85, 0x3b, 0xba,
    0x52, 0x0f, 0x3f, 0x47, 0x49, 0xf7, 0x72, 0x9d, 0x2a, 0x3e, 0xf5, 0x6d, 0xb4, 0xe6, 0x27, 0xc0,
    0x03, 0x80, 0x48, 0x4a, 0xaa, 0x68, 0x66, 0xaa, 0xa8, 0xaf, 0xe4, 0xd8, 0x84, 0x09, 0xdf, 0x6c,
    0x32, 0x59, 0x35, 0x9b, 0x4d, 0x87, 0x6e, 0x8f, 0x7b, 0x65, 0xac, 0xd1, 0x1f, 0x1a, 0x2e, 0xe0,
    0xe2
};
#endif

PyTypeObject *init_QTextLine(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextLine_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextLine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextLine",
        "QTextLine",
        &Sbk_QTextLine_spec,
        &Shiboken::callCppDestructor< ::QTextLine >,
        Sbk_QTextLine_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextLine_TypeF(); // references _Sbk_QTextLine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextLine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextLine_SignatureBytes, QTextLine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextLine_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextLine_PythonToCpp_QTextLine_PTR,
        is_QTextLine_PythonToCpp_QTextLine_PTR_Convertible,
        QTextLine_PTR_CppToPython_QTextLine,
        QTextLine_COPY_CppToPython_QTextLine);

    Shiboken::Conversions::registerConverterName(converter, "QTextLine");
    Shiboken::Conversions::registerConverterName(converter, "QTextLine*");
    Shiboken::Conversions::registerConverterName(converter, "QTextLine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextLine).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextLine_PythonToCpp_QTextLine_COPY,
        is_QTextLine_PythonToCpp_QTextLine_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextLine_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Edge'.
    const char *Edge_Initializer[] = {
        "Leading",
        "Trailing",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Edge_InitializerValues[] = {
        uint8_t(QTextLine::Edge::Leading), //  0x00  0
        uint8_t(QTextLine::Edge::Trailing) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextLine_TypeF(),
        "2:PySide6.QtGui.QTextLine.Edge",
        Edge_Initializer, Edge_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_Edge_IDX].type = EType;
    // Register converter for enum 'QTextLine::Edge'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextLine_Edge_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextLine_Edge,
            is_Enum_PythonToCpp_QTextLine_Edge_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextLine::Edge");
        Shiboken::Conversions::registerConverterAlias(converter, "Edge");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Edge' enum.

    // Initialization of enum 'CursorPosition'.
    const char *CursorPosition_Initializer[] = {
        "CursorBetweenCharacters",
        "CursorOnCharacter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CursorPosition_InitializerValues[] = {
        uint8_t(QTextLine::CursorPosition::CursorBetweenCharacters), //  0x00  0
        uint8_t(QTextLine::CursorPosition::CursorOnCharacter)        //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextLine_TypeF(),
        "2:PySide6.QtGui.QTextLine.CursorPosition",
        CursorPosition_Initializer, CursorPosition_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextLine_CursorPosition_IDX].type = EType;
    // Register converter for enum 'QTextLine::CursorPosition'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextLine_CursorPosition_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextLine_CursorPosition,
            is_Enum_PythonToCpp_QTextLine_CursorPosition_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextLine::CursorPosition");
        Shiboken::Conversions::registerConverterAlias(converter, "CursorPosition");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CursorPosition' enum.

    qRegisterMetaType< ::QTextLine >("QTextLine");
    qRegisterMetaType< ::QTextLine::Edge >("QTextLine::Edge");
    qRegisterMetaType< ::QTextLine::CursorPosition >("QTextLine::CursorPosition");

    return pyType;
}
