// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTOUCHEVENTWRAPPER_H
#define SBK_QTOUCHEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QTouchEventWrapper : public QTouchEvent
{
public:
    QTouchEventWrapper(::QEvent::Type eventType, const ::QPointingDevice * device = nullptr, ::QFlags<Qt::KeyboardModifier> modifiers = Qt::NoModifier, const ::QList<QEventPoint> & touchPoints = {});
    QTouchEventWrapper(const QTouchEventWrapper &) = delete;
    QTouchEventWrapper(const QTouchEvent& self) : QTouchEvent(self)
    {
    }
    QTouchEventWrapper& operator=(const QTouchEventWrapper &) = delete;
    QTouchEventWrapper(QTouchEventWrapper &&) = delete;
    QTouchEventWrapper& operator=(QTouchEventWrapper &&) = delete;
    ~QTouchEventWrapper() override;

    ::QTouchEvent * clone() const override;
    static ::QTouchEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QTOUCHEVENTWRAPPER_H
