// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QWHEELEVENTWRAPPER_H
#define SBK_QWHEELEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QWheelEventWrapper : public QWheelEvent
{
public:
    QWheelEventWrapper(const ::QPointF & pos, const ::QPointF & globalPos, ::QPoint pixelDelta, ::QPoint angleDelta, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::ScrollPhase phase, bool inverted, ::Qt::MouseEventSource source = Qt::MouseEventNotSynthesized, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QWheelEventWrapper(const QWheelEventWrapper &) = delete;
    QWheelEventWrapper(const QWheelEvent& self) : QWheelEvent(self)
    {
    }
    QWheelEventWrapper& operator=(const QWheelEventWrapper &) = delete;
    QWheelEventWrapper(QWheelEventWrapper &&) = delete;
    QWheelEventWrapper& operator=(QWheelEventWrapper &&) = delete;
    ~QWheelEventWrapper() override;

    ::QWheelEvent * clone() const override;
    static ::QWheelEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QWHEELEVENTWRAPPER_H
