// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthelp_python.h"

// main header
#include "qhelpfiltersettingswidget_wrapper.h"

// Wrappers providing overrides
#include "qhelpcontentwidget_wrapper.h"

// Argument includes
#include <QList>
#include <QStringList>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtHelp/qhelpfilterengine.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>
#include <qversionnumber.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QHelpFilterSettingsWidgetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QHelpFilterSettingsWidgetWrapper::QHelpFilterSettingsWidgetWrapper(::QWidget * parent) : QHelpFilterSettingsWidget(parent)
{
}

void QHelpFilterSettingsWidgetWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_actionEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_changeEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_childEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_closeEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QHelpContentWidgetWrapper::sbk_o_connectNotify("QHelpFilterSettingsWidget", funcName, gil, pyOverride, signal);
}

void QHelpFilterSettingsWidgetWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_contextMenuEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_customEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

int QHelpFilterSettingsWidgetWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QHelpContentWidgetWrapper::sbk_o_devType("QHelpFilterSettingsWidget", funcName, gil, pyOverride);
}

void QHelpFilterSettingsWidgetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QHelpContentWidgetWrapper::sbk_o_connectNotify("QHelpFilterSettingsWidget", funcName, gil, pyOverride, signal);
}

void QHelpFilterSettingsWidgetWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dragEnterEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dragLeaveEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dragMoveEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dropEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_enterEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

bool QHelpFilterSettingsWidgetWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::event(event);
    }
    return QHelpContentWidgetWrapper::sbk_o_event("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

bool QHelpFilterSettingsWidgetWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QHelpContentWidgetWrapper::sbk_o_eventFilter("QHelpFilterSettingsWidget", funcName, gil, pyOverride, watched, event);
}

void QHelpFilterSettingsWidgetWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_focusInEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

bool QHelpFilterSettingsWidgetWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QHelpContentWidgetWrapper::sbk_o_focusNextPrevChild("QHelpFilterSettingsWidget", funcName, gil, pyOverride, next);
}

void QHelpFilterSettingsWidgetWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_focusOutEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

bool QHelpFilterSettingsWidgetWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QHelpContentWidgetWrapper::sbk_o_hasHeightForWidth("QHelpFilterSettingsWidget", funcName, gil, pyOverride);
}

int QHelpFilterSettingsWidgetWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_heightForWidth("QHelpFilterSettingsWidget", funcName, gil, pyOverride, arg__1);
}

void QHelpFilterSettingsWidgetWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_hideEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QHelpContentWidgetWrapper::sbk_o_initPainter("QHelpFilterSettingsWidget", funcName, gil, pyOverride, painter);
}

void QHelpFilterSettingsWidgetWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_inputMethodEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

::QVariant QHelpFilterSettingsWidgetWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_inputMethodQuery("QHelpFilterSettingsWidget", funcName, gil, pyOverride, arg__1);
}

void QHelpFilterSettingsWidgetWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_keyPressEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_keyReleaseEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_leaveEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

int QHelpFilterSettingsWidgetWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_metric("QHelpFilterSettingsWidget", funcName, gil, pyOverride, arg__1);
}

::QSize QHelpFilterSettingsWidgetWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QHelpContentWidgetWrapper::sbk_o_minimumSizeHint("QHelpFilterSettingsWidget", funcName, gil, pyOverride);
}

void QHelpFilterSettingsWidgetWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseDoubleClickEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseMoveEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mousePressEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseReleaseEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_moveEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

bool QHelpFilterSettingsWidgetWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QHelpContentWidgetWrapper::sbk_o_nativeEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QHelpFilterSettingsWidgetWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QHelpContentWidgetWrapper::sbk_o_paintEngine("QHelpFilterSettingsWidget", funcName, gil, pyOverride);
}

void QHelpFilterSettingsWidgetWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_paintEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

::QPaintDevice * QHelpFilterSettingsWidgetWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QHelpContentWidgetWrapper::sbk_o_redirected("QHelpFilterSettingsWidget", funcName, gil, pyOverride, offset);
}

void QHelpFilterSettingsWidgetWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_resizeEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QHelpContentWidgetWrapper::sbk_o_setVisible("QHelpFilterSettingsWidget", funcName, gil, pyOverride, visible);
}

::QPainter * QHelpFilterSettingsWidgetWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QHelpContentWidgetWrapper::sbk_o_sharedPainter("QHelpFilterSettingsWidget", funcName, gil, pyOverride);
}

void QHelpFilterSettingsWidgetWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_showEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

::QSize QHelpFilterSettingsWidgetWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QHelpContentWidgetWrapper::sbk_o_minimumSizeHint("QHelpFilterSettingsWidget", funcName, gil, pyOverride);
}

void QHelpFilterSettingsWidgetWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_tabletEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_timerEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

void QHelpFilterSettingsWidgetWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_wheelEvent("QHelpFilterSettingsWidget", funcName, gil, pyOverride, event);
}

const QMetaObject *QHelpFilterSettingsWidgetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QHelpFilterSettingsWidget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QHelpFilterSettingsWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QHelpFilterSettingsWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QHelpFilterSettingsWidgetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QHelpFilterSettingsWidgetWrapper *>(this));
    return QHelpFilterSettingsWidget::qt_metacast(_clname);
}

QHelpFilterSettingsWidgetWrapper::~QHelpFilterSettingsWidgetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHelpFilterSettingsWidget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHelpFilterSettingsWidget >()))
        return -1;

    QHelpFilterSettingsWidgetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QHelpFilterSettingsWidget", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHelpFilterSettingsWidget::QHelpFilterSettingsWidget(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QHelpFilterSettingsWidget(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QHelpFilterSettingsWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QHelpFilterSettingsWidget(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QHelpFilterSettingsWidgetWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QHelpFilterSettingsWidgetWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QHelpFilterSettingsWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QHelpFilterSettingsWidgetFunc_applySettings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterSettingsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpFilterSettingsWidget::applySettings(QHelpFilterEngine*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterEngine_IDX]), (pyArg)))) {
        overloadId = 0; // applySettings(QHelpFilterEngine*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "applySettings", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHelpFilterEngine *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // applySettings(QHelpFilterEngine*)const
            bool cppResult = const_cast<const ::QHelpFilterSettingsWidget *>(cppSelf)->applySettings(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QHelpFilterSettingsWidgetFunc_readSettings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterSettingsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpFilterSettingsWidget::readSettings(const QHelpFilterEngine*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterEngine_IDX]), (pyArg)))) {
        overloadId = 0; // readSettings(const QHelpFilterEngine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readSettings", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHelpFilterEngine *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readSettings(const QHelpFilterEngine*)
            cppSelf->readSettings(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpFilterSettingsWidgetFunc_setAvailableComponents(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterSettingsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpFilterSettingsWidget::setAvailableComponents(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setAvailableComponents(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAvailableComponents", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAvailableComponents(QStringList)
            cppSelf->setAvailableComponents(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpFilterSettingsWidgetFunc_setAvailableVersions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterSettingsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpFilterSettingsWidget::setAvailableVersions(QList<QVersionNumber>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtHelpTypeConverters[SBK_QtHelp_QList_QVersionNumber_IDX], (pyArg)))) {
        overloadId = 0; // setAvailableVersions(QList<QVersionNumber>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAvailableVersions", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]);

    // Call function/method
    {
        ::QList<QVersionNumber> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAvailableVersions(QList<QVersionNumber>)
            cppSelf->setAvailableVersions(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QHelpFilterSettingsWidget_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHelpFilterSettingsWidget_methods[] = {
    {"applySettings", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterSettingsWidgetFunc_applySettings), METH_O, nullptr},
    {"readSettings", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterSettingsWidgetFunc_readSettings), METH_O, nullptr},
    {"setAvailableComponents", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterSettingsWidgetFunc_setAvailableComponents), METH_O, nullptr},
    {"setAvailableVersions", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterSettingsWidgetFunc_setAvailableVersions), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHelpFilterSettingsWidget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QHelpFilterSettingsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QHelpFilterSettingsWidgetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QHelpFilterSettingsWidget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHelpFilterSettingsWidget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QHelpFilterSettingsWidgetSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QHelpFilterSettingsWidget *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHelpFilterSettingsWidget_Type = nullptr;
static PyTypeObject *Sbk_QHelpFilterSettingsWidget_TypeF(void)
{
    return _Sbk_QHelpFilterSettingsWidget_Type;
}

static PyType_Slot Sbk_QHelpFilterSettingsWidget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QHelpFilterSettingsWidget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHelpFilterSettingsWidget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHelpFilterSettingsWidget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHelpFilterSettingsWidget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHelpFilterSettingsWidget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHelpFilterSettingsWidget_spec = {
    "2:PySide6.QtHelp.QHelpFilterSettingsWidget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHelpFilterSettingsWidget_slots
};

} //extern "C"

static void *Sbk_QHelpFilterSettingsWidget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QHelpFilterSettingsWidget *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QHelpFilterSettingsWidget *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QHelpFilterSettingsWidget *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHelpFilterSettingsWidget_PythonToCpp_QHelpFilterSettingsWidget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHelpFilterSettingsWidget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHelpFilterSettingsWidget_PythonToCpp_QHelpFilterSettingsWidget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHelpFilterSettingsWidget_TypeF()))
        return QHelpFilterSettingsWidget_PythonToCpp_QHelpFilterSettingsWidget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHelpFilterSettingsWidget_PTR_CppToPython_QHelpFilterSettingsWidget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QHelpFilterSettingsWidget *>(const_cast<void *>(cppIn)), Sbk_QHelpFilterSettingsWidget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHelpFilterSettingsWidget_SignatureStrings[] = {
    "PySide6.QtHelp.QHelpFilterSettingsWidget(self,parent:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtHelp.QHelpFilterSettingsWidget.applySettings(self,filterEngine:PySide6.QtHelp.QHelpFilterEngine)->bool",
    "PySide6.QtHelp.QHelpFilterSettingsWidget.readSettings(self,filterEngine:PySide6.QtHelp.QHelpFilterEngine)",
    "PySide6.QtHelp.QHelpFilterSettingsWidget.setAvailableComponents(self,components:QStringList)",
    "PySide6.QtHelp.QHelpFilterSettingsWidget.setAvailableVersions(self,versions:QList[PySide6.QtCore.QVersionNumber])",
    nullptr}; // Sentinel
#else
static constexpr size_t QHelpFilterSettingsWidget_SignatureByteSize = 189;
static constexpr uint8_t QHelpFilterSettingsWidget_SignatureBytes[189] = {
    0x78, 0xda, 0xa5, 0x90, 0xc1, 0x0a, 0xc2, 0x30, 0x0c, 0x86, 0xef, 0x7b, 0x12, 0x07, 0xda, 0xa3,
    0x87, 0x82, 0x82, 0x0c, 0xc5, 0x83, 0xc8, 0xca, 0x40, 0x0f, 0xe2, 0xa1, 0x73, 0xd9, 0x28, 0x64,
    0x6d, 0x69, 0xb3, 0xc1, 0xde, 0xde, 0xcd, 0xd5, 0x79, 0x12, 0x86, 0x5e, 0x42, 0x93, 0xfe, 0xf9,
    0x3e, 0x48, 0xda, 0x65, 0xaa, 0x80, 0x35, 0x13, 0x74, 0x04, 0xb4, 0x4c, 0x0c, 0xf5, 0xa0, 0x90,
    0xc0, 0x65, 0x40, 0xa4, 0x74, 0xe5, 0xaf, 0xaa, 0xa8, 0x80, 0x16, 0x1e, 0xb0, 0x5c, 0x5a, 0xe9,
    0x40, 0x13, 0x4f, 0xa7, 0xa5, 0xf1, 0xd3, 0x33, 0x31, 0x3e, 0x36, 0xba, 0x41, 0xb4, 0xe4, 0xe2,
    0x28, 0x9d, 0xc9, 0x65, 0xd2, 0x5a, 0xec, 0xde, 0xb3, 0xd1, 0x52, 0xbe, 0x72, 0x7b, 0x5d, 0x29,
    0x0d, 0xfc, 0x3b, 0x68, 0x0c, 0xc4, 0xab, 0x6d, 0x6e, 0x0c, 0xce, 0x17, 0x3a, 0x90, 0xc5, 0x3f,
    0xbe, 0xf9, 0x26, 0x0f, 0xb4, 0x6b, 0xa5, 0x42, 0x99, 0x23, 0x24, 0xa6, 0xb6, 0x46, 0xf7, 0xc7,
    0x0b, 0xce, 0xc7, 0xd4, 0x73, 0x91, 0x91, 0xeb, 0xb7, 0x4e, 0xca, 0xd3, 0x8f, 0xf0, 0x0b, 0x38,
    0xaf, 0x8c, 0x0e, 0xe8, 0x36, 0x74, 0x5c, 0x0c, 0xc8, 0xdb, 0x87, 0x98, 0x18, 0x07, 0x4c, 0x84,
    0xf0, 0xb9, 0xa9, 0x73, 0x70, 0xf7, 0x38, 0x7a, 0x02, 0x9d, 0xf7, 0xbf, 0xf2
};
#endif

PyTypeObject *init_QHelpFilterSettingsWidget(PyObject *module)
{
    if (SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX].type != nullptr)
        return SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX].type;

    Shiboken::AutoDecRef Sbk_QHelpFilterSettingsWidget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QHelpFilterSettingsWidget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHelpFilterSettingsWidget",
        "QHelpFilterSettingsWidget*",
        &Sbk_QHelpFilterSettingsWidget_spec,
        &Shiboken::callCppDestructor< QHelpFilterSettingsWidget >,
        Sbk_QHelpFilterSettingsWidget_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QHelpFilterSettingsWidget_TypeF(); // references _Sbk_QHelpFilterSettingsWidget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHelpFilterSettingsWidget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHelpFilterSettingsWidget_SignatureBytes, QHelpFilterSettingsWidget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHelpFilterSettingsWidget_PropertyStrings);
    SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterSettingsWidget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHelpFilterSettingsWidget_PythonToCpp_QHelpFilterSettingsWidget_PTR,
        is_QHelpFilterSettingsWidget_PythonToCpp_QHelpFilterSettingsWidget_PTR_Convertible,
        QHelpFilterSettingsWidget_PTR_CppToPython_QHelpFilterSettingsWidget);

    Shiboken::Conversions::registerConverterName(converter, "QHelpFilterSettingsWidget");
    Shiboken::Conversions::registerConverterName(converter, "QHelpFilterSettingsWidget*");
    Shiboken::Conversions::registerConverterName(converter, "QHelpFilterSettingsWidget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHelpFilterSettingsWidget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QHelpFilterSettingsWidgetWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QHelpFilterSettingsWidget_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QHelpFilterSettingsWidget_TypeF(), &Sbk_QHelpFilterSettingsWidgetSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QHelpFilterSettingsWidget_TypeF(), &Sbk_QHelpFilterSettingsWidget_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QHelpFilterSettingsWidget::staticMetaObject, sizeof(QHelpFilterSettingsWidgetWrapper));

    return pyType;
}
