// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGEOSERVICEPROVIDERFACTORYWRAPPER_H
#define SBK_QGEOSERVICEPROVIDERFACTORYWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtLocation/qgeoserviceproviderfactory.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QGeoServiceProviderFactoryWrapper : public QGeoServiceProviderFactory
{
public:
    QGeoServiceProviderFactoryWrapper();
    QGeoServiceProviderFactoryWrapper(const QGeoServiceProviderFactoryWrapper &) = delete;
    QGeoServiceProviderFactoryWrapper& operator=(const QGeoServiceProviderFactoryWrapper &) = delete;
    QGeoServiceProviderFactoryWrapper(QGeoServiceProviderFactoryWrapper &&) = delete;
    QGeoServiceProviderFactoryWrapper& operator=(QGeoServiceProviderFactoryWrapper &&) = delete;
    ~QGeoServiceProviderFactoryWrapper() override;

    ::QGeoCodingManagerEngine * createGeocodingManagerEngine(const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString) const override;
    static ::QGeoCodingManagerEngine * sbk_o_createGeocodingManagerEngine(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString);
    ::QPlaceManagerEngine * createPlaceManagerEngine(const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString) const override;
    static ::QPlaceManagerEngine * sbk_o_createPlaceManagerEngine(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString);
    ::QGeoRoutingManagerEngine * createRoutingManagerEngine(const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString) const override;
    static ::QGeoRoutingManagerEngine * sbk_o_createRoutingManagerEngine(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[3] = {false, false, false};
};

#endif // SBK_QGEOSERVICEPROVIDERFACTORYWRAPPER_H
