// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPLACEMANAGERENGINEWRAPPER_H
#define SBK_QPLACEMANAGERENGINEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtLocation/qplacemanagerengine.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QPlaceManagerEngineWrapper : public QPlaceManagerEngine
{
public:
    QPlaceManagerEngineWrapper(const ::QMap<QString,QVariant> & parameters, ::QObject * parent = nullptr);
    QPlaceManagerEngineWrapper(const QPlaceManagerEngineWrapper &) = delete;
    QPlaceManagerEngineWrapper& operator=(const QPlaceManagerEngineWrapper &) = delete;
    QPlaceManagerEngineWrapper(QPlaceManagerEngineWrapper &&) = delete;
    QPlaceManagerEngineWrapper& operator=(QPlaceManagerEngineWrapper &&) = delete;
    ~QPlaceManagerEngineWrapper() override;

    ::QPlaceCategory category(const ::QString & categoryId) const override;
    static ::QPlaceCategory sbk_o_category(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & categoryId);
    ::QList<QPlaceCategory> childCategories(const ::QString & parentId) const override;
    static ::QList<QPlaceCategory> sbk_o_childCategories(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & parentId);
    ::QStringList childCategoryIds(const ::QString & categoryId) const override;
    static ::QStringList sbk_o_childCategoryIds(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & categoryId);
    void childEvent(::QChildEvent * event) override;
    ::QPlace compatiblePlace(const ::QPlace & original) const override;
    static ::QPlace sbk_o_compatiblePlace(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlace & original);
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QUrl constructIconUrl(const ::QPlaceIcon & icon, const ::QSize & size) const override;
    static ::QUrl sbk_o_constructIconUrl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlaceIcon & icon, const ::QSize & size);
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QPlaceContentReply * getPlaceContent(const ::QPlaceContentRequest & request) override;
    static ::QPlaceContentReply * sbk_o_getPlaceContent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlaceContentRequest & request);
    ::QPlaceDetailsReply * getPlaceDetails(const ::QString & placeId) override;
    static ::QPlaceDetailsReply * sbk_o_getPlaceDetails(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & placeId);
    ::QPlaceReply * initializeCategories() override;
    static ::QPlaceReply * sbk_o_initializeCategories(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QList<QLocale> locales() const override;
    static ::QList<QLocale> sbk_o_locales(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPlaceMatchReply * matchingPlaces(const ::QPlaceMatchRequest & request) override;
    static ::QPlaceMatchReply * sbk_o_matchingPlaces(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlaceMatchRequest & request);
    ::QString parentCategoryId(const ::QString & categoryId) const override;
    static ::QString sbk_o_parentCategoryId(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & categoryId);
    ::QPlaceIdReply * removeCategory(const ::QString & categoryId) override;
    static ::QPlaceIdReply * sbk_o_removeCategory(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & categoryId);
    ::QPlaceIdReply * removePlace(const ::QString & placeId) override;
    ::QPlaceIdReply * saveCategory(const ::QPlaceCategory & category, const ::QString & parentId) override;
    static ::QPlaceIdReply * sbk_o_saveCategory(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlaceCategory & category, const ::QString & parentId);
    ::QPlaceIdReply * savePlace(const ::QPlace & place) override;
    static ::QPlaceIdReply * sbk_o_savePlace(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlace & place);
    ::QPlaceSearchReply * search(const ::QPlaceSearchRequest & request) override;
    static ::QPlaceSearchReply * sbk_o_search(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlaceSearchRequest & request);
    ::QPlaceSearchSuggestionReply * searchSuggestions(const ::QPlaceSearchRequest & request) override;
    static ::QPlaceSearchSuggestionReply * sbk_o_searchSuggestions(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPlaceSearchRequest & request);
    void setLocales(const ::QList<QLocale> & locales) override;
    static void sbk_o_setLocales(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QList<QLocale> & locales);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[25] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QPLACEMANAGERENGINEWRAPPER_H
