// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QNETWORKREPLYWRAPPER_H
#define SBK_QNETWORKREPLYWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetwork/qnetworkreply.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QNetworkReplyWrapper : public QNetworkReply
{
public:
    QNetworkReplyWrapper(::QObject * parent = nullptr);
    QNetworkReplyWrapper(const QNetworkReplyWrapper &) = delete;
    QNetworkReplyWrapper& operator=(const QNetworkReplyWrapper &) = delete;
    QNetworkReplyWrapper(QNetworkReplyWrapper &&) = delete;
    QNetworkReplyWrapper& operator=(QNetworkReplyWrapper &&) = delete;
    ~QNetworkReplyWrapper() override;

    void abort() override;
    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(::QChildEvent * event) override;
    void close() override;
    static void sbk_o_close(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void ignoreSslErrors() override;
    // Inherited overloads, because the using keyword sux
    void ignoreSslErrors(const ::QList<QSslError> & errors) { QNetworkReply::ignoreSslErrors(errors); }

    void ignoreSslErrorsImplementation(const ::QList<QSslError> & arg__1) override;
    static void sbk_o_ignoreSslErrorsImplementation(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QList<QSslError> & arg__1);
    bool isSequential() const override;
    bool open(::QFlags<QIODeviceBase::OpenModeFlag> mode) override;
    static bool sbk_o_open(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QIODeviceBase::OpenModeFlag> mode);
    qint64 pos() const override;
    qint64 readData(char * data, qint64 maxlen) override;
    static qint64 sbk_o_readData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxlen);
    qint64 readLineData(char * data, qint64 maxlen) override;
    static qint64 sbk_o_readLineData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxlen);
    bool reset() override;
    bool seek(qint64 pos) override;
    static bool sbk_o_seek(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 pos);
    void setReadBufferSize(qint64 size) override;
    static void sbk_o_setReadBufferSize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 size);
    void setSslConfigurationImplementation(const ::QSslConfiguration & arg__1) override;
    static void sbk_o_setSslConfigurationImplementation(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSslConfiguration & arg__1);
    qint64 size() const override;
    qint64 skipData(qint64 maxSize) override;
    static qint64 sbk_o_skipData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 maxSize);
    void sslConfigurationImplementation(::QSslConfiguration & arg__1) const override;
    static void sbk_o_sslConfigurationImplementation(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSslConfiguration & arg__1);
    void timerEvent(::QTimerEvent * event) override;
    bool waitForBytesWritten(int msecs) override;
    static bool sbk_o_waitForBytesWritten(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs);
    bool waitForReadyRead(int msecs) override;
    static bool sbk_o_waitForReadyRead(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs);
    qint64 writeData(const char * data, qint64 len) override;
    static qint64 sbk_o_writeData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * data, qint64 len);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[30] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QNETWORKREPLYWRAPPER_H
