// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qtcpsocket_wrapper.h"

// Wrappers providing overrides
#include "qnetworkreply_wrapper.h"
#include "qrestaccessmanager_wrapper.h"
#include "qabstractnetworkcache_wrapper.h"
#include "qabstractsocket_wrapper.h"
#include "qudpsocket_wrapper.h"
#include "qlocalserver_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QTcpSocketWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTcpSocketWrapper::QTcpSocketWrapper(::QObject * parent) : QTcpSocket(parent)
{
}

bool QTcpSocketWrapper::atEnd() const
{
    static const char *funcName = "atEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::atEnd();
    }
    return QLocalServerWrapper::sbk_o_hasPendingConnections("QTcpSocket", funcName, gil, pyOverride);
}

qint64 QTcpSocketWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::bytesAvailable();
    }
    return QAbstractNetworkCacheWrapper::sbk_o_cacheSize("QTcpSocket", funcName, gil, pyOverride);
}

qint64 QTcpSocketWrapper::bytesToWrite() const
{
    static const char *funcName = "bytesToWrite";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::bytesToWrite();
    }
    return QAbstractNetworkCacheWrapper::sbk_o_cacheSize("QTcpSocket", funcName, gil, pyOverride);
}

bool QTcpSocketWrapper::canReadLine() const
{
    static const char *funcName = "canReadLine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::canReadLine();
    }
    return QLocalServerWrapper::sbk_o_hasPendingConnections("QTcpSocket", funcName, gil, pyOverride);
}

void QTcpSocketWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QRestAccessManagerWrapper::sbk_o_childEvent("QTcpSocket", funcName, gil, pyOverride, event);
}

void QTcpSocketWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::close();
    }
    QNetworkReplyWrapper::sbk_o_close("QTcpSocket", funcName, gil, pyOverride);
}

void QTcpSocketWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QRestAccessManagerWrapper::sbk_o_connectNotify("QTcpSocket", funcName, gil, pyOverride, signal);
}

void QTcpSocketWrapper::connectToHost(const ::QString & hostName, quint16 port, ::QFlags<QIODeviceBase::OpenModeFlag> mode, ::QAbstractSocket::NetworkLayerProtocol protocol)
{
    static const char *funcName = "connectToHost";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::connectToHost(hostName, port, mode, protocol);
    }
    QUdpSocketWrapper::sbk_o_connectToHost("QTcpSocket", funcName, gil, pyOverride, hostName, port, mode, protocol);
}

void QTcpSocketWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QRestAccessManagerWrapper::sbk_o_customEvent("QTcpSocket", funcName, gil, pyOverride, event);
}

void QTcpSocketWrapper::disconnectFromHost()
{
    static const char *funcName = "disconnectFromHost";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::disconnectFromHost();
    }
    QUdpSocketWrapper::sbk_o_disconnectFromHost("QTcpSocket", funcName, gil, pyOverride);
}

void QTcpSocketWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QRestAccessManagerWrapper::sbk_o_connectNotify("QTcpSocket", funcName, gil, pyOverride, signal);
}

bool QTcpSocketWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QRestAccessManagerWrapper::sbk_o_event("QTcpSocket", funcName, gil, pyOverride, event);
}

bool QTcpSocketWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QRestAccessManagerWrapper::sbk_o_eventFilter("QTcpSocket", funcName, gil, pyOverride, watched, event);
}

bool QTcpSocketWrapper::isSequential() const
{
    static const char *funcName = "isSequential";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::isSequential();
    }
    return QLocalServerWrapper::sbk_o_hasPendingConnections("QTcpSocket", funcName, gil, pyOverride);
}

bool QTcpSocketWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::open(mode);
    }
    return QNetworkReplyWrapper::sbk_o_open("QTcpSocket", funcName, gil, pyOverride, mode);
}

qint64 QTcpSocketWrapper::pos() const
{
    static const char *funcName = "pos";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::pos();
    }
    return QAbstractNetworkCacheWrapper::sbk_o_cacheSize("QTcpSocket", funcName, gil, pyOverride);
}

qint64 QTcpSocketWrapper::readData(char * data, qint64 maxlen)
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::readData(data, maxlen);
    }
    return QNetworkReplyWrapper::sbk_o_readData("QTcpSocket", funcName, gil, pyOverride, data, maxlen);
}

qint64 QTcpSocketWrapper::readLineData(char * data, qint64 maxlen)
{
    static const char *funcName = "readLineData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::readLineData(data, maxlen);
    }
    return QNetworkReplyWrapper::sbk_o_readLineData("QTcpSocket", funcName, gil, pyOverride, data, maxlen);
}

bool QTcpSocketWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::reset();
    }
    return QLocalServerWrapper::sbk_o_hasPendingConnections("QTcpSocket", funcName, gil, pyOverride);
}

void QTcpSocketWrapper::resume()
{
    static const char *funcName = "resume";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::resume();
    }
    QAbstractNetworkCacheWrapper::sbk_o_clear("QTcpSocket", funcName, gil, pyOverride);
}

bool QTcpSocketWrapper::seek(qint64 pos)
{
    static const char *funcName = "seek";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::seek(pos);
    }
    return QNetworkReplyWrapper::sbk_o_seek("QTcpSocket", funcName, gil, pyOverride, pos);
}

void QTcpSocketWrapper::setReadBufferSize(qint64 size)
{
    static const char *funcName = "setReadBufferSize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::setReadBufferSize(size);
    }
    QNetworkReplyWrapper::sbk_o_setReadBufferSize("QTcpSocket", funcName, gil, pyOverride, size);
}

bool QTcpSocketWrapper::setSocketDescriptor(::qintptr socketDescriptor, ::QAbstractSocket::SocketState state, ::QFlags<QIODeviceBase::OpenModeFlag> openMode)
{
    static const char *funcName = "setSocketDescriptor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::setSocketDescriptor(socketDescriptor, state, openMode);
    }
    return QAbstractSocketWrapper::sbk_o_setSocketDescriptor("QTcpSocket", funcName, gil, pyOverride, socketDescriptor, state, openMode);
}

void QTcpSocketWrapper::setSocketOption(::QAbstractSocket::SocketOption option, const ::QVariant & value)
{
    static const char *funcName = "setSocketOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::setSocketOption(option, value);
    }
    QAbstractSocketWrapper::sbk_o_setSocketOption("QTcpSocket", funcName, gil, pyOverride, option, value);
}

qint64 QTcpSocketWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::size();
    }
    return QAbstractNetworkCacheWrapper::sbk_o_cacheSize("QTcpSocket", funcName, gil, pyOverride);
}

qint64 QTcpSocketWrapper::skipData(qint64 maxSize)
{
    static const char *funcName = "skipData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::skipData(maxSize);
    }
    return QNetworkReplyWrapper::sbk_o_skipData("QTcpSocket", funcName, gil, pyOverride, maxSize);
}

::qintptr QTcpSocketWrapper::socketDescriptor() const
{
    static const char *funcName = "socketDescriptor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::socketDescriptor();
    }
    return QAbstractSocketWrapper::sbk_o_socketDescriptor("QTcpSocket", funcName, gil, pyOverride);
}

::QVariant QTcpSocketWrapper::socketOption(::QAbstractSocket::SocketOption option)
{
    static const char *funcName = "socketOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::socketOption(option);
    }
    return QAbstractSocketWrapper::sbk_o_socketOption("QTcpSocket", funcName, gil, pyOverride, option);
}

void QTcpSocketWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QRestAccessManagerWrapper::sbk_o_timerEvent("QTcpSocket", funcName, gil, pyOverride, event);
}

bool QTcpSocketWrapper::waitForBytesWritten(int msecs)
{
    static const char *funcName = "waitForBytesWritten";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::waitForBytesWritten(msecs);
    }
    return QNetworkReplyWrapper::sbk_o_waitForBytesWritten("QTcpSocket", funcName, gil, pyOverride, msecs);
}

bool QTcpSocketWrapper::waitForConnected(int msecs)
{
    static const char *funcName = "waitForConnected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::waitForConnected(msecs);
    }
    return QUdpSocketWrapper::sbk_o_waitForConnected("QTcpSocket", funcName, gil, pyOverride, msecs);
}

bool QTcpSocketWrapper::waitForDisconnected(int msecs)
{
    static const char *funcName = "waitForDisconnected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::waitForDisconnected(msecs);
    }
    return QUdpSocketWrapper::sbk_o_waitForDisconnected("QTcpSocket", funcName, gil, pyOverride, msecs);
}

bool QTcpSocketWrapper::waitForReadyRead(int msecs)
{
    static const char *funcName = "waitForReadyRead";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::waitForReadyRead(msecs);
    }
    return QNetworkReplyWrapper::sbk_o_waitForReadyRead("QTcpSocket", funcName, gil, pyOverride, msecs);
}

qint64 QTcpSocketWrapper::writeData(const char * data, qint64 len)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSocket::writeData(data, len);
    }
    return QNetworkReplyWrapper::sbk_o_writeData("QTcpSocket", funcName, gil, pyOverride, data, len);
}

const QMetaObject *QTcpSocketWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QTcpSocket::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTcpSocketWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QTcpSocket::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTcpSocketWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTcpSocketWrapper *>(this));
    return QTcpSocket::qt_metacast(_clname);
}

QTcpSocketWrapper::~QTcpSocketWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTcpSocket_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTcpSocket >()))
        return -1;

    QTcpSocketWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QTcpSocket", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTcpSocket::QTcpSocket(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QTcpSocket(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTcpSocket(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QTcpSocket(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QTcpSocketWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QTcpSocketWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QTcpSocket >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QTcpSocketFunc_bind(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTcpSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:bind", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTcpSocket::bind(QHostAddress::SpecialAddress,quint16=,QFlags<QAbstractSocket::BindFlag>=)->bool
    // 1: QAbstractSocket::bind(QHostAddress,quint16=,QFlags<QAbstractSocket::BindFlag>=)->bool
    // 2: QAbstractSocket::bind(quint16=,QFlags<QAbstractSocket::BindFlag>=)->bool
    if (numArgs == 0) {
        overloadId = 2; // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // bind(QHostAddress::SpecialAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // bind(QHostAddress::SpecialAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // bind(QHostAddress::SpecialAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 2; // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // bind(QHostAddress::SpecialAddress addr, quint16 port, QFlags<QAbstractSocket::BindFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"port", 1}, {"mode", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);
                }
            }
            ::QHostAddress::SpecialAddress cppArg0{QHostAddress::Null};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            quint16 cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QAbstractSocket::BindFlag> cppArg2(QAbstractSocket::BindFlag::DefaultForPlatform);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(QHostAddress::SpecialAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
                bool cppResult = cppSelf->bind(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // bind(const QHostAddress &address, quint16 port, QFlags<QAbstractSocket::BindFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"port", 1}, {"mode", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            quint16 cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QAbstractSocket::BindFlag> cppArg2(QAbstractSocket::BindFlag::DefaultForPlatform);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
                bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? reinterpret_cast<QAbstractSocket *>(cppSelf)->::QAbstractSocket::bind(*cppArg0, cppArg1, cppArg2)
                    : reinterpret_cast<QAbstractSocket *>(cppSelf)->bind(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // bind(quint16 port, QFlags<QAbstractSocket::BindFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"port", 0}, {"mode", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0]))))
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]);
                }
            }
            quint16 cppArg0 = 0;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QAbstractSocket::BindFlag> cppArg1(QAbstractSocket::BindFlag::DefaultForPlatform);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
                bool cppResult = reinterpret_cast<QAbstractSocket *>(cppSelf)->bind(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QTcpSocket_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTcpSocket_methods[] = {
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QTcpSocketFunc_bind), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QTcpSocket_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QTcpSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTcpSocketWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QTcpSocket_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTcpSocket_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QTcpSocketSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QTcpSocket *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]))
        return static_cast< ::QAbstractSocket *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTcpSocket_Type = nullptr;
static PyTypeObject *Sbk_QTcpSocket_TypeF(void)
{
    return _Sbk_QTcpSocket_Type;
}

static PyType_Slot Sbk_QTcpSocket_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QTcpSocket_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTcpSocket_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTcpSocket_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTcpSocket_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTcpSocket_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTcpSocket_spec = {
    "2:PySide6.QtNetwork.QTcpSocket",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTcpSocket_slots
};

} //extern "C"

static void *Sbk_QTcpSocket_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QTcpSocket *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTcpSocket_PythonToCpp_QTcpSocket_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTcpSocket_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTcpSocket_PythonToCpp_QTcpSocket_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTcpSocket_TypeF()))
        return QTcpSocket_PythonToCpp_QTcpSocket_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTcpSocket_PTR_CppToPython_QTcpSocket(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QTcpSocket *>(const_cast<void *>(cppIn)), Sbk_QTcpSocket_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTcpSocket_SignatureStrings[] = {
    "PySide6.QtNetwork.QTcpSocket(self,parent:PySide6.QtCore.QObject=nullptr)",
    "2:PySide6.QtNetwork.QTcpSocket.bind(self,addr:PySide6.QtNetwork.QHostAddress.SpecialAddress,port:quint16=0,mode:PySide6.QtNetwork.QAbstractSocket.BindFlag=QAbstractSocket.BindFlag.DefaultForPlatform)->bool",
    "1:PySide6.QtNetwork.QTcpSocket.bind(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16=0,mode:PySide6.QtNetwork.QAbstractSocket.BindFlag=QAbstractSocket.BindFlag.DefaultForPlatform)->bool",
    "0:PySide6.QtNetwork.QTcpSocket.bind(self,port:quint16=0,mode:PySide6.QtNetwork.QAbstractSocket.BindFlag=QAbstractSocket.BindFlag.DefaultForPlatform)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTcpSocket_SignatureByteSize = 210;
static constexpr uint8_t QTcpSocket_SignatureBytes[210] = {
    0x78, 0xda, 0xc5, 0x8f, 0x4b, 0x8b, 0xc2, 0x40, 0x10, 0x84, 0xef, 0xfe, 0x0a, 0x8f, 0x0a, 0xd9,
    0x41, 0xf7, 0x90, 0x43, 0x20, 0x82, 0x0f, 0xc4, 0xd3, 0x6e, 0x42, 0xdc, 0x93, 0x78, 0x98, 0xcc,
    0x74, 0x64, 0x74, 0x32, 0x3d, 0xdb, 0xd3, 0x41, 0xfc, 0xf7, 0x06, 0x56, 0x16, 0xc1, 0x07, 0x7a,
    0xd1, 0x63, 0x51, 0x45, 0x55, 0x7d, 0xd9, 0xa1, 0x30, 0x1a, 0x62, 0x91, 0xf3, 0x17, 0xf0, 0x1e,
    0x69, 0x27, 0xf2, 0xa5, 0xf2, 0x05, 0xaa, 0x1d, 0x70, 0x2f, 0x80, 0xad, 0x22, 0x2f, 0x09, 0x1c,
    0x27, 0xd9, 0x7f, 0x70, 0x8a, 0x04, 0x22, 0xff, 0x2e, 0xb7, 0xa0, 0x38, 0x75, 0x8d, 0xb5, 0x9e,
    0xa9, 0xdf, 0xf9, 0x3c, 0x4b, 0x5c, 0x56, 0x89, 0xd2, 0x38, 0xfd, 0xd7, 0x27, 0xb5, 0xa6, 0x6b,
    0xd9, 0x05, 0x06, 0x1e, 0xb7, 0x1e, 0x84, 0x20, 0x0a, 0x0f, 0xca, 0x48, 0x7b, 0x92, 0x91, 0x47,
    0xe2, 0xe4, 0xb7, 0x31, 0x8e, 0x87, 0x71, 0x3a, 0x88, 0x6a, 0xd4, 0x70, 0xad, 0x61, 0x5c, 0x06,
    0x26, 0xa9, 0xf8, 0x34, 0x39, 0x69, 0x27, 0xe7, 0x56, 0x6e, 0xd2, 0x5b, 0x86, 0x98, 0x41, 0x25,
    0x1b, 0xcb, 0x73, 0xa4, 0xcc, 0x4a, 0xae, 0x90, 0xea, 0xfe, 0xc7, 0xa8, 0x44, 0xb4, 0x9d, 0xe1,
    0x33, 0x34, 0xed, 0xc5, 0x84, 0x0f, 0xde, 0xb8, 0x8d, 0xf8, 0x71, 0x06, 0xdd, 0xea, 0x3e, 0x5d,
    0xd4, 0x7d, 0x8a, 0x7e, 0xfd, 0x06, 0xfc, 0xc1, 0xa3, 0xf8, 0xaf, 0xbf, 0x76, 0x04, 0x5d, 0x54,
    0xfb, 0xcd
};
#endif

PyTypeObject *init_QTcpSocket(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX].type;

    Shiboken::AutoDecRef Sbk_QTcpSocket_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]))));

    _Sbk_QTcpSocket_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTcpSocket",
        "QTcpSocket*",
        &Sbk_QTcpSocket_spec,
        &Shiboken::callCppDestructor< QTcpSocket >,
        Sbk_QTcpSocket_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTcpSocket_TypeF(); // references _Sbk_QTcpSocket_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTcpSocket_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTcpSocket_SignatureBytes, QTcpSocket_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTcpSocket_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTcpSocket_PythonToCpp_QTcpSocket_PTR,
        is_QTcpSocket_PythonToCpp_QTcpSocket_PTR_Convertible,
        QTcpSocket_PTR_CppToPython_QTcpSocket);

    Shiboken::Conversions::registerConverterName(converter, "QTcpSocket");
    Shiboken::Conversions::registerConverterName(converter, "QTcpSocket*");
    Shiboken::Conversions::registerConverterName(converter, "QTcpSocket&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTcpSocket).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTcpSocketWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QTcpSocket_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QTcpSocket_TypeF(), &Sbk_QTcpSocketSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QTcpSocket_TypeF(), &Sbk_QTcpSocket_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QTcpSocket::staticMetaObject, sizeof(QTcpSocketWrapper));

    return pyType;
}
