// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qabstractoauth2_wrapper.h"

// Wrappers providing overrides
#include "qoauth1_wrapper.h"
#include "qabstractoauth_wrapper.h"
#include "qabstractoauthreplyhandler_wrapper.h"

// Argument includes
#include <QMap>
#include <QMultiMap>
#include <QSet>
#include <QString>
#include <QtNetwork/qhttpmultipart.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetworkAuth/qabstractoauth2.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractOAuth2Wrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractOAuth2Wrapper::QAbstractOAuth2Wrapper(::QNetworkAccessManager * manager, ::QObject * parent) : QAbstractOAuth2(manager, parent)
{
}

QAbstractOAuth2Wrapper::QAbstractOAuth2Wrapper(::QObject * parent) : QAbstractOAuth2(parent)
{
}

void QAbstractOAuth2Wrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_childEvent("QAbstractOAuth2", funcName, gil, pyOverride, event);
}

void QAbstractOAuth2Wrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QAbstractOAuth2", funcName, gil, pyOverride, signal);
}

::QUrl QAbstractOAuth2Wrapper::createAuthenticatedUrl(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "createAuthenticatedUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::createAuthenticatedUrl(url, parameters);
    }
    return sbk_o_createAuthenticatedUrl("QAbstractOAuth2", funcName, gil, pyOverride, url, parameters);
}

::QUrl QAbstractOAuth2Wrapper::sbk_o_createAuthenticatedUrl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QUrl >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QUrl cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractOAuth2Wrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_customEvent("QAbstractOAuth2", funcName, gil, pyOverride, event);
}

::QNetworkReply * QAbstractOAuth2Wrapper::deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "deleteResource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::deleteResource(url, parameters);
    }
    return QOAuth1Wrapper::sbk_o_deleteResource("QAbstractOAuth2", funcName, gil, pyOverride, url, parameters);
}

void QAbstractOAuth2Wrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QAbstractOAuth2", funcName, gil, pyOverride, signal);
}

bool QAbstractOAuth2Wrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_event("QAbstractOAuth2", funcName, gil, pyOverride, event);
}

bool QAbstractOAuth2Wrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_eventFilter("QAbstractOAuth2", funcName, gil, pyOverride, watched, event);
}

::QNetworkReply * QAbstractOAuth2Wrapper::get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "get";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::get(url, parameters);
    }
    return QOAuth1Wrapper::sbk_o_get("QAbstractOAuth2", funcName, gil, pyOverride, url, parameters);
}

void QAbstractOAuth2Wrapper::grant()
{
    static const char *funcName = "grant";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth2.grant");
        return;
    }
    QAbstractOAuthWrapper::sbk_o_grant("QAbstractOAuth2", funcName, gil, pyOverride);
}

::QNetworkReply * QAbstractOAuth2Wrapper::head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "head";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::head(url, parameters);
    }
    return QOAuth1Wrapper::sbk_o_head("QAbstractOAuth2", funcName, gil, pyOverride, url, parameters);
}

::QNetworkReply * QAbstractOAuth2Wrapper::post(const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, multiPart);
    }
    return sbk_o_post("QAbstractOAuth2", funcName, gil, pyOverride, url, multiPart);
}

::QNetworkReply * QAbstractOAuth2Wrapper::sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QAbstractOAuth2Wrapper::post(const ::QUrl & url, const ::QByteArray & data)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, data);
    }
    return sbk_o_post("QAbstractOAuth2", funcName, gil, pyOverride, url, data);
}

::QNetworkReply * QAbstractOAuth2Wrapper::sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QAbstractOAuth2Wrapper::post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, parameters);
    }
    return QOAuth1Wrapper::sbk_o_post("QAbstractOAuth2", funcName, gil, pyOverride, url, parameters);
}

void QAbstractOAuth2Wrapper::prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body)
{
    static const char *funcName = "prepareRequest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::prepareRequest(request, verb, body);
    }
    QAbstractOAuthWrapper::sbk_o_prepareRequest("QAbstractOAuth2", funcName, gil, pyOverride, request, verb, body);
}

::QNetworkReply * QAbstractOAuth2Wrapper::put(const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, multiPart);
    }
    return sbk_o_put("QAbstractOAuth2", funcName, gil, pyOverride, url, multiPart);
}

::QNetworkReply * QAbstractOAuth2Wrapper::sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QAbstractOAuth2Wrapper::put(const ::QUrl & url, const ::QByteArray & data)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, data);
    }
    return sbk_o_put("QAbstractOAuth2", funcName, gil, pyOverride, url, data);
}

::QNetworkReply * QAbstractOAuth2Wrapper::sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QAbstractOAuth2Wrapper::put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, parameters);
    }
    return QOAuth1Wrapper::sbk_o_put("QAbstractOAuth2", funcName, gil, pyOverride, url, parameters);
}

void QAbstractOAuth2Wrapper::resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters)
{
    static const char *funcName = "resourceOwnerAuthorization";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth::resourceOwnerAuthorization(url, parameters);
    }
    QAbstractOAuthWrapper::sbk_o_resourceOwnerAuthorization("QAbstractOAuth2", funcName, gil, pyOverride, url, parameters);
}

void QAbstractOAuth2Wrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_timerEvent("QAbstractOAuth2", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstractOAuth2Wrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractOAuth2::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractOAuth2Wrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractOAuth2::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractOAuth2Wrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractOAuth2Wrapper *>(this));
    return QAbstractOAuth2::qt_metacast(_clname);
}

QAbstractOAuth2Wrapper::~QAbstractOAuth2Wrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractOAuth2_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAbstractOAuth2");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractOAuth2 >()))
        return -1;

    QAbstractOAuth2Wrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QAbstractOAuth2", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractOAuth2::QAbstractOAuth2(QNetworkAccessManager*,QObject*=)
    // 1: QAbstractOAuth2::QAbstractOAuth2(QObject*=)
    if (numArgs == 0) {
        overloadId = 1; // QAbstractOAuth2(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QAbstractOAuth2(QNetworkAccessManager*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QAbstractOAuth2(QNetworkAccessManager*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QAbstractOAuth2(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAbstractOAuth2(QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkAccessManager *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAbstractOAuth2(QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAbstractOAuth2Wrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAbstractOAuth2Wrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QAbstractOAuth2(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAbstractOAuth2(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAbstractOAuth2Wrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAbstractOAuth2Wrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractOAuth2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAbstractOAuth2Func_autoRefresh(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoRefresh()const
        bool cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->autoRefresh();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_clearNetworkRequestModifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearNetworkRequestModifier()
        cppSelf->clearNetworkRequestModifier();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_clientIdentifierSharedKey(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientIdentifierSharedKey()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->clientIdentifierSharedKey();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_createAuthenticatedUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createAuthenticatedUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    if (PyArg_ParseTuple(args, "|OO:createAuthenticatedUrl", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth2::createAuthenticatedUrl(QUrl,const QMap<QString,QVariant>&=)->QUrl
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createAuthenticatedUrl(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // createAuthenticatedUrl(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createAuthenticatedUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "createAuthenticatedUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createAuthenticatedUrl(QUrl,QMap<QString,QVariant>)
            QUrl cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractOAuth2::createAuthenticatedUrl(*cppArg0, cppArg1)
                : cppSelf->createAuthenticatedUrl(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_deleteResource(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    if (PyArg_ParseTuple(args, "|OO:deleteResource", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::deleteResource(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // deleteResource(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // deleteResource(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "deleteResource(const QUrl &url, const QMap<QString,QVariant> &parameters)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deleteResource(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractOAuth2::deleteResource(*cppArg0, cppArg1)
                : cppSelf->deleteResource(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_expirationAt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expirationAt()const
        QDateTime cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->expirationAt();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_get(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    if (PyArg_ParseTuple(args, "|OO:get", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::get(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // get(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // get(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "get(const QUrl &url, const QMap<QString,QVariant> &parameters)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // get(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractOAuth2::get(*cppArg0, cppArg1)
                : cppSelf->get(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_grantedScopeTokens(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grantedScopeTokens()const
        QSet<QByteArray> cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->grantedScopeTokens();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_head(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    if (PyArg_ParseTuple(args, "|OO:head", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::head(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // head(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // head(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "head(const QUrl &url, const QMap<QString,QVariant> &parameters)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // head(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractOAuth2::head(*cppArg0, cppArg1)
                : cppSelf->head(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_idToken(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // idToken()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->idToken();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_nonce(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nonce()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->nonce();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_nonceMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nonceMode()const
        QAbstractOAuth2::NonceMode cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->nonceMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_NonceMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_post(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    if (PyArg_ParseTuple(args, "|OO:post", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::post(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    // 1: QAbstractOAuth2::post(QUrl,QByteArray)->QNetworkReply*
    // 2: QAbstractOAuth2::post(QUrl,QHttpMultiPart*)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // post(QUrl,QMap<QString,QVariant>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), (pyArgs[1])))) {
            overloadId = 2; // post(QUrl,QHttpMultiPart*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 1; // post(QUrl,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // post(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // post(const QUrl &url, const QMap<QString,QVariant> &parameters)
        {
            Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "post(const QUrl &url, const QMap<QString,QVariant> &parameters)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QMap<QString,QVariant> cppArg1 = QVariantMap();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QUrl,QMap<QString,QVariant>)
                QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractOAuth2::post(*cppArg0, cppArg1)
                    : cppSelf->post(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
        case 1: // post(const QUrl &url, const QByteArray &data)
        {
            Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "post(const QUrl &url, const QByteArray &data)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QUrl,QByteArray)
                QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractOAuth2::post(*cppArg0, *cppArg1)
                    : cppSelf->post(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
        case 2: // post(const QUrl &url, QHttpMultiPart *multiPart)
        {
            Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "post(const QUrl &url, QHttpMultiPart *multiPart)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpMultiPart *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QUrl,QHttpMultiPart*)
                QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractOAuth2::post(*cppArg0, cppArg1)
                    : cppSelf->post(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_prepareRequest(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:prepareRequest", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::prepareRequest(QNetworkRequest*,QByteArray,const QByteArray&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
            overloadId = 0; // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"body", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QNetworkRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QByteArray cppArg2_local = QByteArray();
        ::QByteArray *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractOAuth2::prepareRequest(cppArg0, *cppArg1, *cppArg2)
                : cppSelf->prepareRequest(cppArg0, *cppArg1, *cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_put(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    if (PyArg_ParseTuple(args, "|OO:put", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::put(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    // 1: QAbstractOAuth2::put(QUrl,QByteArray)->QNetworkReply*
    // 2: QAbstractOAuth2::put(QUrl,QHttpMultiPart*)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // put(QUrl,QMap<QString,QVariant>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), (pyArgs[1])))) {
            overloadId = 2; // put(QUrl,QHttpMultiPart*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 1; // put(QUrl,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // put(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // put(const QUrl &url, const QMap<QString,QVariant> &parameters)
        {
            Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "put(const QUrl &url, const QMap<QString,QVariant> &parameters)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QMap<QString,QVariant> cppArg1 = QVariantMap();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QUrl,QMap<QString,QVariant>)
                QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractOAuth2::put(*cppArg0, cppArg1)
                    : cppSelf->put(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
        case 1: // put(const QUrl &url, const QByteArray &data)
        {
            Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "put(const QUrl &url, const QByteArray &data)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QUrl,QByteArray)
                QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractOAuth2::put(*cppArg0, *cppArg1)
                    : cppSelf->put(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
        case 2: // put(const QUrl &url, QHttpMultiPart *multiPart)
        {
            Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "put(const QUrl &url, QHttpMultiPart *multiPart)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpMultiPart *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QUrl,QHttpMultiPart*)
                QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractOAuth2::put(*cppArg0, cppArg1)
                    : cppSelf->put(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_refreshLeadTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refreshLeadTime()const
        std::chrono::seconds cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->refreshLeadTime();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_std_chrono_seconds_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_refreshToken(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refreshToken()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->refreshToken();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_refreshTokens(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refreshTokens()
        cppSelf->refreshTokens();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_refreshTokensImplementation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refreshTokensImplementation()
        cppSelf->refreshTokensImplementation();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_requestedScopeTokens(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestedScopeTokens()const
        QSet<QByteArray> cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->requestedScopeTokens();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_responseType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // responseType()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->responseType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_scope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "scope() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // scope()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->scope();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_setAutoRefresh(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setAutoRefresh(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoRefresh(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoRefresh", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoRefresh(bool)
            cppSelf->setAutoRefresh(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setClientIdentifierSharedKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setClientIdentifierSharedKey(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setClientIdentifierSharedKey(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setClientIdentifierSharedKey", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClientIdentifierSharedKey(QString)
            cppSelf->setClientIdentifierSharedKey(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setNonce(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setNonce(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setNonce(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNonce", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNonce(QString)
            cppSelf->setNonce(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setNonceMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setNonceMode(QAbstractOAuth2::NonceMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_NonceMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setNonceMode(QAbstractOAuth2::NonceMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNonceMode", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QAbstractOAuth2::NonceMode cppArg0{QAbstractOAuth2::NonceMode::Automatic};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNonceMode(QAbstractOAuth2::NonceMode)
            cppSelf->setNonceMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setRefreshLeadTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setRefreshLeadTime(std::chrono::seconds)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_std_chrono_seconds_IDX], (pyArg)))) {
        overloadId = 0; // setRefreshLeadTime(std::chrono::seconds)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRefreshLeadTime", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        std::chrono::seconds cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRefreshLeadTime(std::chrono::seconds)
            cppSelf->setRefreshLeadTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setRefreshToken(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setRefreshToken(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRefreshToken(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRefreshToken", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRefreshToken(QString)
            cppSelf->setRefreshToken(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setRequestedScopeTokens(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setRequestedScopeTokens(QSet<QByteArray>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QSet_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // setRequestedScopeTokens(QSet<QByteArray>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRequestedScopeTokens", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QSet<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRequestedScopeTokens(QSet<QByteArray>)
            cppSelf->setRequestedScopeTokens(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setResponseType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setResponseType(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setResponseType(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResponseType", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setResponseType(QString)
            cppSelf->setResponseType(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setScope(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setScope(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScope", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QAbstractOAuth2", "setScope(const QString &scope)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScope(QString)
            cppSelf->setScope(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setSslConfiguration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setSslConfiguration(QSslConfiguration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArg)))) {
        overloadId = 0; // setSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSslConfiguration", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslConfiguration cppArg0_local;
        ::QSslConfiguration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSslConfiguration(QSslConfiguration)
            cppSelf->setSslConfiguration(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setState(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setState(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setState", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setState(QString)
            cppSelf->setState(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setTokenUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setTokenUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setTokenUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTokenUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTokenUrl(QUrl)
            cppSelf->setTokenUrl(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_setUserAgent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth2::setUserAgent(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setUserAgent(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserAgent", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserAgent(QString)
            cppSelf->setUserAgent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractOAuth2Func_sslConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sslConfiguration()const
        QSslConfiguration cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->sslConfiguration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_tokenUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tokenUrl()const
        QUrl cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->tokenUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractOAuth2Func_userAgent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userAgent()const
        QString cppResult = const_cast<const ::QAbstractOAuth2 *>(cppSelf)->userAgent();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QAbstractOAuth2_PropertyStrings[] = {
    "autoRefresh::",
    "clientIdentifierSharedKey::",
    "expiration:expirationAt",
    "grantedScopeTokens:",
    "idToken:",
    "nonce::",
    "nonceMode::",
    "refreshLeadTime::",
    "refreshToken::",
    "requestedScopeTokens::",
    "scope::",
    "state::",
    "tokenUrl::",
    "userAgent::",
    nullptr // Sentinel
};

static const char *Sbk_QAbstractOAuth2_EnumFlagInfo[] = {
    "NonceMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractOAuth2_methods[] = {
    {"autoRefresh", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_autoRefresh), METH_NOARGS, nullptr},
    {"clearNetworkRequestModifier", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_clearNetworkRequestModifier), METH_NOARGS, nullptr},
    {"clientIdentifierSharedKey", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_clientIdentifierSharedKey), METH_NOARGS, nullptr},
    {"createAuthenticatedUrl", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_createAuthenticatedUrl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"deleteResource", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_deleteResource), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"expirationAt", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_expirationAt), METH_NOARGS, nullptr},
    {"get", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_get), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"grantedScopeTokens", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_grantedScopeTokens), METH_NOARGS, nullptr},
    {"head", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_head), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"idToken", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_idToken), METH_NOARGS, nullptr},
    {"nonce", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_nonce), METH_NOARGS, nullptr},
    {"nonceMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_nonceMode), METH_NOARGS, nullptr},
    {"post", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_post), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"prepareRequest", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_prepareRequest), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"put", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_put), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"refreshLeadTime", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_refreshLeadTime), METH_NOARGS, nullptr},
    {"refreshToken", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_refreshToken), METH_NOARGS, nullptr},
    {"refreshTokens", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_refreshTokens), METH_NOARGS, nullptr},
    {"refreshTokensImplementation", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_refreshTokensImplementation), METH_NOARGS, nullptr},
    {"requestedScopeTokens", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_requestedScopeTokens), METH_NOARGS, nullptr},
    {"responseType", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_responseType), METH_NOARGS, nullptr},
    {"scope", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_scope), METH_NOARGS, nullptr},
    {"setAutoRefresh", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setAutoRefresh), METH_O, nullptr},
    {"setClientIdentifierSharedKey", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setClientIdentifierSharedKey), METH_O, nullptr},
    {"setNonce", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setNonce), METH_O, nullptr},
    {"setNonceMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setNonceMode), METH_O, nullptr},
    {"setRefreshLeadTime", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setRefreshLeadTime), METH_O, nullptr},
    {"setRefreshToken", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setRefreshToken), METH_O, nullptr},
    {"setRequestedScopeTokens", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setRequestedScopeTokens), METH_O, nullptr},
    {"setResponseType", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setResponseType), METH_O, nullptr},
    {"setScope", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setScope), METH_O, nullptr},
    {"setSslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setSslConfiguration), METH_O, nullptr},
    {"setState", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setState), METH_O, nullptr},
    {"setTokenUrl", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setTokenUrl), METH_O, nullptr},
    {"setUserAgent", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_setUserAgent), METH_O, nullptr},
    {"sslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_sslConfiguration), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_state), METH_NOARGS, nullptr},
    {"tokenUrl", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_tokenUrl), METH_NOARGS, nullptr},
    {"userAgent", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuth2Func_userAgent), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractOAuth2_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractOAuth2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractOAuth2Wrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractOAuth2_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractOAuth2_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractOAuth2_Type = nullptr;
static PyTypeObject *Sbk_QAbstractOAuth2_TypeF(void)
{
    return _Sbk_QAbstractOAuth2_Type;
}

static PyType_Slot Sbk_QAbstractOAuth2_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractOAuth2_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractOAuth2_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractOAuth2_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractOAuth2_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractOAuth2_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractOAuth2_spec = {
    "2:PySide6.QtNetworkAuth.QAbstractOAuth2",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractOAuth2_slots
};

} //extern "C"

static void *Sbk_QAbstractOAuth2_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractOAuth2 *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractOAuth2_NonceMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractOAuth2::NonceMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractOAuth2::NonceMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractOAuth2_NonceMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_NonceMode_IDX])))
        return Enum_PythonToCpp_QAbstractOAuth2_NonceMode;
    return {};
}

static PyObject *QAbstractOAuth2_NonceMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractOAuth2::NonceMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractOAuth2::NonceMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_NonceMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractOAuth2_PythonToCpp_QAbstractOAuth2_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractOAuth2_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractOAuth2_PythonToCpp_QAbstractOAuth2_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractOAuth2_TypeF()))
        return QAbstractOAuth2_PythonToCpp_QAbstractOAuth2_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractOAuth2_PTR_CppToPython_QAbstractOAuth2(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractOAuth2 *>(const_cast<void *>(cppIn)), Sbk_QAbstractOAuth2_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractOAuth2_SignatureStrings[] = {
    "1:PySide6.QtNetworkAuth.QAbstractOAuth2(self,manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,scope:QString=None,grantedScopeTokens:QSet[PySide6.QtCore.QByteArray]=None,requestedScopeTokens:QSet[PySide6.QtCore.QByteArray]=None,userAgent:QString=None,clientIdentifierSharedKey:QString=None,state:QString=None,expiration:QDateTime=None,refreshToken:QString=None,refreshLeadTime:std.chrono.seconds=None,autoRefresh:bool=None,nonceMode:QAbstractOAuth2.NonceMode=None,nonce:QString=None,idToken:QString=None,tokenUrl:QUrl=None)",
    "0:PySide6.QtNetworkAuth.QAbstractOAuth2(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,scope:QString=None,grantedScopeTokens:QSet[PySide6.QtCore.QByteArray]=None,requestedScopeTokens:QSet[PySide6.QtCore.QByteArray]=None,userAgent:QString=None,clientIdentifierSharedKey:QString=None,state:QString=None,expiration:QDateTime=None,refreshToken:QString=None,refreshLeadTime:std.chrono.seconds=None,autoRefresh:bool=None,nonceMode:QAbstractOAuth2.NonceMode=None,nonce:QString=None,idToken:QString=None,tokenUrl:QUrl=None)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.autoRefresh(self)->bool",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.clearNetworkRequestModifier(self)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.clientIdentifierSharedKey(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.createAuthenticatedUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.deleteResource(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.expirationAt(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.get(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.grantedScopeTokens(self)->QSet[PySide6.QtCore.QByteArray]",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.head(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.idToken(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.nonce(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.nonceMode(self)->PySide6.QtNetworkAuth.QAbstractOAuth2.NonceMode",
    "2:PySide6.QtNetworkAuth.QAbstractOAuth2.post(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetworkAuth.QAbstractOAuth2.post(self,url:typing.Union[PySide6.QtCore.QUrl, QString],data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetworkAuth.QAbstractOAuth2.post(self,url:typing.Union[PySide6.QtCore.QUrl, QString],multiPart:PySide6.QtNetwork.QHttpMultiPart)->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.prepareRequest(self,request:PySide6.QtNetwork.QNetworkRequest,verb:typing.Union[PySide6.QtCore.QByteArray, char*],body:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "2:PySide6.QtNetworkAuth.QAbstractOAuth2.put(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetworkAuth.QAbstractOAuth2.put(self,url:typing.Union[PySide6.QtCore.QUrl, QString],data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetworkAuth.QAbstractOAuth2.put(self,url:typing.Union[PySide6.QtCore.QUrl, QString],multiPart:PySide6.QtNetwork.QHttpMultiPart)->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.refreshLeadTime(self)->std.chrono.seconds",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.refreshToken(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.refreshTokens(self)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.refreshTokensImplementation(self)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.requestedScopeTokens(self)->QSet[PySide6.QtCore.QByteArray]",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.responseType(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.scope(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setAutoRefresh(self,enable:bool)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setClientIdentifierSharedKey(self,clientIdentifierSharedKey:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setNonce(self,nonce:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setNonceMode(self,mode:PySide6.QtNetworkAuth.QAbstractOAuth2.NonceMode)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setRefreshLeadTime(self,leadTime:std.chrono.seconds)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setRefreshToken(self,refreshToken:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setRequestedScopeTokens(self,tokens:QSet[PySide6.QtCore.QByteArray])",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setResponseType(self,responseType:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setScope(self,scope:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setSslConfiguration(self,configuration:PySide6.QtNetwork.QSslConfiguration)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setState(self,state:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setTokenUrl(self,tokenUrl:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.setUserAgent(self,userAgent:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.sslConfiguration(self)->PySide6.QtNetwork.QSslConfiguration",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.state(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.tokenUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QAbstractOAuth2.userAgent(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractOAuth2_SignatureByteSize = 813;
static constexpr uint8_t QAbstractOAuth2_SignatureBytes[813] = {
    0x78, 0xda, 0xed, 0x58, 0x3b, 0x6f, 0xdb, 0x30, 0x10, 0xde, 0xf3, 0x2b, 0x32, 0xc6, 0x81, 0x2a,
    0x24, 0x19, 0x3a, 0x08, 0x70, 0x01, 0x37, 0x1d, 0x1a, 0xb4, 0x76, 0x22, 0x3f, 0xb2, 0x04, 0x1e,
    0x68, 0xf2, 0x6c, 0xab, 0xa1, 0x48, 0x95, 0x3c, 0xb5, 0xd5, 0xbf, 0x2f, 0xf5, 0xb2, 0x25, 0x59,
    0x71, 0x44, 0x27, 0x29, 0x6a, 0xb4, 0x8b, 0x21, 0x93, 0xf7, 0xf8, 0x78, 0xfc, 0x78, 0xbc, 0xe3,
    0xa5, 0x77, 0x97, 0x4c, 0x02, 0x06, 0xef, 0x5d, 0x1f, 0x47, 0x80, 0x3f, 0xa5, 0x7a, 0x1c, 0xc4,
    0xb8, 0x76, 0xfd, 0xc1, 0x42, 0xa3, 0x22, 0x14, 0x6f, 0xd3, 0xbf, 0x57, 0x67, 0x1a, 0xf8, 0xd2,
    0x09, 0x89, 0x20, 0x2b, 0x50, 0xbb, 0x2a, 0xae, 0x5f, 0xea, 0x52, 0x0a, 0x5a, 0x0f, 0x73, 0x39,
    0x27, 0x22, 0x0a, 0x04, 0x56, 0xc4, 0xaf, 0xa5, 0x02, 0xd7, 0xbf, 0x5d, 0x7c, 0x03, 0x8a, 0x7d,
    0x11, 0x73, 0x1e, 0xa1, 0x72, 0xce, 0xbd, 0x2f, 0x90, 0x18, 0x65, 0x76, 0x2b, 0x78, 0xd2, 0x1f,
    0x49, 0x01, 0x8e, 0xa6, 0x32, 0x02, 0xcf, 0x9f, 0xa0, 0x0a, 0xc4, 0x2a, 0x1f, 0x5a, 0x29, 0x22,
    0x10, 0xd8, 0x24, 0x9d, 0x99, 0xca, 0x47, 0x10, 0xda, 0xcc, 0x03, 0x3e, 0x34, 0x8d, 0x7f, 0x4c,
    0x10, 0x06, 0x4a, 0x91, 0x64, 0x9e, 0xeb, 0x29, 0xf8, 0x1e, 0x83, 0x3e, 0x44, 0x33, 0xd6, 0xa0,
    0x06, 0xab, 0x74, 0x01, 0x35, 0x20, 0x94, 0x07, 0x66, 0xec, 0x86, 0x99, 0x9f, 0x60, 0x19, 0x80,
    0x9a, 0xac, 0xcd, 0x2a, 0x99, 0x59, 0x42, 0x5d, 0x4c, 0x23, 0xc1, 0xc6, 0x12, 0xe0, 0x57, 0x14,
    0x28, 0x82, 0x81, 0x14, 0x9e, 0xff, 0xc9, 0xcc, 0x4e, 0x83, 0x10, 0x4a, 0x90, 0x4b, 0x05, 0x7a,
    0x9d, 0xa1, 0xab, 0xeb, 0x14, 0x33, 0x5f, 0x81, 0xb0, 0x54, 0xdc, 0xd3, 0xc8, 0x5c, 0xba, 0x56,
    0x52, 0x48, 0x57, 0x03, 0x95, 0x82, 0xe9, 0x5c, 0x8e, 0xc4, 0x28, 0xc7, 0xb9, 0xac, 0xb7, 0x90,
    0x92, 0xe7, 0xa3, 0x42, 0x0a, 0x0a, 0x43, 0xc9, 0x0c, 0x90, 0xfa, 0x7e, 0xba, 0xa3, 0x72, 0xa6,
    0x22, 0x58, 0xf7, 0x1c, 0xb0, 0x16, 0x38, 0x98, 0x0e, 0xcd, 0x14, 0xf7, 0x7c, 0xf3, 0x93, 0x0d,
    0xf5, 0x4e, 0x2e, 0x6c, 0x28, 0xf4, 0x9f, 0x12, 0xff, 0x02, 0x25, 0x3a, 0x11, 0xc2, 0xad, 0x00,
    0xcc, 0xc8, 0xd1, 0x7b, 0xf7, 0x21, 0xc5, 0xd9, 0x51, 0x9b, 0x72, 0x20, 0xaa, 0x10, 0x18, 0xe7,
    0x3b, 0x6a, 0xc0, 0x67, 0xf1, 0xcf, 0xad, 0x75, 0xb6, 0xf3, 0xc4, 0xe6, 0x95, 0x98, 0x8a, 0xd5,
    0x76, 0x35, 0xa7, 0xc0, 0xec, 0x63, 0xfa, 0x9d, 0x1a, 0xa4, 0xe6, 0x9b, 0x99, 0xb8, 0xe4, 0xe4,
    0x8f, 0x4d, 0x94, 0x30, 0x89, 0x8c, 0x31, 0x77, 0x26, 0xcc, 0x9e, 0xef, 0xf0, 0xcd, 0x48, 0x3a,
    0xa7, 0x85, 0xbf, 0x79, 0x7a, 0x56, 0x48, 0x08, 0x08, 0xca, 0xb0, 0x73, 0x48, 0xa2, 0x87, 0x62,
    0xc2, 0x48, 0xdc, 0x13, 0x15, 0x18, 0xee, 0xcf, 0xfb, 0xe5, 0x97, 0x99, 0x3e, 0xeb, 0x19, 0xac,
    0x2d, 0x06, 0x3b, 0xe2, 0x66, 0xc0, 0x8d, 0xab, 0x31, 0x68, 0x19, 0x2b, 0x0a, 0x7f, 0x1e, 0x6f,
    0xf3, 0x26, 0x19, 0x43, 0xc4, 0x93, 0x8e, 0xd8, 0xb7, 0xa7, 0x68, 0x80, 0xe5, 0xae, 0x35, 0xa1,
    0x96, 0xa7, 0xab, 0xa3, 0xc9, 0x15, 0xe0, 0x71, 0xc5, 0x60, 0x37, 0x19, 0x6e, 0xf9, 0xbb, 0x37,
    0xb3, 0x75, 0xb4, 0xbf, 0x36, 0xe9, 0xe6, 0xb8, 0x22, 0x52, 0x64, 0xab, 0xc3, 0x8e, 0x71, 0x96,
    0xfd, 0x5e, 0xa0, 0x9a, 0xe6, 0xd1, 0x5d, 0x2a, 0xee, 0x53, 0xdb, 0xa4, 0xdf, 0x93, 0xab, 0x6e,
    0x17, 0xaa, 0x1b, 0x49, 0xfd, 0xd7, 0x90, 0xf4, 0xf2, 0xad, 0x31, 0x33, 0x82, 0x64, 0xbf, 0xfc,
    0x86, 0xd2, 0xce, 0x29, 0x35, 0x39, 0xfc, 0x7c, 0xde, 0x01, 0xf6, 0xc5, 0x5b, 0xc3, 0x0e, 0x63,
    0x8e, 0xc1, 0x1d, 0x51, 0xd8, 0x56, 0x34, 0x7f, 0x46, 0x8c, 0x86, 0xa5, 0xc0, 0xab, 0xf1, 0x3e,
    0x52, 0x90, 0x56, 0x59, 0xc5, 0x9d, 0x98, 0xa3, 0x2e, 0x4a, 0x1e, 0x6f, 0x9f, 0x87, 0x4c, 0xc2,
    0xf9, 0x01, 0x6a, 0x61, 0x19, 0x67, 0x67, 0x21, 0x59, 0x62, 0xa9, 0xd3, 0xdf, 0x0e, 0x19, 0x7e,
    0x75, 0xa7, 0x7c, 0x7c, 0x7c, 0x8c, 0x8f, 0x8f, 0x92, 0xf0, 0xf1, 0xd1, 0xf0, 0xbd, 0x51, 0x0f,
    0x97, 0x59, 0x77, 0xb7, 0x2c, 0xb6, 0xb3, 0xf7, 0x82, 0xcb, 0xa3, 0x6a, 0x41, 0x5b, 0x15, 0xa3,
    0x35, 0xcd, 0x9b, 0x30, 0xe2, 0x10, 0x9a, 0x32, 0x32, 0x2b, 0x6d, 0x2c, 0xed, 0xec, 0xb6, 0x38,
    0xaf, 0x5b, 0x0f, 0x18, 0x98, 0x91, 0x14, 0x1a, 0xa6, 0x49, 0x74, 0xe0, 0x3d, 0x99, 0x75, 0x74,
    0x07, 0xaa, 0x02, 0x0e, 0x1a, 0xcd, 0x83, 0x03, 0x82, 0x2c, 0x38, 0x64, 0x9d, 0x4e, 0xaf, 0xbb,
    0x99, 0xeb, 0xbd, 0xd5, 0xff, 0xf3, 0x9d, 0x9d, 0x85, 0xab, 0xd1, 0xa6, 0xa4, 0xa8, 0xf7, 0x56,
    0xb6, 0x26, 0x36, 0xa5, 0x85, 0x13, 0xa6, 0x6d, 0x9c, 0x65, 0x75, 0x61, 0xe1, 0x6d, 0xdc, 0x72,
    0xb0, 0x1c, 0xfe, 0x74, 0xdb, 0x69, 0x6f, 0x7a, 0x7b, 0xc6, 0x5a, 0xfb, 0x5d, 0x2b, 0x83, 0x4f,
    0x10, 0x3e, 0xef, 0x4f, 0x9f, 0xed, 0xef, 0xad, 0x5c, 0x35, 0x98, 0xef, 0x54, 0xcf, 0xc2, 0x01,
    0xd8, 0x27, 0x9b, 0x83, 0x50, 0x7f, 0xe5, 0xb0, 0x31, 0xa1, 0xf9, 0xb5, 0x14, 0xcb, 0x60, 0x15,
    0xab, 0x6d, 0xb2, 0x70, 0x68, 0x75, 0xa8, 0x2d, 0x21, 0x37, 0xd5, 0x6c, 0x3c, 0xa6, 0x8f, 0x19,
    0x05, 0xe8, 0xea, 0xbb, 0x86, 0x85, 0x89, 0x69, 0xf1, 0x72, 0x50, 0xd9, 0xa7, 0x99, 0xd5, 0x6d,
    0x63, 0xe1, 0x6b, 0x56, 0xbe, 0xdc, 0x14, 0xb7, 0x5a, 0xf3, 0x21, 0xa7, 0xb3, 0xa9, 0xb6, 0x40,
    0xb7, 0x5f, 0x65, 0xcd, 0xe0, 0x76, 0xf5, 0xb0, 0x09, 0xac, 0x75, 0x5a, 0xc4, 0x6a, 0x40, 0x5f,
    0xf4, 0x1a, 0x10, 0xd7, 0xc2, 0x55, 0x01, 0xf2, 0x1b, 0x40, 0xf0, 0x24, 0xea
};
#endif

PyTypeObject *init_QAbstractOAuth2(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractOAuth2_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]))));

    _Sbk_QAbstractOAuth2_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractOAuth2",
        "QAbstractOAuth2*",
        &Sbk_QAbstractOAuth2_spec,
        &Shiboken::callCppDestructor< QAbstractOAuth2 >,
        Sbk_QAbstractOAuth2_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractOAuth2_TypeF(); // references _Sbk_QAbstractOAuth2_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractOAuth2_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractOAuth2_SignatureBytes, QAbstractOAuth2_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractOAuth2_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractOAuth2_PythonToCpp_QAbstractOAuth2_PTR,
        is_QAbstractOAuth2_PythonToCpp_QAbstractOAuth2_PTR_Convertible,
        QAbstractOAuth2_PTR_CppToPython_QAbstractOAuth2);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth2");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth2*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth2&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractOAuth2).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractOAuth2Wrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractOAuth2_TypeF(), &Sbk_QAbstractOAuth2_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractOAuth2_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'NonceMode'.
    const char *NonceMode_Initializer[] = {
        "Automatic",
        "Enabled",
        "Disabled",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t NonceMode_InitializerValues[] = {
        uint8_t(QAbstractOAuth2::NonceMode::Automatic), //  0x00  0
        uint8_t(QAbstractOAuth2::NonceMode::Enabled),   //  0x01  1
        uint8_t(QAbstractOAuth2::NonceMode::Disabled)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractOAuth2_TypeF(),
        "2:PySide6.QtNetworkAuth.QAbstractOAuth2.NonceMode",
        NonceMode_Initializer, NonceMode_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_NonceMode_IDX].type = EType;
    // Register converter for enum 'QAbstractOAuth2::NonceMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractOAuth2_NonceMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractOAuth2_NonceMode,
            is_Enum_PythonToCpp_QAbstractOAuth2_NonceMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth2::NonceMode");
        Shiboken::Conversions::registerConverterAlias(converter, "NonceMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'NonceMode' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstractOAuth2::staticMetaObject);
    qRegisterMetaType< ::QAbstractOAuth2::NonceMode >("QAbstractOAuth2::NonceMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractOAuth2::staticMetaObject, sizeof(QAbstractOAuth2Wrapper));

    return pyType;
}
