// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTOAUTH2WRAPPER_H
#define SBK_QABSTRACTOAUTH2WRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetworkAuth/qabstractoauth2.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractOAuth2Wrapper : public QAbstractOAuth2
{
public:
    QAbstractOAuth2Wrapper(::QNetworkAccessManager * manager, ::QObject * parent = nullptr);
    QAbstractOAuth2Wrapper(::QObject * parent = nullptr);
    QAbstractOAuth2Wrapper(const QAbstractOAuth2Wrapper &) = delete;
    QAbstractOAuth2Wrapper& operator=(const QAbstractOAuth2Wrapper &) = delete;
    QAbstractOAuth2Wrapper(QAbstractOAuth2Wrapper &&) = delete;
    QAbstractOAuth2Wrapper& operator=(QAbstractOAuth2Wrapper &&) = delete;
    ~QAbstractOAuth2Wrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QUrl createAuthenticatedUrl(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QUrl sbk_o_createAuthenticatedUrl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void customEvent(::QEvent * event) override;
    ::QNetworkReply * deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QNetworkReply * get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void grant() override;
    ::QNetworkReply * head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    ::QNetworkReply * post(const ::QUrl & url, ::QHttpMultiPart * multiPart) override;
    static ::QNetworkReply * sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart);
    ::QNetworkReply * post(const ::QUrl & url, const ::QByteArray & data) override;
    static ::QNetworkReply * sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data);
    ::QNetworkReply * post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body = QByteArray()) override;
    ::QNetworkReply * put(const ::QUrl & url, ::QHttpMultiPart * multiPart) override;
    static ::QNetworkReply * sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart);
    ::QNetworkReply * put(const ::QUrl & url, const ::QByteArray & data) override;
    static ::QNetworkReply * sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data);
    ::QNetworkReply * put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters) override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[20] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTOAUTH2WRAPPER_H
