// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QOAUTH1WRAPPER_H
#define SBK_QOAUTH1WRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetworkAuth/qoauth1.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QOAuth1Wrapper : public QOAuth1
{
public:
    QOAuth1Wrapper(::QNetworkAccessManager * manager, ::QObject * parent = nullptr);
    QOAuth1Wrapper(::QObject * parent = nullptr);
    QOAuth1Wrapper(const ::QString & clientIdentifier, const ::QString & clientSharedSecret, ::QNetworkAccessManager * manager, ::QObject * parent = nullptr);
    QOAuth1Wrapper(const QOAuth1Wrapper &) = delete;
    QOAuth1Wrapper& operator=(const QOAuth1Wrapper &) = delete;
    QOAuth1Wrapper(QOAuth1Wrapper &&) = delete;
    QOAuth1Wrapper& operator=(QOAuth1Wrapper &&) = delete;
    ~QOAuth1Wrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    ::QNetworkReply * deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_deleteResource(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QNetworkReply * get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_get(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void grant() override;
    ::QNetworkReply * head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_head(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    ::QNetworkReply * post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body = QByteArray()) override;
    ::QNetworkReply * put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters) override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[15] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QOAUTH1WRAPPER_H
