// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qoauth2authorizationcodeflow_wrapper.h"

// Wrappers providing overrides
#include "qoauth2deviceauthorizationflow_wrapper.h"
#include "qabstractoauth2_wrapper.h"
#include "qabstractoauth_wrapper.h"
#include "qabstractoauthreplyhandler_wrapper.h"

// Argument includes
#include <QMap>
#include <QMultiMap>
#include <QString>
#include <QtNetwork/qhttpmultipart.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qoauth2authorizationcodeflow.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOAuth2AuthorizationCodeFlowWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOAuth2AuthorizationCodeFlowWrapper::QOAuth2AuthorizationCodeFlowWrapper(::QNetworkAccessManager * manager, ::QObject * parent) : QOAuth2AuthorizationCodeFlow(manager, parent)
{
}

QOAuth2AuthorizationCodeFlowWrapper::QOAuth2AuthorizationCodeFlowWrapper(::QObject * parent) : QOAuth2AuthorizationCodeFlow(parent)
{
}

QOAuth2AuthorizationCodeFlowWrapper::QOAuth2AuthorizationCodeFlowWrapper(const ::QString & clientIdentifier, ::QNetworkAccessManager * manager, ::QObject * parent) : QOAuth2AuthorizationCodeFlow(clientIdentifier, manager, parent)
{
}

QOAuth2AuthorizationCodeFlowWrapper::QOAuth2AuthorizationCodeFlowWrapper(const ::QString & clientIdentifier, const ::QUrl & authorizationUrl, const ::QUrl & accessTokenUrl, ::QNetworkAccessManager * manager, ::QObject * parent) : QOAuth2AuthorizationCodeFlow(clientIdentifier, authorizationUrl, accessTokenUrl, manager, parent)
{
}

QOAuth2AuthorizationCodeFlowWrapper::QOAuth2AuthorizationCodeFlowWrapper(const ::QUrl & authorizationUrl, const ::QUrl & accessTokenUrl, ::QNetworkAccessManager * manager, ::QObject * parent) : QOAuth2AuthorizationCodeFlow(authorizationUrl, accessTokenUrl, manager, parent)
{
}

void QOAuth2AuthorizationCodeFlowWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_childEvent("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, event);
}

void QOAuth2AuthorizationCodeFlowWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, signal);
}

::QUrl QOAuth2AuthorizationCodeFlowWrapper::createAuthenticatedUrl(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "createAuthenticatedUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::createAuthenticatedUrl(url, parameters);
    }
    return QAbstractOAuth2Wrapper::sbk_o_createAuthenticatedUrl("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2AuthorizationCodeFlowWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_customEvent("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, event);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "deleteResource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::deleteResource(url, parameters);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_deleteResource("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2AuthorizationCodeFlowWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, signal);
}

bool QOAuth2AuthorizationCodeFlowWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_event("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, event);
}

bool QOAuth2AuthorizationCodeFlowWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_eventFilter("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, watched, event);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "get";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::get(url, parameters);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_get("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2AuthorizationCodeFlowWrapper::grant()
{
    static const char *funcName = "grant";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuth2AuthorizationCodeFlow::grant();
    }
    QAbstractOAuthWrapper::sbk_o_grant("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "head";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::head(url, parameters);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_head("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, parameters);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::post(const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, multiPart);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_post("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, multiPart);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::post(const ::QUrl & url, const ::QByteArray & data)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, data);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_post("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, data);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, parameters);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_post("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2AuthorizationCodeFlowWrapper::prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body)
{
    static const char *funcName = "prepareRequest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::prepareRequest(request, verb, body);
    }
    QAbstractOAuthWrapper::sbk_o_prepareRequest("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, request, verb, body);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::put(const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, multiPart);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_put("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, multiPart);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::put(const ::QUrl & url, const ::QByteArray & data)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, data);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_put("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, data);
}

::QNetworkReply * QOAuth2AuthorizationCodeFlowWrapper::put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, parameters);
    }
    return QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_put("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2AuthorizationCodeFlowWrapper::resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters)
{
    static const char *funcName = "resourceOwnerAuthorization";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuth2AuthorizationCodeFlow::resourceOwnerAuthorization(url, parameters);
    }
    QAbstractOAuthWrapper::sbk_o_resourceOwnerAuthorization("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2AuthorizationCodeFlowWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_timerEvent("QOAuth2AuthorizationCodeFlow", funcName, gil, pyOverride, event);
}

const QMetaObject *QOAuth2AuthorizationCodeFlowWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOAuth2AuthorizationCodeFlow::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOAuth2AuthorizationCodeFlowWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOAuth2AuthorizationCodeFlow::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOAuth2AuthorizationCodeFlowWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOAuth2AuthorizationCodeFlowWrapper *>(this));
    return QOAuth2AuthorizationCodeFlow::qt_metacast(_clname);
}

QOAuth2AuthorizationCodeFlowWrapper::~QOAuth2AuthorizationCodeFlowWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOAuth2AuthorizationCodeFlow_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOAuth2AuthorizationCodeFlow >()))
        return -1;

    QOAuth2AuthorizationCodeFlowWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOOO:QOAuth2AuthorizationCodeFlow", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOAuth2AuthorizationCodeFlow::QOAuth2AuthorizationCodeFlow(QNetworkAccessManager*,QObject*=)
    // 1: QOAuth2AuthorizationCodeFlow::QOAuth2AuthorizationCodeFlow(QObject*=)
    // 2: QOAuth2AuthorizationCodeFlow::QOAuth2AuthorizationCodeFlow(QString,QNetworkAccessManager*,QObject*=)
    // 3: QOAuth2AuthorizationCodeFlow::QOAuth2AuthorizationCodeFlow(QString,QUrl,QUrl,QNetworkAccessManager*,QObject*=)
    // 4: QOAuth2AuthorizationCodeFlow::QOAuth2AuthorizationCodeFlow(QUrl,QUrl,QNetworkAccessManager*,QObject*=)
    if (numArgs == 0) {
        overloadId = 1; // QOAuth2AuthorizationCodeFlow(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QOAuth2AuthorizationCodeFlow(QNetworkAccessManager*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QOAuth2AuthorizationCodeFlow(QNetworkAccessManager*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOAuth2AuthorizationCodeFlow(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 3; // QOAuth2AuthorizationCodeFlow(QString,QUrl,QUrl,QNetworkAccessManager*,QObject*)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
                overloadId = 3; // QOAuth2AuthorizationCodeFlow(QString,QUrl,QUrl,QNetworkAccessManager*,QObject*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // QOAuth2AuthorizationCodeFlow(QString,QNetworkAccessManager*,QObject*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
                overloadId = 2; // QOAuth2AuthorizationCodeFlow(QString,QNetworkAccessManager*,QObject*)
            }
        }
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 4; // QOAuth2AuthorizationCodeFlow(QUrl,QUrl,QNetworkAccessManager*,QObject*)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))) {
            overloadId = 4; // QOAuth2AuthorizationCodeFlow(QUrl,QUrl,QNetworkAccessManager*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOAuth2AuthorizationCodeFlow(QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkAccessManager *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth2AuthorizationCodeFlow(QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth2AuthorizationCodeFlowWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth2AuthorizationCodeFlowWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QOAuth2AuthorizationCodeFlow(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth2AuthorizationCodeFlow(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth2AuthorizationCodeFlowWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth2AuthorizationCodeFlowWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 2: // QOAuth2AuthorizationCodeFlow(const QString &clientIdentifier, QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QNetworkAccessManager *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth2AuthorizationCodeFlow(QString,QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth2AuthorizationCodeFlowWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth2AuthorizationCodeFlowWrapper(cppArg0, cppArg1, cppArg2);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 3: // QOAuth2AuthorizationCodeFlow(const QString &clientIdentifier, const QUrl &authorizationUrl, const QUrl &accessTokenUrl, QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 4}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QUrl cppArg1_local;
            ::QUrl *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QUrl cppArg2_local;
            ::QUrl *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QNetworkAccessManager *cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QObject *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth2AuthorizationCodeFlow(QString,QUrl,QUrl,QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth2AuthorizationCodeFlowWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth2AuthorizationCodeFlowWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[4], self);
            }
            break;
        }
        case 4: // QOAuth2AuthorizationCodeFlow(const QUrl &authorizationUrl, const QUrl &accessTokenUrl, QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 3}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QUrl cppArg1_local;
            ::QUrl *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QNetworkAccessManager *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QObject *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth2AuthorizationCodeFlow(QUrl,QUrl,QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth2AuthorizationCodeFlowWrapper(*cppArg0, *cppArg1, cppArg2, cppArg3);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth2AuthorizationCodeFlowWrapper(*cppArg0, *cppArg1, cppArg2, cppArg3);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[3], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOAuth2AuthorizationCodeFlow >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_accessTokenUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QOAuth2AuthorizationCodeFlow", "accessTokenUrl() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // accessTokenUrl()const
        QUrl cppResult = const_cast<const ::QOAuth2AuthorizationCodeFlow *>(cppSelf)->accessTokenUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_buildAuthenticateUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "buildAuthenticateUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    if (PyArg_ParseTuple(args, "|O:buildAuthenticateUrl", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth2AuthorizationCodeFlow::buildAuthenticateUrl(const QMultiMap<QString,QVariant>&=)->QUrl
    if (numArgs == 0) {
        overloadId = 0; // buildAuthenticateUrl(QMultiMap<QString,QVariant>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[0])))) {
        overloadId = 0; // buildAuthenticateUrl(QMultiMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "buildAuthenticateUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "buildAuthenticateUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
            }
        }
        ::QMultiMap<QString,QVariant> cppArg0{};
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // buildAuthenticateUrl(QMultiMap<QString,QVariant>)
            QUrl cppResult = cppSelf->buildAuthenticateUrl(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_grant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grant()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QOAuth2AuthorizationCodeFlow::grant()
            : cppSelf->grant();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_pkceMethod(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pkceMethod()const
        QOAuth2AuthorizationCodeFlow::PkceMethod cppResult = const_cast<const ::QOAuth2AuthorizationCodeFlow *>(cppSelf)->pkceMethod();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_PkceMethod_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_refreshAccessToken(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QOAuth2AuthorizationCodeFlow", "refreshAccessToken()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // refreshAccessToken()
        cppSelf->refreshAccessToken();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_refreshTokensImplementation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refreshTokensImplementation()
        cppSelf->refreshTokensImplementation();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_requestAccessToken(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth2AuthorizationCodeFlow::requestAccessToken(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // requestAccessToken(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "requestAccessToken", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requestAccessToken(QString)
            cppSelf->requestAccessToken(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_resourceOwnerAuthorization(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "resourceOwnerAuthorization", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    if (PyArg_ParseTuple(args, "|OO:resourceOwnerAuthorization", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::resourceOwnerAuthorization(QUrl,const QMultiMap<QString,QVariant>&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // resourceOwnerAuthorization(QUrl,QMultiMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // resourceOwnerAuthorization(QUrl,QMultiMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resourceOwnerAuthorization", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "resourceOwnerAuthorization", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMultiMap<QString,QVariant> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceOwnerAuthorization(QUrl,QMultiMap<QString,QVariant>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth2AuthorizationCodeFlow::resourceOwnerAuthorization(*cppArg0, cppArg1)
                : cppSelf->resourceOwnerAuthorization(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_setAccessTokenUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth2AuthorizationCodeFlow::setAccessTokenUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setAccessTokenUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAccessTokenUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QOAuth2AuthorizationCodeFlow", "setAccessTokenUrl(const QUrl &accessTokenUrl)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccessTokenUrl(QUrl)
            cppSelf->setAccessTokenUrl(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2AuthorizationCodeFlowFunc_setPkceMethod(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPkceMethod", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setPkceMethod", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth2AuthorizationCodeFlow::setPkceMethod(QOAuth2AuthorizationCodeFlow::PkceMethod,qsizetype=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_PkceMethod_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPkceMethod(QOAuth2AuthorizationCodeFlow::PkceMethod,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // setPkceMethod(QOAuth2AuthorizationCodeFlow::PkceMethod,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPkceMethod", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"length", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setPkceMethod", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]);
            }
        }
        ::QOAuth2AuthorizationCodeFlow::PkceMethod cppArg0{QOAuth2AuthorizationCodeFlow::PkceMethod::S256};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 43;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPkceMethod(QOAuth2AuthorizationCodeFlow::PkceMethod,qsizetype)
            cppSelf->setPkceMethod(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QOAuth2AuthorizationCodeFlow_PropertyStrings[] = {
    "accessTokenUrl::",
    nullptr // Sentinel
};

static const char *Sbk_QOAuth2AuthorizationCodeFlow_EnumFlagInfo[] = {
    "PkceMethod:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOAuth2AuthorizationCodeFlow_methods[] = {
    {"accessTokenUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_accessTokenUrl), METH_NOARGS, nullptr},
    {"buildAuthenticateUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_buildAuthenticateUrl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"grant", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_grant), METH_NOARGS, nullptr},
    {"pkceMethod", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_pkceMethod), METH_NOARGS, nullptr},
    {"refreshAccessToken", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_refreshAccessToken), METH_NOARGS, nullptr},
    {"refreshTokensImplementation", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_refreshTokensImplementation), METH_NOARGS, nullptr},
    {"requestAccessToken", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_requestAccessToken), METH_O, nullptr},
    {"resourceOwnerAuthorization", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_resourceOwnerAuthorization), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAccessTokenUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_setAccessTokenUrl), METH_O, nullptr},
    {"setPkceMethod", reinterpret_cast<PyCFunction>(Sbk_QOAuth2AuthorizationCodeFlowFunc_setPkceMethod), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOAuth2AuthorizationCodeFlow_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOAuth2AuthorizationCodeFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOAuth2AuthorizationCodeFlowWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOAuth2AuthorizationCodeFlow_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOAuth2AuthorizationCodeFlow_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOAuth2AuthorizationCodeFlow_Type = nullptr;
static PyTypeObject *Sbk_QOAuth2AuthorizationCodeFlow_TypeF(void)
{
    return _Sbk_QOAuth2AuthorizationCodeFlow_Type;
}

static PyType_Slot Sbk_QOAuth2AuthorizationCodeFlow_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOAuth2AuthorizationCodeFlow_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOAuth2AuthorizationCodeFlow_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOAuth2AuthorizationCodeFlow_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOAuth2AuthorizationCodeFlow_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOAuth2AuthorizationCodeFlow_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOAuth2AuthorizationCodeFlow_spec = {
    "2:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOAuth2AuthorizationCodeFlow_slots
};

} //extern "C"

static void *Sbk_QOAuth2AuthorizationCodeFlow_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOAuth2AuthorizationCodeFlow *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOAuth2AuthorizationCodeFlow_PkceMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOAuth2AuthorizationCodeFlow::PkceMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOAuth2AuthorizationCodeFlow::PkceMethod *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOAuth2AuthorizationCodeFlow_PkceMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_PkceMethod_IDX])))
        return Enum_PythonToCpp_QOAuth2AuthorizationCodeFlow_PkceMethod;
    return {};
}

static PyObject *QOAuth2AuthorizationCodeFlow_PkceMethod_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOAuth2AuthorizationCodeFlow::PkceMethod>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOAuth2AuthorizationCodeFlow::PkceMethod *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_PkceMethod_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOAuth2AuthorizationCodeFlow_PythonToCpp_QOAuth2AuthorizationCodeFlow_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOAuth2AuthorizationCodeFlow_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOAuth2AuthorizationCodeFlow_PythonToCpp_QOAuth2AuthorizationCodeFlow_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuth2AuthorizationCodeFlow_TypeF()))
        return QOAuth2AuthorizationCodeFlow_PythonToCpp_QOAuth2AuthorizationCodeFlow_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOAuth2AuthorizationCodeFlow_PTR_CppToPython_QOAuth2AuthorizationCodeFlow(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOAuth2AuthorizationCodeFlow *>(const_cast<void *>(cppIn)), Sbk_QOAuth2AuthorizationCodeFlow_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOAuth2AuthorizationCodeFlow_SignatureStrings[] = {
    "4:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow(self,manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,accessTokenUrl:QUrl=None)",
    "3:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,accessTokenUrl:QUrl=None)",
    "2:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow(self,clientIdentifier:QString,manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,accessTokenUrl:QUrl=None)",
    "1:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow(self,clientIdentifier:QString,authorizationUrl:typing.Union[PySide6.QtCore.QUrl, QString],accessTokenUrl:typing.Union[PySide6.QtCore.QUrl, QString],manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,accessTokenUrl:QUrl=None)",
    "0:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow(self,authorizationUrl:typing.Union[PySide6.QtCore.QUrl, QString],accessTokenUrl:typing.Union[PySide6.QtCore.QUrl, QString],manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,accessTokenUrl:QUrl=None)",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.accessTokenUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.buildAuthenticateUrl(self,parameters:QMultiMap[QString, QVariant]={})->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.grant(self)",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.pkceMethod(self)->PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.PkceMethod",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.refreshAccessToken(self)",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.refreshTokensImplementation(self)",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.requestAccessToken(self,code:QString)",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.resourceOwnerAuthorization(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMultiMap[QString, QVariant]={})",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.setAccessTokenUrl(self,accessTokenUrl:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.setPkceMethod(self,method:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.PkceMethod,length:qsizetype=43)",
    nullptr}; // Sentinel
#else
static constexpr size_t QOAuth2AuthorizationCodeFlow_SignatureByteSize = 405;
static constexpr uint8_t QOAuth2AuthorizationCodeFlow_SignatureBytes[405] = {
    0x78, 0xda, 0xe5, 0x54, 0x5d, 0x6b, 0xc2, 0x30, 0x14, 0x7d, 0xf7, 0x57, 0xf8, 0x38, 0x47, 0x56,
    0x36, 0x95, 0x3d, 0x14, 0x3a, 0x10, 0x61, 0x20, 0xa3, 0x6a, 0x71, 0xee, 0x45, 0x7c, 0x88, 0xe9,
    0x55, 0x33, 0xd3, 0xa4, 0x26, 0x29, 0x52, 0xc7, 0xfe, 0xfb, 0xd2, 0x6a, 0x9d, 0x1f, 0x7b, 0x58,
    0xa3, 0x03, 0x61, 0x2f, 0xe9, 0xc7, 0xbd, 0xe7, 0xdc, 0x73, 0x4f, 0x6e, 0xd2, 0x74, 0xfb, 0xe9,
    0x80, 0x86, 0xf0, 0xe8, 0x04, 0xba, 0x0b, 0x7a, 0x25, 0xe4, 0xa2, 0x95, 0xe8, 0xb9, 0x13, 0xf4,
    0xb2, 0x47, 0x3d, 0x5b, 0x84, 0xa4, 0x6b, 0xac, 0xa9, 0xe0, 0x6d, 0x11, 0xc2, 0x33, 0x13, 0xab,
    0x1b, 0x05, 0x6c, 0x8a, 0x22, 0xcc, 0xf1, 0x0c, 0xe4, 0x29, 0xde, 0x09, 0x0a, 0x22, 0x42, 0x40,
    0x29, 0x7f, 0x93, 0x87, 0x62, 0x2c, 0x81, 0xeb, 0xbd, 0xf4, 0xb6, 0x90, 0x60, 0xea, 0x4c, 0xde,
    0x81, 0x68, 0x8f, 0x27, 0x8c, 0xc5, 0x5a, 0xa2, 0x5b, 0xf7, 0x05, 0x52, 0x03, 0x0e, 0x7b, 0x9c,
    0xa5, 0x5e, 0x57, 0x70, 0x40, 0x38, 0xa7, 0x79, 0x15, 0x0b, 0xe0, 0x43, 0xc9, 0xdc, 0xc0, 0x2c,
    0x79, 0xa0, 0x56, 0x69, 0x58, 0x8b, 0xff, 0x03, 0x31, 0x75, 0x6b, 0x31, 0x84, 0x51, 0x23, 0xa6,
    0x13, 0x9a, 0x85, 0x4e, 0xa9, 0xb1, 0x34, 0x18, 0x68, 0x49, 0xf9, 0xec, 0x1a, 0x2c, 0x7e, 0xb8,
    0x7c, 0x57, 0x78, 0x1f, 0x93, 0x95, 0xd3, 0x69, 0x6c, 0xfe, 0x3b, 0x43, 0x6e, 0xbe, 0x47, 0xc7,
    0xe2, 0x4d, 0x02, 0xaa, 0x6e, 0xa1, 0xe3, 0x63, 0xa1, 0x25, 0x90, 0x57, 0xe0, 0xe5, 0xbd, 0xb5,
    0x97, 0xff, 0xd6, 0xb2, 0xf2, 0x86, 0x39, 0x87, 0x64, 0xb9, 0x7f, 0xb5, 0xbb, 0xa7, 0x1f, 0x3a,
    0xb5, 0x21, 0x9f, 0x24, 0x94, 0x85, 0x59, 0x28, 0x9b, 0x6a, 0x82, 0x35, 0x14, 0x25, 0xb2, 0xe6,
    0x71, 0x04, 0x1a, 0xa4, 0x72, 0x03, 0x3f, 0x61, 0x9a, 0xfa, 0x38, 0x1e, 0x15, 0x23, 0x5f, 0x0d,
    0xde, 0xb0, 0xa4, 0x98, 0xeb, 0xb1, 0xf7, 0xf1, 0x79, 0x39, 0x35, 0x33, 0x69, 0x28, 0x37, 0x1d,
    0xda, 0xc0, 0xe3, 0x05, 0x01, 0x1f, 0x4c, 0x24, 0x3c, 0x75, 0xe9, 0xd7, 0x24, 0xfd, 0x1d, 0x89,
    0x8d, 0x04, 0x09, 0x53, 0x09, 0x6a, 0xde, 0xfa, 0xde, 0x33, 0xfb, 0x76, 0xb6, 0x5c, 0x39, 0x8b,
    0xea, 0x44, 0x31, 0x83, 0xc8, 0xec, 0x52, 0x9e, 0x73, 0x0e, 0xe9, 0x32, 0x01, 0xa5, 0x8f, 0x05,
    0x22, 0x62, 0x12, 0x8a, 0x1b, 0xcd, 0x92, 0x58, 0x89, 0x44, 0x12, 0xe8, 0xad, 0x38, 0xc8, 0x83,
    0x94, 0x4d, 0x81, 0xa4, 0xdc, 0x59, 0x2d, 0x31, 0x7e, 0x36, 0x6a, 0x15, 0xec, 0x5b, 0xb0, 0x1b,
    0x7a, 0xeb, 0xbb, 0xc5, 0x56, 0x44, 0xff, 0x70, 0x64, 0x51, 0x94, 0xbf, 0xbb, 0x67, 0xcd, 0x2d,
    0x62, 0xc0, 0x67, 0x7a, 0xee, 0x2e, 0x15, 0x5d, 0x83, 0x69, 0x01, 0xbc, 0x66, 0xa3, 0x56, 0xf9,
    0x02, 0x31, 0xff, 0x62, 0x72
};
#endif

PyTypeObject *init_QOAuth2AuthorizationCodeFlow(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX].type;

    Shiboken::AutoDecRef Sbk_QOAuth2AuthorizationCodeFlow_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]))));

    _Sbk_QOAuth2AuthorizationCodeFlow_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOAuth2AuthorizationCodeFlow",
        "QOAuth2AuthorizationCodeFlow*",
        &Sbk_QOAuth2AuthorizationCodeFlow_spec,
        &Shiboken::callCppDestructor< QOAuth2AuthorizationCodeFlow >,
        Sbk_QOAuth2AuthorizationCodeFlow_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOAuth2AuthorizationCodeFlow_TypeF(); // references _Sbk_QOAuth2AuthorizationCodeFlow_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOAuth2AuthorizationCodeFlow_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOAuth2AuthorizationCodeFlow_SignatureBytes, QOAuth2AuthorizationCodeFlow_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOAuth2AuthorizationCodeFlow_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOAuth2AuthorizationCodeFlow_PythonToCpp_QOAuth2AuthorizationCodeFlow_PTR,
        is_QOAuth2AuthorizationCodeFlow_PythonToCpp_QOAuth2AuthorizationCodeFlow_PTR_Convertible,
        QOAuth2AuthorizationCodeFlow_PTR_CppToPython_QOAuth2AuthorizationCodeFlow);

    Shiboken::Conversions::registerConverterName(converter, "QOAuth2AuthorizationCodeFlow");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth2AuthorizationCodeFlow*");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth2AuthorizationCodeFlow&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOAuth2AuthorizationCodeFlow).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOAuth2AuthorizationCodeFlowWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOAuth2AuthorizationCodeFlow_TypeF(), &Sbk_QOAuth2AuthorizationCodeFlow_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOAuth2AuthorizationCodeFlow_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PkceMethod'.
    const char *PkceMethod_Initializer[] = {
        "S256",
        "Plain",
        "None_",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t PkceMethod_InitializerValues[] = {
        uint8_t(QOAuth2AuthorizationCodeFlow::PkceMethod::S256),  //  0x00  0
        uint8_t(QOAuth2AuthorizationCodeFlow::PkceMethod::Plain), //  0x01  1
        uint8_t(QOAuth2AuthorizationCodeFlow::PkceMethod::None)   //  0xff  255
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOAuth2AuthorizationCodeFlow_TypeF(),
        "2:PySide6.QtNetworkAuth.QOAuth2AuthorizationCodeFlow.PkceMethod",
        PkceMethod_Initializer, PkceMethod_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2AuthorizationCodeFlow_PkceMethod_IDX].type = EType;
    // Register converter for enum 'QOAuth2AuthorizationCodeFlow::PkceMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOAuth2AuthorizationCodeFlow_PkceMethod_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOAuth2AuthorizationCodeFlow_PkceMethod,
            is_Enum_PythonToCpp_QOAuth2AuthorizationCodeFlow_PkceMethod_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOAuth2AuthorizationCodeFlow::PkceMethod");
        Shiboken::Conversions::registerConverterAlias(converter, "PkceMethod");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PkceMethod' enum.

    PySide::Signal::registerSignals(pyType, &::QOAuth2AuthorizationCodeFlow::staticMetaObject);
    qRegisterMetaType< ::QOAuth2AuthorizationCodeFlow::PkceMethod >("QOAuth2AuthorizationCodeFlow::PkceMethod");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOAuth2AuthorizationCodeFlow::staticMetaObject, sizeof(QOAuth2AuthorizationCodeFlowWrapper));

    return pyType;
}
