// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qoauth2deviceauthorizationflow_wrapper.h"

// Wrappers providing overrides
#include "qabstractoauth2_wrapper.h"
#include "qabstractoauth_wrapper.h"
#include "qabstractoauthreplyhandler_wrapper.h"

// Argument includes
#include <QMap>
#include <QMultiMap>
#include <QString>
#include <QtNetwork/qhttpmultipart.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOAuth2DeviceAuthorizationFlowWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOAuth2DeviceAuthorizationFlowWrapper::QOAuth2DeviceAuthorizationFlowWrapper()
{
}

QOAuth2DeviceAuthorizationFlowWrapper::QOAuth2DeviceAuthorizationFlowWrapper(::QNetworkAccessManager * manager, ::QObject * parent) : QOAuth2DeviceAuthorizationFlow(manager, parent)
{
}

QOAuth2DeviceAuthorizationFlowWrapper::QOAuth2DeviceAuthorizationFlowWrapper(::QObject * parent) : QOAuth2DeviceAuthorizationFlow(parent)
{
}

void QOAuth2DeviceAuthorizationFlowWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_childEvent("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, event);
}

void QOAuth2DeviceAuthorizationFlowWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, signal);
}

::QUrl QOAuth2DeviceAuthorizationFlowWrapper::createAuthenticatedUrl(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "createAuthenticatedUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::createAuthenticatedUrl(url, parameters);
    }
    return QAbstractOAuth2Wrapper::sbk_o_createAuthenticatedUrl("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2DeviceAuthorizationFlowWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_customEvent("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, event);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "deleteResource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::deleteResource(url, parameters);
    }
    return sbk_o_deleteResource("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, parameters);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_deleteResource(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth2DeviceAuthorizationFlowWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, signal);
}

bool QOAuth2DeviceAuthorizationFlowWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuth2DeviceAuthorizationFlow::event(event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_event("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, event);
}

bool QOAuth2DeviceAuthorizationFlowWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_eventFilter("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, watched, event);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "get";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::get(url, parameters);
    }
    return sbk_o_get("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, parameters);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_get(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth2DeviceAuthorizationFlowWrapper::grant()
{
    static const char *funcName = "grant";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuth2DeviceAuthorizationFlow::grant();
    }
    QAbstractOAuthWrapper::sbk_o_grant("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "head";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::head(url, parameters);
    }
    return sbk_o_head("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, parameters);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_head(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::post(const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, multiPart);
    }
    return sbk_o_post("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, multiPart);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::post(const ::QUrl & url, const ::QByteArray & data)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, data);
    }
    return sbk_o_post("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, data);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "post";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::post(url, parameters);
    }
    return sbk_o_post("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, parameters);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth2DeviceAuthorizationFlowWrapper::prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body)
{
    static const char *funcName = "prepareRequest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::prepareRequest(request, verb, body);
    }
    QAbstractOAuthWrapper::sbk_o_prepareRequest("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, request, verb, body);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::put(const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, multiPart);
    }
    return sbk_o_put("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, multiPart);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), multiPart)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::put(const ::QUrl & url, const ::QByteArray & data)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, data);
    }
    return sbk_o_put("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, data);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    static const char *funcName = "put";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth2::put(url, parameters);
    }
    return sbk_o_put("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, parameters);
}

::QNetworkReply * QOAuth2DeviceAuthorizationFlowWrapper::sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth2DeviceAuthorizationFlowWrapper::resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters)
{
    static const char *funcName = "resourceOwnerAuthorization";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractOAuth::resourceOwnerAuthorization(url, parameters);
    }
    QAbstractOAuthWrapper::sbk_o_resourceOwnerAuthorization("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, url, parameters);
}

void QOAuth2DeviceAuthorizationFlowWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_timerEvent("QOAuth2DeviceAuthorizationFlow", funcName, gil, pyOverride, event);
}

const QMetaObject *QOAuth2DeviceAuthorizationFlowWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOAuth2DeviceAuthorizationFlow::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOAuth2DeviceAuthorizationFlowWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOAuth2DeviceAuthorizationFlow::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOAuth2DeviceAuthorizationFlowWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOAuth2DeviceAuthorizationFlowWrapper *>(this));
    return QOAuth2DeviceAuthorizationFlow::qt_metacast(_clname);
}

QOAuth2DeviceAuthorizationFlowWrapper::~QOAuth2DeviceAuthorizationFlowWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOAuth2DeviceAuthorizationFlow_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOAuth2DeviceAuthorizationFlow >()))
        return -1;

    QOAuth2DeviceAuthorizationFlowWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QOAuth2DeviceAuthorizationFlow", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOAuth2DeviceAuthorizationFlow::QOAuth2DeviceAuthorizationFlow()
    // 1: QOAuth2DeviceAuthorizationFlow::QOAuth2DeviceAuthorizationFlow(QNetworkAccessManager*,QObject*=)
    // 2: QOAuth2DeviceAuthorizationFlow::QOAuth2DeviceAuthorizationFlow(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QOAuth2DeviceAuthorizationFlow()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QOAuth2DeviceAuthorizationFlow(QNetworkAccessManager*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QOAuth2DeviceAuthorizationFlow(QNetworkAccessManager*,QObject*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QOAuth2DeviceAuthorizationFlow(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOAuth2DeviceAuthorizationFlow()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);
            }

            // QOAuth2DeviceAuthorizationFlow()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QOAuth2DeviceAuthorizationFlowWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QOAuth2DeviceAuthorizationFlowWrapper();
            }

            break;
        }
        case 1: // QOAuth2DeviceAuthorizationFlow(QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkAccessManager *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth2DeviceAuthorizationFlow(QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth2DeviceAuthorizationFlowWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth2DeviceAuthorizationFlowWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 2: // QOAuth2DeviceAuthorizationFlow(QObject *parent)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth2DeviceAuthorizationFlow(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth2DeviceAuthorizationFlowWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth2DeviceAuthorizationFlowWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOAuth2DeviceAuthorizationFlow >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_completeVerificationUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // completeVerificationUrl()const
        QUrl cppResult = const_cast<const ::QOAuth2DeviceAuthorizationFlow *>(cppSelf)->completeVerificationUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth2DeviceAuthorizationFlow::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_grant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grant()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QOAuth2DeviceAuthorizationFlow::grant()
            : cppSelf->grant();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_isPolling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPolling()const
        bool cppResult = const_cast<const ::QOAuth2DeviceAuthorizationFlow *>(cppSelf)->isPolling();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_refreshTokensImplementation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refreshTokensImplementation()
        cppSelf->refreshTokensImplementation();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_startTokenPolling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startTokenPolling()
        bool cppResult = cppSelf->startTokenPolling();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_stopTokenPolling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stopTokenPolling()
        cppSelf->stopTokenPolling();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_userCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userCode()const
        QString cppResult = const_cast<const ::QOAuth2DeviceAuthorizationFlow *>(cppSelf)->userCode();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_userCodeExpirationAt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userCodeExpirationAt()const
        QDateTime cppResult = const_cast<const ::QOAuth2DeviceAuthorizationFlow *>(cppSelf)->userCodeExpirationAt();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuth2DeviceAuthorizationFlowFunc_verificationUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // verificationUrl()const
        QUrl cppResult = const_cast<const ::QOAuth2DeviceAuthorizationFlow *>(cppSelf)->verificationUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QOAuth2DeviceAuthorizationFlow_PropertyStrings[] = {
    "completeVerificationUrl:",
    "polling:isPolling",
    "userCode:",
    "userCodeExpirationAt:",
    "verificationUrl:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOAuth2DeviceAuthorizationFlow_methods[] = {
    {"completeVerificationUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_completeVerificationUrl), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_event), METH_O, nullptr},
    {"grant", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_grant), METH_NOARGS, nullptr},
    {"isPolling", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_isPolling), METH_NOARGS, nullptr},
    {"refreshTokensImplementation", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_refreshTokensImplementation), METH_NOARGS, nullptr},
    {"startTokenPolling", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_startTokenPolling), METH_NOARGS, nullptr},
    {"stopTokenPolling", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_stopTokenPolling), METH_NOARGS, nullptr},
    {"userCode", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_userCode), METH_NOARGS, nullptr},
    {"userCodeExpirationAt", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_userCodeExpirationAt), METH_NOARGS, nullptr},
    {"verificationUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth2DeviceAuthorizationFlowFunc_verificationUrl), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOAuth2DeviceAuthorizationFlow_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOAuth2DeviceAuthorizationFlow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOAuth2DeviceAuthorizationFlowWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOAuth2DeviceAuthorizationFlow_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOAuth2DeviceAuthorizationFlow_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOAuth2DeviceAuthorizationFlow_Type = nullptr;
static PyTypeObject *Sbk_QOAuth2DeviceAuthorizationFlow_TypeF(void)
{
    return _Sbk_QOAuth2DeviceAuthorizationFlow_Type;
}

static PyType_Slot Sbk_QOAuth2DeviceAuthorizationFlow_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOAuth2DeviceAuthorizationFlow_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOAuth2DeviceAuthorizationFlow_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOAuth2DeviceAuthorizationFlow_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOAuth2DeviceAuthorizationFlow_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOAuth2DeviceAuthorizationFlow_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOAuth2DeviceAuthorizationFlow_spec = {
    "2:PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOAuth2DeviceAuthorizationFlow_slots
};

} //extern "C"

static void *Sbk_QOAuth2DeviceAuthorizationFlow_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOAuth2DeviceAuthorizationFlow *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOAuth2DeviceAuthorizationFlow_PythonToCpp_QOAuth2DeviceAuthorizationFlow_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOAuth2DeviceAuthorizationFlow_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOAuth2DeviceAuthorizationFlow_PythonToCpp_QOAuth2DeviceAuthorizationFlow_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuth2DeviceAuthorizationFlow_TypeF()))
        return QOAuth2DeviceAuthorizationFlow_PythonToCpp_QOAuth2DeviceAuthorizationFlow_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOAuth2DeviceAuthorizationFlow_PTR_CppToPython_QOAuth2DeviceAuthorizationFlow(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOAuth2DeviceAuthorizationFlow *>(const_cast<void *>(cppIn)), Sbk_QOAuth2DeviceAuthorizationFlow_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOAuth2DeviceAuthorizationFlow_SignatureStrings[] = {
    "2:PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow(self,*:KeywordOnly=None,userCode:QString=None,verificationUrl:QUrl=None,completeVerificationUrl:QUrl=None,polling:bool=None,userCodeExpirationAt:QDateTime=None)",
    "1:PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow(self,manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,userCode:QString=None,verificationUrl:QUrl=None,completeVerificationUrl:QUrl=None,polling:bool=None,userCodeExpirationAt:QDateTime=None)",
    "0:PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow(self,parent:PySide6.QtCore.QObject,*:KeywordOnly=None,userCode:QString=None,verificationUrl:QUrl=None,completeVerificationUrl:QUrl=None,polling:bool=None,userCodeExpirationAt:QDateTime=None)",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.completeVerificationUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.grant(self)",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.isPolling(self)->bool",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.refreshTokensImplementation(self)",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.startTokenPolling(self)->bool",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.stopTokenPolling(self)",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.userCode(self)->QString",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.userCodeExpirationAt(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtNetworkAuth.QOAuth2DeviceAuthorizationFlow.verificationUrl(self)->PySide6.QtCore.QUrl",
    nullptr}; // Sentinel
#else
static constexpr size_t QOAuth2DeviceAuthorizationFlow_SignatureByteSize = 322;
static constexpr uint8_t QOAuth2DeviceAuthorizationFlow_SignatureBytes[322] = {
    0x78, 0xda, 0xcd, 0x53, 0x5f, 0x4f, 0xc2, 0x30, 0x10, 0x7f, 0xf7, 0x93, 0x88, 0x99, 0x8b, 0xf2,
    0xe0, 0xc3, 0x12, 0x4c, 0x08, 0x60, 0x62, 0x8c, 0xc0, 0x02, 0xfa, 0x5e, 0xb6, 0x03, 0x2a, 0x5d,
    0x6f, 0xb9, 0x1e, 0x43, 0xfc, 0xf4, 0x76, 0x1d, 0x4b, 0x40, 0x32, 0x63, 0x3a, 0x1f, 0x78, 0xd9,
    0x9a, 0xde, 0xdd, 0xef, 0x5f, 0xae, 0xdd, 0x68, 0xba, 0x9f, 0xc9, 0x14, 0x1e, 0xc2, 0x98, 0xc7,
    0xc0, 0x3b, 0xa4, 0x4d, 0x7f, 0xcb, 0xeb, 0x30, 0x9e, 0x94, 0xbf, 0xee, 0x10, 0x0a, 0x99, 0x40,
    0x79, 0x44, 0x92, 0x5f, 0x82, 0x25, 0xea, 0x27, 0x85, 0xbb, 0x6b, 0x03, 0x6a, 0x19, 0xdc, 0x44,
    0x2f, 0xb0, 0xb7, 0x13, 0xe9, 0x44, 0xab, 0x7d, 0x6f, 0x8c, 0x1a, 0x82, 0xad, 0x01, 0x1a, 0x60,
    0x0a, 0x51, 0x3c, 0x63, 0x92, 0x7a, 0x55, 0xdd, 0x16, 0x40, 0x72, 0x29, 0x13, 0x37, 0xfe, 0x46,
    0x2a, 0x8a, 0xed, 0xa7, 0xaa, 0x24, 0x98, 0xe5, 0x0a, 0x18, 0xde, 0x1b, 0x3b, 0x72, 0x54, 0xca,
    0x02, 0x45, 0x0b, 0x44, 0x75, 0xca, 0x31, 0xfa, 0xcc, 0x25, 0xb9, 0x89, 0x3e, 0x47, 0xf1, 0x50,
    0x30, 0xcc, 0x65, 0x06, 0xae, 0xa7, 0x73, 0x75, 0xdf, 0xc2, 0x57, 0x26, 0xb4, 0x58, 0x01, 0x9d,
    0x23, 0x84, 0x71, 0x0d, 0x95, 0x24, 0x60, 0xcc, 0x6b, 0xd5, 0x17, 0xe4, 0x82, 0x40, 0xf3, 0x51,
    0xfb, 0x00, 0x09, 0x2c, 0xd3, 0xe2, 0x03, 0x12, 0xee, 0xe9, 0xad, 0x52, 0x39, 0xd3, 0x45, 0xa7,
    0x75, 0xd7, 0x22, 0xad, 0x5f, 0xdd, 0x5f, 0xb4, 0x6b, 0x1f, 0xcf, 0x61, 0x83, 0x1a, 0x97, 0x45,
    0xe7, 0xf6, 0xf1, 0x67, 0x0c, 0xb6, 0xe4, 0xc7, 0x03, 0x85, 0x4d, 0xb5, 0x4a, 0xd8, 0x1d, 0xcf,
    0x02, 0x1e, 0x95, 0xb7, 0x96, 0xb1, 0x34, 0xed, 0x47, 0xb1, 0x22, 0x71, 0xa0, 0xf0, 0xcc, 0x42,
    0x9a, 0x69, 0x95, 0x7c, 0xed, 0xde, 0x5f, 0x0b, 0xc1, 0x92, 0xc0, 0xac, 0xe7, 0xb8, 0x01, 0x6d,
    0x9e, 0xcb, 0x88, 0x33, 0x6b, 0xcf, 0xd5, 0xdb, 0x28, 0x34, 0x2c, 0x88, 0x1d, 0xe8, 0xbf, 0x29,
    0x35, 0x8c, 0xf9, 0x39, 0xa2, 0x1f, 0x56, 0xbd, 0xa6, 0xb5, 0xaa, 0xc3, 0x8b, 0x68, 0x07, 0x76,
    0xbc, 0xf3, 0x4d, 0x6b, 0x59, 0xbf, 0x04, 0x3f, 0xa6, 0xe2, 0xef, 0xbb, 0xff, 0x0d, 0xb1, 0xe7,
    0x60, 0xe9
};
#endif

PyTypeObject *init_QOAuth2DeviceAuthorizationFlow(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX].type;

    Shiboken::AutoDecRef Sbk_QOAuth2DeviceAuthorizationFlow_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth2_IDX]))));

    _Sbk_QOAuth2DeviceAuthorizationFlow_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOAuth2DeviceAuthorizationFlow",
        "QOAuth2DeviceAuthorizationFlow*",
        &Sbk_QOAuth2DeviceAuthorizationFlow_spec,
        &Shiboken::callCppDestructor< QOAuth2DeviceAuthorizationFlow >,
        Sbk_QOAuth2DeviceAuthorizationFlow_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOAuth2DeviceAuthorizationFlow_TypeF(); // references _Sbk_QOAuth2DeviceAuthorizationFlow_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOAuth2DeviceAuthorizationFlow_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOAuth2DeviceAuthorizationFlow_SignatureBytes, QOAuth2DeviceAuthorizationFlow_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOAuth2DeviceAuthorizationFlow_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth2DeviceAuthorizationFlow_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOAuth2DeviceAuthorizationFlow_PythonToCpp_QOAuth2DeviceAuthorizationFlow_PTR,
        is_QOAuth2DeviceAuthorizationFlow_PythonToCpp_QOAuth2DeviceAuthorizationFlow_PTR_Convertible,
        QOAuth2DeviceAuthorizationFlow_PTR_CppToPython_QOAuth2DeviceAuthorizationFlow);

    Shiboken::Conversions::registerConverterName(converter, "QOAuth2DeviceAuthorizationFlow");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth2DeviceAuthorizationFlow*");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth2DeviceAuthorizationFlow&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOAuth2DeviceAuthorizationFlow).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOAuth2DeviceAuthorizationFlowWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOAuth2DeviceAuthorizationFlow_TypeF(), &Sbk_QOAuth2DeviceAuthorizationFlow_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QOAuth2DeviceAuthorizationFlow::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOAuth2DeviceAuthorizationFlow::staticMetaObject, sizeof(QOAuth2DeviceAuthorizationFlowWrapper));

    return pyType;
}
