// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qoauthoobreplyhandler_wrapper.h"

// Wrappers providing overrides
#include "qabstractoauthreplyhandler_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QtNetwork/qnetworkreply.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOAuthOobReplyHandlerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOAuthOobReplyHandlerWrapper::QOAuthOobReplyHandlerWrapper(::QObject * parent) : QOAuthOobReplyHandler(parent)
{
}

::QString QOAuthOobReplyHandlerWrapper::callback() const
{
    static const char *funcName = "callback";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuthOobReplyHandler::callback();
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_callback("QOAuthOobReplyHandler", funcName, gil, pyOverride);
}

void QOAuthOobReplyHandlerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_childEvent("QOAuthOobReplyHandler", funcName, gil, pyOverride, event);
}

void QOAuthOobReplyHandlerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuthOobReplyHandler", funcName, gil, pyOverride, signal);
}

void QOAuthOobReplyHandlerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_customEvent("QOAuthOobReplyHandler", funcName, gil, pyOverride, event);
}

void QOAuthOobReplyHandlerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuthOobReplyHandler", funcName, gil, pyOverride, signal);
}

bool QOAuthOobReplyHandlerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_event("QOAuthOobReplyHandler", funcName, gil, pyOverride, event);
}

bool QOAuthOobReplyHandlerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_eventFilter("QOAuthOobReplyHandler", funcName, gil, pyOverride, watched, event);
}

void QOAuthOobReplyHandlerWrapper::networkReplyFinished(::QNetworkReply * reply)
{
    static const char *funcName = "networkReplyFinished";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuthOobReplyHandler::networkReplyFinished(reply);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_networkReplyFinished("QOAuthOobReplyHandler", funcName, gil, pyOverride, reply);
}

void QOAuthOobReplyHandlerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_timerEvent("QOAuthOobReplyHandler", funcName, gil, pyOverride, event);
}

const QMetaObject *QOAuthOobReplyHandlerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOAuthOobReplyHandler::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOAuthOobReplyHandlerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOAuthOobReplyHandler::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOAuthOobReplyHandlerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOAuthOobReplyHandlerWrapper *>(this));
    return QOAuthOobReplyHandler::qt_metacast(_clname);
}

QOAuthOobReplyHandlerWrapper::~QOAuthOobReplyHandlerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOAuthOobReplyHandler_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOAuthOobReplyHandler >()))
        return -1;

    QOAuthOobReplyHandlerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QOAuthOobReplyHandler", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOAuthOobReplyHandler::QOAuthOobReplyHandler(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QOAuthOobReplyHandler(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QOAuthOobReplyHandler(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QOAuthOobReplyHandler(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QOAuthOobReplyHandlerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QOAuthOobReplyHandlerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOAuthOobReplyHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QOAuthOobReplyHandlerFunc_callback(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthOobReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // callback()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QOAuthOobReplyHandler *>(cppSelf)->::QOAuthOobReplyHandler::callback()
            : const_cast<const ::QOAuthOobReplyHandler *>(cppSelf)->callback();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthOobReplyHandlerFunc_networkReplyFinished(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthOobReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuthReplyHandler::networkReplyFinished(QNetworkReply*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), (pyArg)))) {
        overloadId = 0; // networkReplyFinished(QNetworkReply*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "networkReplyFinished", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkReply *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // networkReplyFinished(QNetworkReply*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuthOobReplyHandler::networkReplyFinished(cppArg0)
                : cppSelf->networkReplyFinished(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QOAuthOobReplyHandler_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOAuthOobReplyHandler_methods[] = {
    {"callback", reinterpret_cast<PyCFunction>(Sbk_QOAuthOobReplyHandlerFunc_callback), METH_NOARGS, nullptr},
    {"networkReplyFinished", reinterpret_cast<PyCFunction>(Sbk_QOAuthOobReplyHandlerFunc_networkReplyFinished), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOAuthOobReplyHandler_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOAuthOobReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOAuthOobReplyHandlerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOAuthOobReplyHandler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOAuthOobReplyHandler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOAuthOobReplyHandler_Type = nullptr;
static PyTypeObject *Sbk_QOAuthOobReplyHandler_TypeF(void)
{
    return _Sbk_QOAuthOobReplyHandler_Type;
}

static PyType_Slot Sbk_QOAuthOobReplyHandler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOAuthOobReplyHandler_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOAuthOobReplyHandler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOAuthOobReplyHandler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOAuthOobReplyHandler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOAuthOobReplyHandler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOAuthOobReplyHandler_spec = {
    "2:PySide6.QtNetworkAuth.QOAuthOobReplyHandler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOAuthOobReplyHandler_slots
};

} //extern "C"

static void *Sbk_QOAuthOobReplyHandler_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOAuthOobReplyHandler *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOAuthOobReplyHandler_PythonToCpp_QOAuthOobReplyHandler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOAuthOobReplyHandler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOAuthOobReplyHandler_PythonToCpp_QOAuthOobReplyHandler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuthOobReplyHandler_TypeF()))
        return QOAuthOobReplyHandler_PythonToCpp_QOAuthOobReplyHandler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOAuthOobReplyHandler_PTR_CppToPython_QOAuthOobReplyHandler(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOAuthOobReplyHandler *>(const_cast<void *>(cppIn)), Sbk_QOAuthOobReplyHandler_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOAuthOobReplyHandler_SignatureStrings[] = {
    "PySide6.QtNetworkAuth.QOAuthOobReplyHandler(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtNetworkAuth.QOAuthOobReplyHandler.callback(self)->QString",
    "PySide6.QtNetworkAuth.QOAuthOobReplyHandler.networkReplyFinished(self,reply:PySide6.QtNetwork.QNetworkReply)",
    nullptr}; // Sentinel
#else
static constexpr size_t QOAuthOobReplyHandler_SignatureByteSize = 141;
static constexpr uint8_t QOAuthOobReplyHandler_SignatureBytes[141] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x4b, 0x2d, 0x29,
    0xcf, 0x2f, 0xca, 0x76, 0x2c, 0x2d, 0xc9, 0xd0, 0x0b, 0xf4, 0x07, 0x51, 0xfe, 0xf9, 0x49, 0x41,
    0xa9, 0x05, 0x39, 0x95, 0x1e, 0x89, 0x79, 0x29, 0x39, 0xa9, 0x45, 0x1a, 0xc5, 0xa9, 0x39, 0x69,
    0x3a, 0x05, 0x89, 0x45, 0xa9, 0x79, 0x25, 0x56, 0x01, 0x70, 0x7d, 0xce, 0xf9, 0x45, 0xa9, 0x40,
    0x0d, 0x49, 0x59, 0xa9, 0xc9, 0x25, 0xb6, 0x79, 0xa5, 0x39, 0x39, 0x05, 0x25, 0x45, 0x9a, 0x5c,
    0x01, 0xc4, 0x9b, 0xab, 0x97, 0x9c, 0x98, 0x93, 0x93, 0x94, 0x98, 0x9c, 0x0d, 0xb6, 0x40, 0x53,
    0xd7, 0x2e, 0x30, 0xb8, 0xa4, 0x28, 0x33, 0x2f, 0x9d, 0x24, 0x33, 0xf2, 0x20, 0x2a, 0xc0, 0x62,
    0x6e, 0x99, 0x79, 0x99, 0xc5, 0x19, 0xa9, 0x29, 0x10, 0x07, 0x17, 0x81, 0x84, 0xac, 0x30, 0xcc,
    0xd2, 0x0b, 0xf4, 0x43, 0xd2, 0xa2, 0xc9, 0x05, 0x00, 0xe1, 0xab, 0x62, 0x3f
};
#endif

PyTypeObject *init_QOAuthOobReplyHandler(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX].type;

    Shiboken::AutoDecRef Sbk_QOAuthOobReplyHandler_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuthReplyHandler_IDX]))));

    _Sbk_QOAuthOobReplyHandler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOAuthOobReplyHandler",
        "QOAuthOobReplyHandler*",
        &Sbk_QOAuthOobReplyHandler_spec,
        &Shiboken::callCppDestructor< QOAuthOobReplyHandler >,
        Sbk_QOAuthOobReplyHandler_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOAuthOobReplyHandler_TypeF(); // references _Sbk_QOAuthOobReplyHandler_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOAuthOobReplyHandler_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOAuthOobReplyHandler_SignatureBytes, QOAuthOobReplyHandler_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOAuthOobReplyHandler_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOAuthOobReplyHandler_PythonToCpp_QOAuthOobReplyHandler_PTR,
        is_QOAuthOobReplyHandler_PythonToCpp_QOAuthOobReplyHandler_PTR_Convertible,
        QOAuthOobReplyHandler_PTR_CppToPython_QOAuthOobReplyHandler);

    Shiboken::Conversions::registerConverterName(converter, "QOAuthOobReplyHandler");
    Shiboken::Conversions::registerConverterName(converter, "QOAuthOobReplyHandler*");
    Shiboken::Conversions::registerConverterName(converter, "QOAuthOobReplyHandler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOAuthOobReplyHandler).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOAuthOobReplyHandlerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOAuthOobReplyHandler_TypeF(), &Sbk_QOAuthOobReplyHandler_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOAuthOobReplyHandler::staticMetaObject, sizeof(QOAuthOobReplyHandlerWrapper));

    return pyType;
}
