// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qoauthurischemereplyhandler_wrapper.h"

// Wrappers providing overrides
#include "qabstractoauthreplyhandler_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qnetworkreply.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOAuthUriSchemeReplyHandlerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOAuthUriSchemeReplyHandlerWrapper::QOAuthUriSchemeReplyHandlerWrapper()
{
}

QOAuthUriSchemeReplyHandlerWrapper::QOAuthUriSchemeReplyHandlerWrapper(::QObject * parent) : QOAuthUriSchemeReplyHandler(parent)
{
}

QOAuthUriSchemeReplyHandlerWrapper::QOAuthUriSchemeReplyHandlerWrapper(const ::QUrl & redirectUrl, ::QObject * parent) : QOAuthUriSchemeReplyHandler(redirectUrl, parent)
{
}

::QString QOAuthUriSchemeReplyHandlerWrapper::callback() const
{
    static const char *funcName = "callback";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuthUriSchemeReplyHandler::callback();
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_callback("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride);
}

void QOAuthUriSchemeReplyHandlerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_childEvent("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, event);
}

void QOAuthUriSchemeReplyHandlerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, signal);
}

void QOAuthUriSchemeReplyHandlerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_customEvent("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, event);
}

void QOAuthUriSchemeReplyHandlerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, signal);
}

bool QOAuthUriSchemeReplyHandlerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_event("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, event);
}

bool QOAuthUriSchemeReplyHandlerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_eventFilter("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, watched, event);
}

void QOAuthUriSchemeReplyHandlerWrapper::networkReplyFinished(::QNetworkReply * reply)
{
    static const char *funcName = "networkReplyFinished";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuthOobReplyHandler::networkReplyFinished(reply);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_networkReplyFinished("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, reply);
}

void QOAuthUriSchemeReplyHandlerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_timerEvent("QOAuthUriSchemeReplyHandler", funcName, gil, pyOverride, event);
}

const QMetaObject *QOAuthUriSchemeReplyHandlerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOAuthUriSchemeReplyHandler::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOAuthUriSchemeReplyHandlerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOAuthUriSchemeReplyHandler::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOAuthUriSchemeReplyHandlerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOAuthUriSchemeReplyHandlerWrapper *>(this));
    return QOAuthUriSchemeReplyHandler::qt_metacast(_clname);
}

QOAuthUriSchemeReplyHandlerWrapper::~QOAuthUriSchemeReplyHandlerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOAuthUriSchemeReplyHandler_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOAuthUriSchemeReplyHandler >()))
        return -1;

    QOAuthUriSchemeReplyHandlerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QOAuthUriSchemeReplyHandler", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOAuthUriSchemeReplyHandler::QOAuthUriSchemeReplyHandler()
    // 1: QOAuthUriSchemeReplyHandler::QOAuthUriSchemeReplyHandler(QObject*)
    // 2: QOAuthUriSchemeReplyHandler::QOAuthUriSchemeReplyHandler(QUrl,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QOAuthUriSchemeReplyHandler()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QOAuthUriSchemeReplyHandler(QUrl,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QOAuthUriSchemeReplyHandler(QUrl,QObject*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOAuthUriSchemeReplyHandler(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOAuthUriSchemeReplyHandler()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);
            }

            // QOAuthUriSchemeReplyHandler()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QOAuthUriSchemeReplyHandlerWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QOAuthUriSchemeReplyHandlerWrapper();
            }

            break;
        }
        case 1: // QOAuthUriSchemeReplyHandler(QObject *parent)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuthUriSchemeReplyHandler(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuthUriSchemeReplyHandlerWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuthUriSchemeReplyHandlerWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 2: // QOAuthUriSchemeReplyHandler(const QUrl &redirectUrl, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuthUriSchemeReplyHandler(QUrl,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuthUriSchemeReplyHandlerWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuthUriSchemeReplyHandlerWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOAuthUriSchemeReplyHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QOAuthUriSchemeReplyHandlerFunc_callback(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // callback()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QOAuthUriSchemeReplyHandler *>(cppSelf)->::QOAuthUriSchemeReplyHandler::callback()
            : const_cast<const ::QOAuthUriSchemeReplyHandler *>(cppSelf)->callback();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthUriSchemeReplyHandlerFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuthUriSchemeReplyHandlerFunc_handleAuthorizationRedirect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuthUriSchemeReplyHandler::handleAuthorizationRedirect(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // handleAuthorizationRedirect(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "handleAuthorizationRedirect", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // handleAuthorizationRedirect(QUrl)
            bool cppResult = cppSelf->handleAuthorizationRedirect(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthUriSchemeReplyHandlerFunc_isListening(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isListening()const
        bool cppResult = const_cast<const ::QOAuthUriSchemeReplyHandler *>(cppSelf)->isListening();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthUriSchemeReplyHandlerFunc_listen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // listen()
        bool cppResult = cppSelf->listen();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthUriSchemeReplyHandlerFunc_redirectUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // redirectUrl()const
        QUrl cppResult = const_cast<const ::QOAuthUriSchemeReplyHandler *>(cppSelf)->redirectUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthUriSchemeReplyHandlerFunc_setRedirectUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuthUriSchemeReplyHandler::setRedirectUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setRedirectUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRedirectUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRedirectUrl(QUrl)
            cppSelf->setRedirectUrl(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QOAuthUriSchemeReplyHandler_PropertyStrings[] = {
    "redirectUrl::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOAuthUriSchemeReplyHandler_methods[] = {
    {"callback", reinterpret_cast<PyCFunction>(Sbk_QOAuthUriSchemeReplyHandlerFunc_callback), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QOAuthUriSchemeReplyHandlerFunc_close), METH_NOARGS, nullptr},
    {"handleAuthorizationRedirect", reinterpret_cast<PyCFunction>(Sbk_QOAuthUriSchemeReplyHandlerFunc_handleAuthorizationRedirect), METH_O, nullptr},
    {"isListening", reinterpret_cast<PyCFunction>(Sbk_QOAuthUriSchemeReplyHandlerFunc_isListening), METH_NOARGS, nullptr},
    {"listen", reinterpret_cast<PyCFunction>(Sbk_QOAuthUriSchemeReplyHandlerFunc_listen), METH_NOARGS, nullptr},
    {"redirectUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuthUriSchemeReplyHandlerFunc_redirectUrl), METH_NOARGS, nullptr},
    {"setRedirectUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuthUriSchemeReplyHandlerFunc_setRedirectUrl), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOAuthUriSchemeReplyHandler_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOAuthUriSchemeReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOAuthUriSchemeReplyHandlerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOAuthUriSchemeReplyHandler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOAuthUriSchemeReplyHandler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOAuthUriSchemeReplyHandler_Type = nullptr;
static PyTypeObject *Sbk_QOAuthUriSchemeReplyHandler_TypeF(void)
{
    return _Sbk_QOAuthUriSchemeReplyHandler_Type;
}

static PyType_Slot Sbk_QOAuthUriSchemeReplyHandler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOAuthUriSchemeReplyHandler_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOAuthUriSchemeReplyHandler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOAuthUriSchemeReplyHandler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOAuthUriSchemeReplyHandler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOAuthUriSchemeReplyHandler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOAuthUriSchemeReplyHandler_spec = {
    "2:PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOAuthUriSchemeReplyHandler_slots
};

} //extern "C"

static void *Sbk_QOAuthUriSchemeReplyHandler_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOAuthUriSchemeReplyHandler *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOAuthUriSchemeReplyHandler_PythonToCpp_QOAuthUriSchemeReplyHandler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOAuthUriSchemeReplyHandler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOAuthUriSchemeReplyHandler_PythonToCpp_QOAuthUriSchemeReplyHandler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuthUriSchemeReplyHandler_TypeF()))
        return QOAuthUriSchemeReplyHandler_PythonToCpp_QOAuthUriSchemeReplyHandler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOAuthUriSchemeReplyHandler_PTR_CppToPython_QOAuthUriSchemeReplyHandler(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOAuthUriSchemeReplyHandler *>(const_cast<void *>(cppIn)), Sbk_QOAuthUriSchemeReplyHandler_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOAuthUriSchemeReplyHandler_SignatureStrings[] = {
    "2:PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler(self,*:KeywordOnly=None,redirectUrl:QUrl=None)",
    "1:PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler(self,parent:PySide6.QtCore.QObject,*:KeywordOnly=None,redirectUrl:QUrl=None)",
    "0:PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler(self,redirectUrl:typing.Union[PySide6.QtCore.QUrl, QString],parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,redirectUrl:QUrl=None)",
    "PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler.callback(self)->QString",
    "PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler.close(self)",
    "PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler.handleAuthorizationRedirect(self,url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    "PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler.isListening(self)->bool",
    "PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler.listen(self)->bool",
    "PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler.redirectUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QOAuthUriSchemeReplyHandler.setRedirectUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    nullptr}; // Sentinel
#else
static constexpr size_t QOAuthUriSchemeReplyHandler_SignatureByteSize = 255;
static constexpr uint8_t QOAuthUriSchemeReplyHandler_SignatureBytes[255] = {
    0x78, 0xda, 0xa5, 0x91, 0x41, 0x4b, 0xc3, 0x40, 0x10, 0x85, 0xef, 0xfd, 0x15, 0x1e, 0xad, 0xc4,
    0xa0, 0x1e, 0x3c, 0x04, 0x2a, 0x88, 0x97, 0x82, 0xd2, 0x9a, 0x84, 0x9c, 0xc4, 0xc3, 0x26, 0x19,
    0xcd, 0xb6, 0xe3, 0x6c, 0x98, 0x9d, 0x20, 0xeb, 0xaf, 0x77, 0x9b, 0xb6, 0x10, 0x8a, 0x08, 0xbb,
    0xbd, 0xec, 0xc0, 0xee, 0xcc, 0x37, 0xef, 0xbd, 0xbd, 0xcb, 0x5e, 0x5d, 0xa9, 0x5b, 0xb8, 0x4f,
    0x73, 0x59, 0x81, 0x7c, 0x1b, 0xde, 0x3e, 0x0e, 0xd2, 0xa5, 0xf9, 0x7a, 0x57, 0x2a, 0xd6, 0x65,
    0xd3, 0xc1, 0x17, 0x14, 0xd0, 0xa3, 0x5b, 0x2a, 0x6a, 0x11, 0xf8, 0xd2, 0x02, 0x7e, 0x24, 0x57,
    0xd9, 0x33, 0x38, 0xdf, 0xde, 0xae, 0x09, 0xdd, 0x62, 0x65, 0x08, 0x12, 0x86, 0x56, 0x33, 0x34,
    0x52, 0x31, 0x66, 0xb9, 0x3f, 0xc6, 0xdb, 0xf9, 0xec, 0x36, 0x76, 0x45, 0xaf, 0x18, 0x48, 0x26,
    0xd3, 0x4f, 0x86, 0xc1, 0x8f, 0xd5, 0x1b, 0xbf, 0x24, 0x40, 0xc0, 0x4d, 0xac, 0x80, 0x29, 0x4f,
    0x5c, 0xaf, 0xe9, 0x33, 0xad, 0x48, 0x1b, 0x7a, 0x3b, 0x95, 0xe4, 0x1b, 0x92, 0x8b, 0xbc, 0x14,
    0xf6, 0x2d, 0xef, 0xff, 0xeb, 0x5e, 0xd0, 0x80, 0xd8, 0x0b, 0x07, 0xe8, 0x0f, 0x56, 0x9f, 0x36,
    0x0a, 0xb1, 0x56, 0xcd, 0x76, 0xb4, 0x31, 0xbf, 0x7e, 0x38, 0x48, 0x8b, 0x21, 0xa1, 0xb1, 0xb0,
    0xc7, 0x44, 0x4c, 0x77, 0x63, 0xdd, 0xbd, 0x1b, 0xd6, 0x3f, 0x4a, 0x7c, 0x76, 0xc5, 0xc1, 0xe3,
    0x3e, 0xe1, 0x21, 0x28, 0x59, 0xef, 0xa4, 0x36, 0x06, 0x23, 0x84, 0x68, 0xfb, 0xa2, 0xad, 0x00,
    0x79, 0xca, 0x31, 0x93, 0x48, 0x12, 0x8e, 0x9c, 0x33, 0x21, 0x93, 0x8f, 0x3e, 0x92, 0xfe, 0x30,
    0x1e, 0x01, 0xb6, 0x20, 0xc5, 0x09, 0x3b, 0x34, 0xe3, 0xd9, 0x2f, 0x2a, 0xf2, 0x7f, 0xd5
};
#endif

PyTypeObject *init_QOAuthUriSchemeReplyHandler(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX].type;

    Shiboken::AutoDecRef Sbk_QOAuthUriSchemeReplyHandler_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]))));

    _Sbk_QOAuthUriSchemeReplyHandler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOAuthUriSchemeReplyHandler",
        "QOAuthUriSchemeReplyHandler*",
        &Sbk_QOAuthUriSchemeReplyHandler_spec,
        &Shiboken::callCppDestructor< QOAuthUriSchemeReplyHandler >,
        Sbk_QOAuthUriSchemeReplyHandler_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOAuthUriSchemeReplyHandler_TypeF(); // references _Sbk_QOAuthUriSchemeReplyHandler_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOAuthUriSchemeReplyHandler_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOAuthUriSchemeReplyHandler_SignatureBytes, QOAuthUriSchemeReplyHandler_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOAuthUriSchemeReplyHandler_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthUriSchemeReplyHandler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOAuthUriSchemeReplyHandler_PythonToCpp_QOAuthUriSchemeReplyHandler_PTR,
        is_QOAuthUriSchemeReplyHandler_PythonToCpp_QOAuthUriSchemeReplyHandler_PTR_Convertible,
        QOAuthUriSchemeReplyHandler_PTR_CppToPython_QOAuthUriSchemeReplyHandler);

    Shiboken::Conversions::registerConverterName(converter, "QOAuthUriSchemeReplyHandler");
    Shiboken::Conversions::registerConverterName(converter, "QOAuthUriSchemeReplyHandler*");
    Shiboken::Conversions::registerConverterName(converter, "QOAuthUriSchemeReplyHandler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOAuthUriSchemeReplyHandler).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOAuthUriSchemeReplyHandlerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOAuthUriSchemeReplyHandler_TypeF(), &Sbk_QOAuthUriSchemeReplyHandler_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QOAuthUriSchemeReplyHandler::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOAuthUriSchemeReplyHandler::staticMetaObject, sizeof(QOAuthUriSchemeReplyHandlerWrapper));

    return pyType;
}
