// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QOPENGLPAINTDEVICEWRAPPER_H
#define SBK_QOPENGLPAINTDEVICEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtOpenGL/qopenglpaintdevice.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QOpenGLPaintDeviceWrapper : public QOpenGLPaintDevice
{
public:
    QOpenGLPaintDeviceWrapper();
    QOpenGLPaintDeviceWrapper(const ::QSize & size);
    QOpenGLPaintDeviceWrapper(int width, int height);
    QOpenGLPaintDeviceWrapper(const QOpenGLPaintDeviceWrapper &) = delete;
    QOpenGLPaintDeviceWrapper& operator=(const QOpenGLPaintDeviceWrapper &) = delete;
    QOpenGLPaintDeviceWrapper(QOpenGLPaintDeviceWrapper &&) = delete;
    QOpenGLPaintDeviceWrapper& operator=(QOpenGLPaintDeviceWrapper &&) = delete;
    ~QOpenGLPaintDeviceWrapper() override;

    int devType() const override;
    static int sbk_o_devType(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void ensureActiveTarget() override;
    static void sbk_o_ensureActiveTarget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void initPainter(::QPainter * painter) const override;
    static void sbk_o_initPainter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter);
    int metric(::QPaintDevice::PaintDeviceMetric metric) const override;
    static int sbk_o_metric(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPaintDevice::PaintDeviceMetric metric);
    ::QPaintEngine * paintEngine() const override;
    static ::QPaintEngine * sbk_o_paintEngine(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    static ::QPaintDevice * sbk_o_redirected(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPoint * offset);
    ::QPainter * sharedPainter() const override;
    static ::QPainter * sbk_o_sharedPainter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[7] = {false, false, false, false, false, false, false};
};

#endif // SBK_QOPENGLPAINTDEVICEWRAPPER_H
