// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QOPENGLWINDOWWRAPPER_H
#define SBK_QOPENGLWINDOWWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtOpenGL/qopenglwindow.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QOpenGLWindowWrapper : public QOpenGLWindow
{
public:
    QOpenGLWindowWrapper(::QOpenGLContext * shareContext, ::QOpenGLWindow::UpdateBehavior updateBehavior = QOpenGLWindow::UpdateBehavior::NoPartialUpdate, ::QWindow * parent = nullptr);
    QOpenGLWindowWrapper(::QOpenGLWindow::UpdateBehavior updateBehavior = QOpenGLWindow::UpdateBehavior::NoPartialUpdate, ::QWindow * parent = nullptr);
    QOpenGLWindowWrapper(const QOpenGLWindowWrapper &) = delete;
    QOpenGLWindowWrapper& operator=(const QOpenGLWindowWrapper &) = delete;
    QOpenGLWindowWrapper(QOpenGLWindowWrapper &&) = delete;
    QOpenGLWindowWrapper& operator=(QOpenGLWindowWrapper &&) = delete;
    ~QOpenGLWindowWrapper() override;

    ::QAccessibleInterface * accessibleRoot() const override;
    static ::QAccessibleInterface * sbk_o_accessibleRoot(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void childEvent(::QChildEvent * event) override;
    void closeEvent(::QCloseEvent * arg__1) override;
    static void sbk_o_closeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QCloseEvent * arg__1);
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    int devType() const override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void exposeEvent(::QExposeEvent * arg__1) override;
    static void sbk_o_exposeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QExposeEvent * arg__1);
    void focusInEvent(::QFocusEvent * arg__1) override;
    static void sbk_o_focusInEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFocusEvent * arg__1);
    ::QObject * focusObject() const override;
    static ::QObject * sbk_o_focusObject(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void focusOutEvent(::QFocusEvent * arg__1) override;
    ::QSurfaceFormat format() const override;
    static ::QSurfaceFormat sbk_o_format(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void hideEvent(::QHideEvent * arg__1) override;
    static void sbk_o_hideEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QHideEvent * arg__1);
    void initPainter(::QPainter * painter) const override;
    void initializeGL() override;
    void keyPressEvent(::QKeyEvent * arg__1) override;
    static void sbk_o_keyPressEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QKeyEvent * arg__1);
    void keyReleaseEvent(::QKeyEvent * arg__1) override;
    int metric(::QPaintDevice::PaintDeviceMetric metric) const override;
    void mouseDoubleClickEvent(::QMouseEvent * arg__1) override;
    static void sbk_o_mouseDoubleClickEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QMouseEvent * arg__1);
    void mouseMoveEvent(::QMouseEvent * arg__1) override;
    void mousePressEvent(::QMouseEvent * arg__1) override;
    void mouseReleaseEvent(::QMouseEvent * arg__1) override;
    void moveEvent(::QMoveEvent * arg__1) override;
    static void sbk_o_moveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QMoveEvent * arg__1);
    bool nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result) override;
    static bool sbk_o_nativeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QByteArray & eventType, void * message, ::qintptr * result);
    void paintEvent(::QPaintEvent * event) override;
    static void sbk_o_paintEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPaintEvent * event);
    void paintGL() override;
    void paintOverGL() override;
    void paintUnderGL() override;
    ::QPaintDevice * redirected(::QPoint * arg__1) const override;
    void resizeEvent(::QResizeEvent * event) override;
    static void sbk_o_resizeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QResizeEvent * event);
    void resizeGL(int w, int h) override;
    static void sbk_o_resizeGL(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int w, int h);
    ::QPainter * sharedPainter() const override;
    void showEvent(::QShowEvent * arg__1) override;
    static void sbk_o_showEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QShowEvent * arg__1);
    ::QSize size() const override;
    static ::QSize sbk_o_size(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QSurface::SurfaceType surfaceType() const override;
    static ::QSurface::SurfaceType sbk_o_surfaceType(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void tabletEvent(::QTabletEvent * arg__1) override;
    static void sbk_o_tabletEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTabletEvent * arg__1);
    void timerEvent(::QTimerEvent * event) override;
    void touchEvent(::QTouchEvent * arg__1) override;
    static void sbk_o_touchEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTouchEvent * arg__1);
    void wheelEvent(::QWheelEvent * arg__1) override;
    static void sbk_o_wheelEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWheelEvent * arg__1);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[41] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QOPENGLWINDOWWRAPPER_H
