// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QNMEASATELLITEINFOSOURCEWRAPPER_H
#define SBK_QNMEASATELLITEINFOSOURCEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtPositioning/qnmeasatelliteinfosource.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QNmeaSatelliteInfoSourceWrapper : public QNmeaSatelliteInfoSource
{
public:
    QNmeaSatelliteInfoSourceWrapper(::QNmeaSatelliteInfoSource::UpdateMode mode, ::QObject * parent = nullptr);
    QNmeaSatelliteInfoSourceWrapper(const QNmeaSatelliteInfoSourceWrapper &) = delete;
    QNmeaSatelliteInfoSourceWrapper& operator=(const QNmeaSatelliteInfoSourceWrapper &) = delete;
    QNmeaSatelliteInfoSourceWrapper(QNmeaSatelliteInfoSourceWrapper &&) = delete;
    QNmeaSatelliteInfoSourceWrapper& operator=(QNmeaSatelliteInfoSourceWrapper &&) = delete;
    ~QNmeaSatelliteInfoSourceWrapper() override;

    ::QVariant backendProperty(const ::QString & name) const override;
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QGeoSatelliteInfoSource::Error error() const override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    int minimumUpdateInterval() const override;
    ::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus parseSatelliteInfoFromNmea(const char * data, int size, ::QList<QGeoSatelliteInfo> & infos, ::QGeoSatelliteInfo::SatelliteSystem & system) override;
    static ::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus sbk_o_parseSatelliteInfoFromNmea(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * data, int size, ::QList<QGeoSatelliteInfo> & infos, ::QGeoSatelliteInfo::SatelliteSystem & system);
    // Inherited overloads, because the using keyword sux
    ::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus parseSatelliteInfoFromNmea(::QByteArrayView data, ::QList<QGeoSatelliteInfo> & infos, ::QGeoSatelliteInfo::SatelliteSystem & system) { return QNmeaSatelliteInfoSource::parseSatelliteInfoFromNmea(data, infos, system); }

    ::QGeoSatelliteInfo::SatelliteSystem parseSatellitesInUseFromNmea(const char * data, int size, ::QList<int> & pnrsInUse) override;
    static ::QGeoSatelliteInfo::SatelliteSystem sbk_o_parseSatellitesInUseFromNmea(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * data, int size, ::QList<int> & pnrsInUse);
    // Inherited overloads, because the using keyword sux
    ::QGeoSatelliteInfo::SatelliteSystem parseSatellitesInUseFromNmea(::QByteArrayView data, ::QList<int> & pnrsInUse) { return QNmeaSatelliteInfoSource::parseSatellitesInUseFromNmea(data, pnrsInUse); }

    void requestUpdate(int timeout = 0) override;
    bool setBackendProperty(const ::QString & name, const ::QVariant & value) override;
    void setUpdateInterval(int msec) override;
    void startUpdates() override;
    void stopUpdates() override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[17] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QNMEASATELLITEINFOSOURCEWRAPPER_H
