// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtprintsupport_python.h"

// main header
#include "qabstractprintdialog_wrapper.h"

// Wrappers providing overrides
#include "qprinter_wrapper.h"
#include "qprintengine_wrapper.h"
#include "qprintpreviewdialog_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtPrintSupport/qabstractprintdialog.h>
#include <QtPrintSupport/qprinter.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractPrintDialogWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractPrintDialogWrapper::QAbstractPrintDialogWrapper(::QPrinter * printer, ::QWidget * parent) : QAbstractPrintDialog(printer, parent)
{
}

void QAbstractPrintDialogWrapper::accept()
{
    static const char *funcName = "accept";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::accept();
    }
    QPrintPreviewDialogWrapper::sbk_o_accept("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_actionEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_changeEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_childEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::closeEvent(::QCloseEvent * arg__1)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::closeEvent(arg__1);
    }
    QPrintPreviewDialogWrapper::sbk_o_closeEvent("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

void QAbstractPrintDialogWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QPrintPreviewDialogWrapper::sbk_o_connectNotify("QAbstractPrintDialog", funcName, gil, pyOverride, signal);
}

void QAbstractPrintDialogWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::contextMenuEvent(arg__1);
    }
    QPrintPreviewDialogWrapper::sbk_o_contextMenuEvent("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

void QAbstractPrintDialogWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_customEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

int QAbstractPrintDialogWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QPrinterWrapper::sbk_o_devType("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QPrintPreviewDialogWrapper::sbk_o_connectNotify("QAbstractPrintDialog", funcName, gil, pyOverride, signal);
}

void QAbstractPrintDialogWrapper::done(int arg__1)
{
    static const char *funcName = "done";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::done(arg__1);
    }
    QPrintPreviewDialogWrapper::sbk_o_done("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

void QAbstractPrintDialogWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_dragEnterEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_dragLeaveEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_dragMoveEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_dropEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_enterEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

bool QAbstractPrintDialogWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::event(event);
    }
    return QPrintPreviewDialogWrapper::sbk_o_event("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

bool QAbstractPrintDialogWrapper::eventFilter(::QObject * arg__1, ::QEvent * arg__2)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::eventFilter(arg__1, arg__2);
    }
    return QPrintPreviewDialogWrapper::sbk_o_eventFilter("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1, arg__2);
}

int QAbstractPrintDialogWrapper::exec()
{
    static const char *funcName = "exec";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::exec();
    }
    return QPrintPreviewDialogWrapper::sbk_o_exec("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_focusInEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

bool QAbstractPrintDialogWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QPrintPreviewDialogWrapper::sbk_o_focusNextPrevChild("QAbstractPrintDialog", funcName, gil, pyOverride, next);
}

void QAbstractPrintDialogWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_focusOutEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

bool QAbstractPrintDialogWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QPrintEngineWrapper::sbk_o_abort("QAbstractPrintDialog", funcName, gil, pyOverride);
}

int QAbstractPrintDialogWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QPrintPreviewDialogWrapper::sbk_o_heightForWidth("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

void QAbstractPrintDialogWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_hideEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QPrinterWrapper::sbk_o_initPainter("QAbstractPrintDialog", funcName, gil, pyOverride, painter);
}

void QAbstractPrintDialogWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_inputMethodEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

::QVariant QAbstractPrintDialogWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QPrintPreviewDialogWrapper::sbk_o_inputMethodQuery("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

void QAbstractPrintDialogWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::keyPressEvent(arg__1);
    }
    QPrintPreviewDialogWrapper::sbk_o_keyPressEvent("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

void QAbstractPrintDialogWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_keyReleaseEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_leaveEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

int QAbstractPrintDialogWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QPrintEngineWrapper::sbk_o_metric("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

::QSize QAbstractPrintDialogWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::minimumSizeHint();
    }
    return QPrintPreviewDialogWrapper::sbk_o_minimumSizeHint("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_mouseDoubleClickEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_mouseMoveEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_mousePressEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_mouseReleaseEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_moveEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

bool QAbstractPrintDialogWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QPrintPreviewDialogWrapper::sbk_o_nativeEvent("QAbstractPrintDialog", funcName, gil, pyOverride, eventType, message, result);
}

void QAbstractPrintDialogWrapper::open()
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::open();
    }
    QPrintPreviewDialogWrapper::sbk_o_accept("QAbstractPrintDialog", funcName, gil, pyOverride);
}

::QPaintEngine * QAbstractPrintDialogWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QPrinterWrapper::sbk_o_paintEngine("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_paintEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

::QPaintDevice * QAbstractPrintDialogWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QPrinterWrapper::sbk_o_redirected("QAbstractPrintDialog", funcName, gil, pyOverride, offset);
}

void QAbstractPrintDialogWrapper::reject()
{
    static const char *funcName = "reject";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::reject();
    }
    QPrintPreviewDialogWrapper::sbk_o_accept("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::resizeEvent(::QResizeEvent * arg__1)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::resizeEvent(arg__1);
    }
    QPrintPreviewDialogWrapper::sbk_o_resizeEvent("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

void QAbstractPrintDialogWrapper::setVisible(bool visible)
{
    static const char *funcName = "setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::setVisible(visible);
    }
    QPrintPreviewDialogWrapper::sbk_o_setVisible("QAbstractPrintDialog", funcName, gil, pyOverride, visible);
}

::QPainter * QAbstractPrintDialogWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QPrinterWrapper::sbk_o_sharedPainter("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::showEvent(::QShowEvent * arg__1)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::showEvent(arg__1);
    }
    QPrintPreviewDialogWrapper::sbk_o_showEvent("QAbstractPrintDialog", funcName, gil, pyOverride, arg__1);
}

::QSize QAbstractPrintDialogWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::sizeHint();
    }
    return QPrintPreviewDialogWrapper::sbk_o_minimumSizeHint("QAbstractPrintDialog", funcName, gil, pyOverride);
}

void QAbstractPrintDialogWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_tabletEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_timerEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

void QAbstractPrintDialogWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QPrintPreviewDialogWrapper::sbk_o_wheelEvent("QAbstractPrintDialog", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstractPrintDialogWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractPrintDialog::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractPrintDialogWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractPrintDialog::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractPrintDialogWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractPrintDialogWrapper *>(this));
    return QAbstractPrintDialog::qt_metacast(_clname);
}

QAbstractPrintDialogWrapper::~QAbstractPrintDialogWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractPrintDialog_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractPrintDialog >()))
        return -1;

    QAbstractPrintDialogWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QAbstractPrintDialog", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractPrintDialog::QAbstractPrintDialog(QPrinter*,QWidget*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QAbstractPrintDialog(QPrinter*,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QAbstractPrintDialog(QPrinter*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QPrinter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QWidget *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractPrintDialog(QPrinter*,QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAbstractPrintDialogWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAbstractPrintDialogWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractPrintDialog >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAbstractPrintDialogFunc_fromPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fromPage()const
        int cppResult = const_cast<const ::QAbstractPrintDialog *>(cppSelf)->fromPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractPrintDialogFunc_maxPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxPage()const
        int cppResult = const_cast<const ::QAbstractPrintDialog *>(cppSelf)->maxPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractPrintDialogFunc_minPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minPage()const
        int cppResult = const_cast<const ::QAbstractPrintDialog *>(cppSelf)->minPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractPrintDialogFunc_printRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // printRange()const
        QAbstractPrintDialog::PrintRange cppResult = const_cast<const ::QAbstractPrintDialog *>(cppSelf)->printRange();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintRange_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractPrintDialogFunc_printer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // printer()const
        QPrinter * cppResult = const_cast<const ::QAbstractPrintDialog *>(cppSelf)->printer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractPrintDialogFunc_setFromTo(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFromTo", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractPrintDialog::setFromTo(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setFromTo(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFromTo", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFromTo(int,int)
            cppSelf->setFromTo(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractPrintDialogFunc_setMinMax(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMinMax", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractPrintDialog::setMinMax(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setMinMax(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMinMax", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinMax(int,int)
            cppSelf->setMinMax(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractPrintDialogFunc_setOptionTabs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPrintDialog::setOptionTabs(QList<QWidget*>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QWidgetPTR_IDX], (pyArg)))) {
        overloadId = 0; // setOptionTabs(QList<QWidget*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOptionTabs", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);

    // Call function/method
    {
        ::QList<QWidget*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptionTabs(QList<QWidget*>)
            cppSelf->setOptionTabs(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractPrintDialogFunc_setPrintRange(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPrintDialog::setPrintRange(QAbstractPrintDialog::PrintRange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintRange_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPrintRange(QAbstractPrintDialog::PrintRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPrintRange", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]);

    // Call function/method
    {
        ::QAbstractPrintDialog::PrintRange cppArg0{QAbstractPrintDialog::AllPages};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrintRange(QAbstractPrintDialog::PrintRange)
            cppSelf->setPrintRange(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractPrintDialogFunc_toPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPage()const
        int cppResult = const_cast<const ::QAbstractPrintDialog *>(cppSelf)->toPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QAbstractPrintDialog_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QAbstractPrintDialog_EnumFlagInfo[] = {
    "PrintDialogOption:Flag:PrintDialogOptions",
    "PrintRange:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractPrintDialog_methods[] = {
    {"fromPage", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_fromPage), METH_NOARGS, nullptr},
    {"maxPage", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_maxPage), METH_NOARGS, nullptr},
    {"minPage", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_minPage), METH_NOARGS, nullptr},
    {"printRange", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_printRange), METH_NOARGS, nullptr},
    {"printer", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_printer), METH_NOARGS, nullptr},
    {"setFromTo", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_setFromTo), METH_VARARGS, nullptr},
    {"setMinMax", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_setMinMax), METH_VARARGS, nullptr},
    {"setOptionTabs", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_setOptionTabs), METH_O, nullptr},
    {"setPrintRange", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_setPrintRange), METH_O, nullptr},
    {"toPage", reinterpret_cast<PyCFunction>(Sbk_QAbstractPrintDialogFunc_toPage), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractPrintDialog_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractPrintDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractPrintDialogWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractPrintDialog_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractPrintDialog_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QAbstractPrintDialogSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QAbstractPrintDialog *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX]))
        return static_cast< ::QDialog *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractPrintDialog_Type = nullptr;
static PyTypeObject *Sbk_QAbstractPrintDialog_TypeF(void)
{
    return _Sbk_QAbstractPrintDialog_Type;
}

static PyType_Slot Sbk_QAbstractPrintDialog_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractPrintDialog_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractPrintDialog_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractPrintDialog_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractPrintDialog_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractPrintDialog_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractPrintDialog_spec = {
    "2:PySide6.QtPrintSupport.QAbstractPrintDialog",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractPrintDialog_slots
};

} //extern "C"

static void *Sbk_QAbstractPrintDialog_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QAbstractPrintDialog *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractPrintDialog *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QAbstractPrintDialog *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractPrintDialog_PrintRange(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractPrintDialog::PrintRange>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractPrintDialog::PrintRange *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractPrintDialog_PrintRange_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintRange_IDX])))
        return Enum_PythonToCpp_QAbstractPrintDialog_PrintRange;
    return {};
}

static PyObject *QAbstractPrintDialog_PrintRange_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractPrintDialog::PrintRange>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractPrintDialog::PrintRange *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintRange_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractPrintDialog_PrintDialogOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractPrintDialog::PrintDialogOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractPrintDialog::PrintDialogOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractPrintDialog_PrintDialogOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintDialogOption_IDX])))
        return Enum_PythonToCpp_QAbstractPrintDialog_PrintDialogOption;
    return {};
}

static PyObject *QAbstractPrintDialog_PrintDialogOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractPrintDialog::PrintDialogOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractPrintDialog::PrintDialogOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintDialogOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QAbstractPrintDialog_PrintDialogOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QAbstractPrintDialog::PrintDialogOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QAbstractPrintDialog::PrintDialogOption> *>(cppOut) = value;

}

static PyObject *QAbstractPrintDialog_PrintDialogOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QAbstractPrintDialog::PrintDialogOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintDialogOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractPrintDialog_PythonToCpp_QAbstractPrintDialog_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractPrintDialog_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractPrintDialog_PythonToCpp_QAbstractPrintDialog_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractPrintDialog_TypeF()))
        return QAbstractPrintDialog_PythonToCpp_QAbstractPrintDialog_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractPrintDialog_PTR_CppToPython_QAbstractPrintDialog(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractPrintDialog *>(const_cast<void *>(cppIn)), Sbk_QAbstractPrintDialog_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractPrintDialog_SignatureStrings[] = {
    "PySide6.QtPrintSupport.QAbstractPrintDialog(self,printer:PySide6.QtPrintSupport.QPrinter,parent:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.fromPage(self)->int",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.maxPage(self)->int",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.minPage(self)->int",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.printRange(self)->PySide6.QtPrintSupport.QAbstractPrintDialog.PrintRange",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.printer(self)->PySide6.QtPrintSupport.QPrinter",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.setFromTo(self,fromPage:int,toPage:int)",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.setMinMax(self,min:int,max:int)",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.setOptionTabs(self,tabs:QList[PySide6.QtWidgets.QWidget])",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.setPrintRange(self,range:PySide6.QtPrintSupport.QAbstractPrintDialog.PrintRange)",
    "PySide6.QtPrintSupport.QAbstractPrintDialog.toPage(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractPrintDialog_SignatureByteSize = 227;
static constexpr uint8_t QAbstractPrintDialog_SignatureBytes[227] = {
    0x78, 0xda, 0xa5, 0x52, 0xcb, 0x0a, 0xc2, 0x30, 0x10, 0xbc, 0xfb, 0x25, 0x16, 0x62, 0x8e, 0x1e,
    0x0a, 0x0a, 0x82, 0x78, 0x52, 0x4c, 0xad, 0xe0, 0x41, 0x3c, 0xa4, 0x36, 0x96, 0x40, 0x9b, 0x84,
    0xcd, 0x16, 0xf4, 0xef, 0x8d, 0x8d, 0x8f, 0x7a, 0x28, 0x9a, 0xf6, 0x36, 0xec, 0xee, 0xcc, 0x2c,
    0x3b, 0xcb, 0x6e, 0xa9, 0xcc, 0xc5, 0x94, 0x26, 0xc8, 0x40, 0x2a, 0x4c, 0x6b, 0x63, 0x34, 0x20,
    0x4d, 0x16, 0x99, 0x45, 0xe0, 0x67, 0x5f, 0x5d, 0x4a, 0x5e, 0xea, 0x62, 0x6c, 0x45, 0x79, 0x21,
    0xe6, 0x51, 0x10, 0x10, 0xb3, 0x0e, 0x22, 0xf3, 0x7d, 0x62, 0x38, 0x08, 0x85, 0xad, 0xb1, 0x83,
    0xcc, 0x0b, 0x81, 0x96, 0x26, 0x1e, 0xcc, 0x54, 0x5d, 0x96, 0x06, 0x21, 0x1a, 0xb1, 0xff, 0x57,
    0xa0, 0x17, 0xd0, 0x15, 0xe3, 0x85, 0x68, 0x76, 0x89, 0x26, 0x73, 0xd7, 0x09, 0xe2, 0x57, 0xfc,
    0x3a, 0x88, 0x2e, 0xd5, 0x10, 0x7a, 0x73, 0xbb, 0x1d, 0x57, 0x1f, 0x85, 0x10, 0x36, 0x7b, 0xb3,
    0xc3, 0x4d, 0x05, 0xfc, 0x72, 0x7c, 0xe6, 0x16, 0x24, 0x6d, 0x05, 0xae, 0x5c, 0x20, 0x7b, 0xed,
    0x5f, 0xe3, 0x15, 0x4e, 0xec, 0x26, 0x08, 0xea, 0x17, 0x8c, 0x42, 0x35, 0x37, 0x52, 0x6d, 0xf8,
    0xd5, 0x6b, 0xba, 0x8b, 0x37, 0x72, 0x2e, 0xb8, 0x5e, 0x5a, 0x5b, 0x83, 0x52, 0xab, 0x3d, 0xcf,
    0xac, 0xd7, 0x43, 0x87, 0xe2, 0x64, 0x2d, 0x2d, 0x1e, 0x3b, 0x5f, 0xf3, 0x14, 0xec, 0xc2, 0xbe,
    0x83, 0x25, 0xf0, 0x80, 0x71, 0xbf, 0x70, 0xc3, 0xcc, 0xfd, 0x99, 0xdb, 0x0f, 0x79, 0x07, 0x50,
    0x58, 0x6d, 0x48
};
#endif

PyTypeObject *init_QAbstractPrintDialog(PyObject *module)
{
    if (SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX].type != nullptr)
        return SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractPrintDialog_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX]))));

    _Sbk_QAbstractPrintDialog_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractPrintDialog",
        "QAbstractPrintDialog*",
        &Sbk_QAbstractPrintDialog_spec,
        &Shiboken::callCppDestructor< QAbstractPrintDialog >,
        Sbk_QAbstractPrintDialog_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QAbstractPrintDialog_TypeF(); // references _Sbk_QAbstractPrintDialog_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractPrintDialog_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractPrintDialog_SignatureBytes, QAbstractPrintDialog_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractPrintDialog_PropertyStrings);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractPrintDialog_PythonToCpp_QAbstractPrintDialog_PTR,
        is_QAbstractPrintDialog_PythonToCpp_QAbstractPrintDialog_PTR_Convertible,
        QAbstractPrintDialog_PTR_CppToPython_QAbstractPrintDialog);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractPrintDialog");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractPrintDialog*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractPrintDialog&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractPrintDialog).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractPrintDialogWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QAbstractPrintDialog_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QAbstractPrintDialog_TypeF(), &Sbk_QAbstractPrintDialogSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractPrintDialog_TypeF(), &Sbk_QAbstractPrintDialog_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractPrintDialog_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PrintRange'.
    const char *PrintRange_Initializer[] = {
        "AllPages",
        "Selection",
        "PageRange",
        "CurrentPage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PrintRange_InitializerValues[] = {
        uint8_t(QAbstractPrintDialog::PrintRange::AllPages),   //  0x00  0
        uint8_t(QAbstractPrintDialog::PrintRange::Selection),  //  0x01  1
        uint8_t(QAbstractPrintDialog::PrintRange::PageRange),  //  0x02  2
        uint8_t(QAbstractPrintDialog::PrintRange::CurrentPage) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractPrintDialog_TypeF(),
        "2:PySide6.QtPrintSupport.QAbstractPrintDialog.PrintRange",
        PrintRange_Initializer, PrintRange_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintRange_IDX].type = EType;
    // Register converter for enum 'QAbstractPrintDialog::PrintRange'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractPrintDialog_PrintRange_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractPrintDialog_PrintRange,
            is_Enum_PythonToCpp_QAbstractPrintDialog_PrintRange_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractPrintDialog::PrintRange");
        Shiboken::Conversions::registerConverterAlias(converter, "PrintRange");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PrintRange' enum.

    // Initialization of enum 'PrintDialogOption'.
    const char *PrintDialogOption_Initializer[] = {
        "PrintToFile",
        "PrintSelection",
        "PrintPageRange",
        "PrintShowPageSize",
        "PrintCollateCopies",
        "PrintCurrentPage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PrintDialogOption_InitializerValues[] = {
        uint8_t(QAbstractPrintDialog::PrintDialogOption::PrintToFile),        //  0x01  1
        uint8_t(QAbstractPrintDialog::PrintDialogOption::PrintSelection),     //  0x02  2
        uint8_t(QAbstractPrintDialog::PrintDialogOption::PrintPageRange),     //  0x04  4
        uint8_t(QAbstractPrintDialog::PrintDialogOption::PrintShowPageSize),  //  0x08  8
        uint8_t(QAbstractPrintDialog::PrintDialogOption::PrintCollateCopies), //  0x10  16
        uint8_t(QAbstractPrintDialog::PrintDialogOption::PrintCurrentPage)    //  0x40  64
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractPrintDialog_TypeF(),
        "2:PySide6.QtPrintSupport.QAbstractPrintDialog.PrintDialogOption",
        PrintDialogOption_Initializer, PrintDialogOption_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QAbstractPrintDialog_PrintDialogOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QFlags_QAbstractPrintDialog_PrintDialogOption_IDX].type =
        EType;
    // Register converter for enum 'QAbstractPrintDialog::PrintDialogOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractPrintDialog_PrintDialogOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractPrintDialog_PrintDialogOption,
            is_Enum_PythonToCpp_QAbstractPrintDialog_PrintDialogOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractPrintDialog::PrintDialogOption");
        Shiboken::Conversions::registerConverterAlias(converter, "PrintDialogOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QAbstractPrintDialog_PrintDialogOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QAbstractPrintDialog_PrintDialogOption,
            is_Enum_PythonToCpp_QAbstractPrintDialog_PrintDialogOption_Convertible);
        // Register converter for flag 'QFlags<QAbstractPrintDialog::PrintDialogOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QAbstractPrintDialog::PrintDialogOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QAbstractPrintDialog::PrintDialogOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PrintDialogOption' enum/flags.

    qRegisterMetaType< ::QAbstractPrintDialog::PrintRange >("QAbstractPrintDialog::PrintRange");
    qRegisterMetaType< ::QAbstractPrintDialog::PrintDialogOption >("QAbstractPrintDialog::PrintDialogOption");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractPrintDialog::staticMetaObject, sizeof(QAbstractPrintDialogWrapper));

    return pyType;
}
