// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qpyqmlparserstatus_wrapper.h"

// Wrappers providing overrides
#include "qqmlparserstatus_wrapper.h"
#include "qqmlpropertymap_wrapper.h"

// Argument includes
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPyQmlParserStatusWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPyQmlParserStatusWrapper::QPyQmlParserStatusWrapper(::QObject * parent) : QPyQmlParserStatus(parent)
{
}

void QPyQmlParserStatusWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_childEvent("QPyQmlParserStatus", funcName, gil, pyOverride, event);
}

void QPyQmlParserStatusWrapper::classBegin()
{
    static const char *funcName = "classBegin";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyQmlParserStatus.classBegin");
        return;
    }
    QQmlParserStatusWrapper::sbk_o_classBegin("QPyQmlParserStatus", funcName, gil, pyOverride);
}

void QPyQmlParserStatusWrapper::componentComplete()
{
    static const char *funcName = "componentComplete";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QPyQmlParserStatus.componentComplete");
        return;
    }
    QQmlParserStatusWrapper::sbk_o_classBegin("QPyQmlParserStatus", funcName, gil, pyOverride);
}

void QPyQmlParserStatusWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QQmlPropertyMapWrapper::sbk_o_connectNotify("QPyQmlParserStatus", funcName, gil, pyOverride, signal);
}

void QPyQmlParserStatusWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_customEvent("QPyQmlParserStatus", funcName, gil, pyOverride, event);
}

void QPyQmlParserStatusWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QQmlPropertyMapWrapper::sbk_o_connectNotify("QPyQmlParserStatus", funcName, gil, pyOverride, signal);
}

bool QPyQmlParserStatusWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QQmlPropertyMapWrapper::sbk_o_event("QPyQmlParserStatus", funcName, gil, pyOverride, event);
}

bool QPyQmlParserStatusWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QQmlPropertyMapWrapper::sbk_o_eventFilter("QPyQmlParserStatus", funcName, gil, pyOverride, watched, event);
}

void QPyQmlParserStatusWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_timerEvent("QPyQmlParserStatus", funcName, gil, pyOverride, event);
}

const QMetaObject *QPyQmlParserStatusWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPyQmlParserStatus::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPyQmlParserStatusWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPyQmlParserStatus::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPyQmlParserStatusWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPyQmlParserStatusWrapper *>(this));
    return QPyQmlParserStatus::qt_metacast(_clname);
}

QPyQmlParserStatusWrapper::~QPyQmlParserStatusWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPyQmlParserStatus_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QPyQmlParserStatus");
        return -1;
    }

    Shiboken::ObjectType::copyMultipleInheritance(type, myType);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPyQmlParserStatus >()))
        return -1;

    QPyQmlParserStatusWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QPyQmlParserStatus", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPyQmlParserStatus::QPyQmlParserStatus(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QPyQmlParserStatus(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPyQmlParserStatus(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPyQmlParserStatus(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPyQmlParserStatusWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPyQmlParserStatusWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPyQmlParserStatus >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX]);
    };


    return 1;
}


static const char *Sbk_QPyQmlParserStatus_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPyQmlParserStatus_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPyQmlParserStatus_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPyQmlParserStatus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPyQmlParserStatusWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPyQmlParserStatus_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPyQmlParserStatus_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_QPyQmlParserStatus_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QPyQmlParserStatus *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QPyQmlParserStatus *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QQmlParserStatus *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QQmlParserStatus *>(static_cast<const QPyQmlParserStatus *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QPyQmlParserStatusSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QPyQmlParserStatus *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))
        return static_cast< ::QQmlParserStatus *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPyQmlParserStatus_Type = nullptr;
static PyTypeObject *Sbk_QPyQmlParserStatus_TypeF(void)
{
    return _Sbk_QPyQmlParserStatus_Type;
}

static PyType_Slot Sbk_QPyQmlParserStatus_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPyQmlParserStatus_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPyQmlParserStatus_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPyQmlParserStatus_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPyQmlParserStatus_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPyQmlParserStatus_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPyQmlParserStatus_spec = {
    "2:PySide6.QtQml.QPyQmlParserStatus",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPyQmlParserStatus_slots
};

} //extern "C"

static void *Sbk_QPyQmlParserStatus_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPyQmlParserStatus *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QQmlParserStatus >())
        return dynamic_cast< ::QPyQmlParserStatus *>(reinterpret_cast< ::QQmlParserStatus *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPyQmlParserStatus_PythonToCpp_QPyQmlParserStatus_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPyQmlParserStatus_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPyQmlParserStatus_PythonToCpp_QPyQmlParserStatus_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPyQmlParserStatus_TypeF()))
        return QPyQmlParserStatus_PythonToCpp_QPyQmlParserStatus_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPyQmlParserStatus_PTR_CppToPython_QPyQmlParserStatus(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPyQmlParserStatus *>(const_cast<void *>(cppIn)), Sbk_QPyQmlParserStatus_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPyQmlParserStatus_SignatureStrings[] = {
    "PySide6.QtQml.QPyQmlParserStatus(self,parent:PySide6.QtCore.QObject=nullptr)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPyQmlParserStatus_SignatureByteSize = 76;
static constexpr uint8_t QPyQmlParserStatus_SignatureBytes[76] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcc, 0xcd, 0xd1,
    0x0b, 0x0c, 0xa8, 0x04, 0x52, 0x01, 0x89, 0x45, 0xc5, 0xa9, 0x45, 0xc1, 0x25, 0x89, 0x25, 0xa5,
    0xc5, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x3a, 0x05, 0x89, 0x45, 0xa9, 0x79, 0x25, 0x56, 0x01, 0x70,
    0xc5, 0xce, 0xf9, 0x45, 0xa9, 0x7a, 0x81, 0xfe, 0x49, 0x59, 0xa9, 0xc9, 0x25, 0xb6, 0x79, 0xa5,
    0x39, 0x39, 0x05, 0x25, 0x45, 0x9a, 0x5c, 0x00, 0x4f, 0x8d, 0x1c, 0x1e
};
#endif

PyTypeObject *init_QPyQmlParserStatus(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX].type;

    Shiboken::AutoDecRef Sbk_QPyQmlParserStatus_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))));

    _Sbk_QPyQmlParserStatus_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPyQmlParserStatus",
        "QPyQmlParserStatus*",
        &Sbk_QPyQmlParserStatus_spec,
        &Shiboken::callCppDestructor< QPyQmlParserStatus >,
        Sbk_QPyQmlParserStatus_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPyQmlParserStatus_TypeF(); // references _Sbk_QPyQmlParserStatus_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPyQmlParserStatus_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPyQmlParserStatus_SignatureBytes, QPyQmlParserStatus_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPyQmlParserStatus_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QPyQmlParserStatus_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPyQmlParserStatus_PythonToCpp_QPyQmlParserStatus_PTR,
        is_QPyQmlParserStatus_PythonToCpp_QPyQmlParserStatus_PTR_Convertible,
        QPyQmlParserStatus_PTR_CppToPython_QPyQmlParserStatus);

    Shiboken::Conversions::registerConverterName(converter, "QPyQmlParserStatus");
    Shiboken::Conversions::registerConverterName(converter, "QPyQmlParserStatus*");
    Shiboken::Conversions::registerConverterName(converter, "QPyQmlParserStatus&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPyQmlParserStatus).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPyQmlParserStatusWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QPyQmlParserStatus_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QPyQmlParserStatus_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QPyQmlParserStatus_TypeF(), &Sbk_QPyQmlParserStatusSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPyQmlParserStatus_TypeF(), &Sbk_QPyQmlParserStatus_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPyQmlParserStatus::staticMetaObject, sizeof(QPyQmlParserStatusWrapper));

    return pyType;
}
