// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlfileselector_wrapper.h"

// Wrappers providing overrides
#include "qqmlpropertymap_wrapper.h"

// Argument includes
#include <QStringList>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlfileselector.h>
#include <qcoreevent.h>
#include <qfileselector.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlFileSelectorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlFileSelectorWrapper::QQmlFileSelectorWrapper(::QQmlEngine * engine, ::QObject * parent) : QQmlFileSelector(engine, parent)
{
}

void QQmlFileSelectorWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_childEvent("QQmlFileSelector", funcName, gil, pyOverride, event);
}

void QQmlFileSelectorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QQmlPropertyMapWrapper::sbk_o_connectNotify("QQmlFileSelector", funcName, gil, pyOverride, signal);
}

void QQmlFileSelectorWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_customEvent("QQmlFileSelector", funcName, gil, pyOverride, event);
}

void QQmlFileSelectorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QQmlPropertyMapWrapper::sbk_o_connectNotify("QQmlFileSelector", funcName, gil, pyOverride, signal);
}

bool QQmlFileSelectorWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QQmlPropertyMapWrapper::sbk_o_event("QQmlFileSelector", funcName, gil, pyOverride, event);
}

bool QQmlFileSelectorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QQmlPropertyMapWrapper::sbk_o_eventFilter("QQmlFileSelector", funcName, gil, pyOverride, watched, event);
}

void QQmlFileSelectorWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_timerEvent("QQmlFileSelector", funcName, gil, pyOverride, event);
}

const QMetaObject *QQmlFileSelectorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQmlFileSelector::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQmlFileSelectorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQmlFileSelector::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQmlFileSelectorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQmlFileSelectorWrapper *>(this));
    return QQmlFileSelector::qt_metacast(_clname);
}

QQmlFileSelectorWrapper::~QQmlFileSelectorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlFileSelector_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlFileSelector >()))
        return -1;

    QQmlFileSelectorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QQmlFileSelector", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQmlFileSelector::QQmlFileSelector(QQmlEngine*,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QQmlFileSelector(QQmlEngine*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QQmlFileSelector(QQmlEngine*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QQmlEngine *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQmlFileSelector(QQmlEngine*,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQmlFileSelectorWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQmlFileSelectorWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlFileSelector >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQmlFileSelectorFunc_get(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQmlFileSelector::get(QQmlEngine*)->QQmlFileSelector*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), (pyArg)))) {
        overloadId = 0; // get(QQmlEngine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "get", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QQmlFileSelector", "get(QQmlEngine *arg__1)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlEngine *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // get(QQmlEngine*)
            QQmlFileSelector * cppResult = ::QQmlFileSelector::get(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlFileSelectorFunc_selector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selector()const
        QFileSelector * cppResult = const_cast<const ::QQmlFileSelector *>(cppSelf)->selector();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlFileSelectorFunc_setExtraSelectors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlFileSelector::setExtraSelectors(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setExtraSelectors(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtraSelectors", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtraSelectors(QStringList)
            cppSelf->setExtraSelectors(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQmlFileSelectorFunc_setSelector(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlFileSelector::setSelector(QFileSelector*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]), (pyArg)))) {
        overloadId = 0; // setSelector(QFileSelector*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelector", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFileSelector *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelector(QFileSelector*)
            cppSelf->setSelector(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QQmlFileSelector_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlFileSelector_methods[] = {
    {"get", reinterpret_cast<PyCFunction>(Sbk_QQmlFileSelectorFunc_get), METH_O|METH_STATIC, nullptr},
    {"selector", reinterpret_cast<PyCFunction>(Sbk_QQmlFileSelectorFunc_selector), METH_NOARGS, nullptr},
    {"setExtraSelectors", reinterpret_cast<PyCFunction>(Sbk_QQmlFileSelectorFunc_setExtraSelectors), METH_O, nullptr},
    {"setSelector", reinterpret_cast<PyCFunction>(Sbk_QQmlFileSelectorFunc_setSelector), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlFileSelector_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlFileSelectorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlFileSelector_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlFileSelector_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlFileSelector_Type = nullptr;
static PyTypeObject *Sbk_QQmlFileSelector_TypeF(void)
{
    return _Sbk_QQmlFileSelector_Type;
}

static PyType_Slot Sbk_QQmlFileSelector_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlFileSelector_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlFileSelector_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlFileSelector_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlFileSelector_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlFileSelector_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlFileSelector_spec = {
    "2:PySide6.QtQml.QQmlFileSelector",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlFileSelector_slots
};

} //extern "C"

static void *Sbk_QQmlFileSelector_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQmlFileSelector *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlFileSelector_PythonToCpp_QQmlFileSelector_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlFileSelector_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlFileSelector_PythonToCpp_QQmlFileSelector_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlFileSelector_TypeF()))
        return QQmlFileSelector_PythonToCpp_QQmlFileSelector_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlFileSelector_PTR_CppToPython_QQmlFileSelector(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQmlFileSelector *>(const_cast<void *>(cppIn)), Sbk_QQmlFileSelector_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlFileSelector_SignatureStrings[] = {
    "PySide6.QtQml.QQmlFileSelector(self,engine:PySide6.QtQml.QQmlEngine,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtQml.QQmlFileSelector.get(arg__1:PySide6.QtQml.QQmlEngine)->PySide6.QtQml.QQmlFileSelector",
    "PySide6.QtQml.QQmlFileSelector.selector(self)->PySide6.QtCore.QFileSelector",
    "PySide6.QtQml.QQmlFileSelector.setExtraSelectors(self,strings:QStringList)",
    "PySide6.QtQml.QQmlFileSelector.setSelector(self,selector:PySide6.QtCore.QFileSelector)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlFileSelector_SignatureByteSize = 161;
static constexpr uint8_t QQmlFileSelector_SignatureBytes[161] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcc, 0xcd, 0xd1,
    0x0b, 0x04, 0x12, 0x6e, 0x99, 0x39, 0xa9, 0xc1, 0xa9, 0x39, 0xa9, 0xc9, 0x25, 0xf9, 0x45, 0x1a,
    0xc5, 0xa9, 0x39, 0x69, 0x3a, 0xa9, 0x79, 0xe9, 0x99, 0x79, 0xa9, 0x56, 0x01, 0x18, 0x4a, 0x5d,
    0xc1, 0x12, 0x3a, 0x05, 0x89, 0x45, 0xa9, 0x79, 0x25, 0x48, 0xf2, 0xce, 0xf9, 0x45, 0xa9, 0x7a,
    0x81, 0xfe, 0x49, 0x59, 0x40, 0x43, 0x6c, 0xf3, 0x4a, 0x73, 0x72, 0x0a, 0x4a, 0x8a, 0x34, 0xb9,
    0x02, 0xf0, 0x5a, 0xa5, 0x97, 0x9e, 0x5a, 0xa2, 0x91, 0x58, 0x94, 0x1e, 0x1f, 0x6f, 0x88, 0xd3,
    0x26, 0x4d, 0x5d, 0x3b, 0xfc, 0x86, 0x10, 0xb2, 0xa3, 0x18, 0xd9, 0x5f, 0x28, 0xa6, 0x41, 0x9c,
    0x4c, 0x9a, 0x59, 0x25, 0xae, 0x15, 0x25, 0x45, 0x89, 0x30, 0x81, 0x62, 0x48, 0x60, 0x15, 0x97,
    0x14, 0x65, 0xe6, 0xa5, 0x17, 0x5b, 0x05, 0x06, 0x83, 0x19, 0x3e, 0x99, 0xc5, 0x25, 0x9a, 0x44,
    0x18, 0x85, 0x1a, 0xe2, 0x30, 0x77, 0x5a, 0xe1, 0x73, 0xa0, 0x26, 0x17, 0x00, 0x9f, 0x36, 0xa1,
    0x20
};
#endif

PyTypeObject *init_QQmlFileSelector(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlFileSelector_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QQmlFileSelector_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlFileSelector",
        "QQmlFileSelector*",
        &Sbk_QQmlFileSelector_spec,
        &Shiboken::callCppDestructor< QQmlFileSelector >,
        Sbk_QQmlFileSelector_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlFileSelector_TypeF(); // references _Sbk_QQmlFileSelector_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlFileSelector_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlFileSelector_SignatureBytes, QQmlFileSelector_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlFileSelector_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlFileSelector_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlFileSelector_PythonToCpp_QQmlFileSelector_PTR,
        is_QQmlFileSelector_PythonToCpp_QQmlFileSelector_PTR_Convertible,
        QQmlFileSelector_PTR_CppToPython_QQmlFileSelector);

    Shiboken::Conversions::registerConverterName(converter, "QQmlFileSelector");
    Shiboken::Conversions::registerConverterName(converter, "QQmlFileSelector*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlFileSelector&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlFileSelector).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlFileSelectorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQmlFileSelector_TypeF(), &Sbk_QQmlFileSelector_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQmlFileSelector::staticMetaObject, sizeof(QQmlFileSelectorWrapper));

    return pyType;
}
