// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickframebufferobject_wrapper.h"

// Wrappers providing overrides
#include "qquickitem_wrapper.h"
#include "qsgnode_wrapper.h"
#include "qsgtextureprovider_wrapper.h"
#include "qquickrhiitem_wrapper.h"
#include "qsgtextnode_wrapper.h"

// inner classes
#include "qquickframebufferobject_renderer_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtQuick/qquickframebufferobject.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickFramebufferObjectWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickFramebufferObjectWrapper::QQuickFramebufferObjectWrapper(::QQuickItem * parent) : QQuickFramebufferObject(parent)
{
}

::QRectF QQuickFramebufferObjectWrapper::boundingRect() const
{
    static const char *funcName = "boundingRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::boundingRect();
    }
    return QSGTextNodeWrapper::sbk_o_viewport("QQuickFramebufferObject", funcName, gil, pyOverride);
}

void QQuickFramebufferObjectWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_childEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

bool QQuickFramebufferObjectWrapper::childMouseEventFilter(::QQuickItem * arg__1, ::QEvent * arg__2)
{
    static const char *funcName = "childMouseEventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::childMouseEventFilter(arg__1, arg__2);
    }
    return QQuickItemWrapper::sbk_o_childMouseEventFilter("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1, arg__2);
}

void QQuickFramebufferObjectWrapper::classBegin()
{
    static const char *funcName = "classBegin";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::classBegin();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickFramebufferObject", funcName, gil, pyOverride);
}

::QRectF QQuickFramebufferObjectWrapper::clipRect() const
{
    static const char *funcName = "clipRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::clipRect();
    }
    return QSGTextNodeWrapper::sbk_o_viewport("QQuickFramebufferObject", funcName, gil, pyOverride);
}

void QQuickFramebufferObjectWrapper::componentComplete()
{
    static const char *funcName = "componentComplete";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::componentComplete();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickFramebufferObject", funcName, gil, pyOverride);
}

void QQuickFramebufferObjectWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickFramebufferObject", funcName, gil, pyOverride, signal);
}

bool QQuickFramebufferObjectWrapper::contains(const ::QPointF & point) const
{
    static const char *funcName = "contains";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::contains(point);
    }
    return QQuickItemWrapper::sbk_o_contains("QQuickFramebufferObject", funcName, gil, pyOverride, point);
}

::QQuickFramebufferObject::Renderer * QQuickFramebufferObjectWrapper::createRenderer() const
{
    static const char *funcName = "createRenderer";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QQuickFramebufferObject.createRenderer");
        return nullptr;
    }
    return sbk_o_createRenderer("QQuickFramebufferObject", funcName, gil, pyOverride);
}

::QQuickFramebufferObject::Renderer * QQuickFramebufferObjectWrapper::sbk_o_createRenderer(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QQuickFramebufferObject::Renderer >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QQuickFramebufferObject::Renderer *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

void QQuickFramebufferObjectWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_customEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickFramebufferObject", funcName, gil, pyOverride, signal);
}

void QQuickFramebufferObjectWrapper::dragEnterEvent(::QDragEnterEvent * arg__1)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dragEnterEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dragEnterEvent("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

void QQuickFramebufferObjectWrapper::dragLeaveEvent(::QDragLeaveEvent * arg__1)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dragLeaveEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dragLeaveEvent("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

void QQuickFramebufferObjectWrapper::dragMoveEvent(::QDragMoveEvent * arg__1)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dragMoveEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dragMoveEvent("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

void QQuickFramebufferObjectWrapper::dropEvent(::QDropEvent * arg__1)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dropEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dropEvent("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

bool QQuickFramebufferObjectWrapper::event(::QEvent * arg__1)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::event(arg__1);
    }
    return QSGTextureProviderWrapper::sbk_o_event("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

bool QQuickFramebufferObjectWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSGTextureProviderWrapper::sbk_o_eventFilter("QQuickFramebufferObject", funcName, gil, pyOverride, watched, event);
}

void QQuickFramebufferObjectWrapper::focusInEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::focusInEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_focusInEvent("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

void QQuickFramebufferObjectWrapper::focusOutEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::focusOutEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_focusInEvent("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

void QQuickFramebufferObjectWrapper::geometryChange(const ::QRectF & newGeometry, const ::QRectF & oldGeometry)
{
    static const char *funcName = "geometryChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickFramebufferObject::geometryChange(newGeometry, oldGeometry);
    }
    QQuickItemWrapper::sbk_o_geometryChange("QQuickFramebufferObject", funcName, gil, pyOverride, newGeometry, oldGeometry);
}

void QQuickFramebufferObjectWrapper::hoverEnterEvent(::QHoverEvent * event)
{
    static const char *funcName = "hoverEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::hoverEnterEvent(event);
    }
    QQuickItemWrapper::sbk_o_hoverEnterEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::hoverLeaveEvent(::QHoverEvent * event)
{
    static const char *funcName = "hoverLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::hoverLeaveEvent(event);
    }
    QQuickItemWrapper::sbk_o_hoverEnterEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::hoverMoveEvent(::QHoverEvent * event)
{
    static const char *funcName = "hoverMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::hoverMoveEvent(event);
    }
    QQuickItemWrapper::sbk_o_hoverEnterEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::inputMethodEvent(::QInputMethodEvent * arg__1)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::inputMethodEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_inputMethodEvent("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1);
}

::QVariant QQuickFramebufferObjectWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::inputMethodQuery(query);
    }
    return QQuickItemWrapper::sbk_o_inputMethodQuery("QQuickFramebufferObject", funcName, gil, pyOverride, query);
}

bool QQuickFramebufferObjectWrapper::isTextureProvider() const
{
    static const char *funcName = "isTextureProvider";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickFramebufferObject::isTextureProvider();
    }
    return QSGNodeWrapper::sbk_o_isSubtreeBlocked("QQuickFramebufferObject", funcName, gil, pyOverride);
}

void QQuickFramebufferObjectWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::keyPressEvent(event);
    }
    QQuickItemWrapper::sbk_o_keyPressEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::keyReleaseEvent(event);
    }
    QQuickItemWrapper::sbk_o_keyPressEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseDoubleClickEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseMoveEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mousePressEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseReleaseEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::mouseUngrabEvent()
{
    static const char *funcName = "mouseUngrabEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseUngrabEvent();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickFramebufferObject", funcName, gil, pyOverride);
}

void QQuickFramebufferObjectWrapper::releaseResources()
{
    static const char *funcName = "releaseResources";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickFramebufferObject::releaseResources();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickFramebufferObject", funcName, gil, pyOverride);
}

::QSGTextureProvider * QQuickFramebufferObjectWrapper::textureProvider() const
{
    static const char *funcName = "textureProvider";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickFramebufferObject::textureProvider();
    }
    return QQuickItemWrapper::sbk_o_textureProvider("QQuickFramebufferObject", funcName, gil, pyOverride);
}

void QQuickFramebufferObjectWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_timerEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::touchEvent(::QTouchEvent * event)
{
    static const char *funcName = "touchEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::touchEvent(event);
    }
    QQuickItemWrapper::sbk_o_touchEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

void QQuickFramebufferObjectWrapper::touchUngrabEvent()
{
    static const char *funcName = "touchUngrabEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::touchUngrabEvent();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickFramebufferObject", funcName, gil, pyOverride);
}

::QSGNode * QQuickFramebufferObjectWrapper::updatePaintNode(::QSGNode * arg__1, ::QQuickItem::UpdatePaintNodeData * arg__2)
{
    static const char *funcName = "updatePaintNode";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickFramebufferObject::updatePaintNode(arg__1, arg__2);
    }
    return QQuickRhiItemWrapper::sbk_o_updatePaintNode("QQuickFramebufferObject", funcName, gil, pyOverride, arg__1, arg__2);
}

void QQuickFramebufferObjectWrapper::updatePolish()
{
    static const char *funcName = "updatePolish";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::updatePolish();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickFramebufferObject", funcName, gil, pyOverride);
}

void QQuickFramebufferObjectWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::wheelEvent(event);
    }
    QQuickItemWrapper::sbk_o_wheelEvent("QQuickFramebufferObject", funcName, gil, pyOverride, event);
}

const QMetaObject *QQuickFramebufferObjectWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuickFramebufferObject::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuickFramebufferObjectWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuickFramebufferObject::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuickFramebufferObjectWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuickFramebufferObjectWrapper *>(this));
    return QQuickFramebufferObject::qt_metacast(_clname);
}

QQuickFramebufferObjectWrapper::~QQuickFramebufferObjectWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickFramebufferObject_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQuickFramebufferObject");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickFramebufferObject >()))
        return -1;

    QQuickFramebufferObjectWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QQuickFramebufferObject", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickFramebufferObject::QQuickFramebufferObject(QQuickItem*=)
    if (numArgs == 0) {
        overloadId = 0; // QQuickFramebufferObject(QQuickItem*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QQuickFramebufferObject(QQuickItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QQuickItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQuickFramebufferObject(QQuickItem*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQuickFramebufferObjectWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQuickFramebufferObjectWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickFramebufferObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_createRenderer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createRenderer()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QQuickFramebufferObject.createRenderer");
            return {};
        }
        QQuickFramebufferObject::Renderer * cppResult = const_cast<const ::QQuickFramebufferObject *>(cppSelf)->createRenderer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_geometryChange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "geometryChange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::geometryChange(QRectF,QRectF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // geometryChange(QRectF,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "geometryChange", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // geometryChange(QRectF,QRectF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickFramebufferObject::geometryChange(*cppArg0, *cppArg1)
                : cppSelf->geometryChange(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_isTextureProvider(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTextureProvider()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickFramebufferObject *>(cppSelf)->::QQuickFramebufferObject::isTextureProvider()
            : const_cast<const ::QQuickFramebufferObject *>(cppSelf)->isTextureProvider();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_mirrorVertically(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mirrorVertically()const
        bool cppResult = const_cast<const ::QQuickFramebufferObject *>(cppSelf)->mirrorVertically();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_releaseResources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // releaseResources()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickFramebufferObject::releaseResources()
            : cppSelf->releaseResources();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_setMirrorVertically(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickFramebufferObject::setMirrorVertically(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMirrorVertically(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMirrorVertically", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMirrorVertically(bool)
            cppSelf->setMirrorVertically(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_setTextureFollowsItemSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickFramebufferObject::setTextureFollowsItemSize(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTextureFollowsItemSize(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureFollowsItemSize", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureFollowsItemSize(bool)
            cppSelf->setTextureFollowsItemSize(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_textureFollowsItemSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureFollowsItemSize()const
        bool cppResult = const_cast<const ::QQuickFramebufferObject *>(cppSelf)->textureFollowsItemSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_textureProvider(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureProvider()const
        QSGTextureProvider * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickFramebufferObject *>(cppSelf)->::QQuickFramebufferObject::textureProvider()
            : const_cast<const ::QQuickFramebufferObject *>(cppSelf)->textureProvider();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureProvider_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickFramebufferObjectFunc_updatePaintNode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updatePaintNode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)->QSGNode*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_UpdatePaintNodeData_IDX]), (pyArgs[1])))) {
        overloadId = 0; // updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updatePaintNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQuickItem::UpdatePaintNodeData *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)
            QSGNode * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickFramebufferObject::updatePaintNode(cppArg0, cppArg1)
                : cppSelf->updatePaintNode(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QQuickFramebufferObject_PropertyStrings[] = {
    "mirrorVertically::",
    "textureFollowsItemSize::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickFramebufferObject_methods[] = {
    {"createRenderer", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_createRenderer), METH_NOARGS, nullptr},
    {"geometryChange", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_geometryChange), METH_VARARGS, nullptr},
    {"isTextureProvider", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_isTextureProvider), METH_NOARGS, nullptr},
    {"mirrorVertically", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_mirrorVertically), METH_NOARGS, nullptr},
    {"releaseResources", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_releaseResources), METH_NOARGS, nullptr},
    {"setMirrorVertically", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_setMirrorVertically), METH_O, nullptr},
    {"setTextureFollowsItemSize", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_setTextureFollowsItemSize), METH_O, nullptr},
    {"textureFollowsItemSize", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_textureFollowsItemSize), METH_NOARGS, nullptr},
    {"textureProvider", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_textureProvider), METH_NOARGS, nullptr},
    {"updatePaintNode", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObjectFunc_updatePaintNode), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickFramebufferObject_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickFramebufferObjectWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickFramebufferObject_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickFramebufferObject_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QQuickFramebufferObjectSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QQuickFramebufferObject *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]))
        return static_cast< ::QQuickItem *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))
        return static_cast< ::QQmlParserStatus *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickFramebufferObject_Type = nullptr;
static PyTypeObject *Sbk_QQuickFramebufferObject_TypeF(void)
{
    return _Sbk_QQuickFramebufferObject_Type;
}

static PyType_Slot Sbk_QQuickFramebufferObject_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickFramebufferObject_spec = {
    "2:PySide6.QtQuick.QQuickFramebufferObject",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickFramebufferObject_slots
};

} //extern "C"

static void *Sbk_QQuickFramebufferObject_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QQuickItem >())
        return dynamic_cast< ::QQuickFramebufferObject *>(reinterpret_cast< ::QQuickItem *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuickFramebufferObject *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QQmlParserStatus >())
        return dynamic_cast< ::QQuickFramebufferObject *>(reinterpret_cast< ::QQmlParserStatus *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickFramebufferObject_PythonToCpp_QQuickFramebufferObject_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickFramebufferObject_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickFramebufferObject_PythonToCpp_QQuickFramebufferObject_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickFramebufferObject_TypeF()))
        return QQuickFramebufferObject_PythonToCpp_QQuickFramebufferObject_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickFramebufferObject_PTR_CppToPython_QQuickFramebufferObject(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuickFramebufferObject *>(const_cast<void *>(cppIn)), Sbk_QQuickFramebufferObject_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickFramebufferObject_SignatureStrings[] = {
    "PySide6.QtQuick.QQuickFramebufferObject(self,parent:PySide6.QtQuick.QQuickItem=nullptr,*:KeywordOnly=None,textureFollowsItemSize:bool=None,mirrorVertically:bool=None)",
    "PySide6.QtQuick.QQuickFramebufferObject.createRenderer(self)->PySide6.QtQuick.QQuickFramebufferObject.Renderer",
    "PySide6.QtQuick.QQuickFramebufferObject.geometryChange(self,newGeometry:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],oldGeometry:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtQuick.QQuickFramebufferObject.isTextureProvider(self)->bool",
    "PySide6.QtQuick.QQuickFramebufferObject.mirrorVertically(self)->bool",
    "PySide6.QtQuick.QQuickFramebufferObject.releaseResources(self)",
    "PySide6.QtQuick.QQuickFramebufferObject.setMirrorVertically(self,enable:bool)",
    "PySide6.QtQuick.QQuickFramebufferObject.setTextureFollowsItemSize(self,follows:bool)",
    "PySide6.QtQuick.QQuickFramebufferObject.textureFollowsItemSize(self)->bool",
    "PySide6.QtQuick.QQuickFramebufferObject.textureProvider(self)->PySide6.QtQuick.QSGTextureProvider",
    "PySide6.QtQuick.QQuickFramebufferObject.updatePaintNode(self,arg__1:PySide6.QtQuick.QSGNode,arg__2:PySide6.QtQuick.QQuickItem.UpdatePaintNodeData)->PySide6.QtQuick.QSGNode",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickFramebufferObject_SignatureByteSize = 332;
static constexpr uint8_t QQuickFramebufferObject_SignatureBytes[332] = {
    0x78, 0xda, 0xa5, 0x94, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfb, 0x15, 0x1c, 0x19, 0x2a,
    0x95, 0xe0, 0xc0, 0xa1, 0xd2, 0xb8, 0x0c, 0x6d, 0x42, 0x88, 0xad, 0xdd, 0x07, 0x17, 0x84, 0xa6,
    0xb4, 0x75, 0x4b, 0x20, 0x8d, 0x2b, 0xd7, 0x65, 0x94, 0x5f, 0x4f, 0xbb, 0x0c, 0x26, 0x46, 0x40,
    0x19, 0x9c, 0x22, 0xd9, 0x7e, 0x1f, 0xbb, 0x7e, 0xd3, 0x84, 0xcd, 0x5c, 0xa6, 0x70, 0xe1, 0x47,
    0x1c, 0xd5, 0x32, 0x79, 0xf6, 0xa3, 0xcd, 0x31, 0x22, 0x51, 0x40, 0x5c, 0x67, 0x19, 0xd0, 0x34,
    0x7e, 0x82, 0x84, 0x8f, 0x2b, 0x50, 0x99, 0x57, 0x0a, 0x02, 0xcd, 0x41, 0x68, 0xd5, 0x5c, 0x33,
    0x14, 0x03, 0x5d, 0x2b, 0x55, 0x32, 0x79, 0x27, 0xc1, 0x0d, 0x34, 0x6b, 0xa4, 0x74, 0xaa, 0x55,
    0x33, 0x98, 0xa0, 0x06, 0x8f, 0xe1, 0x95, 0x6b, 0x82, 0x11, 0x2a, 0x85, 0xeb, 0xaa, 0xab, 0x9e,
    0xcb, 0x37, 0x08, 0x62, 0x44, 0x65, 0x0a, 0x0a, 0x49, 0x84, 0x74, 0x07, 0xc4, 0x32, 0x11, 0x4a,
    0x35, 0xbb, 0x54, 0xbf, 0x17, 0xba, 0x8d, 0xe9, 0x27, 0x04, 0x82, 0x61, 0x06, 0x3a, 0x05, 0x02,
    0xda, 0x4c, 0xdd, 0x3f, 0xbd, 0x74, 0x55, 0x7f, 0xe8, 0x9c, 0xdb, 0xe5, 0x80, 0x05, 0x30, 0x35,
    0xc3, 0x47, 0xa1, 0x73, 0x30, 0x4b, 0xd2, 0xb0, 0x1e, 0x6f, 0xc3, 0x01, 0x37, 0xa5, 0xd4, 0xb9,
    0xbf, 0xd4, 0x12, 0xf5, 0xfd, 0x0e, 0x3a, 0x44, 0x02, 0x3f, 0x9a, 0xb5, 0x84, 0x91, 0x77, 0x64,
    0x0b, 0x3f, 0x78, 0xa8, 0xd2, 0xff, 0x53, 0xdc, 0xf7, 0x26, 0xab, 0x85, 0xb1, 0x27, 0x24, 0x7c,
    0x69, 0x15, 0x9f, 0xab, 0xeb, 0x3c, 0x70, 0xa6, 0xec, 0x3b, 0xf8, 0x27, 0x08, 0x81, 0x02, 0x51,
    0xb5, 0x1e, 0x56, 0x58, 0x53, 0x02, 0x95, 0x81, 0x38, 0xcb, 0x2b, 0xe0, 0x5b, 0xdb, 0x18, 0x1e,
    0x68, 0x11, 0x2b, 0x73, 0xdf, 0x0e, 0xa2, 0x2d, 0xac, 0xf7, 0xd6, 0x30, 0x33, 0x13, 0x3c, 0x10,
    0xca, 0x3f, 0x13, 0x0f, 0x5d, 0x16, 0xdb, 0x5d, 0xfb, 0x26, 0x9f, 0x8f, 0xf7, 0xfc, 0x75, 0xee,
    0x50, 0x97, 0x69, 0xfb, 0x47, 0x85, 0x42, 0x6a, 0x9e, 0x60, 0xba, 0xfd, 0x6e, 0x41, 0xf9, 0x6a,
    0x75, 0x16, 0x58, 0xda, 0x74, 0x35, 0x26, 0x7d, 0xfe, 0xcb, 0x3b, 0xe1, 0x2f, 0xbf, 0x52, 0xaf,
    0x04, 0x0b, 0xfb, 0xd8, 0x5d, 0xb6, 0xf7, 0x0e, 0xd2, 0x4d, 0xb7, 0xcc
};
#endif

PyTypeObject *init_QQuickFramebufferObject(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickFramebufferObject_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]))));

    _Sbk_QQuickFramebufferObject_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickFramebufferObject",
        "QQuickFramebufferObject*",
        &Sbk_QQuickFramebufferObject_spec,
        &Shiboken::callCppDestructor< QQuickFramebufferObject >,
        Sbk_QQuickFramebufferObject_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QQuickFramebufferObject_TypeF(); // references _Sbk_QQuickFramebufferObject_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickFramebufferObject_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickFramebufferObject_SignatureBytes, QQuickFramebufferObject_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickFramebufferObject_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickFramebufferObject_PythonToCpp_QQuickFramebufferObject_PTR,
        is_QQuickFramebufferObject_PythonToCpp_QQuickFramebufferObject_PTR_Convertible,
        QQuickFramebufferObject_PTR_CppToPython_QQuickFramebufferObject);

    Shiboken::Conversions::registerConverterName(converter, "QQuickFramebufferObject");
    Shiboken::Conversions::registerConverterName(converter, "QQuickFramebufferObject*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickFramebufferObject&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickFramebufferObject).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickFramebufferObjectWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QQuickFramebufferObject_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QQuickFramebufferObject_TypeF(), &Sbk_QQuickFramebufferObjectSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuickFramebufferObject_TypeF(), &Sbk_QQuickFramebufferObject_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QQuickFramebufferObject::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuickFramebufferObject::staticMetaObject, sizeof(QQuickFramebufferObjectWrapper));

    return pyType;
}
