// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QQUICKITEMWRAPPER_H
#define SBK_QQUICKITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtQuick/qquickitem.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QQuickItemWrapper : public QQuickItem
{
public:
    QQuickItemWrapper(::QQuickItem * parent = nullptr);
    QQuickItemWrapper(const QQuickItemWrapper &) = delete;
    QQuickItemWrapper& operator=(const QQuickItemWrapper &) = delete;
    QQuickItemWrapper(QQuickItemWrapper &&) = delete;
    QQuickItemWrapper& operator=(QQuickItemWrapper &&) = delete;
    ~QQuickItemWrapper() override;

    ::QRectF boundingRect() const override;
    void childEvent(::QChildEvent * event) override;
    bool childMouseEventFilter(::QQuickItem * arg__1, ::QEvent * arg__2) override;
    static bool sbk_o_childMouseEventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QQuickItem * arg__1, ::QEvent * arg__2);
    void classBegin() override;
    ::QRectF clipRect() const override;
    void componentComplete() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    bool contains(const ::QPointF & point) const override;
    static bool sbk_o_contains(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF & point);
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void dragEnterEvent(::QDragEnterEvent * arg__1) override;
    static void sbk_o_dragEnterEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDragEnterEvent * arg__1);
    void dragLeaveEvent(::QDragLeaveEvent * arg__1) override;
    static void sbk_o_dragLeaveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDragLeaveEvent * arg__1);
    void dragMoveEvent(::QDragMoveEvent * arg__1) override;
    static void sbk_o_dragMoveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDragMoveEvent * arg__1);
    void dropEvent(::QDropEvent * arg__1) override;
    static void sbk_o_dropEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDropEvent * arg__1);
    bool event(::QEvent * arg__1) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void focusInEvent(::QFocusEvent * arg__1) override;
    static void sbk_o_focusInEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFocusEvent * arg__1);
    void focusOutEvent(::QFocusEvent * arg__1) override;
    void geometryChange(const ::QRectF & newGeometry, const ::QRectF & oldGeometry) override;
    static void sbk_o_geometryChange(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & newGeometry, const ::QRectF & oldGeometry);
    void hoverEnterEvent(::QHoverEvent * event) override;
    static void sbk_o_hoverEnterEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QHoverEvent * event);
    void hoverLeaveEvent(::QHoverEvent * event) override;
    void hoverMoveEvent(::QHoverEvent * event) override;
    void inputMethodEvent(::QInputMethodEvent * arg__1) override;
    static void sbk_o_inputMethodEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QInputMethodEvent * arg__1);
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery query) const override;
    static ::QVariant sbk_o_inputMethodQuery(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::Qt::InputMethodQuery query);
    bool isTextureProvider() const override;
    void keyPressEvent(::QKeyEvent * event) override;
    static void sbk_o_keyPressEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QKeyEvent * event);
    void keyReleaseEvent(::QKeyEvent * event) override;
    void mouseDoubleClickEvent(::QMouseEvent * event) override;
    static void sbk_o_mouseDoubleClickEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QMouseEvent * event);
    void mouseMoveEvent(::QMouseEvent * event) override;
    void mousePressEvent(::QMouseEvent * event) override;
    void mouseReleaseEvent(::QMouseEvent * event) override;
    void mouseUngrabEvent() override;
    void releaseResources() override;
    ::QSGTextureProvider * textureProvider() const override;
    static ::QSGTextureProvider * sbk_o_textureProvider(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void timerEvent(::QTimerEvent * event) override;
    void touchEvent(::QTouchEvent * event) override;
    static void sbk_o_touchEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTouchEvent * event);
    void touchUngrabEvent() override;
    ::QSGNode * updatePaintNode(::QSGNode * arg__1, ::QQuickItem::UpdatePaintNodeData * arg__2) override;
    static ::QSGNode * sbk_o_updatePaintNode(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSGNode * arg__1, ::QQuickItem::UpdatePaintNodeData * arg__2);
    void updatePolish() override;
    void wheelEvent(::QWheelEvent * event) override;
    static void sbk_o_wheelEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWheelEvent * event);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[40] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QQUICKITEMWRAPPER_H
