// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickrhiitem_wrapper.h"

// Wrappers providing overrides
#include "qquickitem_wrapper.h"
#include "qsgnode_wrapper.h"
#include "qsgtextureprovider_wrapper.h"
#include "qsgtextnode_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickrhiitem.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickRhiItemWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickRhiItemWrapper::QQuickRhiItemWrapper(::QQuickItem * parent) : QQuickRhiItem(parent)
{
}

::QRectF QQuickRhiItemWrapper::boundingRect() const
{
    static const char *funcName = "boundingRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::boundingRect();
    }
    return QSGTextNodeWrapper::sbk_o_viewport("QQuickRhiItem", funcName, gil, pyOverride);
}

void QQuickRhiItemWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_childEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

bool QQuickRhiItemWrapper::childMouseEventFilter(::QQuickItem * arg__1, ::QEvent * arg__2)
{
    static const char *funcName = "childMouseEventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::childMouseEventFilter(arg__1, arg__2);
    }
    return QQuickItemWrapper::sbk_o_childMouseEventFilter("QQuickRhiItem", funcName, gil, pyOverride, arg__1, arg__2);
}

void QQuickRhiItemWrapper::classBegin()
{
    static const char *funcName = "classBegin";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::classBegin();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickRhiItem", funcName, gil, pyOverride);
}

::QRectF QQuickRhiItemWrapper::clipRect() const
{
    static const char *funcName = "clipRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::clipRect();
    }
    return QSGTextNodeWrapper::sbk_o_viewport("QQuickRhiItem", funcName, gil, pyOverride);
}

void QQuickRhiItemWrapper::componentComplete()
{
    static const char *funcName = "componentComplete";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::componentComplete();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickRhiItem", funcName, gil, pyOverride);
}

void QQuickRhiItemWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickRhiItem", funcName, gil, pyOverride, signal);
}

bool QQuickRhiItemWrapper::contains(const ::QPointF & point) const
{
    static const char *funcName = "contains";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::contains(point);
    }
    return QQuickItemWrapper::sbk_o_contains("QQuickRhiItem", funcName, gil, pyOverride, point);
}

::QQuickRhiItemRenderer * QQuickRhiItemWrapper::createRenderer()
{
    static const char *funcName = "createRenderer";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItem.createRenderer");
        return nullptr;
    }
    return sbk_o_createRenderer("QQuickRhiItem", funcName, gil, pyOverride);
}

::QQuickRhiItemRenderer * QQuickRhiItemWrapper::sbk_o_createRenderer(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QQuickRhiItemRenderer >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QQuickRhiItemRenderer *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickRhiItemWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_customEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickRhiItem", funcName, gil, pyOverride, signal);
}

void QQuickRhiItemWrapper::dragEnterEvent(::QDragEnterEvent * arg__1)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dragEnterEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dragEnterEvent("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

void QQuickRhiItemWrapper::dragLeaveEvent(::QDragLeaveEvent * arg__1)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dragLeaveEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dragLeaveEvent("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

void QQuickRhiItemWrapper::dragMoveEvent(::QDragMoveEvent * arg__1)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dragMoveEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dragMoveEvent("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

void QQuickRhiItemWrapper::dropEvent(::QDropEvent * arg__1)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::dropEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_dropEvent("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

bool QQuickRhiItemWrapper::event(::QEvent * arg__1)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickRhiItem::event(arg__1);
    }
    return QSGTextureProviderWrapper::sbk_o_event("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

bool QQuickRhiItemWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSGTextureProviderWrapper::sbk_o_eventFilter("QQuickRhiItem", funcName, gil, pyOverride, watched, event);
}

void QQuickRhiItemWrapper::focusInEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::focusInEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_focusInEvent("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

void QQuickRhiItemWrapper::focusOutEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::focusOutEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_focusInEvent("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

void QQuickRhiItemWrapper::geometryChange(const ::QRectF & newGeometry, const ::QRectF & oldGeometry)
{
    static const char *funcName = "geometryChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickRhiItem::geometryChange(newGeometry, oldGeometry);
    }
    QQuickItemWrapper::sbk_o_geometryChange("QQuickRhiItem", funcName, gil, pyOverride, newGeometry, oldGeometry);
}

void QQuickRhiItemWrapper::hoverEnterEvent(::QHoverEvent * event)
{
    static const char *funcName = "hoverEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::hoverEnterEvent(event);
    }
    QQuickItemWrapper::sbk_o_hoverEnterEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::hoverLeaveEvent(::QHoverEvent * event)
{
    static const char *funcName = "hoverLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::hoverLeaveEvent(event);
    }
    QQuickItemWrapper::sbk_o_hoverEnterEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::hoverMoveEvent(::QHoverEvent * event)
{
    static const char *funcName = "hoverMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::hoverMoveEvent(event);
    }
    QQuickItemWrapper::sbk_o_hoverEnterEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::inputMethodEvent(::QInputMethodEvent * arg__1)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::inputMethodEvent(arg__1);
    }
    QQuickItemWrapper::sbk_o_inputMethodEvent("QQuickRhiItem", funcName, gil, pyOverride, arg__1);
}

::QVariant QQuickRhiItemWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::inputMethodQuery(query);
    }
    return QQuickItemWrapper::sbk_o_inputMethodQuery("QQuickRhiItem", funcName, gil, pyOverride, query);
}

bool QQuickRhiItemWrapper::isTextureProvider() const
{
    static const char *funcName = "isTextureProvider";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickRhiItem::isTextureProvider();
    }
    return QSGNodeWrapper::sbk_o_isSubtreeBlocked("QQuickRhiItem", funcName, gil, pyOverride);
}

void QQuickRhiItemWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::keyPressEvent(event);
    }
    QQuickItemWrapper::sbk_o_keyPressEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::keyReleaseEvent(event);
    }
    QQuickItemWrapper::sbk_o_keyPressEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseDoubleClickEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseMoveEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mousePressEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseReleaseEvent(event);
    }
    QQuickItemWrapper::sbk_o_mouseDoubleClickEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::mouseUngrabEvent()
{
    static const char *funcName = "mouseUngrabEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::mouseUngrabEvent();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickRhiItem", funcName, gil, pyOverride);
}

void QQuickRhiItemWrapper::releaseResources()
{
    static const char *funcName = "releaseResources";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickRhiItem::releaseResources();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickRhiItem", funcName, gil, pyOverride);
}

::QSGTextureProvider * QQuickRhiItemWrapper::textureProvider() const
{
    static const char *funcName = "textureProvider";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickRhiItem::textureProvider();
    }
    return QQuickItemWrapper::sbk_o_textureProvider("QQuickRhiItem", funcName, gil, pyOverride);
}

void QQuickRhiItemWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_timerEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::touchEvent(::QTouchEvent * event)
{
    static const char *funcName = "touchEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::touchEvent(event);
    }
    QQuickItemWrapper::sbk_o_touchEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

void QQuickRhiItemWrapper::touchUngrabEvent()
{
    static const char *funcName = "touchUngrabEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::touchUngrabEvent();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickRhiItem", funcName, gil, pyOverride);
}

::QSGNode * QQuickRhiItemWrapper::updatePaintNode(::QSGNode * arg__1, ::QQuickItem::UpdatePaintNodeData * arg__2)
{
    static const char *funcName = "updatePaintNode";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickRhiItem::updatePaintNode(arg__1, arg__2);
    }
    return sbk_o_updatePaintNode("QQuickRhiItem", funcName, gil, pyOverride, arg__1, arg__2);
}

::QSGNode * QQuickRhiItemWrapper::sbk_o_updatePaintNode(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSGNode * arg__1, ::QQuickItem::UpdatePaintNodeData * arg__2)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_UpdatePaintNodeData_IDX]), arg__2)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_UpdatePaintNodeData_IDX]), arg__2)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSGNode >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGNode *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

void QQuickRhiItemWrapper::updatePolish()
{
    static const char *funcName = "updatePolish";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::updatePolish();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickRhiItem", funcName, gil, pyOverride);
}

void QQuickRhiItemWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickItem::wheelEvent(event);
    }
    QQuickItemWrapper::sbk_o_wheelEvent("QQuickRhiItem", funcName, gil, pyOverride, event);
}

const QMetaObject *QQuickRhiItemWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuickRhiItem::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuickRhiItemWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuickRhiItem::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuickRhiItemWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuickRhiItemWrapper *>(this));
    return QQuickRhiItem::qt_metacast(_clname);
}

QQuickRhiItemWrapper::~QQuickRhiItemWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickRhiItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQuickRhiItem");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickRhiItem >()))
        return -1;

    QQuickRhiItemWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QQuickRhiItem", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickRhiItem::QQuickRhiItem(QQuickItem*=)
    if (numArgs == 0) {
        overloadId = 0; // QQuickRhiItem(QQuickItem*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QQuickRhiItem(QQuickItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QQuickItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQuickRhiItem(QQuickItem*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQuickRhiItemWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQuickRhiItemWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickRhiItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuickRhiItemFunc_alphaBlending(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alphaBlending()const
        bool cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->alphaBlending();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_colorBufferFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorBufferFormat()const
        QQuickRhiItem::TextureFormat cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->colorBufferFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_TextureFormat_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_createRenderer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createRenderer()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItem.createRenderer");
            return {};
        }
        QQuickRhiItemRenderer * cppResult = cppSelf->createRenderer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_effectiveColorBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // effectiveColorBufferSize()const
        QSize cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->effectiveColorBufferSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickRhiItem::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_fixedColorBufferHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fixedColorBufferHeight()const
        int cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->fixedColorBufferHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_fixedColorBufferWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fixedColorBufferWidth()const
        int cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->fixedColorBufferWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_geometryChange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "geometryChange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::geometryChange(QRectF,QRectF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // geometryChange(QRectF,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "geometryChange", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // geometryChange(QRectF,QRectF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickRhiItem::geometryChange(*cppArg0, *cppArg1)
                : cppSelf->geometryChange(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_isAutoRenderTargetEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAutoRenderTargetEnabled()const
        bool cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->isAutoRenderTargetEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_isMirrorVerticallyEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMirrorVerticallyEnabled()const
        bool cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->isMirrorVerticallyEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_isTextureProvider(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTextureProvider()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickRhiItem *>(cppSelf)->::QQuickRhiItem::isTextureProvider()
            : const_cast<const ::QQuickRhiItem *>(cppSelf)->isTextureProvider();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_releaseResources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // releaseResources()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickRhiItem::releaseResources()
            : cppSelf->releaseResources();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleCount()const
        int cppResult = const_cast<const ::QQuickRhiItem *>(cppSelf)->sampleCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_setAlphaBlending(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItem::setAlphaBlending(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAlphaBlending(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlphaBlending", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlphaBlending(bool)
            cppSelf->setAlphaBlending(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_setAutoRenderTarget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItem::setAutoRenderTarget(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoRenderTarget(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoRenderTarget", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoRenderTarget(bool)
            cppSelf->setAutoRenderTarget(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_setColorBufferFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItem::setColorBufferFormat(QQuickRhiItem::TextureFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_TextureFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorBufferFormat(QQuickRhiItem::TextureFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorBufferFormat", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        ::QQuickRhiItem::TextureFormat cppArg0{QQuickRhiItem::TextureFormat::RGBA8};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorBufferFormat(QQuickRhiItem::TextureFormat)
            cppSelf->setColorBufferFormat(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_setFixedColorBufferHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItem::setFixedColorBufferHeight(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFixedColorBufferHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFixedColorBufferHeight", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFixedColorBufferHeight(int)
            cppSelf->setFixedColorBufferHeight(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_setFixedColorBufferWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItem::setFixedColorBufferWidth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFixedColorBufferWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFixedColorBufferWidth", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFixedColorBufferWidth(int)
            cppSelf->setFixedColorBufferWidth(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_setMirrorVertically(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItem::setMirrorVertically(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMirrorVertically(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMirrorVertically", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMirrorVertically(bool)
            cppSelf->setMirrorVertically(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_setSampleCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItem::setSampleCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSampleCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSampleCount", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleCount(int)
            cppSelf->setSampleCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickRhiItemFunc_textureProvider(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureProvider()const
        QSGTextureProvider * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickRhiItem *>(cppSelf)->::QQuickRhiItem::textureProvider()
            : const_cast<const ::QQuickRhiItem *>(cppSelf)->textureProvider();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureProvider_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickRhiItemFunc_updatePaintNode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updatePaintNode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)->QSGNode*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_UpdatePaintNodeData_IDX]), (pyArgs[1])))) {
        overloadId = 0; // updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updatePaintNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQuickItem::UpdatePaintNodeData *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)
            QSGNode * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickRhiItem::updatePaintNode(cppArg0, cppArg1)
                : cppSelf->updatePaintNode(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QQuickRhiItem_PropertyStrings[] = {
    "alphaBlending::",
    "colorBufferFormat::",
    "effectiveColorBufferSize:",
    "fixedColorBufferHeight::",
    "fixedColorBufferWidth::",
    "mirrorVertically:isMirrorVerticallyEnabled:",
    "sampleCount::",
    nullptr // Sentinel
};

static const char *Sbk_QQuickRhiItem_EnumFlagInfo[] = {
    "TextureFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickRhiItem_methods[] = {
    {"alphaBlending", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_alphaBlending), METH_NOARGS, nullptr},
    {"colorBufferFormat", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_colorBufferFormat), METH_NOARGS, nullptr},
    {"createRenderer", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_createRenderer), METH_NOARGS, nullptr},
    {"effectiveColorBufferSize", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_effectiveColorBufferSize), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_event), METH_O, nullptr},
    {"fixedColorBufferHeight", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_fixedColorBufferHeight), METH_NOARGS, nullptr},
    {"fixedColorBufferWidth", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_fixedColorBufferWidth), METH_NOARGS, nullptr},
    {"geometryChange", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_geometryChange), METH_VARARGS, nullptr},
    {"isAutoRenderTargetEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_isAutoRenderTargetEnabled), METH_NOARGS, nullptr},
    {"isMirrorVerticallyEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_isMirrorVerticallyEnabled), METH_NOARGS, nullptr},
    {"isTextureProvider", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_isTextureProvider), METH_NOARGS, nullptr},
    {"releaseResources", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_releaseResources), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_sampleCount), METH_NOARGS, nullptr},
    {"setAlphaBlending", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_setAlphaBlending), METH_O, nullptr},
    {"setAutoRenderTarget", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_setAutoRenderTarget), METH_O, nullptr},
    {"setColorBufferFormat", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_setColorBufferFormat), METH_O, nullptr},
    {"setFixedColorBufferHeight", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_setFixedColorBufferHeight), METH_O, nullptr},
    {"setFixedColorBufferWidth", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_setFixedColorBufferWidth), METH_O, nullptr},
    {"setMirrorVertically", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_setMirrorVertically), METH_O, nullptr},
    {"setSampleCount", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_setSampleCount), METH_O, nullptr},
    {"textureProvider", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_textureProvider), METH_NOARGS, nullptr},
    {"updatePaintNode", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemFunc_updatePaintNode), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickRhiItem_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickRhiItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickRhiItemWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickRhiItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickRhiItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QQuickRhiItemSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QQuickRhiItem *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]))
        return static_cast< ::QQuickItem *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))
        return static_cast< ::QQmlParserStatus *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickRhiItem_Type = nullptr;
static PyTypeObject *Sbk_QQuickRhiItem_TypeF(void)
{
    return _Sbk_QQuickRhiItem_Type;
}

static PyType_Slot Sbk_QQuickRhiItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickRhiItem_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickRhiItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickRhiItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickRhiItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickRhiItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickRhiItem_spec = {
    "2:PySide6.QtQuick.QQuickRhiItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickRhiItem_slots
};

} //extern "C"

static void *Sbk_QQuickRhiItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QQuickItem >())
        return dynamic_cast< ::QQuickRhiItem *>(reinterpret_cast< ::QQuickItem *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuickRhiItem *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QQmlParserStatus >())
        return dynamic_cast< ::QQuickRhiItem *>(reinterpret_cast< ::QQmlParserStatus *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QQuickRhiItem_TextureFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickRhiItem::TextureFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickRhiItem::TextureFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickRhiItem_TextureFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_TextureFormat_IDX])))
        return Enum_PythonToCpp_QQuickRhiItem_TextureFormat;
    return {};
}

static PyObject *QQuickRhiItem_TextureFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickRhiItem::TextureFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickRhiItem::TextureFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_TextureFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickRhiItem_PythonToCpp_QQuickRhiItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickRhiItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickRhiItem_PythonToCpp_QQuickRhiItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickRhiItem_TypeF()))
        return QQuickRhiItem_PythonToCpp_QQuickRhiItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickRhiItem_PTR_CppToPython_QQuickRhiItem(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuickRhiItem *>(const_cast<void *>(cppIn)), Sbk_QQuickRhiItem_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickRhiItem_SignatureStrings[] = {
    "PySide6.QtQuick.QQuickRhiItem(self,parent:PySide6.QtQuick.QQuickItem=nullptr,*:KeywordOnly=None,sampleCount:int=None,colorBufferFormat:QQuickRhiItem.TextureFormat=None,mirrorVertically:bool=None,alphaBlending:bool=None,fixedColorBufferWidth:int=None,fixedColorBufferHeight:int=None,effectiveColorBufferSize:QSize=None)",
    "PySide6.QtQuick.QQuickRhiItem.alphaBlending(self)->bool",
    "PySide6.QtQuick.QQuickRhiItem.colorBufferFormat(self)->PySide6.QtQuick.QQuickRhiItem.TextureFormat",
    "PySide6.QtQuick.QQuickRhiItem.createRenderer(self)->PySide6.QtQuick.QQuickRhiItemRenderer",
    "PySide6.QtQuick.QQuickRhiItem.effectiveColorBufferSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtQuick.QQuickRhiItem.event(self,arg__1:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtQuick.QQuickRhiItem.fixedColorBufferHeight(self)->int",
    "PySide6.QtQuick.QQuickRhiItem.fixedColorBufferWidth(self)->int",
    "PySide6.QtQuick.QQuickRhiItem.geometryChange(self,newGeometry:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],oldGeometry:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtQuick.QQuickRhiItem.isAutoRenderTargetEnabled(self)->bool",
    "PySide6.QtQuick.QQuickRhiItem.isMirrorVerticallyEnabled(self)->bool",
    "PySide6.QtQuick.QQuickRhiItem.isTextureProvider(self)->bool",
    "PySide6.QtQuick.QQuickRhiItem.releaseResources(self)",
    "PySide6.QtQuick.QQuickRhiItem.sampleCount(self)->int",
    "PySide6.QtQuick.QQuickRhiItem.setAlphaBlending(self,enable:bool)",
    "PySide6.QtQuick.QQuickRhiItem.setAutoRenderTarget(self,enabled:bool)",
    "PySide6.QtQuick.QQuickRhiItem.setColorBufferFormat(self,format:PySide6.QtQuick.QQuickRhiItem.TextureFormat)",
    "PySide6.QtQuick.QQuickRhiItem.setFixedColorBufferHeight(self,height:int)",
    "PySide6.QtQuick.QQuickRhiItem.setFixedColorBufferWidth(self,width:int)",
    "PySide6.QtQuick.QQuickRhiItem.setMirrorVertically(self,enable:bool)",
    "PySide6.QtQuick.QQuickRhiItem.setSampleCount(self,samples:int)",
    "PySide6.QtQuick.QQuickRhiItem.textureProvider(self)->PySide6.QtQuick.QSGTextureProvider",
    "PySide6.QtQuick.QQuickRhiItem.updatePaintNode(self,arg__1:PySide6.QtQuick.QSGNode,arg__2:PySide6.QtQuick.QQuickItem.UpdatePaintNodeData)->PySide6.QtQuick.QSGNode",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickRhiItem_SignatureByteSize = 505;
static constexpr uint8_t QQuickRhiItem_SignatureBytes[505] = {
    0x78, 0xda, 0xa5, 0x55, 0x51, 0x6f, 0x9b, 0x30, 0x10, 0x7e, 0xef, 0xaf, 0xd8, 0xe3, 0x32, 0x79,
    0x48, 0xdb, 0xc3, 0x1e, 0x90, 0x3a, 0xa9, 0x65, 0x4d, 0x37, 0x4d, 0xeb, 0x48, 0xd2, 0x6e, 0x0f,
    0xd3, 0x54, 0xb9, 0xf8, 0x00, 0x6b, 0xc6, 0x46, 0x67, 0x93, 0x94, 0xfd, 0xfa, 0x19, 0x9c, 0x34,
    0x84, 0x90, 0xe0, 0x64, 0x2f, 0x20, 0xf9, 0xee, 0xbe, 0x3b, 0xbe, 0xfb, 0xfc, 0x11, 0xd7, 0x0b,
    0xce, 0xe0, 0x43, 0x30, 0x33, 0xb3, 0x8a, 0x27, 0x7f, 0x82, 0x59, 0xfb, 0x9a, 0xe7, 0xfc, 0x8b,
    0x81, 0xe2, 0xb5, 0x06, 0x91, 0x92, 0x92, 0x22, 0x48, 0x13, 0xc6, 0x83, 0x99, 0x4d, 0xda, 0xa5,
    0xac, 0x84, 0x28, 0x0d, 0x92, 0x37, 0xe1, 0x57, 0xa8, 0x57, 0x0a, 0xd9, 0x77, 0x29, 0xea, 0xcb,
    0x3b, 0x25, 0x81, 0x68, 0x5a, 0x94, 0x02, 0x22, 0x55, 0x59, 0x04, 0x2e, 0x8d, 0x3b, 0x4c, 0x94,
    0x50, 0x78, 0x5d, 0xa5, 0x29, 0xe0, 0x54, 0x61, 0x41, 0x4d, 0xb8, 0xd3, 0x36, 0xb8, 0x87, 0x67,
    0x53, 0x21, 0xb8, 0x98, 0x2b, 0x29, 0x38, 0xa2, 0xc2, 0x1f, 0x80, 0x86, 0x27, 0x54, 0x88, 0x3a,
    0x7c, 0x52, 0x4a, 0xb8, 0x10, 0x15, 0x65, 0x4e, 0xaf, 0x05, 0x48, 0xc6, 0x65, 0xd6, 0x39, 0x4f,
    0xf9, 0x33, 0xb0, 0x68, 0xdb, 0xea, 0x27, 0x67, 0x26, 0xdf, 0x0e, 0xd1, 0x0f, 0x7f, 0x06, 0x9e,
    0xe5, 0x9d, 0x21, 0xc1, 0x1e, 0x26, 0x86, 0x2f, 0xa1, 0x93, 0xb3, 0xe0, 0x7f, 0x21, 0x9c, 0x35,
    0xcf, 0x36, 0x67, 0x72, 0x11, 0x1f, 0xa3, 0x2f, 0xd8, 0x99, 0xac, 0x25, 0x73, 0xf2, 0xf6, 0x63,
    0x33, 0xe0, 0x48, 0xdd, 0x1e, 0x3f, 0x9b, 0xda, 0xe3, 0x65, 0x3b, 0xb4, 0x8d, 0xb5, 0x40, 0xa0,
    0x06, 0xe6, 0x76, 0x34, 0x40, 0x40, 0x2f, 0xfc, 0x4d, 0xf2, 0x08, 0xf2, 0x21, 0xde, 0xf6, 0x7b,
    0x44, 0x0a, 0x21, 0x68, 0xd9, 0x1c, 0x83, 0x5c, 0x5a, 0x01, 0x3a, 0x31, 0x52, 0xcc, 0x1e, 0x1f,
    0xdf, 0x85, 0x7d, 0x90, 0x9b, 0x26, 0xc3, 0x8f, 0xdc, 0xe1, 0xbd, 0x6f, 0xa6, 0xb3, 0xeb, 0x3f,
    0xb1, 0xbe, 0x95, 0x95, 0x7f, 0x79, 0x06, 0xaa, 0x00, 0x83, 0x75, 0x94, 0x53, 0x99, 0x39, 0x52,
    0x88, 0x84, 0xd5, 0xed, 0xfa, 0x38, 0x34, 0x75, 0x69, 0xc5, 0x12, 0x3c, 0x48, 0xae, 0xe4, 0xaf,
    0xfe, 0x67, 0xce, 0x2d, 0xb3, 0x53, 0xf2, 0x6a, 0xe8, 0xf8, 0x37, 0x51, 0x82, 0xfd, 0x3f, 0xca,
    0x98, 0xa4, 0xb9, 0xbe, 0xaa, 0x8c, 0x72, 0x52, 0xb8, 0xb7, 0xcb, 0x00, 0x73, 0x23, 0xe9, 0x93,
    0x00, 0x76, 0x82, 0xbc, 0xb9, 0xfe, 0xd6, 0xbb, 0xcd, 0xe7, 0x60, 0xac, 0xd5, 0x1e, 0xa3, 0x5a,
    0xda, 0x3c, 0x3c, 0xa1, 0x16, 0x41, 0x00, 0xd5, 0x56, 0xfc, 0x5a, 0x55, 0x98, 0x80, 0x76, 0xa5,
    0x23, 0x45, 0x1d, 0x23, 0xf3, 0x5f, 0xb6, 0x06, 0x73, 0xb5, 0xe7, 0x01, 0x04, 0xda, 0xaf, 0x6d,
    0x9d, 0x6a, 0xe2, 0x01, 0xd0, 0xe3, 0xbb, 0x8b, 0xc1, 0x7c, 0x41, 0xa2, 0x41, 0x47, 0x21, 0xa9,
    0x73, 0xdf, 0x13, 0x6c, 0xc5, 0xa3, 0xd7, 0xf4, 0xf0, 0x05, 0x23, 0xf9, 0x8b, 0xc9, 0x9e, 0x01,
    0xb4, 0xbd, 0x69, 0x64, 0xb5, 0xf1, 0x72, 0x0f, 0x98, 0xbe, 0xd8, 0xce, 0x59, 0xc2, 0xa2, 0xb7,
    0xfd, 0xf5, 0x7f, 0x4d, 0xfb, 0x8c, 0x60, 0x86, 0x85, 0xba, 0x57, 0xb4, 0xb8, 0xed, 0x49, 0x7a,
    0x04, 0xb7, 0x2a, 0x99, 0xb5, 0xf0, 0x98, 0xda, 0x11, 0xee, 0x14, 0x83, 0x03, 0xfe, 0xf8, 0x02,
    0xde, 0xe4, 0xb8, 0xf0, 0xfb, 0x23, 0xff, 0xf2, 0xe0, 0x61, 0x17, 0xf5, 0x13, 0x35, 0x74, 0x78,
    0xd8, 0x26, 0x7a, 0xf1, 0x0f, 0x3d, 0xb9, 0x04, 0xfc
};
#endif

PyTypeObject *init_QQuickRhiItem(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickRhiItem_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]))));

    _Sbk_QQuickRhiItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickRhiItem",
        "QQuickRhiItem*",
        &Sbk_QQuickRhiItem_spec,
        &Shiboken::callCppDestructor< QQuickRhiItem >,
        Sbk_QQuickRhiItem_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QQuickRhiItem_TypeF(); // references _Sbk_QQuickRhiItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickRhiItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickRhiItem_SignatureBytes, QQuickRhiItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickRhiItem_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickRhiItem_PythonToCpp_QQuickRhiItem_PTR,
        is_QQuickRhiItem_PythonToCpp_QQuickRhiItem_PTR_Convertible,
        QQuickRhiItem_PTR_CppToPython_QQuickRhiItem);

    Shiboken::Conversions::registerConverterName(converter, "QQuickRhiItem");
    Shiboken::Conversions::registerConverterName(converter, "QQuickRhiItem*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickRhiItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickRhiItem).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickRhiItemWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QQuickRhiItem_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QQuickRhiItem_TypeF(), &Sbk_QQuickRhiItemSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuickRhiItem_TypeF(), &Sbk_QQuickRhiItem_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QQuickRhiItem_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TextureFormat'.
    const char *TextureFormat_Initializer[] = {
        "RGBA8",
        "RGBA16F",
        "RGBA32F",
        "RGB10A2",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t TextureFormat_InitializerValues[] = {
        int8_t(QQuickRhiItem::TextureFormat::RGBA8),   //  0x00  0
        int8_t(QQuickRhiItem::TextureFormat::RGBA16F), //  0x01  1
        int8_t(QQuickRhiItem::TextureFormat::RGBA32F), //  0x02  2
        int8_t(QQuickRhiItem::TextureFormat::RGB10A2)  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickRhiItem_TypeF(),
        "2:PySide6.QtQuick.QQuickRhiItem.TextureFormat",
        TextureFormat_Initializer, TextureFormat_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_TextureFormat_IDX].type = EType;
    // Register converter for enum 'QQuickRhiItem::TextureFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickRhiItem_TextureFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickRhiItem_TextureFormat,
            is_Enum_PythonToCpp_QQuickRhiItem_TextureFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickRhiItem::TextureFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "TextureFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TextureFormat' enum.

    PySide::Signal::registerSignals(pyType, &::QQuickRhiItem::staticMetaObject);
    qRegisterMetaType< ::QQuickRhiItem::TextureFormat >("QQuickRhiItem::TextureFormat");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuickRhiItem::staticMetaObject, sizeof(QQuickRhiItemWrapper));

    return pyType;
}
