// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSGIMAGENODEWRAPPER_H
#define SBK_QSGIMAGENODEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtQuick/qsgimagenode.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSGImageNodeWrapper : public QSGImageNode
{
public:
    QSGImageNodeWrapper();
    QSGImageNodeWrapper(const QSGImageNodeWrapper &) = delete;
    QSGImageNodeWrapper& operator=(const QSGImageNodeWrapper &) = delete;
    QSGImageNodeWrapper(QSGImageNodeWrapper &&) = delete;
    QSGImageNodeWrapper& operator=(QSGImageNodeWrapper &&) = delete;
    ~QSGImageNodeWrapper() override;

    ::QSGTexture::AnisotropyLevel anisotropyLevel() const override;
    static ::QSGTexture::AnisotropyLevel sbk_o_anisotropyLevel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QSGTexture::Filtering filtering() const override;
    bool isSubtreeBlocked() const override;
    ::QSGTexture::Filtering mipmapFiltering() const override;
    bool ownsTexture() const override;
    void preprocess() override;
    ::QRectF rect() const override;
    void setAnisotropyLevel(::QSGTexture::AnisotropyLevel level) override;
    static void sbk_o_setAnisotropyLevel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSGTexture::AnisotropyLevel level);
    void setFiltering(::QSGTexture::Filtering filtering) override;
    void setMipmapFiltering(::QSGTexture::Filtering filtering) override;
    void setOwnsTexture(bool owns) override;
    static void sbk_o_setOwnsTexture(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, bool owns);
    void setRect(const ::QRectF & rect) override;
    // Inherited overloads, because the using keyword sux
    void setRect(qreal x, qreal y, qreal w, qreal h) { QSGImageNode::setRect(x, y, w, h); }

    void setSourceRect(const ::QRectF & r) override;
    // Inherited overloads, because the using keyword sux
    void setSourceRect(qreal x, qreal y, qreal w, qreal h) { QSGImageNode::setSourceRect(x, y, w, h); }

    void setTexture(::QSGTexture * texture) override;
    void setTextureCoordinatesTransform(::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> mode) override;
    static void sbk_o_setTextureCoordinatesTransform(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> mode);
    ::QRectF sourceRect() const override;
    ::QSGTexture * texture() const override;
    static ::QSGTexture * sbk_o_texture(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> textureCoordinatesTransform() const override;
    static ::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> sbk_o_textureCoordinatesTransform(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[18] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSGIMAGENODEWRAPPER_H
