// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qremoteobjectdynamicreplica_wrapper.h"

// Wrappers providing overrides
#include "qremoteobjectreplica_wrapper.h"
#include "qtroiodevicebase_wrapper.h"

// Argument includes
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRemoteObjectDynamicReplicaWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QRemoteObjectDynamicReplicaWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_childEvent("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, event);
}

void QRemoteObjectDynamicReplicaWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, signal);
}

void QRemoteObjectDynamicReplicaWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_customEvent("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, event);
}

void QRemoteObjectDynamicReplicaWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, signal);
}

bool QRemoteObjectDynamicReplicaWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_event("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, event);
}

bool QRemoteObjectDynamicReplicaWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_eventFilter("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, watched, event);
}

void QRemoteObjectDynamicReplicaWrapper::initialize()
{
    static const char *funcName = "initialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectReplica::initialize();
    }
    QtROIoDeviceBaseWrapper::sbk_o_close("QRemoteObjectDynamicReplica", funcName, gil, pyOverride);
}

void QRemoteObjectDynamicReplicaWrapper::setNode(::QRemoteObjectNode * node)
{
    // This method belongs to a property.
    static const char *funcName = "2:setNode";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectReplica::setNode(node);
    }
    QRemoteObjectReplicaWrapper::sbk_o_setNode("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, node);
}

void QRemoteObjectDynamicReplicaWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_timerEvent("QRemoteObjectDynamicReplica", funcName, gil, pyOverride, event);
}

const QMetaObject *QRemoteObjectDynamicReplicaWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRemoteObjectDynamicReplica::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRemoteObjectDynamicReplicaWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRemoteObjectDynamicReplica::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRemoteObjectDynamicReplicaWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRemoteObjectDynamicReplicaWrapper *>(this));
    return QRemoteObjectDynamicReplica::qt_metacast(_clname);
}

QRemoteObjectDynamicReplicaWrapper::~QRemoteObjectDynamicReplicaWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QRemoteObjectDynamicReplica_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QRemoteObjectDynamicReplica");
    return -1;
}


static const char *Sbk_QRemoteObjectDynamicReplica_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRemoteObjectDynamicReplica_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRemoteObjectDynamicReplica_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRemoteObjectDynamicReplica *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectDynamicReplica_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRemoteObjectDynamicReplicaWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRemoteObjectDynamicReplica_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRemoteObjectDynamicReplica_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRemoteObjectDynamicReplica_Type = nullptr;
static PyTypeObject *Sbk_QRemoteObjectDynamicReplica_TypeF(void)
{
    return _Sbk_QRemoteObjectDynamicReplica_Type;
}

static PyType_Slot Sbk_QRemoteObjectDynamicReplica_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRemoteObjectDynamicReplica_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRemoteObjectDynamicReplica_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRemoteObjectDynamicReplica_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRemoteObjectDynamicReplica_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRemoteObjectDynamicReplica_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRemoteObjectDynamicReplica_spec = {
    "2:PySide6.QtRemoteObjects.QRemoteObjectDynamicReplica",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRemoteObjectDynamicReplica_slots
};

} //extern "C"

static void *Sbk_QRemoteObjectDynamicReplica_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QRemoteObjectDynamicReplica *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRemoteObjectDynamicReplica_PythonToCpp_QRemoteObjectDynamicReplica_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRemoteObjectDynamicReplica_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRemoteObjectDynamicReplica_PythonToCpp_QRemoteObjectDynamicReplica_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRemoteObjectDynamicReplica_TypeF()))
        return QRemoteObjectDynamicReplica_PythonToCpp_QRemoteObjectDynamicReplica_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRemoteObjectDynamicReplica_PTR_CppToPython_QRemoteObjectDynamicReplica(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QRemoteObjectDynamicReplica *>(const_cast<void *>(cppIn)), Sbk_QRemoteObjectDynamicReplica_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRemoteObjectDynamicReplica_SignatureStrings[] = {
    nullptr}; // Sentinel
#else
static constexpr size_t QRemoteObjectDynamicReplica_SignatureByteSize = 0;
static constexpr uint8_t QRemoteObjectDynamicReplica_SignatureBytes[1] = {
    0x00
};
#endif

PyTypeObject *init_QRemoteObjectDynamicReplica(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectDynamicReplica_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectDynamicReplica_IDX].type;

    Shiboken::AutoDecRef Sbk_QRemoteObjectDynamicReplica_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectReplica_IDX]))));

    _Sbk_QRemoteObjectDynamicReplica_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRemoteObjectDynamicReplica",
        "QRemoteObjectDynamicReplica*",
        &Sbk_QRemoteObjectDynamicReplica_spec,
        &Shiboken::callCppDestructor< QRemoteObjectDynamicReplica >,
        Sbk_QRemoteObjectDynamicReplica_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRemoteObjectDynamicReplica_TypeF(); // references _Sbk_QRemoteObjectDynamicReplica_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRemoteObjectDynamicReplica_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRemoteObjectDynamicReplica_SignatureBytes, QRemoteObjectDynamicReplica_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRemoteObjectDynamicReplica_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectDynamicReplica_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRemoteObjectDynamicReplica_PythonToCpp_QRemoteObjectDynamicReplica_PTR,
        is_QRemoteObjectDynamicReplica_PythonToCpp_QRemoteObjectDynamicReplica_PTR_Convertible,
        QRemoteObjectDynamicReplica_PTR_CppToPython_QRemoteObjectDynamicReplica);

    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectDynamicReplica");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectDynamicReplica*");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectDynamicReplica&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectDynamicReplica).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRemoteObjectDynamicReplicaWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRemoteObjectDynamicReplica_TypeF(), &Sbk_QRemoteObjectDynamicReplica_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QRemoteObjectDynamicReplica::staticMetaObject, sizeof(QRemoteObjectDynamicReplicaWrapper));

    return pyType;
}
