// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qremoteobjectregistry_wrapper.h"

// Wrappers providing overrides
#include "qremoteobjectreplica_wrapper.h"
#include "qtroiodevicebase_wrapper.h"

// Argument includes
#include <QHash>
#include <QString>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRemoteObjectRegistryWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QRemoteObjectRegistryWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_childEvent("QRemoteObjectRegistry", funcName, gil, pyOverride, event);
}

void QRemoteObjectRegistryWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectRegistry", funcName, gil, pyOverride, signal);
}

void QRemoteObjectRegistryWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_customEvent("QRemoteObjectRegistry", funcName, gil, pyOverride, event);
}

void QRemoteObjectRegistryWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectRegistry", funcName, gil, pyOverride, signal);
}

bool QRemoteObjectRegistryWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_event("QRemoteObjectRegistry", funcName, gil, pyOverride, event);
}

bool QRemoteObjectRegistryWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_eventFilter("QRemoteObjectRegistry", funcName, gil, pyOverride, watched, event);
}

void QRemoteObjectRegistryWrapper::setNode(::QRemoteObjectNode * node)
{
    // This method belongs to a property.
    static const char *funcName = "2:setNode";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectReplica::setNode(node);
    }
    QRemoteObjectReplicaWrapper::sbk_o_setNode("QRemoteObjectRegistry", funcName, gil, pyOverride, node);
}

void QRemoteObjectRegistryWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_timerEvent("QRemoteObjectRegistry", funcName, gil, pyOverride, event);
}

const QMetaObject *QRemoteObjectRegistryWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRemoteObjectRegistry::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRemoteObjectRegistryWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRemoteObjectRegistry::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRemoteObjectRegistryWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRemoteObjectRegistryWrapper *>(this));
    return QRemoteObjectRegistry::qt_metacast(_clname);
}

QRemoteObjectRegistryWrapper::~QRemoteObjectRegistryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QRemoteObjectRegistry_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QRemoteObjectRegistry");
    return -1;
}

static PyObject *Sbk_QRemoteObjectRegistryFunc_addSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectRegistry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectRegistry::addSource(std::pair<QString,QRemoteObjectSourceLocationInfo>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtRemoteObjectsTypeConverters[SBK_QtRemoteObjects_std_pair_QString_QRemoteObjectSourceLocationInfo_IDX], (pyArg)))) {
        overloadId = 0; // addSource(std::pair<QString,QRemoteObjectSourceLocationInfo>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addSource", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]);

    // Call function/method
    {
        std::pair<QString,QRemoteObjectSourceLocationInfo> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSource(std::pair<QString,QRemoteObjectSourceLocationInfo>)
            cppSelf->addSource(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRemoteObjectRegistryFunc_initialize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectRegistry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("initialize()");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRemoteObjectRegistryFunc_pushToRegistryIfNeeded(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectRegistry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pushToRegistryIfNeeded()
        cppSelf->pushToRegistryIfNeeded();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRemoteObjectRegistryFunc_registerMetatypes(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // registerMetatypes()
        ::QRemoteObjectRegistry::registerMetatypes();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRemoteObjectRegistryFunc_removeSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectRegistry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectRegistry::removeSource(std::pair<QString,QRemoteObjectSourceLocationInfo>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtRemoteObjectsTypeConverters[SBK_QtRemoteObjects_std_pair_QString_QRemoteObjectSourceLocationInfo_IDX], (pyArg)))) {
        overloadId = 0; // removeSource(std::pair<QString,QRemoteObjectSourceLocationInfo>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeSource", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]);

    // Call function/method
    {
        std::pair<QString,QRemoteObjectSourceLocationInfo> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeSource(std::pair<QString,QRemoteObjectSourceLocationInfo>)
            cppSelf->removeSource(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRemoteObjectRegistryFunc_sourceLocations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectRegistry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceLocations()const
        QHash<QString,QRemoteObjectSourceLocationInfo> cppResult = const_cast<const ::QRemoteObjectRegistry *>(cppSelf)->sourceLocations();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtRemoteObjectsTypeConverters[SBK_QtRemoteObjects_QHash_QString_QRemoteObjectSourceLocationInfo_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QRemoteObjectRegistry_PropertyStrings[] = {
    "sourceLocations:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRemoteObjectRegistry_methods[] = {
    {"addSource", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectRegistryFunc_addSource), METH_O, nullptr},
    {"initialize", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectRegistryFunc_initialize), METH_NOARGS, nullptr},
    {"pushToRegistryIfNeeded", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectRegistryFunc_pushToRegistryIfNeeded), METH_NOARGS, nullptr},
    {"registerMetatypes", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectRegistryFunc_registerMetatypes), METH_NOARGS|METH_STATIC, nullptr},
    {"removeSource", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectRegistryFunc_removeSource), METH_O, nullptr},
    {"sourceLocations", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectRegistryFunc_sourceLocations), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRemoteObjectRegistry_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRemoteObjectRegistry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRemoteObjectRegistryWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRemoteObjectRegistry_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRemoteObjectRegistry_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRemoteObjectRegistry_Type = nullptr;
static PyTypeObject *Sbk_QRemoteObjectRegistry_TypeF(void)
{
    return _Sbk_QRemoteObjectRegistry_Type;
}

static PyType_Slot Sbk_QRemoteObjectRegistry_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRemoteObjectRegistry_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRemoteObjectRegistry_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRemoteObjectRegistry_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRemoteObjectRegistry_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRemoteObjectRegistry_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRemoteObjectRegistry_spec = {
    "2:PySide6.QtRemoteObjects.QRemoteObjectRegistry",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRemoteObjectRegistry_slots
};

} //extern "C"

static void *Sbk_QRemoteObjectRegistry_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QRemoteObjectRegistry *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRemoteObjectRegistry_PythonToCpp_QRemoteObjectRegistry_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRemoteObjectRegistry_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRemoteObjectRegistry_PythonToCpp_QRemoteObjectRegistry_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRemoteObjectRegistry_TypeF()))
        return QRemoteObjectRegistry_PythonToCpp_QRemoteObjectRegistry_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRemoteObjectRegistry_PTR_CppToPython_QRemoteObjectRegistry(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QRemoteObjectRegistry *>(const_cast<void *>(cppIn)), Sbk_QRemoteObjectRegistry_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRemoteObjectRegistry_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QRemoteObjectRegistry.addSource(self,entry:std.pair[QString, PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo])",
    "PySide6.QtRemoteObjects.QRemoteObjectRegistry.initialize(self)",
    "PySide6.QtRemoteObjects.QRemoteObjectRegistry.pushToRegistryIfNeeded(self)",
    "PySide6.QtRemoteObjects.QRemoteObjectRegistry.registerMetatypes()",
    "PySide6.QtRemoteObjects.QRemoteObjectRegistry.removeSource(self,entry:std.pair[QString, PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo])",
    "PySide6.QtRemoteObjects.QRemoteObjectRegistry.sourceLocations(self)->QHash[QString, PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo]",
    nullptr}; // Sentinel
#else
static constexpr size_t QRemoteObjectRegistry_SignatureByteSize = 172;
static constexpr uint8_t QRemoteObjectRegistry_SignatureBytes[172] = {
    0x78, 0xda, 0xcd, 0x90, 0xbb, 0x0e, 0x82, 0x40, 0x10, 0x45, 0x7b, 0xbe, 0xc2, 0x12, 0x13, 0xdc,
    0xd2, 0xc2, 0xc2, 0x5a, 0x12, 0x1f, 0x2c, 0xd8, 0x19, 0x8b, 0x95, 0x1d, 0x60, 0x0c, 0xec, 0x90,
    0x9d, 0xc1, 0x04, 0xbf, 0x5e, 0x23, 0x31, 0xd1, 0x4e, 0xb4, 0xb1, 0x9b, 0x3b, 0xc9, 0x3d, 0x39,
    0xb9, 0x49, 0x9f, 0xa1, 0x85, 0xb9, 0xd2, 0x92, 0x42, 0x43, 0x02, 0xbb, 0xd3, 0x19, 0x72, 0x61,
    0xa5, 0x5f, 0x63, 0x0a, 0x25, 0xb2, 0xf8, 0x5e, 0x19, 0x6b, 0x33, 0xea, 0x7c, 0x0e, 0x21, 0x43,
    0x5d, 0x44, 0xe0, 0xee, 0xcf, 0x05, 0x8b, 0x55, 0xad, 0x41, 0x7f, 0xd0, 0x99, 0x78, 0x74, 0x65,
    0x34, 0x49, 0x3e, 0x81, 0x0e, 0xa0, 0x35, 0xe5, 0x46, 0x90, 0x5c, 0xec, 0x0a, 0x3a, 0x4e, 0x83,
    0x64, 0x94, 0x0e, 0x3a, 0x14, 0x34, 0x35, 0x5e, 0x07, 0x9f, 0xb1, 0xf5, 0xb6, 0xe3, 0x6a, 0x4f,
    0xcf, 0x18, 0x17, 0x5b, 0x00, 0x0b, 0xf6, 0x2b, 0x94, 0x7f, 0x1c, 0xe0, 0x37, 0x20, 0x46, 0xfa,
    0x16, 0x38, 0x1c, 0x4f, 0x68, 0xe8, 0x02, 0xff, 0xb4, 0x2e, 0xbf, 0x21, 0x78, 0xd8, 0x65, 0xb6,
    0xd4, 0x2b, 0xc3, 0xd5, 0xef, 0x36, 0xc1, 0x0d, 0x60, 0xd1, 0xee, 0xbf
};
#endif

PyTypeObject *init_QRemoteObjectRegistry(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX].type;

    Shiboken::AutoDecRef Sbk_QRemoteObjectRegistry_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectReplica_IDX]))));

    _Sbk_QRemoteObjectRegistry_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRemoteObjectRegistry",
        "QRemoteObjectRegistry*",
        &Sbk_QRemoteObjectRegistry_spec,
        &Shiboken::callCppDestructor< QRemoteObjectRegistry >,
        Sbk_QRemoteObjectRegistry_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRemoteObjectRegistry_TypeF(); // references _Sbk_QRemoteObjectRegistry_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRemoteObjectRegistry_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRemoteObjectRegistry_SignatureBytes, QRemoteObjectRegistry_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRemoteObjectRegistry_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRemoteObjectRegistry_PythonToCpp_QRemoteObjectRegistry_PTR,
        is_QRemoteObjectRegistry_PythonToCpp_QRemoteObjectRegistry_PTR_Convertible,
        QRemoteObjectRegistry_PTR_CppToPython_QRemoteObjectRegistry);

    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectRegistry");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectRegistry*");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectRegistry&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectRegistry).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRemoteObjectRegistryWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRemoteObjectRegistry_TypeF(), &Sbk_QRemoteObjectRegistry_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QRemoteObjectRegistry::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QRemoteObjectRegistry::staticMetaObject, sizeof(QRemoteObjectRegistryWrapper));

    return pyType;
}
