// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qremoteobjectregistryhost_wrapper.h"

// Wrappers providing overrides
#include "qremoteobjecthostbase_wrapper.h"
#include "qconnectionabstractserver_wrapper.h"
#include "qremoteobjectnode_wrapper.h"
#include "qtroiodevicebase_wrapper.h"

// Argument includes
#include <QString>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRemoteObjectRegistryHostWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QRemoteObjectRegistryHostWrapper::QRemoteObjectRegistryHostWrapper(const ::QUrl & registryAddress, ::QObject * parent) : QRemoteObjectRegistryHost(registryAddress, parent)
{
}

void QRemoteObjectRegistryHostWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_childEvent("QRemoteObjectRegistryHost", funcName, gil, pyOverride, event);
}

void QRemoteObjectRegistryHostWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectRegistryHost", funcName, gil, pyOverride, signal);
}

void QRemoteObjectRegistryHostWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_customEvent("QRemoteObjectRegistryHost", funcName, gil, pyOverride, event);
}

void QRemoteObjectRegistryHostWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectRegistryHost", funcName, gil, pyOverride, signal);
}

bool QRemoteObjectRegistryHostWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_event("QRemoteObjectRegistryHost", funcName, gil, pyOverride, event);
}

bool QRemoteObjectRegistryHostWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_eventFilter("QRemoteObjectRegistryHost", funcName, gil, pyOverride, watched, event);
}

::QUrl QRemoteObjectRegistryHostWrapper::hostUrl() const
{
    static const char *funcName = "hostUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectHostBase::hostUrl();
    }
    return QConnectionAbstractServerWrapper::sbk_o_address("QRemoteObjectRegistryHost", funcName, gil, pyOverride);
}

bool QRemoteObjectRegistryHostWrapper::setHostUrl(const ::QUrl & hostAddress, ::QRemoteObjectHostBase::AllowedSchemas allowedSchemas)
{
    static const char *funcName = "setHostUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectHostBase::setHostUrl(hostAddress, allowedSchemas);
    }
    return QRemoteObjectHostBaseWrapper::sbk_o_setHostUrl("QRemoteObjectRegistryHost", funcName, gil, pyOverride, hostAddress, allowedSchemas);
}

void QRemoteObjectRegistryHostWrapper::setName(const ::QString & name)
{
    static const char *funcName = "setName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectHostBase::setName(name);
    }
    QRemoteObjectNodeWrapper::sbk_o_setName("QRemoteObjectRegistryHost", funcName, gil, pyOverride, name);
}

bool QRemoteObjectRegistryHostWrapper::setRegistryUrl(const ::QUrl & registryUrl)
{
    static const char *funcName = "setRegistryUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectRegistryHost::setRegistryUrl(registryUrl);
    }
    return QRemoteObjectNodeWrapper::sbk_o_setRegistryUrl("QRemoteObjectRegistryHost", funcName, gil, pyOverride, registryUrl);
}

void QRemoteObjectRegistryHostWrapper::timerEvent(::QTimerEvent * arg__1)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectNode::timerEvent(arg__1);
    }
    QtROIoDeviceBaseWrapper::sbk_o_timerEvent("QRemoteObjectRegistryHost", funcName, gil, pyOverride, arg__1);
}

const QMetaObject *QRemoteObjectRegistryHostWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRemoteObjectRegistryHost::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRemoteObjectRegistryHostWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRemoteObjectRegistryHost::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRemoteObjectRegistryHostWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRemoteObjectRegistryHostWrapper *>(this));
    return QRemoteObjectRegistryHost::qt_metacast(_clname);
}

QRemoteObjectRegistryHostWrapper::~QRemoteObjectRegistryHostWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRemoteObjectRegistryHost_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRemoteObjectRegistryHost >()))
        return -1;

    QRemoteObjectRegistryHostWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QRemoteObjectRegistryHost", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRemoteObjectRegistryHost::QRemoteObjectRegistryHost(const QUrl&=,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QRemoteObjectRegistryHost(QUrl,QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QRemoteObjectRegistryHost(QUrl,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QRemoteObjectRegistryHost(QUrl,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"registryAddress", 0}, {"parent", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QUrl cppArg0_local = QUrl();
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRemoteObjectRegistryHost(QUrl,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QRemoteObjectRegistryHostWrapper(*cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QRemoteObjectRegistryHostWrapper(*cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QRemoteObjectRegistryHost >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QRemoteObjectRegistryHostFunc_setRegistryUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectRegistryHost *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setRegistryUrl(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setRegistryUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRegistryUrl", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRegistryUrl(QUrl)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRemoteObjectRegistryHost::setRegistryUrl(*cppArg0)
                : cppSelf->setRegistryUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QRemoteObjectRegistryHost_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRemoteObjectRegistryHost_methods[] = {
    {"setRegistryUrl", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectRegistryHostFunc_setRegistryUrl), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRemoteObjectRegistryHost_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRemoteObjectRegistryHost *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRemoteObjectRegistryHostWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRemoteObjectRegistryHost_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRemoteObjectRegistryHost_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRemoteObjectRegistryHost_Type = nullptr;
static PyTypeObject *Sbk_QRemoteObjectRegistryHost_TypeF(void)
{
    return _Sbk_QRemoteObjectRegistryHost_Type;
}

static PyType_Slot Sbk_QRemoteObjectRegistryHost_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRemoteObjectRegistryHost_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRemoteObjectRegistryHost_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRemoteObjectRegistryHost_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRemoteObjectRegistryHost_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRemoteObjectRegistryHost_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRemoteObjectRegistryHost_spec = {
    "2:PySide6.QtRemoteObjects.QRemoteObjectRegistryHost",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRemoteObjectRegistryHost_slots
};

} //extern "C"

static void *Sbk_QRemoteObjectRegistryHost_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QRemoteObjectRegistryHost *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRemoteObjectRegistryHost_PythonToCpp_QRemoteObjectRegistryHost_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRemoteObjectRegistryHost_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRemoteObjectRegistryHost_PythonToCpp_QRemoteObjectRegistryHost_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRemoteObjectRegistryHost_TypeF()))
        return QRemoteObjectRegistryHost_PythonToCpp_QRemoteObjectRegistryHost_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRemoteObjectRegistryHost_PTR_CppToPython_QRemoteObjectRegistryHost(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QRemoteObjectRegistryHost *>(const_cast<void *>(cppIn)), Sbk_QRemoteObjectRegistryHost_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRemoteObjectRegistryHost_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QRemoteObjectRegistryHost(self,registryAddress:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl(),parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtRemoteObjects.QRemoteObjectRegistryHost.setRegistryUrl(self,registryUrl:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QRemoteObjectRegistryHost_SignatureByteSize = 148;
static constexpr uint8_t QRemoteObjectRegistryHost_SignatureBytes[148] = {
    0x78, 0xda, 0x95, 0x8e, 0xb1, 0x0a, 0xc2, 0x30, 0x14, 0x45, 0xf7, 0x7e, 0x85, 0x63, 0x03, 0x31,
    0xa3, 0x43, 0xa1, 0x82, 0xb8, 0xb8, 0x99, 0xb4, 0x74, 0x12, 0x07, 0x6b, 0x9e, 0x25, 0x12, 0x93,
    0xf0, 0xde, 0x73, 0xc8, 0xdf, 0xdb, 0xa2, 0x14, 0x75, 0xeb, 0x78, 0x2e, 0x97, 0x7b, 0x8f, 0xce,
    0xad, 0xb3, 0xb0, 0x51, 0x86, 0x1b, 0x78, 0x44, 0x86, 0x63, 0x7f, 0x87, 0x2b, 0x93, 0x32, 0xdf,
    0xd8, 0xc0, 0xe0, 0x88, 0x31, 0x1f, 0x22, 0x71, 0x49, 0xe0, 0x6f, 0x12, 0x3f, 0xc9, 0xce, 0x5a,
    0x04, 0xa2, 0x8a, 0x73, 0x72, 0x61, 0x50, 0x5d, 0x70, 0x31, 0x9c, 0xf4, 0xbc, 0xb9, 0x8f, 0x08,
    0xca, 0x74, 0xe8, 0xe5, 0xca, 0xb4, 0x8c, 0x63, 0xe5, 0x5c, 0x4f, 0x58, 0x0a, 0x99, 0x2e, 0x08,
    0x81, 0xab, 0xff, 0xee, 0xfb, 0xb0, 0x0e, 0x4f, 0xef, 0x13, 0xa3, 0x28, 0xf4, 0x52, 0x3f, 0x45,
    0x30, 0xf3, 0xf4, 0xf4, 0xa3, 0x3b, 0x06, 0x0b, 0x54, 0xc5, 0x7a, 0xdb, 0xc7, 0xe8, 0x8b, 0x17,
    0x84, 0x0a, 0x6c, 0x71
};
#endif

PyTypeObject *init_QRemoteObjectRegistryHost(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX].type;

    Shiboken::AutoDecRef Sbk_QRemoteObjectRegistryHost_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]))));

    _Sbk_QRemoteObjectRegistryHost_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRemoteObjectRegistryHost",
        "QRemoteObjectRegistryHost*",
        &Sbk_QRemoteObjectRegistryHost_spec,
        &Shiboken::callCppDestructor< QRemoteObjectRegistryHost >,
        Sbk_QRemoteObjectRegistryHost_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRemoteObjectRegistryHost_TypeF(); // references _Sbk_QRemoteObjectRegistryHost_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRemoteObjectRegistryHost_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRemoteObjectRegistryHost_SignatureBytes, QRemoteObjectRegistryHost_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRemoteObjectRegistryHost_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistryHost_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRemoteObjectRegistryHost_PythonToCpp_QRemoteObjectRegistryHost_PTR,
        is_QRemoteObjectRegistryHost_PythonToCpp_QRemoteObjectRegistryHost_PTR_Convertible,
        QRemoteObjectRegistryHost_PTR_CppToPython_QRemoteObjectRegistryHost);

    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectRegistryHost");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectRegistryHost*");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectRegistryHost&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectRegistryHost).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRemoteObjectRegistryHostWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRemoteObjectRegistryHost_TypeF(), &Sbk_QRemoteObjectRegistryHost_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QRemoteObjectRegistryHost::staticMetaObject, sizeof(QRemoteObjectRegistryHostWrapper));

    return pyType;
}
