// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qtroclientiodevice_wrapper.h"

// Wrappers providing overrides
#include "qtroiodevicebase_wrapper.h"

// Argument includes
#include <QString>
#include <QtRemoteObjects/qconnectionfactories.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QtROClientIoDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QtROClientIoDeviceWrapper::QtROClientIoDeviceWrapper(::QObject * parent) : QtROClientIoDevice(parent)
{
}

qint64 QtROClientIoDeviceWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::bytesAvailable();
    }
    return QtROIoDeviceBaseWrapper::sbk_o_bytesAvailable("QtROClientIoDevice", funcName, gil, pyOverride);
}

void QtROClientIoDeviceWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_childEvent("QtROClientIoDevice", funcName, gil, pyOverride, event);
}

void QtROClientIoDeviceWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::close();
    }
    QtROIoDeviceBaseWrapper::sbk_o_close("QtROClientIoDevice", funcName, gil, pyOverride);
}

void QtROClientIoDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QtROClientIoDevice", funcName, gil, pyOverride, signal);
}

void QtROClientIoDeviceWrapper::connectToServer()
{
    static const char *funcName = "connectToServer";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QtROClientIoDevice.connectToServer");
        return;
    }
    QtROIoDeviceBaseWrapper::sbk_o_close("QtROClientIoDevice", funcName, gil, pyOverride);
}

::QIODevice * QtROClientIoDeviceWrapper::connection() const
{
    static const char *funcName = "connection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QtROClientIoDevice.connection");
        return nullptr;
    }
    return QtROIoDeviceBaseWrapper::sbk_o_connection("QtROClientIoDevice", funcName, gil, pyOverride);
}

void QtROClientIoDeviceWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_customEvent("QtROClientIoDevice", funcName, gil, pyOverride, event);
}

::QString QtROClientIoDeviceWrapper::deviceType() const
{
    static const char *funcName = "deviceType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROClientIoDevice::deviceType();
    }
    return QtROIoDeviceBaseWrapper::sbk_o_deviceType("QtROClientIoDevice", funcName, gil, pyOverride);
}

void QtROClientIoDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QtROClientIoDevice", funcName, gil, pyOverride, signal);
}

void QtROClientIoDeviceWrapper::doClose()
{
    static const char *funcName = "doClose";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QtROClientIoDevice.doClose");
        return;
    }
    QtROIoDeviceBaseWrapper::sbk_o_close("QtROClientIoDevice", funcName, gil, pyOverride);
}

void QtROClientIoDeviceWrapper::doDisconnectFromServer()
{
    static const char *funcName = "doDisconnectFromServer";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QtROClientIoDevice.doDisconnectFromServer");
        return;
    }
    QtROIoDeviceBaseWrapper::sbk_o_close("QtROClientIoDevice", funcName, gil, pyOverride);
}

bool QtROClientIoDeviceWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_event("QtROClientIoDevice", funcName, gil, pyOverride, event);
}

bool QtROClientIoDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_eventFilter("QtROClientIoDevice", funcName, gil, pyOverride, watched, event);
}

bool QtROClientIoDeviceWrapper::isOpen() const
{
    static const char *funcName = "isOpen";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::isOpen();
    }
    return QtROIoDeviceBaseWrapper::sbk_o_isOpen("QtROClientIoDevice", funcName, gil, pyOverride);
}

void QtROClientIoDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_timerEvent("QtROClientIoDevice", funcName, gil, pyOverride, event);
}

void QtROClientIoDeviceWrapper::write(const ::QByteArray & data)
{
    static const char *funcName = "write";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::write(data);
    }
    QtROIoDeviceBaseWrapper::sbk_o_write("QtROClientIoDevice", funcName, gil, pyOverride, data);
}

void QtROClientIoDeviceWrapper::write(const ::QByteArray & data, qint64 arg__2)
{
    static const char *funcName = "write";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::write(data, arg__2);
    }
    QtROIoDeviceBaseWrapper::sbk_o_write("QtROClientIoDevice", funcName, gil, pyOverride, data, arg__2);
}

const QMetaObject *QtROClientIoDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QtROClientIoDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QtROClientIoDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QtROClientIoDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QtROClientIoDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QtROClientIoDeviceWrapper *>(this));
    return QtROClientIoDevice::qt_metacast(_clname);
}

QtROClientIoDeviceWrapper::~QtROClientIoDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QtROClientIoDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QtROClientIoDevice");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QtROClientIoDevice >()))
        return -1;

    QtROClientIoDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QtROClientIoDevice", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QtROClientIoDevice::QtROClientIoDevice(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QtROClientIoDevice(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QtROClientIoDevice(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QtROClientIoDevice(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QtROClientIoDeviceWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QtROClientIoDeviceWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QtROClientIoDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QtROClientIoDeviceFunc_connectToServer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectToServer()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QtROClientIoDevice.connectToServer");
            return {};
        }
        cppSelf->connectToServer();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QtROClientIoDeviceFunc_deviceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deviceType()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QtROClientIoDevice *>(cppSelf)->::QtROClientIoDevice::deviceType()
            : const_cast<const ::QtROClientIoDevice *>(cppSelf)->deviceType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QtROClientIoDeviceFunc_disconnectFromServer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // disconnectFromServer()
        cppSelf->disconnectFromServer();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QtROClientIoDeviceFunc_doDisconnectFromServer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // doDisconnectFromServer()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QtROClientIoDevice.doDisconnectFromServer");
            return {};
        }
        cppSelf->doDisconnectFromServer();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QtROClientIoDeviceFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QtROClientIoDevice::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrl", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QtROClientIoDeviceFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QtROClientIoDevice *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QtROClientIoDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtROClientIoDevice_methods[] = {
    {"connectToServer", reinterpret_cast<PyCFunction>(Sbk_QtROClientIoDeviceFunc_connectToServer), METH_NOARGS, nullptr},
    {"deviceType", reinterpret_cast<PyCFunction>(Sbk_QtROClientIoDeviceFunc_deviceType), METH_NOARGS, nullptr},
    {"disconnectFromServer", reinterpret_cast<PyCFunction>(Sbk_QtROClientIoDeviceFunc_disconnectFromServer), METH_NOARGS, nullptr},
    {"doDisconnectFromServer", reinterpret_cast<PyCFunction>(Sbk_QtROClientIoDeviceFunc_doDisconnectFromServer), METH_NOARGS, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QtROClientIoDeviceFunc_setUrl), METH_O, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QtROClientIoDeviceFunc_url), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QtROClientIoDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QtROClientIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QtROClientIoDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QtROClientIoDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtROClientIoDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtROClientIoDevice_Type = nullptr;
static PyTypeObject *Sbk_QtROClientIoDevice_TypeF(void)
{
    return _Sbk_QtROClientIoDevice_Type;
}

static PyType_Slot Sbk_QtROClientIoDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QtROClientIoDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtROClientIoDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtROClientIoDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtROClientIoDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QtROClientIoDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtROClientIoDevice_spec = {
    "2:PySide6.QtRemoteObjects.QtROClientIoDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtROClientIoDevice_slots
};

} //extern "C"

static void *Sbk_QtROClientIoDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QtROClientIoDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QtROClientIoDevice_PythonToCpp_QtROClientIoDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtROClientIoDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QtROClientIoDevice_PythonToCpp_QtROClientIoDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QtROClientIoDevice_TypeF()))
        return QtROClientIoDevice_PythonToCpp_QtROClientIoDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QtROClientIoDevice_PTR_CppToPython_QtROClientIoDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QtROClientIoDevice *>(const_cast<void *>(cppIn)), Sbk_QtROClientIoDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtROClientIoDevice_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QtROClientIoDevice(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtRemoteObjects.QtROClientIoDevice.connectToServer(self)",
    "PySide6.QtRemoteObjects.QtROClientIoDevice.deviceType(self)->QString",
    "PySide6.QtRemoteObjects.QtROClientIoDevice.disconnectFromServer(self)",
    "PySide6.QtRemoteObjects.QtROClientIoDevice.doDisconnectFromServer(self)",
    "PySide6.QtRemoteObjects.QtROClientIoDevice.setUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtRemoteObjects.QtROClientIoDevice.url(self)->PySide6.QtCore.QUrl",
    nullptr}; // Sentinel
#else
static constexpr size_t QtROClientIoDevice_SignatureByteSize = 182;
static constexpr uint8_t QtROClientIoDevice_SignatureBytes[182] = {
    0x78, 0xda, 0xad, 0x90, 0x31, 0x0f, 0x82, 0x40, 0x0c, 0x85, 0x77, 0x7e, 0x85, 0xa3, 0x24, 0x78,
    0xa3, 0x03, 0x89, 0x2e, 0x10, 0x13, 0x27, 0x40, 0x60, 0x32, 0x0e, 0x0a, 0xd5, 0x9c, 0x39, 0xae,
    0x97, 0x5e, 0x21, 0xe1, 0xdf, 0x7b, 0x02, 0x71, 0x30, 0x0e, 0x62, 0x9c, 0x9a, 0x6b, 0xaf, 0xdf,
    0x7b, 0x7d, 0x69, 0x9f, 0xcb, 0x1a, 0xd6, 0x22, 0xe3, 0x03, 0x34, 0xc8, 0x90, 0x5c, 0xee, 0x50,
    0xb1, 0x7d, 0xbe, 0x93, 0x48, 0x49, 0xd0, 0xbc, 0xc7, 0x18, 0x3a, 0x59, 0xc1, 0xd2, 0x82, 0xba,
    0x06, 0xe6, 0x4c, 0xae, 0x17, 0xa6, 0xaf, 0xb5, 0x08, 0x09, 0x44, 0x36, 0xae, 0x6d, 0x74, 0xab,
    0x94, 0x61, 0xf2, 0xbd, 0xf4, 0x6b, 0xac, 0xa8, 0x50, 0x6b, 0x37, 0x2b, 0x30, 0x07, 0xea, 0x80,
    0x06, 0x99, 0x59, 0x80, 0x7a, 0x28, 0x45, 0x6f, 0x46, 0x8b, 0xfe, 0x6a, 0x9b, 0xe5, 0x4c, 0x52,
    0xdf, 0x66, 0x41, 0xa4, 0x9d, 0x8c, 0xec, 0x08, 0x9b, 0x9f, 0xad, 0x60, 0xfc, 0x17, 0x8e, 0x05,
    0x2e, 0x49, 0x8d, 0x89, 0xb7, 0xa4, 0x42, 0xee, 0x8d, 0xbb, 0x47, 0x94, 0x5a, 0xa2, 0x3e, 0xbe,
    0x67, 0xef, 0x7e, 0x06, 0x8b, 0xe9, 0xe4, 0xd3, 0x2c, 0x99, 0x76, 0xd2, 0x70, 0x91, 0x7d, 0x80,
    0x7a, 0x0f, 0xd5, 0x06, 0xc5, 0x62
};
#endif

PyTypeObject *init_QtROClientIoDevice(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QtROClientIoDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROIoDeviceBase_IDX]))));

    _Sbk_QtROClientIoDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtROClientIoDevice",
        "QtROClientIoDevice*",
        &Sbk_QtROClientIoDevice_spec,
        &Shiboken::callCppDestructor< QtROClientIoDevice >,
        Sbk_QtROClientIoDevice_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtROClientIoDevice_TypeF(); // references _Sbk_QtROClientIoDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtROClientIoDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtROClientIoDevice_SignatureBytes, QtROClientIoDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtROClientIoDevice_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QtROClientIoDevice_PythonToCpp_QtROClientIoDevice_PTR,
        is_QtROClientIoDevice_PythonToCpp_QtROClientIoDevice_PTR_Convertible,
        QtROClientIoDevice_PTR_CppToPython_QtROClientIoDevice);

    Shiboken::Conversions::registerConverterName(converter, "QtROClientIoDevice");
    Shiboken::Conversions::registerConverterName(converter, "QtROClientIoDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QtROClientIoDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtROClientIoDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QtROClientIoDeviceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QtROClientIoDevice_TypeF(), &Sbk_QtROClientIoDevice_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QtROClientIoDevice::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QtROClientIoDevice::staticMetaObject, sizeof(QtROClientIoDeviceWrapper));

    return pyType;
}
