// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmlstaticscxmlservicefactory_wrapper.h"

// Wrappers providing overrides
#include "qscxmlinvokableservicefactory_wrapper.h"
#include "qscxmlstatemachine_wrapper.h"

// Argument includes
#include <QList>
#include <QtScxml/qscxmlexecutablecontent.h>
#include <QtScxml/qscxmlinvokableservice.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QScxmlStaticScxmlServiceFactoryWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QScxmlStaticScxmlServiceFactoryWrapper::QScxmlStaticScxmlServiceFactoryWrapper(const ::QMetaObject * metaObject, const ::QScxmlExecutableContent::InvokeInfo & invokeInfo, const ::QList<int> & nameList, const ::QList<QScxmlExecutableContent::ParameterInfo> & parameters, ::QObject * parent) : QScxmlStaticScxmlServiceFactory(metaObject, invokeInfo, nameList, parameters, parent)
{
}

void QScxmlStaticScxmlServiceFactoryWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QScxmlStateMachineWrapper::sbk_o_childEvent("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, event);
}

void QScxmlStaticScxmlServiceFactoryWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QScxmlStateMachineWrapper::sbk_o_connectNotify("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, signal);
}

void QScxmlStaticScxmlServiceFactoryWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QScxmlStateMachineWrapper::sbk_o_customEvent("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, event);
}

void QScxmlStaticScxmlServiceFactoryWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QScxmlStateMachineWrapper::sbk_o_connectNotify("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, signal);
}

bool QScxmlStaticScxmlServiceFactoryWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QScxmlStateMachineWrapper::sbk_o_event("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, event);
}

bool QScxmlStaticScxmlServiceFactoryWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QScxmlStateMachineWrapper::sbk_o_eventFilter("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, watched, event);
}

::QScxmlInvokableService * QScxmlStaticScxmlServiceFactoryWrapper::invoke(::QScxmlStateMachine * parentStateMachine)
{
    static const char *funcName = "invoke";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QScxmlStaticScxmlServiceFactory::invoke(parentStateMachine);
    }
    return QScxmlInvokableServiceFactoryWrapper::sbk_o_invoke("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, parentStateMachine);
}

void QScxmlStaticScxmlServiceFactoryWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QScxmlStateMachineWrapper::sbk_o_timerEvent("QScxmlStaticScxmlServiceFactory", funcName, gil, pyOverride, event);
}

const QMetaObject *QScxmlStaticScxmlServiceFactoryWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QScxmlStaticScxmlServiceFactory::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QScxmlStaticScxmlServiceFactoryWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QScxmlStaticScxmlServiceFactory::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QScxmlStaticScxmlServiceFactoryWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QScxmlStaticScxmlServiceFactoryWrapper *>(this));
    return QScxmlStaticScxmlServiceFactory::qt_metacast(_clname);
}

QScxmlStaticScxmlServiceFactoryWrapper::~QScxmlStaticScxmlServiceFactoryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlStaticScxmlServiceFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlStaticScxmlServiceFactory >()))
        return -1;

    QScxmlStaticScxmlServiceFactoryWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOOO:QScxmlStaticScxmlServiceFactory", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScxmlStaticScxmlServiceFactory::QScxmlStaticScxmlServiceFactory(const QMetaObject*,QScxmlExecutableContent::InvokeInfo,QList<int>,QList<QScxmlExecutableContent::ParameterInfo>,QObject*=)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlExecutableContent_InvokeInfo_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QList_int_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QList_QScxmlExecutableContent_ParameterInfo_IDX], (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // QScxmlStaticScxmlServiceFactory(const QMetaObject*,QScxmlExecutableContent::InvokeInfo,QList<int>,QList<QScxmlExecutableContent::ParameterInfo>,QObject*)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
            overloadId = 0; // QScxmlStaticScxmlServiceFactory(const QMetaObject*,QScxmlExecutableContent::InvokeInfo,QList<int>,QList<QScxmlExecutableContent::ParameterInfo>,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 4}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QMetaObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QScxmlExecutableContent::InvokeInfo cppArg1_local;
        ::QScxmlExecutableContent::InvokeInfo *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QList<int> cppArg2_local;
        ::QList<int> *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        ::QList<QScxmlExecutableContent::ParameterInfo> cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return -1;
        ::QObject *cppArg4 = nullptr;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QScxmlStaticScxmlServiceFactory(const QMetaObject*,QScxmlExecutableContent::InvokeInfo,QList<int>,QList<QScxmlExecutableContent::ParameterInfo>,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QScxmlStaticScxmlServiceFactoryWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QScxmlStaticScxmlServiceFactoryWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[4], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QScxmlStaticScxmlServiceFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QScxmlStaticScxmlServiceFactoryFunc_invoke(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStaticScxmlServiceFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlInvokableServiceFactory::invoke(QScxmlStateMachine*)->QScxmlInvokableService*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), (pyArg)))) {
        overloadId = 0; // invoke(QScxmlStateMachine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "invoke", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScxmlStateMachine *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // invoke(QScxmlStateMachine*)
            QScxmlInvokableService * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QScxmlStaticScxmlServiceFactory::invoke(cppArg0)
                : cppSelf->invoke(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlInvokableService_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QScxmlStaticScxmlServiceFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlStaticScxmlServiceFactory_methods[] = {
    {"invoke", reinterpret_cast<PyCFunction>(Sbk_QScxmlStaticScxmlServiceFactoryFunc_invoke), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScxmlStaticScxmlServiceFactory_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScxmlStaticScxmlServiceFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QScxmlStaticScxmlServiceFactoryWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScxmlStaticScxmlServiceFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlStaticScxmlServiceFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlStaticScxmlServiceFactory_Type = nullptr;
static PyTypeObject *Sbk_QScxmlStaticScxmlServiceFactory_TypeF(void)
{
    return _Sbk_QScxmlStaticScxmlServiceFactory_Type;
}

static PyType_Slot Sbk_QScxmlStaticScxmlServiceFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScxmlStaticScxmlServiceFactory_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlStaticScxmlServiceFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlStaticScxmlServiceFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlStaticScxmlServiceFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlStaticScxmlServiceFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlStaticScxmlServiceFactory_spec = {
    "2:PySide6.QtScxml.QScxmlStaticScxmlServiceFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlStaticScxmlServiceFactory_slots
};

} //extern "C"

static void *Sbk_QScxmlStaticScxmlServiceFactory_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QScxmlStaticScxmlServiceFactory *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScxmlStaticScxmlServiceFactory_PythonToCpp_QScxmlStaticScxmlServiceFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlStaticScxmlServiceFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScxmlStaticScxmlServiceFactory_PythonToCpp_QScxmlStaticScxmlServiceFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlStaticScxmlServiceFactory_TypeF()))
        return QScxmlStaticScxmlServiceFactory_PythonToCpp_QScxmlStaticScxmlServiceFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScxmlStaticScxmlServiceFactory_PTR_CppToPython_QScxmlStaticScxmlServiceFactory(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QScxmlStaticScxmlServiceFactory *>(const_cast<void *>(cppIn)), Sbk_QScxmlStaticScxmlServiceFactory_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScxmlStaticScxmlServiceFactory_SignatureStrings[] = {
    "PySide6.QtScxml.QScxmlStaticScxmlServiceFactory(self,metaObject:PySide6.QtCore.QMetaObject,invokeInfo:PySide6.QtScxml.QScxmlExecutableContent.InvokeInfo,nameList:QList[int],parameters:QList[PySide6.QtScxml.QScxmlExecutableContent.ParameterInfo],parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtScxml.QScxmlStaticScxmlServiceFactory.invoke(self,parentStateMachine:PySide6.QtScxml.QScxmlStateMachine)->PySide6.QtScxml.QScxmlInvokableService",
    nullptr}; // Sentinel
#else
static constexpr size_t QScxmlStaticScxmlServiceFactory_SignatureByteSize = 196;
static constexpr uint8_t QScxmlStaticScxmlServiceFactory_SignatureBytes[196] = {
    0x78, 0xda, 0x95, 0x50, 0xcf, 0x0b, 0x82, 0x30, 0x14, 0xbe, 0xf7, 0x97, 0x24, 0xd8, 0x8e, 0x1d,
    0x84, 0xba, 0x48, 0x81, 0x90, 0x34, 0xf1, 0x18, 0x1d, 0xe6, 0x7a, 0xd2, 0x6a, 0x6e, 0x32, 0x9f,
    0xa2, 0xff, 0x7d, 0xce, 0xa9, 0x08, 0x15, 0xd4, 0x65, 0x1b, 0xdf, 0xbe, 0x1f, 0xef, 0x7d, 0xb4,
    0x4b, 0xc5, 0x0d, 0xb6, 0x24, 0xc1, 0x94, 0xb7, 0x85, 0x24, 0xc9, 0x70, 0xa5, 0xc8, 0x50, 0x70,
    0xf7, 0x04, 0xd3, 0x08, 0x0e, 0x47, 0xc6, 0x51, 0x9b, 0x6e, 0x5d, 0x81, 0xcc, 0xfd, 0x02, 0x90,
    0x9d, 0xb3, 0x07, 0x70, 0x0c, 0xe8, 0xac, 0x0f, 0xb5, 0x01, 0x92, 0xc4, 0xf3, 0x97, 0x2f, 0x54,
    0xa3, 0x9f, 0x10, 0xa9, 0x5c, 0x2f, 0x58, 0xcb, 0x94, 0x43, 0x0b, 0xbc, 0x46, 0x96, 0x49, 0x08,
    0xb5, 0x42, 0x50, 0x48, 0xa2, 0x59, 0xe2, 0x2b, 0x56, 0xc0, 0x49, 0x54, 0x18, 0x24, 0xf6, 0xbc,
    0x08, 0x85, 0x57, 0xbf, 0x64, 0xa6, 0x47, 0x11, 0x4c, 0x35, 0xa2, 0xbf, 0xfa, 0xd2, 0x49, 0x68,
    0xad, 0x07, 0x9f, 0x1e, 0x7d, 0x9b, 0xdd, 0xcd, 0xbd, 0x53, 0xb5, 0x94, 0x25, 0x1a, 0x6f, 0x45,
    0xff, 0xeb, 0x86, 0xb8, 0x85, 0x5d, 0x45, 0x2e, 0xc2, 0x72, 0x21, 0x66, 0xfc, 0x2e, 0x14, 0x04,
    0xdf, 0xed, 0x26, 0x8a, 0xb7, 0xd9, 0x7f, 0x26, 0x0d, 0xbd, 0xd8, 0x85, 0xc6, 0xc4, 0xd5, 0x0b,
    0xd0, 0x8e, 0xa4, 0xa0
};
#endif

PyTypeObject *init_QScxmlStaticScxmlServiceFactory(PyObject *module)
{
    if (SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX].type != nullptr)
        return SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QScxmlStaticScxmlServiceFactory_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlInvokableServiceFactory_IDX]))));

    _Sbk_QScxmlStaticScxmlServiceFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScxmlStaticScxmlServiceFactory",
        "QScxmlStaticScxmlServiceFactory*",
        &Sbk_QScxmlStaticScxmlServiceFactory_spec,
        &Shiboken::callCppDestructor< QScxmlStaticScxmlServiceFactory >,
        Sbk_QScxmlStaticScxmlServiceFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScxmlStaticScxmlServiceFactory_TypeF(); // references _Sbk_QScxmlStaticScxmlServiceFactory_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScxmlStaticScxmlServiceFactory_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScxmlStaticScxmlServiceFactory_SignatureBytes, QScxmlStaticScxmlServiceFactory_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlStaticScxmlServiceFactory_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStaticScxmlServiceFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScxmlStaticScxmlServiceFactory_PythonToCpp_QScxmlStaticScxmlServiceFactory_PTR,
        is_QScxmlStaticScxmlServiceFactory_PythonToCpp_QScxmlStaticScxmlServiceFactory_PTR_Convertible,
        QScxmlStaticScxmlServiceFactory_PTR_CppToPython_QScxmlStaticScxmlServiceFactory);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlStaticScxmlServiceFactory");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlStaticScxmlServiceFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlStaticScxmlServiceFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlStaticScxmlServiceFactory).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QScxmlStaticScxmlServiceFactoryWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QScxmlStaticScxmlServiceFactory_TypeF(), &Sbk_QScxmlStaticScxmlServiceFactory_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QScxmlStaticScxmlServiceFactory::staticMetaObject, sizeof(QScxmlStaticScxmlServiceFactoryWrapper));

    return pyType;
}
