// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qirproximitysensor_wrapper.h"

// Wrappers providing overrides
#include "qsensorreading_wrapper.h"

// Argument includes
#include <QtSensors/qirproximitysensor.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QIRProximitySensorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QIRProximitySensorWrapper::QIRProximitySensorWrapper(::QObject * parent) : QIRProximitySensor(parent)
{
}

void QIRProximitySensorWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSensorReadingWrapper::sbk_o_childEvent("QIRProximitySensor", funcName, gil, pyOverride, event);
}

void QIRProximitySensorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSensorReadingWrapper::sbk_o_connectNotify("QIRProximitySensor", funcName, gil, pyOverride, signal);
}

void QIRProximitySensorWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSensorReadingWrapper::sbk_o_customEvent("QIRProximitySensor", funcName, gil, pyOverride, event);
}

void QIRProximitySensorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSensorReadingWrapper::sbk_o_connectNotify("QIRProximitySensor", funcName, gil, pyOverride, signal);
}

bool QIRProximitySensorWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QSensorReadingWrapper::sbk_o_event("QIRProximitySensor", funcName, gil, pyOverride, event);
}

bool QIRProximitySensorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSensorReadingWrapper::sbk_o_eventFilter("QIRProximitySensor", funcName, gil, pyOverride, watched, event);
}

void QIRProximitySensorWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSensorReadingWrapper::sbk_o_timerEvent("QIRProximitySensor", funcName, gil, pyOverride, event);
}

const QMetaObject *QIRProximitySensorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QIRProximitySensor::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QIRProximitySensorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QIRProximitySensor::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QIRProximitySensorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QIRProximitySensorWrapper *>(this));
    return QIRProximitySensor::qt_metacast(_clname);
}

QIRProximitySensorWrapper::~QIRProximitySensorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QIRProximitySensor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QIRProximitySensor >()))
        return -1;

    QIRProximitySensorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QIRProximitySensor", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QIRProximitySensor::QIRProximitySensor(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QIRProximitySensor(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QIRProximitySensor(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QIRProximitySensor(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QIRProximitySensorWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QIRProximitySensorWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QIRProximitySensor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QIRProximitySensorFunc_reading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QIRProximitySensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reading()const
        QIRProximityReading * cppResult = const_cast<const ::QIRProximitySensor *>(cppSelf)->reading();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityReading_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QIRProximitySensor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QIRProximitySensor_methods[] = {
    {"reading", reinterpret_cast<PyCFunction>(Sbk_QIRProximitySensorFunc_reading), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QIRProximitySensor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QIRProximitySensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QIRProximitySensorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QIRProximitySensor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QIRProximitySensor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QIRProximitySensor_Type = nullptr;
static PyTypeObject *Sbk_QIRProximitySensor_TypeF(void)
{
    return _Sbk_QIRProximitySensor_Type;
}

static PyType_Slot Sbk_QIRProximitySensor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QIRProximitySensor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QIRProximitySensor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QIRProximitySensor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QIRProximitySensor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QIRProximitySensor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QIRProximitySensor_spec = {
    "2:PySide6.QtSensors.QIRProximitySensor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QIRProximitySensor_slots
};

} //extern "C"

static void *Sbk_QIRProximitySensor_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QIRProximitySensor *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QIRProximitySensor_PythonToCpp_QIRProximitySensor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QIRProximitySensor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QIRProximitySensor_PythonToCpp_QIRProximitySensor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QIRProximitySensor_TypeF()))
        return QIRProximitySensor_PythonToCpp_QIRProximitySensor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QIRProximitySensor_PTR_CppToPython_QIRProximitySensor(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QIRProximitySensor *>(const_cast<void *>(cppIn)), Sbk_QIRProximitySensor_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QIRProximitySensor_SignatureStrings[] = {
    "PySide6.QtSensors.QIRProximitySensor(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtSensors.QIRProximitySensor.reading(self)->PySide6.QtSensors.QIRProximityReading",
    nullptr}; // Sentinel
#else
static constexpr size_t QIRProximitySensor_SignatureByteSize = 100;
static constexpr uint8_t QIRProximitySensor_SignatureBytes[100] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4e, 0xcd, 0x2b,
    0xce, 0x2f, 0x2a, 0xd6, 0x0b, 0xf4, 0x0c, 0x0a, 0x28, 0xca, 0xaf, 0xc8, 0xcc, 0xcd, 0x2c, 0xa9,
    0x84, 0x88, 0x69, 0x14, 0xa7, 0xe6, 0xa4, 0xe9, 0x14, 0x24, 0x16, 0xa5, 0xe6, 0x95, 0x58, 0x05,
    0xc0, 0x35, 0x38, 0xe7, 0x17, 0xa5, 0xea, 0x05, 0xfa, 0x27, 0x65, 0xa5, 0x26, 0x97, 0xd8, 0xe6,
    0x95, 0xe6, 0xe4, 0x14, 0x94, 0x14, 0x69, 0x72, 0x05, 0x10, 0x61, 0xa0, 0x5e, 0x51, 0x6a, 0x62,
    0x4a, 0x66, 0x5e, 0x3a, 0xd8, 0x60, 0x4d, 0x5d, 0x3b, 0xfc, 0x7a, 0x82, 0x20, 0x8a, 0xb9, 0x00,
    0x4a, 0xf5, 0x3f, 0x39
};
#endif

PyTypeObject *init_QIRProximitySensor(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX].type;

    Shiboken::AutoDecRef Sbk_QIRProximitySensor_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]))));

    _Sbk_QIRProximitySensor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QIRProximitySensor",
        "QIRProximitySensor*",
        &Sbk_QIRProximitySensor_spec,
        &Shiboken::callCppDestructor< QIRProximitySensor >,
        Sbk_QIRProximitySensor_Type_bases.object(),
        0);
    auto *pyType = Sbk_QIRProximitySensor_TypeF(); // references _Sbk_QIRProximitySensor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QIRProximitySensor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QIRProximitySensor_SignatureBytes, QIRProximitySensor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QIRProximitySensor_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximitySensor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QIRProximitySensor_PythonToCpp_QIRProximitySensor_PTR,
        is_QIRProximitySensor_PythonToCpp_QIRProximitySensor_PTR_Convertible,
        QIRProximitySensor_PTR_CppToPython_QIRProximitySensor);

    Shiboken::Conversions::registerConverterName(converter, "QIRProximitySensor");
    Shiboken::Conversions::registerConverterName(converter, "QIRProximitySensor*");
    Shiboken::Conversions::registerConverterName(converter, "QIRProximitySensor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QIRProximitySensor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QIRProximitySensorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QIRProximitySensor_TypeF(), &Sbk_QIRProximitySensor_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QIRProximitySensor::staticMetaObject, sizeof(QIRProximitySensorWrapper));

    return pyType;
}

PyTypeObject *init_QIRProximitySensorStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QIRProximitySensor");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "sensorType",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), QIRProximitySensor::sensorType));
    return type;
}
