// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QCANBUSDEVICEWRAPPER_H
#define SBK_QCANBUSDEVICEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSerialBus/qcanbusdevice.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QCanBusDeviceWrapper : public QCanBusDevice
{
public:
    QCanBusDeviceWrapper(::QObject * parent = nullptr);
    QCanBusDeviceWrapper(const QCanBusDeviceWrapper &) = delete;
    QCanBusDeviceWrapper& operator=(const QCanBusDeviceWrapper &) = delete;
    QCanBusDeviceWrapper(QCanBusDeviceWrapper &&) = delete;
    QCanBusDeviceWrapper& operator=(QCanBusDeviceWrapper &&) = delete;
    ~QCanBusDeviceWrapper() override;

    ::QCanBusDevice::CanBusStatus busStatus() override;
    static ::QCanBusDevice::CanBusStatus sbk_o_busStatus(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void childEvent(::QChildEvent * event) override;
    void close() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool hasBusStatus() const override;
    ::QString interpretErrorFrame(const ::QCanBusFrame & errorFrame) override;
    static ::QString sbk_o_interpretErrorFrame(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QCanBusFrame & errorFrame);
    bool open() override;
    void resetController() override;
    void setConfigurationParameter(::QCanBusDevice::ConfigurationKey key, const ::QVariant & value) override;
    static void sbk_o_setConfigurationParameter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QCanBusDevice::ConfigurationKey key, const ::QVariant & value);
    void timerEvent(::QTimerEvent * event) override;
    bool waitForFramesReceived(int msecs) override;
    static bool sbk_o_waitForFramesReceived(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs);
    bool waitForFramesWritten(int msecs) override;
    bool writeFrame(const ::QCanBusFrame & frame) override;
    static bool sbk_o_writeFrame(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QCanBusFrame & frame);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[17] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QCANBUSDEVICEWRAPPER_H
