// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbusrtuserialserver_wrapper.h"

// Wrappers providing overrides
#include "qmodbusdevice_wrapper.h"
#include "qmodbusserver_wrapper.h"
#include "qmodbusreply_wrapper.h"

// Argument includes
#include <QMap>
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbuspdu.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusRtuSerialServerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusRtuSerialServerWrapper::QModbusRtuSerialServerWrapper(::QObject * parent) : QModbusRtuSerialServer(parent)
{
}

void QModbusRtuSerialServerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QModbusReplyWrapper::sbk_o_childEvent("QModbusRtuSerialServer", funcName, gil, pyOverride, event);
}

void QModbusRtuSerialServerWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusRtuSerialServer::close();
    }
    QModbusDeviceWrapper::sbk_o_close("QModbusRtuSerialServer", funcName, gil, pyOverride);
}

void QModbusRtuSerialServerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QModbusRtuSerialServer", funcName, gil, pyOverride, signal);
}

void QModbusRtuSerialServerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QModbusReplyWrapper::sbk_o_customEvent("QModbusRtuSerialServer", funcName, gil, pyOverride, event);
}

void QModbusRtuSerialServerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QModbusRtuSerialServer", funcName, gil, pyOverride, signal);
}

bool QModbusRtuSerialServerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QModbusReplyWrapper::sbk_o_event("QModbusRtuSerialServer", funcName, gil, pyOverride, event);
}

bool QModbusRtuSerialServerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QModbusReplyWrapper::sbk_o_eventFilter("QModbusRtuSerialServer", funcName, gil, pyOverride, watched, event);
}

bool QModbusRtuSerialServerWrapper::open()
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusRtuSerialServer::open();
    }
    return QModbusDeviceWrapper::sbk_o_open("QModbusRtuSerialServer", funcName, gil, pyOverride);
}

::QModbusResponse QModbusRtuSerialServerWrapper::processPrivateRequest(const ::QModbusPdu & request)
{
    static const char *funcName = "processPrivateRequest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::processPrivateRequest(request);
    }
    return QModbusServerWrapper::sbk_o_processPrivateRequest("QModbusRtuSerialServer", funcName, gil, pyOverride, request);
}

::QModbusResponse QModbusRtuSerialServerWrapper::processRequest(const ::QModbusPdu & request)
{
    static const char *funcName = "processRequest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusRtuSerialServer::processRequest(request);
    }
    return QModbusServerWrapper::sbk_o_processPrivateRequest("QModbusRtuSerialServer", funcName, gil, pyOverride, request);
}

bool QModbusRtuSerialServerWrapper::processesBroadcast() const
{
    static const char *funcName = "processesBroadcast";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusRtuSerialServer::processesBroadcast();
    }
    return QModbusDeviceWrapper::sbk_o_open("QModbusRtuSerialServer", funcName, gil, pyOverride);
}

bool QModbusRtuSerialServerWrapper::readData(::QModbusDataUnit * newData) const
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::readData(newData);
    }
    return QModbusServerWrapper::sbk_o_readData("QModbusRtuSerialServer", funcName, gil, pyOverride, newData);
}

bool QModbusRtuSerialServerWrapper::setMap(const ::QMap<QModbusDataUnit::RegisterType,QModbusDataUnit> & map)
{
    static const char *funcName = "setMap";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::setMap(map);
    }
    return QModbusServerWrapper::sbk_o_setMap("QModbusRtuSerialServer", funcName, gil, pyOverride, map);
}

bool QModbusRtuSerialServerWrapper::setValue(int option, const ::QVariant & value)
{
    static const char *funcName = "setValue";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::setValue(option, value);
    }
    return QModbusServerWrapper::sbk_o_setValue("QModbusRtuSerialServer", funcName, gil, pyOverride, option, value);
}

void QModbusRtuSerialServerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QModbusReplyWrapper::sbk_o_timerEvent("QModbusRtuSerialServer", funcName, gil, pyOverride, event);
}

::QVariant QModbusRtuSerialServerWrapper::value(int option) const
{
    static const char *funcName = "value";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::value(option);
    }
    return QModbusServerWrapper::sbk_o_value("QModbusRtuSerialServer", funcName, gil, pyOverride, option);
}

bool QModbusRtuSerialServerWrapper::writeData(const ::QModbusDataUnit & unit)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::writeData(unit);
    }
    return QModbusServerWrapper::sbk_o_writeData("QModbusRtuSerialServer", funcName, gil, pyOverride, unit);
}

const QMetaObject *QModbusRtuSerialServerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QModbusRtuSerialServer::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QModbusRtuSerialServerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QModbusRtuSerialServer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QModbusRtuSerialServerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QModbusRtuSerialServerWrapper *>(this));
    return QModbusRtuSerialServer::qt_metacast(_clname);
}

QModbusRtuSerialServerWrapper::~QModbusRtuSerialServerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusRtuSerialServer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusRtuSerialServer >()))
        return -1;

    QModbusRtuSerialServerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QModbusRtuSerialServer", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusRtuSerialServer::QModbusRtuSerialServer(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QModbusRtuSerialServer(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QModbusRtuSerialServer(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QModbusRtuSerialServer(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QModbusRtuSerialServerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QModbusRtuSerialServerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QModbusRtuSerialServer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QModbusRtuSerialServerFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusRtuSerialServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QModbusRtuSerialServer::close()
            : cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QModbusRtuSerialServerFunc_interFrameDelay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusRtuSerialServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // interFrameDelay()const
        int cppResult = const_cast<const ::QModbusRtuSerialServer *>(cppSelf)->interFrameDelay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusRtuSerialServerFunc_open(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusRtuSerialServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // open()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QModbusRtuSerialServer::open()
            : cppSelf->open();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusRtuSerialServerFunc_processRequest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusRtuSerialServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusServer::processRequest(QModbusPdu)->QModbusResponse
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), (pyArg)))) {
        overloadId = 0; // processRequest(QModbusPdu)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "processRequest", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModbusPdu *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // processRequest(QModbusPdu)
            QModbusResponse* cppResult = new QModbusResponse(Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QModbusRtuSerialServer::processRequest(*cppArg0)
                : cppSelf->processRequest(*cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), cppResult, true, true);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusRtuSerialServerFunc_processesBroadcast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusRtuSerialServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // processesBroadcast()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QModbusRtuSerialServer *>(cppSelf)->::QModbusRtuSerialServer::processesBroadcast()
            : const_cast<const ::QModbusRtuSerialServer *>(cppSelf)->processesBroadcast();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusRtuSerialServerFunc_setInterFrameDelay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusRtuSerialServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusRtuSerialServer::setInterFrameDelay(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setInterFrameDelay(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInterFrameDelay", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInterFrameDelay(int)
            cppSelf->setInterFrameDelay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QModbusRtuSerialServer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusRtuSerialServer_methods[] = {
    {"close", reinterpret_cast<PyCFunction>(Sbk_QModbusRtuSerialServerFunc_close), METH_NOARGS, nullptr},
    {"interFrameDelay", reinterpret_cast<PyCFunction>(Sbk_QModbusRtuSerialServerFunc_interFrameDelay), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QModbusRtuSerialServerFunc_open), METH_NOARGS, nullptr},
    {"processRequest", reinterpret_cast<PyCFunction>(Sbk_QModbusRtuSerialServerFunc_processRequest), METH_O, nullptr},
    {"processesBroadcast", reinterpret_cast<PyCFunction>(Sbk_QModbusRtuSerialServerFunc_processesBroadcast), METH_NOARGS, nullptr},
    {"setInterFrameDelay", reinterpret_cast<PyCFunction>(Sbk_QModbusRtuSerialServerFunc_setInterFrameDelay), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusRtuSerialServer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusRtuSerialServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusRtuSerialServerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QModbusRtuSerialServer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusRtuSerialServer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusRtuSerialServer_Type = nullptr;
static PyTypeObject *Sbk_QModbusRtuSerialServer_TypeF(void)
{
    return _Sbk_QModbusRtuSerialServer_Type;
}

static PyType_Slot Sbk_QModbusRtuSerialServer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusRtuSerialServer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusRtuSerialServer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusRtuSerialServer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusRtuSerialServer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusRtuSerialServer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusRtuSerialServer_spec = {
    "2:PySide6.QtSerialBus.QModbusRtuSerialServer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusRtuSerialServer_slots
};

} //extern "C"

static void *Sbk_QModbusRtuSerialServer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QModbusRtuSerialServer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusRtuSerialServer_PythonToCpp_QModbusRtuSerialServer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusRtuSerialServer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusRtuSerialServer_PythonToCpp_QModbusRtuSerialServer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusRtuSerialServer_TypeF()))
        return QModbusRtuSerialServer_PythonToCpp_QModbusRtuSerialServer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusRtuSerialServer_PTR_CppToPython_QModbusRtuSerialServer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QModbusRtuSerialServer *>(const_cast<void *>(cppIn)), Sbk_QModbusRtuSerialServer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModbusRtuSerialServer_SignatureStrings[] = {
    "PySide6.QtSerialBus.QModbusRtuSerialServer(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtSerialBus.QModbusRtuSerialServer.close(self)",
    "PySide6.QtSerialBus.QModbusRtuSerialServer.interFrameDelay(self)->int",
    "PySide6.QtSerialBus.QModbusRtuSerialServer.open(self)->bool",
    "PySide6.QtSerialBus.QModbusRtuSerialServer.processRequest(self,request:PySide6.QtSerialBus.QModbusPdu)->PySide6.QtSerialBus.QModbusResponse",
    "PySide6.QtSerialBus.QModbusRtuSerialServer.processesBroadcast(self)->bool",
    "PySide6.QtSerialBus.QModbusRtuSerialServer.setInterFrameDelay(self,microseconds:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QModbusRtuSerialServer_SignatureByteSize = 191;
static constexpr uint8_t QModbusRtuSerialServer_SignatureBytes[191] = {
    0x78, 0xda, 0x9d, 0x91, 0x41, 0x0b, 0xc2, 0x30, 0x0c, 0x85, 0xef, 0xfb, 0x25, 0x0e, 0x74, 0x47,
    0x0f, 0x03, 0x3d, 0xa8, 0x08, 0x1e, 0xc4, 0x4d, 0x7f, 0x41, 0xd7, 0x3e, 0x61, 0xd2, 0x35, 0x35,
    0x69, 0x05, 0xff, 0xbd, 0xc5, 0xa9, 0x27, 0x11, 0xb7, 0x4b, 0x20, 0x81, 0xf7, 0xbd, 0xe4, 0xa5,
    0xba, 0x9f, 0x5a, 0x83, 0x79, 0x51, 0x87, 0x13, 0xb8, 0x55, 0x76, 0x15, 0xa5, 0xa8, 0xf7, 0x64,
    0x9a, 0x28, 0xc7, 0x10, 0xfb, 0x59, 0xaa, 0x37, 0xf0, 0x44, 0x60, 0xcf, 0x53, 0xaf, 0x18, 0x2e,
    0x94, 0xd5, 0x47, 0xb6, 0x26, 0x46, 0x51, 0x1f, 0x9a, 0x0b, 0x74, 0x58, 0xb8, 0x68, 0xad, 0x0f,
    0x9c, 0x67, 0xd5, 0xdf, 0xd8, 0x42, 0x5b, 0x12, 0x3c, 0xe1, 0x83, 0x64, 0xad, 0x0b, 0xe0, 0x2d,
    0xab, 0x0e, 0x1b, 0x58, 0x75, 0xef, 0x01, 0xb3, 0x65, 0x1a, 0x0f, 0xa1, 0x90, 0x87, 0x7b, 0x4b,
    0x1b, 0x22, 0x3b, 0x44, 0xeb, 0x99, 0x34, 0x44, 0x8e, 0xb8, 0x46, 0x48, 0xe8, 0xe3, 0xe1, 0xbe,
    0x29, 0x7f, 0x60, 0x2a, 0x13, 0x93, 0xd9, 0x2f, 0x1f, 0x88, 0x27, 0x27, 0x18, 0xb1, 0x0b, 0x64,
    0xc5, 0xa4, 0x8c, 0x56, 0xaf, 0x7d, 0x46, 0x5c, 0x25, 0x08, 0xbb, 0x2f, 0xd1, 0x4e, 0xbb, 0x56,
    0x73, 0x7a, 0x94, 0x26, 0x67, 0xa4, 0x4c, 0x29, 0xe7, 0xd9, 0x03, 0x5a, 0x79, 0xd4, 0x32
};
#endif

PyTypeObject *init_QModbusRtuSerialServer(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusRtuSerialServer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusServer_IDX]))));

    _Sbk_QModbusRtuSerialServer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusRtuSerialServer",
        "QModbusRtuSerialServer*",
        &Sbk_QModbusRtuSerialServer_spec,
        &Shiboken::callCppDestructor< QModbusRtuSerialServer >,
        Sbk_QModbusRtuSerialServer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QModbusRtuSerialServer_TypeF(); // references _Sbk_QModbusRtuSerialServer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModbusRtuSerialServer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModbusRtuSerialServer_SignatureBytes, QModbusRtuSerialServer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusRtuSerialServer_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusRtuSerialServer_PythonToCpp_QModbusRtuSerialServer_PTR,
        is_QModbusRtuSerialServer_PythonToCpp_QModbusRtuSerialServer_PTR_Convertible,
        QModbusRtuSerialServer_PTR_CppToPython_QModbusRtuSerialServer);

    Shiboken::Conversions::registerConverterName(converter, "QModbusRtuSerialServer");
    Shiboken::Conversions::registerConverterName(converter, "QModbusRtuSerialServer*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusRtuSerialServer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusRtuSerialServer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QModbusRtuSerialServerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QModbusRtuSerialServer_TypeF(), &Sbk_QModbusRtuSerialServer_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QModbusRtuSerialServer::staticMetaObject, sizeof(QModbusRtuSerialServerWrapper));

    return pyType;
}
