// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QMODBUSSERVERWRAPPER_H
#define SBK_QMODBUSSERVERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSerialBus/qmodbusserver.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QModbusServerWrapper : public QModbusServer
{
public:
    QModbusServerWrapper(::QObject * parent = nullptr);
    QModbusServerWrapper(const QModbusServerWrapper &) = delete;
    QModbusServerWrapper& operator=(const QModbusServerWrapper &) = delete;
    QModbusServerWrapper(QModbusServerWrapper &&) = delete;
    QModbusServerWrapper& operator=(QModbusServerWrapper &&) = delete;
    ~QModbusServerWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void close() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool open() override;
    ::QModbusResponse processPrivateRequest(const ::QModbusPdu & request) override;
    static ::QModbusResponse sbk_o_processPrivateRequest(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModbusPdu & request);
    ::QModbusResponse processRequest(const ::QModbusPdu & request) override;
    bool processesBroadcast() const override;
    bool readData(::QModbusDataUnit * newData) const override;
    static bool sbk_o_readData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QModbusDataUnit * newData);
    bool setMap(const ::QMap<QModbusDataUnit::RegisterType,QModbusDataUnit> & map) override;
    static bool sbk_o_setMap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMap<QModbusDataUnit::RegisterType,QModbusDataUnit> & map);
    bool setValue(int option, const ::QVariant & value) override;
    static bool sbk_o_setValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int option, const ::QVariant & value);
    void timerEvent(::QTimerEvent * event) override;
    ::QVariant value(int option) const override;
    static ::QVariant sbk_o_value(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int option);
    bool writeData(const ::QModbusDataUnit & unit) override;
    static bool sbk_o_writeData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModbusDataUnit & unit);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[17] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QMODBUSSERVERWRAPPER_H
