// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbustcpserver_wrapper.h"

// Wrappers providing overrides
#include "qmodbusdevice_wrapper.h"
#include "qmodbusserver_wrapper.h"
#include "qmodbusreply_wrapper.h"

// Argument includes
#include <QMap>
#include <QtNetwork/qtcpsocket.h>
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbuspdu.h>
#include <QtSerialBus/qmodbustcpserver.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusTcpServerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusTcpServerWrapper::QModbusTcpServerWrapper(::QObject * parent) : QModbusTcpServer(parent)
{
}

void QModbusTcpServerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QModbusReplyWrapper::sbk_o_childEvent("QModbusTcpServer", funcName, gil, pyOverride, event);
}

void QModbusTcpServerWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusTcpServer::close();
    }
    QModbusDeviceWrapper::sbk_o_close("QModbusTcpServer", funcName, gil, pyOverride);
}

void QModbusTcpServerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QModbusTcpServer", funcName, gil, pyOverride, signal);
}

void QModbusTcpServerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QModbusReplyWrapper::sbk_o_customEvent("QModbusTcpServer", funcName, gil, pyOverride, event);
}

void QModbusTcpServerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QModbusTcpServer", funcName, gil, pyOverride, signal);
}

bool QModbusTcpServerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QModbusReplyWrapper::sbk_o_event("QModbusTcpServer", funcName, gil, pyOverride, event);
}

bool QModbusTcpServerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QModbusReplyWrapper::sbk_o_eventFilter("QModbusTcpServer", funcName, gil, pyOverride, watched, event);
}

bool QModbusTcpServerWrapper::open()
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusTcpServer::open();
    }
    return QModbusDeviceWrapper::sbk_o_open("QModbusTcpServer", funcName, gil, pyOverride);
}

::QModbusResponse QModbusTcpServerWrapper::processPrivateRequest(const ::QModbusPdu & request)
{
    static const char *funcName = "processPrivateRequest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::processPrivateRequest(request);
    }
    return QModbusServerWrapper::sbk_o_processPrivateRequest("QModbusTcpServer", funcName, gil, pyOverride, request);
}

::QModbusResponse QModbusTcpServerWrapper::processRequest(const ::QModbusPdu & request)
{
    static const char *funcName = "processRequest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusTcpServer::processRequest(request);
    }
    return QModbusServerWrapper::sbk_o_processPrivateRequest("QModbusTcpServer", funcName, gil, pyOverride, request);
}

bool QModbusTcpServerWrapper::processesBroadcast() const
{
    static const char *funcName = "processesBroadcast";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::processesBroadcast();
    }
    return QModbusDeviceWrapper::sbk_o_open("QModbusTcpServer", funcName, gil, pyOverride);
}

bool QModbusTcpServerWrapper::readData(::QModbusDataUnit * newData) const
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::readData(newData);
    }
    return QModbusServerWrapper::sbk_o_readData("QModbusTcpServer", funcName, gil, pyOverride, newData);
}

bool QModbusTcpServerWrapper::setMap(const ::QMap<QModbusDataUnit::RegisterType,QModbusDataUnit> & map)
{
    static const char *funcName = "setMap";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::setMap(map);
    }
    return QModbusServerWrapper::sbk_o_setMap("QModbusTcpServer", funcName, gil, pyOverride, map);
}

bool QModbusTcpServerWrapper::setValue(int option, const ::QVariant & value)
{
    static const char *funcName = "setValue";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::setValue(option, value);
    }
    return QModbusServerWrapper::sbk_o_setValue("QModbusTcpServer", funcName, gil, pyOverride, option, value);
}

void QModbusTcpServerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QModbusReplyWrapper::sbk_o_timerEvent("QModbusTcpServer", funcName, gil, pyOverride, event);
}

::QVariant QModbusTcpServerWrapper::value(int option) const
{
    static const char *funcName = "value";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::value(option);
    }
    return QModbusServerWrapper::sbk_o_value("QModbusTcpServer", funcName, gil, pyOverride, option);
}

bool QModbusTcpServerWrapper::writeData(const ::QModbusDataUnit & unit)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusServer::writeData(unit);
    }
    return QModbusServerWrapper::sbk_o_writeData("QModbusTcpServer", funcName, gil, pyOverride, unit);
}

const QMetaObject *QModbusTcpServerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QModbusTcpServer::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QModbusTcpServerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QModbusTcpServer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QModbusTcpServerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QModbusTcpServerWrapper *>(this));
    return QModbusTcpServer::qt_metacast(_clname);
}

QModbusTcpServerWrapper::~QModbusTcpServerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusTcpServer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusTcpServer >()))
        return -1;

    QModbusTcpServerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QModbusTcpServer", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusTcpServer::QModbusTcpServer(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QModbusTcpServer(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QModbusTcpServer(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QModbusTcpServer(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QModbusTcpServerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QModbusTcpServerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QModbusTcpServer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QModbusTcpServerFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusTcpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QModbusTcpServer::close()
            : cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QModbusTcpServerFunc_installConnectionObserver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusTcpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusTcpServer::installConnectionObserver(QModbusTcpConnectionObserver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpConnectionObserver_IDX]), (pyArg)))) {
        overloadId = 0; // installConnectionObserver(QModbusTcpConnectionObserver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "installConnectionObserver", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModbusTcpConnectionObserver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // installConnectionObserver(QModbusTcpConnectionObserver*)
            cppSelf->installConnectionObserver(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QModbusTcpServerFunc_open(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusTcpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // open()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QModbusTcpServer::open()
            : cppSelf->open();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusTcpServerFunc_processRequest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusTcpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusServer::processRequest(QModbusPdu)->QModbusResponse
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), (pyArg)))) {
        overloadId = 0; // processRequest(QModbusPdu)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "processRequest", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModbusPdu *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // processRequest(QModbusPdu)
            QModbusResponse* cppResult = new QModbusResponse(Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QModbusTcpServer::processRequest(*cppArg0)
                : cppSelf->processRequest(*cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), cppResult, true, true);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QModbusTcpServer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusTcpServer_methods[] = {
    {"close", reinterpret_cast<PyCFunction>(Sbk_QModbusTcpServerFunc_close), METH_NOARGS, nullptr},
    {"installConnectionObserver", reinterpret_cast<PyCFunction>(Sbk_QModbusTcpServerFunc_installConnectionObserver), METH_O, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QModbusTcpServerFunc_open), METH_NOARGS, nullptr},
    {"processRequest", reinterpret_cast<PyCFunction>(Sbk_QModbusTcpServerFunc_processRequest), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusTcpServer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusTcpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusTcpServerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QModbusTcpServer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusTcpServer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusTcpServer_Type = nullptr;
static PyTypeObject *Sbk_QModbusTcpServer_TypeF(void)
{
    return _Sbk_QModbusTcpServer_Type;
}

static PyType_Slot Sbk_QModbusTcpServer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusTcpServer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusTcpServer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusTcpServer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusTcpServer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusTcpServer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusTcpServer_spec = {
    "2:PySide6.QtSerialBus.QModbusTcpServer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusTcpServer_slots
};

} //extern "C"

static void *Sbk_QModbusTcpServer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QModbusTcpServer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusTcpServer_PythonToCpp_QModbusTcpServer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusTcpServer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusTcpServer_PythonToCpp_QModbusTcpServer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusTcpServer_TypeF()))
        return QModbusTcpServer_PythonToCpp_QModbusTcpServer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusTcpServer_PTR_CppToPython_QModbusTcpServer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QModbusTcpServer *>(const_cast<void *>(cppIn)), Sbk_QModbusTcpServer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModbusTcpServer_SignatureStrings[] = {
    "PySide6.QtSerialBus.QModbusTcpServer(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtSerialBus.QModbusTcpServer.close(self)",
    "PySide6.QtSerialBus.QModbusTcpServer.installConnectionObserver(self,observer:PySide6.QtSerialBus.QModbusTcpConnectionObserver)",
    "PySide6.QtSerialBus.QModbusTcpServer.open(self)->bool",
    "PySide6.QtSerialBus.QModbusTcpServer.processRequest(self,request:PySide6.QtSerialBus.QModbusPdu)->PySide6.QtSerialBus.QModbusResponse",
    nullptr}; // Sentinel
#else
static constexpr size_t QModbusTcpServer_SignatureByteSize = 164;
static constexpr uint8_t QModbusTcpServer_SignatureBytes[164] = {
    0x78, 0xda, 0x8d, 0x8e, 0x41, 0x0a, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0x9e, 0x44, 0x41, 0xb3, 0x74,
    0x51, 0xd0, 0x85, 0x5d, 0x4b, 0xd3, 0xd6, 0x0b, 0x34, 0xe9, 0x08, 0x91, 0x61, 0x26, 0xce, 0x24,
    0x82, 0xb7, 0xb7, 0x58, 0x11, 0x41, 0x28, 0x59, 0xfe, 0x61, 0xde, 0xff, 0xcf, 0x3e, 0xfb, 0x30,
    0xc2, 0xde, 0xb4, 0xa9, 0x07, 0x09, 0x03, 0x9e, 0xb2, 0x9a, 0xf6, 0xcc, 0xa3, 0xcb, 0x7a, 0xf1,
    0x71, 0xba, 0x3d, 0x40, 0xd6, 0x0a, 0x78, 0xdd, 0xc6, 0x41, 0x80, 0x52, 0x65, 0xbf, 0x40, 0xcd,
    0x02, 0xa6, 0x6d, 0xdc, 0x0d, 0x7c, 0x3a, 0x50, 0x46, 0x8c, 0x49, 0x36, 0x2b, 0x5b, 0x50, 0x68,
    0x3c, 0xb2, 0xc2, 0xbb, 0xb6, 0x10, 0x08, 0xa4, 0x69, 0x40, 0xac, 0x99, 0x68, 0x5a, 0x0b, 0x4c,
    0x8d, 0xd3, 0x1f, 0x37, 0xfe, 0xa4, 0x6a, 0xb9, 0xec, 0x1f, 0x2f, 0x9c, 0xe7, 0x08, 0x34, 0xeb,
    0xee, 0x8e, 0x8e, 0x19, 0xcb, 0xa8, 0x28, 0xec, 0x41, 0xb5, 0x83, 0x7b, 0x06, 0x4d, 0xb3, 0xa9,
    0xcc, 0x61, 0x49, 0xd4, 0x8e, 0x79, 0x9a, 0x59, 0x78, 0xe8, 0x40, 0x23, 0x93, 0xc2, 0xea, 0x05,
    0xb7, 0x72, 0xa5, 0x01
};
#endif

PyTypeObject *init_QModbusTcpServer(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusTcpServer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusServer_IDX]))));

    _Sbk_QModbusTcpServer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusTcpServer",
        "QModbusTcpServer*",
        &Sbk_QModbusTcpServer_spec,
        &Shiboken::callCppDestructor< QModbusTcpServer >,
        Sbk_QModbusTcpServer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QModbusTcpServer_TypeF(); // references _Sbk_QModbusTcpServer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModbusTcpServer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModbusTcpServer_SignatureBytes, QModbusTcpServer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusTcpServer_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusTcpServer_PythonToCpp_QModbusTcpServer_PTR,
        is_QModbusTcpServer_PythonToCpp_QModbusTcpServer_PTR_Convertible,
        QModbusTcpServer_PTR_CppToPython_QModbusTcpServer);

    Shiboken::Conversions::registerConverterName(converter, "QModbusTcpServer");
    Shiboken::Conversions::registerConverterName(converter, "QModbusTcpServer*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusTcpServer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusTcpServer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QModbusTcpServerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QModbusTcpServer_TypeF(), &Sbk_QModbusTcpServer_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QModbusTcpServer::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QModbusTcpServer::staticMetaObject, sizeof(QModbusTcpServerWrapper));

    return pyType;
}
