// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtspatialaudio_python.h"

// main header
#include "qambientsound_wrapper.h"

// Wrappers providing overrides
#include "qspatialsound_wrapper.h"

// Argument includes
#include <QtSpatialAudio/qaudioengine.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAmbientSoundWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAmbientSoundWrapper::QAmbientSoundWrapper(::QAudioEngine * engine) : QAmbientSound(engine)
{
}

void QAmbientSoundWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSpatialSoundWrapper::sbk_o_childEvent("QAmbientSound", funcName, gil, pyOverride, event);
}

void QAmbientSoundWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSpatialSoundWrapper::sbk_o_connectNotify("QAmbientSound", funcName, gil, pyOverride, signal);
}

void QAmbientSoundWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSpatialSoundWrapper::sbk_o_customEvent("QAmbientSound", funcName, gil, pyOverride, event);
}

void QAmbientSoundWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSpatialSoundWrapper::sbk_o_connectNotify("QAmbientSound", funcName, gil, pyOverride, signal);
}

bool QAmbientSoundWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QSpatialSoundWrapper::sbk_o_event("QAmbientSound", funcName, gil, pyOverride, event);
}

bool QAmbientSoundWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSpatialSoundWrapper::sbk_o_eventFilter("QAmbientSound", funcName, gil, pyOverride, watched, event);
}

void QAmbientSoundWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSpatialSoundWrapper::sbk_o_timerEvent("QAmbientSound", funcName, gil, pyOverride, event);
}

const QMetaObject *QAmbientSoundWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAmbientSound::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAmbientSoundWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAmbientSound::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAmbientSoundWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAmbientSoundWrapper *>(this));
    return QAmbientSound::qt_metacast(_clname);
}

QAmbientSoundWrapper::~QAmbientSoundWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAmbientSound_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAmbientSound >()))
        return -1;

    QAmbientSoundWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAmbientSound", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAmbientSound::QAmbientSound(QAudioEngine*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAmbientSound(QAudioEngine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QAudioEngine *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAmbientSound(QAudioEngine*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAmbientSoundWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAmbientSoundWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAmbientSound >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAmbientSoundFunc_autoPlay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoPlay()const
        bool cppResult = const_cast<const ::QAmbientSound *>(cppSelf)->autoPlay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAmbientSoundFunc_engine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // engine()const
        QAudioEngine * cppResult = const_cast<const ::QAmbientSound *>(cppSelf)->engine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAmbientSoundFunc_loops(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loops()const
        int cppResult = const_cast<const ::QAmbientSound *>(cppSelf)->loops();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAmbientSoundFunc_pause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pause()
        cppSelf->pause();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAmbientSoundFunc_play(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // play()
        cppSelf->play();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAmbientSoundFunc_setAutoPlay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAmbientSound::setAutoPlay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoPlay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoPlay", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoPlay(bool)
            cppSelf->setAutoPlay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAmbientSoundFunc_setLoops(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAmbientSound::setLoops(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLoops(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLoops", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLoops(int)
            cppSelf->setLoops(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAmbientSoundFunc_setSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAmbientSound::setSource(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setSource(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSource", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSource(QUrl)
            cppSelf->setSource(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAmbientSoundFunc_setVolume(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAmbientSound::setVolume(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setVolume(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVolume", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVolume(float)
            cppSelf->setVolume(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAmbientSoundFunc_source(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // source()const
        QUrl cppResult = const_cast<const ::QAmbientSound *>(cppSelf)->source();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAmbientSoundFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAmbientSoundFunc_volume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // volume()const
        float cppResult = const_cast<const ::QAmbientSound *>(cppSelf)->volume();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QAmbientSound_PropertyStrings[] = {
    "autoPlay::",
    "loops::",
    "source::",
    "volume::",
    nullptr // Sentinel
};

static const char *Sbk_QAmbientSound_EnumFlagInfo[] = {
    "Loops:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAmbientSound_methods[] = {
    {"autoPlay", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_autoPlay), METH_NOARGS, nullptr},
    {"engine", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_engine), METH_NOARGS, nullptr},
    {"loops", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_loops), METH_NOARGS, nullptr},
    {"pause", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_pause), METH_NOARGS, nullptr},
    {"play", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_play), METH_NOARGS, nullptr},
    {"setAutoPlay", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_setAutoPlay), METH_O, nullptr},
    {"setLoops", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_setLoops), METH_O, nullptr},
    {"setSource", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_setSource), METH_O, nullptr},
    {"setVolume", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_setVolume), METH_O, nullptr},
    {"source", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_source), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_stop), METH_NOARGS, nullptr},
    {"volume", reinterpret_cast<PyCFunction>(Sbk_QAmbientSoundFunc_volume), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAmbientSound_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAmbientSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAmbientSoundWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAmbientSound_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAmbientSound_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAmbientSound_Type = nullptr;
static PyTypeObject *Sbk_QAmbientSound_TypeF(void)
{
    return _Sbk_QAmbientSound_Type;
}

static PyType_Slot Sbk_QAmbientSound_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAmbientSound_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAmbientSound_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAmbientSound_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAmbientSound_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAmbientSound_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAmbientSound_spec = {
    "2:PySide6.QtSpatialAudio.QAmbientSound",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAmbientSound_slots
};

} //extern "C"

static void *Sbk_QAmbientSound_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAmbientSound *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAmbientSound_Loops(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAmbientSound::Loops>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAmbientSound::Loops *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAmbientSound_Loops_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_Loops_IDX])))
        return Enum_PythonToCpp_QAmbientSound_Loops;
    return {};
}

static PyObject *QAmbientSound_Loops_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAmbientSound::Loops>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAmbientSound::Loops *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_Loops_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAmbientSound_PythonToCpp_QAmbientSound_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAmbientSound_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAmbientSound_PythonToCpp_QAmbientSound_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAmbientSound_TypeF()))
        return QAmbientSound_PythonToCpp_QAmbientSound_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAmbientSound_PTR_CppToPython_QAmbientSound(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAmbientSound *>(const_cast<void *>(cppIn)), Sbk_QAmbientSound_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAmbientSound_SignatureStrings[] = {
    "PySide6.QtSpatialAudio.QAmbientSound(self,engine:PySide6.QtSpatialAudio.QAudioEngine,*:KeywordOnly=None,source:QUrl=None,volume:float=None,loops:int=None,autoPlay:bool=None)",
    "PySide6.QtSpatialAudio.QAmbientSound.autoPlay(self)->bool",
    "PySide6.QtSpatialAudio.QAmbientSound.engine(self)->PySide6.QtSpatialAudio.QAudioEngine",
    "PySide6.QtSpatialAudio.QAmbientSound.loops(self)->int",
    "PySide6.QtSpatialAudio.QAmbientSound.pause(self)",
    "PySide6.QtSpatialAudio.QAmbientSound.play(self)",
    "PySide6.QtSpatialAudio.QAmbientSound.setAutoPlay(self,autoPlay:bool)",
    "PySide6.QtSpatialAudio.QAmbientSound.setLoops(self,loops:int)",
    "PySide6.QtSpatialAudio.QAmbientSound.setSource(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtSpatialAudio.QAmbientSound.setVolume(self,volume:float)",
    "PySide6.QtSpatialAudio.QAmbientSound.source(self)->PySide6.QtCore.QUrl",
    "PySide6.QtSpatialAudio.QAmbientSound.stop(self)",
    "PySide6.QtSpatialAudio.QAmbientSound.volume(self)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t QAmbientSound_SignatureByteSize = 262;
static constexpr uint8_t QAmbientSound_SignatureBytes[262] = {
    0x78, 0xda, 0x95, 0x92, 0x3f, 0x6b, 0xc3, 0x30, 0x10, 0xc5, 0xf7, 0x7c, 0x8a, 0x8c, 0x4d, 0x70,
    0x35, 0x76, 0x10, 0xa4, 0x60, 0x4a, 0xa7, 0x94, 0xd6, 0x46, 0x24, 0x4b, 0xe9, 0xa0, 0xd4, 0x97,
    0x20, 0x50, 0x74, 0x42, 0x7f, 0x52, 0xf4, 0xed, 0x6b, 0x4b, 0xb1, 0x9d, 0x0c, 0x85, 0xeb, 0x24,
    0x74, 0xdc, 0xef, 0xdd, 0x7b, 0xd2, 0x35, 0x49, 0xa8, 0x0e, 0x9e, 0x58, 0x1b, 0x84, 0x95, 0x41,
    0x49, 0x5d, 0xc7, 0x4e, 0x21, 0x6b, 0xeb, 0xf3, 0x41, 0x81, 0x09, 0x02, 0xa3, 0xe9, 0x1e, 0x3c,
    0xe8, 0x63, 0x05, 0xe6, 0xa4, 0x0c, 0xf0, 0xe6, 0x2f, 0x60, 0x38, 0x5e, 0x73, 0x4f, 0xb5, 0xe6,
    0x5b, 0x48, 0x3f, 0xe8, 0xba, 0x0f, 0xa3, 0xd3, 0xe6, 0x1d, 0xfb, 0x92, 0xc7, 0xe8, 0xbe, 0x81,
    0xb7, 0x3b, 0xa7, 0x4b, 0xe1, 0x82, 0x3a, 0x9e, 0x81, 0x1f, 0x35, 0xca, 0x50, 0x2a, 0x1a, 0xd1,
    0x7a, 0xae, 0xcc, 0xf5, 0x2a, 0x63, 0xc0, 0x46, 0xcb, 0xc4, 0x0f, 0x88, 0x85, 0x59, 0x2d, 0x1a,
    0x82, 0x5b, 0x36, 0x82, 0xd9, 0xf6, 0xea, 0xf1, 0x79, 0xe0, 0x69, 0x64, 0x89, 0x38, 0x72, 0x84,
    0xa4, 0x34, 0xd9, 0x1c, 0x6c, 0x54, 0xed, 0xf3, 0xd1, 0x28, 0x2b, 0xa3, 0xbf, 0x7a, 0x21, 0x02,
    0x53, 0x66, 0x5a, 0xbf, 0x87, 0x50, 0xdf, 0x3e, 0xd5, 0xfd, 0x8b, 0xd3, 0x45, 0xde, 0xa6, 0x78,
    0xf3, 0x17, 0xd2, 0x69, 0x91, 0x17, 0xa3, 0xe0, 0xd1, 0x69, 0x1e, 0x92, 0x55, 0xe6, 0xc4, 0x76,
    0x46, 0xa1, 0xf9, 0x9c, 0x45, 0x5e, 0xd0, 0x01, 0x1b, 0xb6, 0xa7, 0x5a, 0xb6, 0x22, 0xb8, 0xbe,
    0xe5, 0x8b, 0x3e, 0x63, 0x9f, 0x77, 0xad, 0xcc, 0xb8, 0xdd, 0x3b, 0xaa, 0xc2, 0x6c, 0xf1, 0x6e,
    0x2d, 0x26, 0x4f, 0x44, 0x99, 0x80, 0xf6, 0x3f, 0xff, 0x73, 0x99, 0x5d, 0xf7, 0x63, 0xb3, 0xe1,
    0xc5, 0x2f, 0x84, 0xbe, 0x58, 0xe6
};
#endif

PyTypeObject *init_QAmbientSound(PyObject *module)
{
    if (SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX].type != nullptr)
        return SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX].type;

    Shiboken::AutoDecRef Sbk_QAmbientSound_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAmbientSound_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAmbientSound",
        "QAmbientSound*",
        &Sbk_QAmbientSound_spec,
        &Shiboken::callCppDestructor< QAmbientSound >,
        Sbk_QAmbientSound_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAmbientSound_TypeF(); // references _Sbk_QAmbientSound_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAmbientSound_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAmbientSound_SignatureBytes, QAmbientSound_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAmbientSound_PropertyStrings);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAmbientSound_PythonToCpp_QAmbientSound_PTR,
        is_QAmbientSound_PythonToCpp_QAmbientSound_PTR_Convertible,
        QAmbientSound_PTR_CppToPython_QAmbientSound);

    Shiboken::Conversions::registerConverterName(converter, "QAmbientSound");
    Shiboken::Conversions::registerConverterName(converter, "QAmbientSound*");
    Shiboken::Conversions::registerConverterName(converter, "QAmbientSound&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAmbientSound).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAmbientSoundWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAmbientSound_TypeF(), &Sbk_QAmbientSound_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAmbientSound_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Loops'.
    const char *Loops_Initializer[] = {
        "Infinite",
        "Once",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Loops_InitializerValues[] = {
        int8_t(QAmbientSound::Loops::Infinite), // -0x01 -1
        int8_t(QAmbientSound::Loops::Once)      //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAmbientSound_TypeF(),
        "2:PySide6.QtSpatialAudio.QAmbientSound.Loops",
        Loops_Initializer, Loops_InitializerValues);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAmbientSound_Loops_IDX].type = EType;
    // Register converter for enum 'QAmbientSound::Loops'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAmbientSound_Loops_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAmbientSound_Loops,
            is_Enum_PythonToCpp_QAmbientSound_Loops_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAmbientSound::Loops");
        Shiboken::Conversions::registerConverterAlias(converter, "Loops");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Loops' enum.

    PySide::Signal::registerSignals(pyType, &::QAmbientSound::staticMetaObject);
    qRegisterMetaType< ::QAmbientSound::Loops >("QAmbientSound::Loops");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAmbientSound::staticMetaObject, sizeof(QAmbientSoundWrapper));

    return pyType;
}
