// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqldriver_wrapper.h"

// Wrappers providing overrides
#include "qsqlrelationaldelegate_wrapper.h"
#include "qsqlresult_wrapper.h"
#include "qsqldriver_wrapper.h"

// Extra includes
#include <QSize>
#include <QSqlError>
#include <QSqlIndex>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>

// Argument includes
#include <QString>
#include <QStringList>
#include <QtSql/qsqldriver.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlfield.h>
#include <QtSql/qsqlindex.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qsqlresult.h>
#include <QtSql/qtsqlglobal.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSqlDriverWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSqlDriverWrapper::QSqlDriverWrapper(::QObject * parent) : QSqlDriver(parent)
{
}

bool QSqlDriverWrapper::beginTransaction()
{
    static const char *funcName = "beginTransaction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::beginTransaction();
    }
    return sbk_o_beginTransaction("QSqlDriver", funcName, gil, pyOverride);
}

bool QSqlDriverWrapper::sbk_o_beginTransaction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlDriverWrapper::cancelQuery()
{
    static const char *funcName = "cancelQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::cancelQuery();
    }
    return QSqlResultWrapper::sbk_o_nextResult("QSqlDriver", funcName, gil, pyOverride);
}

void QSqlDriverWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSqlRelationalDelegateWrapper::sbk_o_childEvent("QSqlDriver", funcName, gil, pyOverride, event);
}

void QSqlDriverWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.close");
        return;
    }
    QSqlResultWrapper::sbk_o_detachFromResultSet("QSqlDriver", funcName, gil, pyOverride);
}

bool QSqlDriverWrapper::commitTransaction()
{
    static const char *funcName = "commitTransaction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::commitTransaction();
    }
    return sbk_o_commitTransaction("QSqlDriver", funcName, gil, pyOverride);
}

bool QSqlDriverWrapper::sbk_o_commitTransaction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSqlDriverWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSqlRelationalDelegateWrapper::sbk_o_connectNotify("QSqlDriver", funcName, gil, pyOverride, signal);
}

::QSqlResult * QSqlDriverWrapper::createResult() const
{
    static const char *funcName = "createResult";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.createResult");
        return nullptr;
    }
    return sbk_o_createResult("QSqlDriver", funcName, gil, pyOverride);
}

::QSqlResult * QSqlDriverWrapper::sbk_o_createResult(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSqlResult >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSqlResult *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSqlDriverWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSqlRelationalDelegateWrapper::sbk_o_customEvent("QSqlDriver", funcName, gil, pyOverride, event);
}

void QSqlDriverWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSqlRelationalDelegateWrapper::sbk_o_connectNotify("QSqlDriver", funcName, gil, pyOverride, signal);
}

::QString QSqlDriverWrapper::escapeIdentifier(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const
{
    static const char *funcName = "escapeIdentifier";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::escapeIdentifier(identifier, type);
    }
    return sbk_o_escapeIdentifier("QSqlDriver", funcName, gil, pyOverride, identifier, type);
}

::QString QSqlDriverWrapper::sbk_o_escapeIdentifier(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & identifier, ::QSqlDriver::IdentifierType type)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &identifier),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, &type)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &identifier),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, &type)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlDriverWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QSqlRelationalDelegateWrapper::sbk_o_event("QSqlDriver", funcName, gil, pyOverride, event);
}

bool QSqlDriverWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSqlRelationalDelegateWrapper::sbk_o_eventFilter("QSqlDriver", funcName, gil, pyOverride, watched, event);
}

::QString QSqlDriverWrapper::formatValue(const ::QSqlField & field, bool trimStrings) const
{
    static const char *funcName = "formatValue";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::formatValue(field, trimStrings);
    }
    return sbk_o_formatValue("QSqlDriver", funcName, gil, pyOverride, field, trimStrings);
}

::QString QSqlDriverWrapper::sbk_o_formatValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSqlField & field, bool trimStrings)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), &field),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &trimStrings)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), &field),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &trimStrings)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlDriverWrapper::hasFeature(::QSqlDriver::DriverFeature f) const
{
    static const char *funcName = "hasFeature";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.hasFeature");
        return false;
    }
    return sbk_o_hasFeature("QSqlDriver", funcName, gil, pyOverride, f);
}

bool QSqlDriverWrapper::sbk_o_hasFeature(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSqlDriver::DriverFeature f)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DriverFeature_IDX])))->converter, &f)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DriverFeature_IDX])))->converter, &f)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlDriverWrapper::isIdentifierEscaped(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const
{
    static const char *funcName = "isIdentifierEscaped";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::isIdentifierEscaped(identifier, type);
    }
    return sbk_o_isIdentifierEscaped("QSqlDriver", funcName, gil, pyOverride, identifier, type);
}

bool QSqlDriverWrapper::sbk_o_isIdentifierEscaped(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & identifier, ::QSqlDriver::IdentifierType type)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &identifier),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, &type)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &identifier),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, &type)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlDriverWrapper::isOpen() const
{
    static const char *funcName = "isOpen";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::isOpen();
    }
    return QSqlResultWrapper::sbk_o_nextResult("QSqlDriver", funcName, gil, pyOverride);
}

int QSqlDriverWrapper::maximumIdentifierLength(::QSqlDriver::IdentifierType type) const
{
    static const char *funcName = "maximumIdentifierLength";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::maximumIdentifierLength(type);
    }
    return sbk_o_maximumIdentifierLength("QSqlDriver", funcName, gil, pyOverride, type);
}

int QSqlDriverWrapper::sbk_o_maximumIdentifierLength(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSqlDriver::IdentifierType type)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, &type)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, &type)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlDriverWrapper::open(const ::QString & db, const ::QString & user, const ::QString & password, const ::QString & host, int port, const ::QString & connOpts)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.open");
        return false;
    }
    return sbk_o_open("QSqlDriver", funcName, gil, pyOverride, db, user, password, host, port, connOpts);
}

bool QSqlDriverWrapper::sbk_o_open(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & db, const ::QString & user, const ::QString & password, const ::QString & host, int port, const ::QString & connOpts)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[6] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &db),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &user),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &password),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &host),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &port),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &connOpts)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNNiN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &db),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &user),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &password),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &host),
        port,
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &connOpts)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 6, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
    Py_DECREF(pyArgArray[4]);
    Py_DECREF(pyArgArray[5]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSqlIndex QSqlDriverWrapper::primaryIndex(const ::QString & tableName) const
{
    static const char *funcName = "primaryIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::primaryIndex(tableName);
    }
    return sbk_o_primaryIndex("QSqlDriver", funcName, gil, pyOverride, tableName);
}

::QSqlIndex QSqlDriverWrapper::sbk_o_primaryIndex(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & tableName)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &tableName)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &tableName)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QSqlIndex();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSqlIndex >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return ::QSqlIndex();
    }
    ::QSqlIndex cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSqlRecord QSqlDriverWrapper::record(const ::QString & tableName) const
{
    static const char *funcName = "record";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::record(tableName);
    }
    return sbk_o_record("QSqlDriver", funcName, gil, pyOverride, tableName);
}

::QSqlRecord QSqlDriverWrapper::sbk_o_record(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & tableName)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &tableName)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &tableName)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSqlRecord >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSqlRecord cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlDriverWrapper::rollbackTransaction()
{
    static const char *funcName = "rollbackTransaction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::rollbackTransaction();
    }
    return sbk_o_rollbackTransaction("QSqlDriver", funcName, gil, pyOverride);
}

bool QSqlDriverWrapper::sbk_o_rollbackTransaction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSqlDriverWrapper::setLastError(const ::QSqlError & e)
{
    static const char *funcName = "setLastError";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::setLastError(e);
    }
    QSqlResultWrapper::sbk_o_setLastError("QSqlDriver", funcName, gil, pyOverride, e);
}

void QSqlDriverWrapper::setOpen(bool o)
{
    static const char *funcName = "setOpen";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::setOpen(o);
    }
    QSqlResultWrapper::sbk_o_setActive("QSqlDriver", funcName, gil, pyOverride, o);
}

void QSqlDriverWrapper::setOpenError(bool e)
{
    static const char *funcName = "setOpenError";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::setOpenError(e);
    }
    QSqlResultWrapper::sbk_o_setActive("QSqlDriver", funcName, gil, pyOverride, e);
}

::QString QSqlDriverWrapper::sqlStatement(::QSqlDriver::StatementType type, const ::QString & tableName, const ::QSqlRecord & rec, bool preparedStatement) const
{
    static const char *funcName = "sqlStatement";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::sqlStatement(type, tableName, rec, preparedStatement);
    }
    return sbk_o_sqlStatement("QSqlDriver", funcName, gil, pyOverride, type, tableName, rec, preparedStatement);
}

::QString QSqlDriverWrapper::sbk_o_sqlStatement(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSqlDriver::StatementType type, const ::QString & tableName, const ::QSqlRecord & rec, bool preparedStatement)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_StatementType_IDX])))->converter, &type),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &tableName),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), &rec),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &preparedStatement)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_StatementType_IDX])))->converter, &type),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &tableName),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), &rec),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &preparedStatement)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QString QSqlDriverWrapper::stripDelimiters(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const
{
    static const char *funcName = "stripDelimiters";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::stripDelimiters(identifier, type);
    }
    return QSqlDriverWrapper::sbk_o_escapeIdentifier("QSqlDriver", funcName, gil, pyOverride, identifier, type);
}

bool QSqlDriverWrapper::subscribeToNotification(const ::QString & name)
{
    static const char *funcName = "subscribeToNotification";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::subscribeToNotification(name);
    }
    return QSqlResultWrapper::sbk_o_reset("QSqlDriver", funcName, gil, pyOverride, name);
}

::QStringList QSqlDriverWrapper::subscribedToNotifications() const
{
    static const char *funcName = "subscribedToNotifications";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::subscribedToNotifications();
    }
    return sbk_o_subscribedToNotifications("QSqlDriver", funcName, gil, pyOverride);
}

::QStringList QSqlDriverWrapper::sbk_o_subscribedToNotifications(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QStringList();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QStringList", Py_TYPE(pyResult)->tp_name);
        return ::QStringList();
    }
    ::QStringList cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QStringList QSqlDriverWrapper::tables(::QSql::TableType tableType) const
{
    static const char *funcName = "tables";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::tables(tableType);
    }
    return sbk_o_tables("QSqlDriver", funcName, gil, pyOverride, tableType);
}

::QStringList QSqlDriverWrapper::sbk_o_tables(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSql::TableType tableType)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_TableType_IDX])))->converter, &tableType)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_TableType_IDX])))->converter, &tableType)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QStringList();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QStringList", Py_TYPE(pyResult)->tp_name);
        return ::QStringList();
    }
    ::QStringList cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSqlDriverWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSqlRelationalDelegateWrapper::sbk_o_timerEvent("QSqlDriver", funcName, gil, pyOverride, event);
}

bool QSqlDriverWrapper::unsubscribeFromNotification(const ::QString & name)
{
    static const char *funcName = "unsubscribeFromNotification";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlDriver::unsubscribeFromNotification(name);
    }
    return QSqlResultWrapper::sbk_o_reset("QSqlDriver", funcName, gil, pyOverride, name);
}

const QMetaObject *QSqlDriverWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSqlDriver::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSqlDriverWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSqlDriver::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSqlDriverWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSqlDriverWrapper *>(this));
    return QSqlDriver::qt_metacast(_clname);
}

QSqlDriverWrapper::~QSqlDriverWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlDriver_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSqlDriver");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlDriver >()))
        return -1;

    QSqlDriverWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QSqlDriver", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlDriver::QSqlDriver(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSqlDriver(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSqlDriver(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSqlDriver(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QSqlDriverWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QSqlDriverWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSqlDriver >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSqlDriverFunc_beginTransaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beginTransaction()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlDriver::beginTransaction()
            : cppSelf->beginTransaction();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_cancelQuery(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancelQuery()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlDriver::cancelQuery()
            : cppSelf->cancelQuery();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.close");
            return {};
        }
        cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlDriverFunc_commitTransaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // commitTransaction()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlDriver::commitTransaction()
            : cppSelf->commitTransaction();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_connectionName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectionName()const
        QString cppResult = const_cast<const ::QSqlDriver *>(cppSelf)->connectionName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_createResult(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createResult()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.createResult");
            return {};
        }
        QSqlResult * cppResult = const_cast<const ::QSqlDriver *>(cppSelf)->createResult();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_dbmsType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dbmsType()const
        QSqlDriver::DbmsType cppResult = const_cast<const ::QSqlDriver *>(cppSelf)->dbmsType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DbmsType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_escapeIdentifier(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "escapeIdentifier", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDriver::escapeIdentifier(QString,QSqlDriver::IdentifierType)const->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // escapeIdentifier(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "escapeIdentifier", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QSqlDriver::IdentifierType cppArg1{QSqlDriver::FieldName};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // escapeIdentifier(QString,QSqlDriver::IdentifierType)const
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::escapeIdentifier(cppArg0, cppArg1)
                : const_cast<const ::QSqlDriver *>(cppSelf)->escapeIdentifier(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_formatValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "formatValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    if (PyArg_ParseTuple(args, "|OO:formatValue", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDriver::formatValue(QSqlField,bool=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // formatValue(QSqlField,bool)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // formatValue(QSqlField,bool)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "formatValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"trimStrings", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "formatValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSqlField cppArg0_local;
        ::QSqlField *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = false;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // formatValue(QSqlField,bool)const
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::formatValue(*cppArg0, cppArg1)
                : const_cast<const ::QSqlDriver *>(cppSelf)->formatValue(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_hasFeature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::hasFeature(QSqlDriver::DriverFeature)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DriverFeature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // hasFeature(QSqlDriver::DriverFeature)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasFeature", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QSqlDriver::DriverFeature cppArg0{QSqlDriver::Transactions};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasFeature(QSqlDriver::DriverFeature)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.hasFeature");
                return {};
            }
            bool cppResult = const_cast<const ::QSqlDriver *>(cppSelf)->hasFeature(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_isIdentifierEscaped(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isIdentifierEscaped", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDriver::isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isIdentifierEscaped", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QSqlDriver::IdentifierType cppArg1{QSqlDriver::FieldName};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::isIdentifierEscaped(cppArg0, cppArg1)
                : const_cast<const ::QSqlDriver *>(cppSelf)->isIdentifierEscaped(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_isOpen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOpen()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::isOpen()
            : const_cast<const ::QSqlDriver *>(cppSelf)->isOpen();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_isOpenError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOpenError()const
        bool cppResult = const_cast<const ::QSqlDriver *>(cppSelf)->isOpenError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastError()const
        QSqlError cppResult = const_cast<const ::QSqlDriver *>(cppSelf)->lastError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_maximumIdentifierLength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::maximumIdentifierLength(QSqlDriver::IdentifierType)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // maximumIdentifierLength(QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "maximumIdentifierLength", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QSqlDriver::IdentifierType cppArg0{QSqlDriver::FieldName};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumIdentifierLength(QSqlDriver::IdentifierType)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::maximumIdentifierLength(cppArg0)
                : const_cast<const ::QSqlDriver *>(cppSelf)->maximumIdentifierLength(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_numericalPrecisionPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numericalPrecisionPolicy()const
        QSql::NumericalPrecisionPolicy cppResult = const_cast<const ::QSqlDriver *>(cppSelf)->numericalPrecisionPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_open(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:open", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDriver::open(QString,const QString&=,const QString&=,const QString&=,int=,const QString&=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // open(QString,QString,QString,QString,int,QString)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
                            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[5] = {{"user", 1}, {"password", 2}, {"host", 3}, {"port", 4}, {"connOpts", 5}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 5, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3 = QString();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4 = -1;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QString cppArg5 = QString();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // open(QString,QString,QString,QString,int,QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSqlDriver.open");
                return {};
            }
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->open(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_primaryIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::primaryIndex(QString)const->QSqlIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // primaryIndex(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "primaryIndex", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // primaryIndex(QString)const
            QSqlIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::primaryIndex(cppArg0)
                : const_cast<const ::QSqlDriver *>(cppSelf)->primaryIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_record(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::record(QString)const->QSqlRecord
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // record(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "record", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // record(QString)const
            QSqlRecord cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::record(cppArg0)
                : const_cast<const ::QSqlDriver *>(cppSelf)->record(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_rollbackTransaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rollbackTransaction()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlDriver::rollbackTransaction()
            : cppSelf->rollbackTransaction();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_setLastError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::setLastError(QSqlError)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), (pyArg)))) {
        overloadId = 0; // setLastError(QSqlError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastError", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSqlError cppArg0_local;
        ::QSqlError *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLastError(QSqlError)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlDriver::setLastError(*cppArg0)
                : cppSelf->setLastError(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlDriverFunc_setNumericalPrecisionPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumericalPrecisionPolicy", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QSql::NumericalPrecisionPolicy cppArg0{QSql::HighPrecision};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
            cppSelf->setNumericalPrecisionPolicy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlDriverFunc_setOpen(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::setOpen(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOpen(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOpen", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOpen(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlDriver::setOpen(cppArg0)
                : cppSelf->setOpen(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlDriverFunc_setOpenError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::setOpenError(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOpenError(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOpenError", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOpenError(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlDriver::setOpenError(cppArg0)
                : cppSelf->setOpenError(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlDriverFunc_sqlStatement(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sqlStatement", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDriver::sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const->QString
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_StatementType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
        overloadId = 0; // sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sqlStatement", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QSqlDriver::StatementType cppArg0{QSqlDriver::WhereStatement};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSqlRecord cppArg2_local;
        ::QSqlRecord *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        bool cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::sqlStatement(cppArg0, cppArg1, *cppArg2, cppArg3)
                : const_cast<const ::QSqlDriver *>(cppSelf)->sqlStatement(cppArg0, cppArg1, *cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_stripDelimiters(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "stripDelimiters", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDriver::stripDelimiters(QString,QSqlDriver::IdentifierType)const->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // stripDelimiters(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "stripDelimiters", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QSqlDriver::IdentifierType cppArg1{QSqlDriver::FieldName};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stripDelimiters(QString,QSqlDriver::IdentifierType)const
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::stripDelimiters(cppArg0, cppArg1)
                : const_cast<const ::QSqlDriver *>(cppSelf)->stripDelimiters(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_subscribeToNotification(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::subscribeToNotification(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // subscribeToNotification(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "subscribeToNotification", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // subscribeToNotification(QString)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlDriver::subscribeToNotification(cppArg0)
                : cppSelf->subscribeToNotification(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_subscribedToNotifications(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subscribedToNotifications()const
        QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::subscribedToNotifications()
            : const_cast<const ::QSqlDriver *>(cppSelf)->subscribedToNotifications();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_tables(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::tables(QSql::TableType)const->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_TableType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // tables(QSql::TableType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tables", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QSql::TableType cppArg0 = static_cast< ::QSql::TableType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tables(QSql::TableType)const
            QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlDriver *>(cppSelf)->::QSqlDriver::tables(cppArg0)
                : const_cast<const ::QSqlDriver *>(cppSelf)->tables(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlDriverFunc_unsubscribeFromNotification(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDriver::unsubscribeFromNotification(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // unsubscribeFromNotification(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unsubscribeFromNotification", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unsubscribeFromNotification(QString)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlDriver::unsubscribeFromNotification(cppArg0)
                : cppSelf->unsubscribeFromNotification(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSqlDriver_PropertyStrings[] = {
    "numericalPrecisionPolicy::",
    nullptr // Sentinel
};

static const char *Sbk_QSqlDriver_EnumFlagInfo[] = {
    "DbmsType:Enum",
    "DriverFeature:Enum",
    "IdentifierType:Enum",
    "NotificationSource:Enum",
    "StatementType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlDriver_methods[] = {
    {"beginTransaction", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_beginTransaction), METH_NOARGS, nullptr},
    {"cancelQuery", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_cancelQuery), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_close), METH_NOARGS, nullptr},
    {"commitTransaction", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_commitTransaction), METH_NOARGS, nullptr},
    {"connectionName", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_connectionName), METH_NOARGS, nullptr},
    {"createResult", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_createResult), METH_NOARGS, nullptr},
    {"dbmsType", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_dbmsType), METH_NOARGS, nullptr},
    {"escapeIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_escapeIdentifier), METH_VARARGS, nullptr},
    {"formatValue", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_formatValue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hasFeature", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_hasFeature), METH_O, nullptr},
    {"isIdentifierEscaped", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_isIdentifierEscaped), METH_VARARGS, nullptr},
    {"isOpen", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_isOpen), METH_NOARGS, nullptr},
    {"isOpenError", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_isOpenError), METH_NOARGS, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_lastError), METH_NOARGS, nullptr},
    {"maximumIdentifierLength", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_maximumIdentifierLength), METH_O, nullptr},
    {"numericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_numericalPrecisionPolicy), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_open), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"primaryIndex", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_primaryIndex), METH_O, nullptr},
    {"record", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_record), METH_O, nullptr},
    {"rollbackTransaction", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_rollbackTransaction), METH_NOARGS, nullptr},
    {"setLastError", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_setLastError), METH_O, nullptr},
    {"setNumericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_setNumericalPrecisionPolicy), METH_O, nullptr},
    {"setOpen", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_setOpen), METH_O, nullptr},
    {"setOpenError", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_setOpenError), METH_O, nullptr},
    {"sqlStatement", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_sqlStatement), METH_VARARGS, nullptr},
    {"stripDelimiters", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_stripDelimiters), METH_VARARGS, nullptr},
    {"subscribeToNotification", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_subscribeToNotification), METH_O, nullptr},
    {"subscribedToNotifications", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_subscribedToNotifications), METH_NOARGS, nullptr},
    {"tables", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_tables), METH_O, nullptr},
    {"unsubscribeFromNotification", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverFunc_unsubscribeFromNotification), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSqlDriver_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSqlDriver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSqlDriverWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSqlDriver_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlDriver_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlDriver_Type = nullptr;
static PyTypeObject *Sbk_QSqlDriver_TypeF(void)
{
    return _Sbk_QSqlDriver_Type;
}

static PyType_Slot Sbk_QSqlDriver_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSqlDriver_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlDriver_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlDriver_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlDriver_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlDriver_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlDriver_spec = {
    "2:PySide6.QtSql.QSqlDriver",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlDriver_slots
};

} //extern "C"

static void *Sbk_QSqlDriver_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSqlDriver *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSqlDriver_DriverFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlDriver::DriverFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlDriver::DriverFeature *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlDriver_DriverFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DriverFeature_IDX])))
        return Enum_PythonToCpp_QSqlDriver_DriverFeature;
    return {};
}

static PyObject *QSqlDriver_DriverFeature_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlDriver::DriverFeature>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlDriver::DriverFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DriverFeature_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSqlDriver_StatementType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlDriver::StatementType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlDriver::StatementType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlDriver_StatementType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_StatementType_IDX])))
        return Enum_PythonToCpp_QSqlDriver_StatementType;
    return {};
}

static PyObject *QSqlDriver_StatementType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlDriver::StatementType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlDriver::StatementType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_StatementType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSqlDriver_IdentifierType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlDriver::IdentifierType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlDriver::IdentifierType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlDriver_IdentifierType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX])))
        return Enum_PythonToCpp_QSqlDriver_IdentifierType;
    return {};
}

static PyObject *QSqlDriver_IdentifierType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlDriver::IdentifierType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlDriver::IdentifierType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSqlDriver_NotificationSource(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlDriver::NotificationSource>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlDriver::NotificationSource *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlDriver_NotificationSource_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_NotificationSource_IDX])))
        return Enum_PythonToCpp_QSqlDriver_NotificationSource;
    return {};
}

static PyObject *QSqlDriver_NotificationSource_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlDriver::NotificationSource>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlDriver::NotificationSource *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_NotificationSource_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSqlDriver_DbmsType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlDriver::DbmsType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlDriver::DbmsType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlDriver_DbmsType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DbmsType_IDX])))
        return Enum_PythonToCpp_QSqlDriver_DbmsType;
    return {};
}

static PyObject *QSqlDriver_DbmsType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlDriver::DbmsType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlDriver::DbmsType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DbmsType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlDriver_PythonToCpp_QSqlDriver_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlDriver_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlDriver_PythonToCpp_QSqlDriver_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlDriver_TypeF()))
        return QSqlDriver_PythonToCpp_QSqlDriver_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlDriver_PTR_CppToPython_QSqlDriver(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSqlDriver *>(const_cast<void *>(cppIn)), Sbk_QSqlDriver_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlDriver_SignatureStrings[] = {
    "PySide6.QtSql.QSqlDriver(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "PySide6.QtSql.QSqlDriver.beginTransaction(self)->bool",
    "PySide6.QtSql.QSqlDriver.cancelQuery(self)->bool",
    "PySide6.QtSql.QSqlDriver.close(self)",
    "PySide6.QtSql.QSqlDriver.commitTransaction(self)->bool",
    "PySide6.QtSql.QSqlDriver.connectionName(self)->QString",
    "PySide6.QtSql.QSqlDriver.createResult(self)->PySide6.QtSql.QSqlResult",
    "PySide6.QtSql.QSqlDriver.dbmsType(self)->PySide6.QtSql.QSqlDriver.DbmsType",
    "PySide6.QtSql.QSqlDriver.escapeIdentifier(self,identifier:QString,type:PySide6.QtSql.QSqlDriver.IdentifierType)->QString",
    "PySide6.QtSql.QSqlDriver.formatValue(self,field:PySide6.QtSql.QSqlField,trimStrings:bool=false)->QString",
    "PySide6.QtSql.QSqlDriver.hasFeature(self,f:PySide6.QtSql.QSqlDriver.DriverFeature)->bool",
    "PySide6.QtSql.QSqlDriver.isIdentifierEscaped(self,identifier:QString,type:PySide6.QtSql.QSqlDriver.IdentifierType)->bool",
    "PySide6.QtSql.QSqlDriver.isOpen(self)->bool",
    "PySide6.QtSql.QSqlDriver.isOpenError(self)->bool",
    "PySide6.QtSql.QSqlDriver.lastError(self)->PySide6.QtSql.QSqlError",
    "PySide6.QtSql.QSqlDriver.maximumIdentifierLength(self,type:PySide6.QtSql.QSqlDriver.IdentifierType)->int",
    "PySide6.QtSql.QSqlDriver.numericalPrecisionPolicy(self)->PySide6.QtSql.QSql.NumericalPrecisionPolicy",
    "PySide6.QtSql.QSqlDriver.open(self,db:QString,user:QString=QString(),password:QString=QString(),host:QString=QString(),port:int=-1,connOpts:QString=QString())->bool",
    "PySide6.QtSql.QSqlDriver.primaryIndex(self,tableName:QString)->PySide6.QtSql.QSqlIndex",
    "PySide6.QtSql.QSqlDriver.record(self,tableName:QString)->PySide6.QtSql.QSqlRecord",
    "PySide6.QtSql.QSqlDriver.rollbackTransaction(self)->bool",
    "PySide6.QtSql.QSqlDriver.setLastError(self,e:PySide6.QtSql.QSqlError)",
    "PySide6.QtSql.QSqlDriver.setNumericalPrecisionPolicy(self,precisionPolicy:PySide6.QtSql.QSql.NumericalPrecisionPolicy)",
    "PySide6.QtSql.QSqlDriver.setOpen(self,o:bool)",
    "PySide6.QtSql.QSqlDriver.setOpenError(self,e:bool)",
    "PySide6.QtSql.QSqlDriver.sqlStatement(self,type:PySide6.QtSql.QSqlDriver.StatementType,tableName:QString,rec:PySide6.QtSql.QSqlRecord,preparedStatement:bool)->QString",
    "PySide6.QtSql.QSqlDriver.stripDelimiters(self,identifier:QString,type:PySide6.QtSql.QSqlDriver.IdentifierType)->QString",
    "PySide6.QtSql.QSqlDriver.subscribeToNotification(self,name:QString)->bool",
    "PySide6.QtSql.QSqlDriver.subscribedToNotifications(self)->QStringList",
    "PySide6.QtSql.QSqlDriver.tables(self,tableType:PySide6.QtSql.QSql.TableType)->QStringList",
    "PySide6.QtSql.QSqlDriver.unsubscribeFromNotification(self,name:QString)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlDriver_SignatureByteSize = 594;
static constexpr uint8_t QSqlDriver_SignatureBytes[594] = {
    0x78, 0xda, 0xbd, 0x56, 0xc9, 0x6e, 0xdb, 0x30, 0x10, 0xbd, 0xf7, 0x4b, 0xe2, 0x82, 0x11, 0xd0,
    0x4b, 0x0f, 0x02, 0xdc, 0x4b, 0x1d, 0x03, 0x41, 0x0d, 0x2f, 0xb1, 0xd1, 0x3b, 0x45, 0x8d, 0x6d,
    0xb6, 0x5c, 0x94, 0x19, 0xaa, 0x8d, 0xfe, 0xbe, 0xd4, 0xea, 0x3a, 0x16, 0x25, 0x19, 0x28, 0x7a,
    0xb1, 0x60, 0xcd, 0x7b, 0x6f, 0x16, 0xce, 0x0c, 0xb5, 0x2d, 0xf6, 0x32, 0x85, 0xcf, 0xd1, 0xce,
    0xed, 0x5f, 0x55, 0xb4, 0xf3, 0x3f, 0x0b, 0x94, 0xbf, 0x00, 0x1f, 0x08, 0xd4, 0x91, 0x65, 0x1c,
    0xc1, 0xb8, 0x78, 0xdb, 0x81, 0xbe, 0x5a, 0x84, 0x68, 0xb7, 0x49, 0x7e, 0x80, 0x70, 0x73, 0x93,
    0x2b, 0x95, 0x39, 0x64, 0x1f, 0xe3, 0x6f, 0x50, 0xfc, 0xb6, 0x98, 0x6e, 0x8c, 0x2a, 0xe6, 0x6b,
    0x6b, 0x80, 0x99, 0x5c, 0x03, 0x4a, 0xc1, 0xd5, 0x16, 0x41, 0x48, 0x92, 0xd6, 0x6c, 0xad, 0x92,
    0xa2, 0x88, 0x4b, 0x0f, 0xd1, 0x3a, 0x60, 0xad, 0xb8, 0xb3, 0x0f, 0xdb, 0x40, 0x4c, 0x51, 0x02,
    0x27, 0x69, 0x0e, 0xc8, 0x0d, 0x71, 0xe1, 0x3c, 0xab, 0x0a, 0x72, 0xf6, 0xf8, 0x25, 0xb1, 0x56,
    0x85, 0x59, 0x82, 0x1b, 0x01, 0x6a, 0x97, 0x03, 0x16, 0x13, 0x09, 0xca, 0x12, 0xd4, 0xd0, 0x01,
    0x90, 0xd5, 0x5a, 0xba, 0xfb, 0x83, 0xb1, 0xc6, 0x40, 0x85, 0x5f, 0x73, 0x0d, 0x2d, 0x67, 0xb7,
    0x77, 0x28, 0xcd, 0x69, 0x80, 0x86, 0xc0, 0x1d, 0xbc, 0x00, 0xe5, 0xca, 0xb5, 0xa4, 0x5b, 0x70,
    0x6d, 0x0f, 0xab, 0xa4, 0x89, 0xa6, 0x43, 0x91, 0x41, 0x58, 0xa1, 0x01, 0x2e, 0x1a, 0x60, 0x58,
    0x0a, 0x48, 0xf0, 0x0c, 0x9e, 0x53, 0xdf, 0x1e, 0xf2, 0x28, 0xdb, 0x7e, 0x91, 0xdd, 0xff, 0xb8,
    0x49, 0x89, 0x39, 0x2f, 0x13, 0x07, 0x65, 0x2e, 0x02, 0xa5, 0xbb, 0x29, 0x95, 0x38, 0x5a, 0xd4,
    0xdc, 0x7d, 0xe7, 0x2a, 0xaf, 0xd3, 0x60, 0x9e, 0xac, 0xd2, 0x1e, 0x0f, 0xcb, 0xf2, 0x3d, 0xf3,
    0x6a, 0xba, 0x96, 0xa4, 0xb8, 0x3c, 0x99, 0xf9, 0x91, 0x2b, 0x9a, 0xe4, 0xe8, 0xcc, 0x69, 0xe9,
    0x8b, 0x9e, 0x63, 0xeb, 0x27, 0x9c, 0x45, 0xfd, 0x68, 0xd0, 0xa3, 0x2d, 0x20, 0xe9, 0x92, 0xf5,
    0x53, 0x55, 0xc6, 0xf4, 0x5f, 0x55, 0x6f, 0xcc, 0xf1, 0x26, 0x83, 0x89, 0x7d, 0x5a, 0x63, 0x9f,
    0x10, 0x2d, 0x4e, 0x23, 0x28, 0x4e, 0xee, 0x0a, 0x7e, 0x8b, 0xac, 0xcc, 0x61, 0x05, 0xcd, 0xdf,
    0xa4, 0xce, 0xf5, 0x25, 0xa9, 0x15, 0x98, 0x93, 0x3b, 0xd7, 0xb5, 0xb9, 0xb3, 0x10, 0xd2, 0x0c,
    0x8c, 0x41, 0x68, 0x39, 0x85, 0x23, 0x0f, 0x6e, 0xac, 0xb0, 0x13, 0xdb, 0x96, 0x9a, 0xa5, 0x49,
    0x77, 0x9c, 0x39, 0x5d, 0xce, 0x76, 0xde, 0x3c, 0x1f, 0x66, 0x7e, 0xcd, 0x12, 0x95, 0xfb, 0xb3,
    0xc7, 0x74, 0xb6, 0xe4, 0xfa, 0x18, 0x16, 0x5d, 0xec, 0x93, 0x9c, 0x3f, 0x7e, 0x62, 0xe5, 0x4a,
    0xd9, 0x64, 0x8e, 0x6e, 0x61, 0xa3, 0x87, 0x96, 0xf9, 0xe9, 0xe0, 0x58, 0x3c, 0x9b, 0x14, 0xde,
    0x9a, 0x3a, 0xf3, 0x44, 0x41, 0xb9, 0x9a, 0x5a, 0xb5, 0xde, 0x7a, 0x54, 0x84, 0xb0, 0xac, 0xaf,
    0x91, 0xcf, 0xe6, 0x1e, 0xc1, 0x97, 0x8a, 0x31, 0xa0, 0x68, 0x95, 0x4a, 0xb8, 0xf8, 0x79, 0xf7,
    0xbe, 0x25, 0x70, 0xab, 0xab, 0xce, 0x64, 0x7d, 0x6d, 0x54, 0x99, 0x67, 0x83, 0x2a, 0xeb, 0xa1,
    0xa6, 0x61, 0xd9, 0xbb, 0x6b, 0xee, 0x8e, 0x16, 0x1a, 0x76, 0xdb, 0x4d, 0x2c, 0xb3, 0xd5, 0xfe,
    0x1a, 0x47, 0x5f, 0xa5, 0x3a, 0x46, 0x79, 0x55, 0x7b, 0xe7, 0x2f, 0x16, 0xed, 0xc7, 0x67, 0xca,
    0x9c, 0x75, 0xe0, 0x72, 0xcc, 0x6e, 0x8f, 0x96, 0xf9, 0xcc, 0xe2, 0xd0, 0xe1, 0x96, 0x35, 0x2a,
    0xbf, 0x27, 0xd2, 0x4e, 0xa4, 0x8e, 0x6e, 0xc2, 0x2a, 0x26, 0x6f, 0xcf, 0x16, 0xa0, 0xa4, 0xbf,
    0x71, 0x01, 0xe9, 0xbf, 0xdd, 0x35, 0x94, 0x27, 0x24, 0x50, 0x26, 0x70, 0xb0, 0x6b, 0x5b, 0x52,
    0x05, 0xef, 0x3a, 0x8f, 0x99, 0xeb, 0x9e, 0x1e, 0x69, 0xc3, 0x56, 0x29, 0xbd, 0x96, 0xa2, 0x77,
    0x5f, 0x00, 0x2b, 0x49, 0x03, 0x8b, 0xab, 0x2a, 0x38, 0xfd, 0x35, 0x57, 0x87, 0xfe, 0x84, 0xa3,
    0x43, 0x6b, 0x9c, 0xaa, 0x9c, 0x9b, 0x2e, 0xc2, 0x25, 0x5a, 0x3d, 0x2d, 0xdb, 0x3f, 0xdc, 0x96,
    0xbb, 0xf4
};
#endif

PyTypeObject *init_QSqlDriver(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlDriver_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QSqlDriver_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlDriver",
        "QSqlDriver*",
        &Sbk_QSqlDriver_spec,
        &Shiboken::callCppDestructor< QSqlDriver >,
        Sbk_QSqlDriver_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSqlDriver_TypeF(); // references _Sbk_QSqlDriver_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlDriver_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlDriver_SignatureBytes, QSqlDriver_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlDriver_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlDriver_PythonToCpp_QSqlDriver_PTR,
        is_QSqlDriver_PythonToCpp_QSqlDriver_PTR_Convertible,
        QSqlDriver_PTR_CppToPython_QSqlDriver);

    Shiboken::Conversions::registerConverterName(converter, "QSqlDriver");
    Shiboken::Conversions::registerConverterName(converter, "QSqlDriver*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlDriver&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlDriver).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSqlDriverWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSqlDriver_TypeF(), &Sbk_QSqlDriver_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSqlDriver_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DriverFeature'.
    const char *DriverFeature_Initializer[] = {
        "Transactions",
        "QuerySize",
        "BLOB",
        "Unicode",
        "PreparedQueries",
        "NamedPlaceholders",
        "PositionalPlaceholders",
        "LastInsertId",
        "BatchOperations",
        "SimpleLocking",
        "LowPrecisionNumbers",
        "EventNotifications",
        "FinishQuery",
        "MultipleResultSets",
        "CancelQuery",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DriverFeature_InitializerValues[] = {
        uint8_t(QSqlDriver::DriverFeature::Transactions),           //  0x00  0
        uint8_t(QSqlDriver::DriverFeature::QuerySize),              //  0x01  1
        uint8_t(QSqlDriver::DriverFeature::BLOB),                   //  0x02  2
        uint8_t(QSqlDriver::DriverFeature::Unicode),                //  0x03  3
        uint8_t(QSqlDriver::DriverFeature::PreparedQueries),        //  0x04  4
        uint8_t(QSqlDriver::DriverFeature::NamedPlaceholders),      //  0x05  5
        uint8_t(QSqlDriver::DriverFeature::PositionalPlaceholders), //  0x06  6
        uint8_t(QSqlDriver::DriverFeature::LastInsertId),           //  0x07  7
        uint8_t(QSqlDriver::DriverFeature::BatchOperations),        //  0x08  8
        uint8_t(QSqlDriver::DriverFeature::SimpleLocking),          //  0x09  9
        uint8_t(QSqlDriver::DriverFeature::LowPrecisionNumbers),    //  0x0a  10
        uint8_t(QSqlDriver::DriverFeature::EventNotifications),     //  0x0b  11
        uint8_t(QSqlDriver::DriverFeature::FinishQuery),            //  0x0c  12
        uint8_t(QSqlDriver::DriverFeature::MultipleResultSets),     //  0x0d  13
        uint8_t(QSqlDriver::DriverFeature::CancelQuery)             //  0x0e  14
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlDriver_TypeF(),
        "2:PySide6.QtSql.QSqlDriver.DriverFeature",
        DriverFeature_Initializer, DriverFeature_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DriverFeature_IDX].type = EType;
    // Register converter for enum 'QSqlDriver::DriverFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlDriver_DriverFeature_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlDriver_DriverFeature,
            is_Enum_PythonToCpp_QSqlDriver_DriverFeature_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlDriver::DriverFeature");
        Shiboken::Conversions::registerConverterAlias(converter, "DriverFeature");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DriverFeature' enum.

    // Initialization of enum 'StatementType'.
    const char *StatementType_Initializer[] = {
        "WhereStatement",
        "SelectStatement",
        "UpdateStatement",
        "InsertStatement",
        "DeleteStatement",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StatementType_InitializerValues[] = {
        uint8_t(QSqlDriver::StatementType::WhereStatement),  //  0x00  0
        uint8_t(QSqlDriver::StatementType::SelectStatement), //  0x01  1
        uint8_t(QSqlDriver::StatementType::UpdateStatement), //  0x02  2
        uint8_t(QSqlDriver::StatementType::InsertStatement), //  0x03  3
        uint8_t(QSqlDriver::StatementType::DeleteStatement)  //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlDriver_TypeF(),
        "2:PySide6.QtSql.QSqlDriver.StatementType",
        StatementType_Initializer, StatementType_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_StatementType_IDX].type = EType;
    // Register converter for enum 'QSqlDriver::StatementType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlDriver_StatementType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlDriver_StatementType,
            is_Enum_PythonToCpp_QSqlDriver_StatementType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlDriver::StatementType");
        Shiboken::Conversions::registerConverterAlias(converter, "StatementType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StatementType' enum.

    // Initialization of enum 'IdentifierType'.
    const char *IdentifierType_Initializer[] = {
        "FieldName",
        "TableName",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t IdentifierType_InitializerValues[] = {
        uint8_t(QSqlDriver::IdentifierType::FieldName), //  0x00  0
        uint8_t(QSqlDriver::IdentifierType::TableName)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlDriver_TypeF(),
        "2:PySide6.QtSql.QSqlDriver.IdentifierType",
        IdentifierType_Initializer, IdentifierType_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IdentifierType_IDX].type = EType;
    // Register converter for enum 'QSqlDriver::IdentifierType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlDriver_IdentifierType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlDriver_IdentifierType,
            is_Enum_PythonToCpp_QSqlDriver_IdentifierType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlDriver::IdentifierType");
        Shiboken::Conversions::registerConverterAlias(converter, "IdentifierType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'IdentifierType' enum.

    // Initialization of enum 'NotificationSource'.
    const char *NotificationSource_Initializer[] = {
        "UnknownSource",
        "SelfSource",
        "OtherSource",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NotificationSource_InitializerValues[] = {
        uint8_t(QSqlDriver::NotificationSource::UnknownSource), //  0x00  0
        uint8_t(QSqlDriver::NotificationSource::SelfSource),    //  0x01  1
        uint8_t(QSqlDriver::NotificationSource::OtherSource)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlDriver_TypeF(),
        "2:PySide6.QtSql.QSqlDriver.NotificationSource",
        NotificationSource_Initializer, NotificationSource_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_NotificationSource_IDX].type = EType;
    // Register converter for enum 'QSqlDriver::NotificationSource'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlDriver_NotificationSource_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlDriver_NotificationSource,
            is_Enum_PythonToCpp_QSqlDriver_NotificationSource_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlDriver::NotificationSource");
        Shiboken::Conversions::registerConverterAlias(converter, "NotificationSource");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'NotificationSource' enum.

    // Initialization of enum 'DbmsType'.
    const char *DbmsType_Initializer[] = {
        "UnknownDbms",
        "MSSqlServer",
        "MySqlServer",
        "PostgreSQL",
        "Oracle",
        "Sybase",
        "SQLite",
        "Interbase",
        "DB2",
        "MimerSQL",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DbmsType_InitializerValues[] = {
        uint8_t(QSqlDriver::DbmsType::UnknownDbms), //  0x00  0
        uint8_t(QSqlDriver::DbmsType::MSSqlServer), //  0x01  1
        uint8_t(QSqlDriver::DbmsType::MySqlServer), //  0x02  2
        uint8_t(QSqlDriver::DbmsType::PostgreSQL),  //  0x03  3
        uint8_t(QSqlDriver::DbmsType::Oracle),      //  0x04  4
        uint8_t(QSqlDriver::DbmsType::Sybase),      //  0x05  5
        uint8_t(QSqlDriver::DbmsType::SQLite),      //  0x06  6
        uint8_t(QSqlDriver::DbmsType::Interbase),   //  0x07  7
        uint8_t(QSqlDriver::DbmsType::DB2),         //  0x08  8
        uint8_t(QSqlDriver::DbmsType::MimerSQL)     //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlDriver_TypeF(),
        "2:PySide6.QtSql.QSqlDriver.DbmsType",
        DbmsType_Initializer, DbmsType_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_DbmsType_IDX].type = EType;
    // Register converter for enum 'QSqlDriver::DbmsType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlDriver_DbmsType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlDriver_DbmsType,
            is_Enum_PythonToCpp_QSqlDriver_DbmsType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlDriver::DbmsType");
        Shiboken::Conversions::registerConverterAlias(converter, "DbmsType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DbmsType' enum.

    PySide::Signal::registerSignals(pyType, &::QSqlDriver::staticMetaObject);
    qRegisterMetaType< ::QSqlDriver::DriverFeature >("QSqlDriver::DriverFeature");
    qRegisterMetaType< ::QSqlDriver::StatementType >("QSqlDriver::StatementType");
    qRegisterMetaType< ::QSqlDriver::IdentifierType >("QSqlDriver::IdentifierType");
    qRegisterMetaType< ::QSqlDriver::NotificationSource >("QSqlDriver::NotificationSource");
    qRegisterMetaType< ::QSqlDriver::DbmsType >("QSqlDriver::DbmsType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSqlDriver::staticMetaObject, sizeof(QSqlDriverWrapper));

    return pyType;
}
