// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSQLDRIVERWRAPPER_H
#define SBK_QSQLDRIVERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSql/qsqldriver.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QSqlDriverWrapper : public QSqlDriver
{
public:
    QSqlDriverWrapper(::QObject * parent = nullptr);
    QSqlDriverWrapper(const QSqlDriverWrapper &) = delete;
    QSqlDriverWrapper& operator=(const QSqlDriverWrapper &) = delete;
    QSqlDriverWrapper(QSqlDriverWrapper &&) = delete;
    QSqlDriverWrapper& operator=(QSqlDriverWrapper &&) = delete;
    ~QSqlDriverWrapper() override;

    bool beginTransaction() override;
    static bool sbk_o_beginTransaction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool cancelQuery() override;
    void childEvent(::QChildEvent * event) override;
    void close() override;
    bool commitTransaction() override;
    static bool sbk_o_commitTransaction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QSqlResult * createResult() const override;
    static ::QSqlResult * sbk_o_createResult(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QString escapeIdentifier(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const override;
    static ::QString sbk_o_escapeIdentifier(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & identifier, ::QSqlDriver::IdentifierType type);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QString formatValue(const ::QSqlField & field, bool trimStrings = false) const override;
    static ::QString sbk_o_formatValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSqlField & field, bool trimStrings = false);
    bool hasFeature(::QSqlDriver::DriverFeature f) const override;
    static bool sbk_o_hasFeature(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSqlDriver::DriverFeature f);
    bool isIdentifierEscaped(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const override;
    static bool sbk_o_isIdentifierEscaped(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & identifier, ::QSqlDriver::IdentifierType type);
    bool isOpen() const override;
    int maximumIdentifierLength(::QSqlDriver::IdentifierType type) const override;
    static int sbk_o_maximumIdentifierLength(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSqlDriver::IdentifierType type);
    bool open(const ::QString & db, const ::QString & user = QString(), const ::QString & password = QString(), const ::QString & host = QString(), int port = -1, const ::QString & connOpts = QString()) override;
    static bool sbk_o_open(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & db, const ::QString & user = QString(), const ::QString & password = QString(), const ::QString & host = QString(), int port = -1, const ::QString & connOpts = QString());
    ::QSqlIndex primaryIndex(const ::QString & tableName) const override;
    static ::QSqlIndex sbk_o_primaryIndex(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & tableName);
    ::QSqlRecord record(const ::QString & tableName) const override;
    static ::QSqlRecord sbk_o_record(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & tableName);
    bool rollbackTransaction() override;
    static bool sbk_o_rollbackTransaction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setLastError(const ::QSqlError & e) override;
    void setOpen(bool o) override;
    void setOpenError(bool e) override;
    ::QString sqlStatement(::QSqlDriver::StatementType type, const ::QString & tableName, const ::QSqlRecord & rec, bool preparedStatement) const override;
    static ::QString sbk_o_sqlStatement(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSqlDriver::StatementType type, const ::QString & tableName, const ::QSqlRecord & rec, bool preparedStatement);
    ::QString stripDelimiters(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const override;
    bool subscribeToNotification(const ::QString & name) override;
    ::QStringList subscribedToNotifications() const override;
    static ::QStringList sbk_o_subscribedToNotifications(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QStringList tables(::QSql::TableType tableType) const override;
    static ::QStringList sbk_o_tables(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSql::TableType tableType);
    void timerEvent(::QTimerEvent * event) override;
    bool unsubscribeFromNotification(const ::QString & name) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[31] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSQLDRIVERWRAPPER_H
