// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtstatemachine_python.h"

// main header
#include "qsignaltransition_wrapper.h"

// Wrappers providing overrides
#include "qabstracttransition_wrapper.h"

// Argument includes
#include <QtStateMachine/qstate.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSignalTransitionWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSignalTransitionWrapper::QSignalTransitionWrapper(::QState * sourceState) : QSignalTransition(sourceState)
{
}

QSignalTransitionWrapper::QSignalTransitionWrapper(const ::QObject * sender, const char * signal, ::QState * sourceState) : QSignalTransition(sender, signal, sourceState)
{
}

void QSignalTransitionWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstractTransitionWrapper::sbk_o_childEvent("QSignalTransition", funcName, gil, pyOverride, event);
}

void QSignalTransitionWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstractTransitionWrapper::sbk_o_connectNotify("QSignalTransition", funcName, gil, pyOverride, signal);
}

void QSignalTransitionWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstractTransitionWrapper::sbk_o_customEvent("QSignalTransition", funcName, gil, pyOverride, event);
}

void QSignalTransitionWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstractTransitionWrapper::sbk_o_connectNotify("QSignalTransition", funcName, gil, pyOverride, signal);
}

bool QSignalTransitionWrapper::event(::QEvent * e)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSignalTransition::event(e);
    }
    return QAbstractTransitionWrapper::sbk_o_event("QSignalTransition", funcName, gil, pyOverride, e);
}

bool QSignalTransitionWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstractTransitionWrapper::sbk_o_eventFilter("QSignalTransition", funcName, gil, pyOverride, watched, event);
}

bool QSignalTransitionWrapper::eventTest(::QEvent * event)
{
    static const char *funcName = "eventTest";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSignalTransition::eventTest(event);
    }
    return QAbstractTransitionWrapper::sbk_o_eventTest("QSignalTransition", funcName, gil, pyOverride, event);
}

void QSignalTransitionWrapper::onTransition(::QEvent * event)
{
    static const char *funcName = "onTransition";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSignalTransition::onTransition(event);
    }
    QAbstractTransitionWrapper::sbk_o_onTransition("QSignalTransition", funcName, gil, pyOverride, event);
}

void QSignalTransitionWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstractTransitionWrapper::sbk_o_timerEvent("QSignalTransition", funcName, gil, pyOverride, event);
}

const QMetaObject *QSignalTransitionWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSignalTransition::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSignalTransitionWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSignalTransition::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSignalTransitionWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSignalTransitionWrapper *>(this));
    return QSignalTransition::qt_metacast(_clname);
}

QSignalTransitionWrapper::~QSignalTransitionWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSignalTransition_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSignalTransition >()))
        return -1;

    QSignalTransitionWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QSignalTransition", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSignalTransition::QSignalTransition(PyObject*,QState*=)
    // 1: QSignalTransition::QSignalTransition(QState*=)
    // 2: QSignalTransition::QSignalTransition(const QObject*,const char*,QState*=)
    if (numArgs == 0) {
        overloadId = 1; // QSignalTransition(QState*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSignalTransition(QState*)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // QSignalTransition(const QObject*,const char*,QState*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_IDX]), (pyArgs[2])))) {
            overloadId = 2; // QSignalTransition(const QObject*,const char*,QState*)
        }
    } else if (numArgs >= 1
        && true) {
        if (numArgs == 1) {
            overloadId = 0; // QSignalTransition(PyObject*,QState*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QSignalTransition(PyObject*,QState*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSignalTransition(PyObject *signal, QState *state)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"state", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QState *cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalTransition(PyObject*,QState*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtstatemachine.cpp (qsignaltransition)]
                if (PyObject_TypeCheck(pyArgs[0], PySideSignalInstance_TypeF())) {
                    auto *signalInstance = reinterpret_cast<PySideSignalInstance *>(pyArgs[1-1]);
                    PyObject *dataSource = PySide::Signal::getObject(signalInstance);
                    Shiboken::AutoDecRef obType(PyObject_Type(dataSource));
                    ::QObject* sender{nullptr};
                Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), dataSource, &(sender));
                    //XXX   /|\ omitting this space crashes shiboken!
                    if (sender) {
                        const char *dataSignature = PySide::Signal::getSignature(signalInstance);
                        QByteArray signature(dataSignature); // Append SIGNAL flag (2)
                        signature.prepend('2');
                        cptr = new QSignalTransitionWrapper(sender, signature, cppArg1);
                    }
                }
                // END of custom code block [file: ../glue/qtstatemachine.cpp (qsignaltransition)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // QSignalTransition(QState *sourceState)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"sourceState", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QState *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalTransition(QState*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSignalTransitionWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSignalTransitionWrapper(cppArg0);
                }

            }
            break;
        }
        case 2: // QSignalTransition(const QObject *sender, const char *signal, QState *sourceState)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"sourceState", 2}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_IDX]), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QState *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalTransition(const QObject*,const char*,QState*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSignalTransitionWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSignalTransitionWrapper(cppArg0, cppArg1, cppArg2);
                }

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSignalTransition >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSignalTransitionFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSignalTransition::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSignalTransitionFunc_eventTest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTransition::eventTest(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // eventTest(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "eventTest", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventTest(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSignalTransition::eventTest(cppArg0)
                : cppSelf->eventTest(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSignalTransitionFunc_onTransition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTransition::onTransition(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // onTransition(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "onTransition", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // onTransition(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSignalTransition::onTransition(cppArg0)
                : cppSelf->onTransition(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSignalTransitionFunc_senderObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // senderObject()const
        const QObject * cppResult = const_cast<const ::QSignalTransition *>(cppSelf)->senderObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSignalTransitionFunc_setSenderObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSignalTransition::setSenderObject(const QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setSenderObject(const QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSenderObject", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSenderObject(const QObject*)
            cppSelf->setSenderObject(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSignalTransitionFunc_setSignal(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSignalTransition::setSignal(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setSignal(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSignal", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSignal(QByteArray)
            cppSelf->setSignal(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSignalTransitionFunc_signal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // signal()const
        QByteArray cppResult = const_cast<const ::QSignalTransition *>(cppSelf)->signal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSignalTransition_PropertyStrings[] = {
    "senderObject::",
    "signal::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSignalTransition_methods[] = {
    {"event", reinterpret_cast<PyCFunction>(Sbk_QSignalTransitionFunc_event), METH_O, nullptr},
    {"eventTest", reinterpret_cast<PyCFunction>(Sbk_QSignalTransitionFunc_eventTest), METH_O, nullptr},
    {"onTransition", reinterpret_cast<PyCFunction>(Sbk_QSignalTransitionFunc_onTransition), METH_O, nullptr},
    {"senderObject", reinterpret_cast<PyCFunction>(Sbk_QSignalTransitionFunc_senderObject), METH_NOARGS, nullptr},
    {"setSenderObject", reinterpret_cast<PyCFunction>(Sbk_QSignalTransitionFunc_setSenderObject), METH_O, nullptr},
    {"setSignal", reinterpret_cast<PyCFunction>(Sbk_QSignalTransitionFunc_setSignal), METH_O, nullptr},
    {"signal", reinterpret_cast<PyCFunction>(Sbk_QSignalTransitionFunc_signal), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSignalTransition_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSignalTransition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSignalTransitionWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSignalTransition_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSignalTransition_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSignalTransition_Type = nullptr;
static PyTypeObject *Sbk_QSignalTransition_TypeF(void)
{
    return _Sbk_QSignalTransition_Type;
}

static PyType_Slot Sbk_QSignalTransition_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSignalTransition_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSignalTransition_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSignalTransition_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSignalTransition_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSignalTransition_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSignalTransition_spec = {
    "2:PySide6.QtStateMachine.QSignalTransition",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSignalTransition_slots
};

} //extern "C"

static void *Sbk_QSignalTransition_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSignalTransition *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSignalTransition_PythonToCpp_QSignalTransition_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSignalTransition_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSignalTransition_PythonToCpp_QSignalTransition_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSignalTransition_TypeF()))
        return QSignalTransition_PythonToCpp_QSignalTransition_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSignalTransition_PTR_CppToPython_QSignalTransition(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSignalTransition *>(const_cast<void *>(cppIn)), Sbk_QSignalTransition_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSignalTransition_SignatureStrings[] = {
    "2:PySide6.QtStateMachine.QSignalTransition(self,signal:PyObject,state:PySide6.QtStateMachine.QState=0,*:KeywordOnly=None,senderObject:QObject=None,signal:QByteArray=None)",
    "1:PySide6.QtStateMachine.QSignalTransition(self,sourceState:PySide6.QtStateMachine.QState=nullptr,*:KeywordOnly=None,senderObject:QObject=None,signal:QByteArray=None)",
    "0:PySide6.QtStateMachine.QSignalTransition(self,sender:PySide6.QtCore.QObject,signal:char*,sourceState:PySide6.QtStateMachine.QState=nullptr,*:KeywordOnly=None,senderObject:QObject=None,signal:QByteArray=None)",
    "PySide6.QtStateMachine.QSignalTransition.event(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtStateMachine.QSignalTransition.eventTest(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtStateMachine.QSignalTransition.onTransition(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QSignalTransition.senderObject(self)->PySide6.QtCore.QObject",
    "PySide6.QtStateMachine.QSignalTransition.setSenderObject(self,sender:PySide6.QtCore.QObject)",
    "PySide6.QtStateMachine.QSignalTransition.setSignal(self,signal:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtStateMachine.QSignalTransition.signal(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t QSignalTransition_SignatureByteSize = 269;
static constexpr uint8_t QSignalTransition_SignatureBytes[269] = {
    0x78, 0xda, 0xc5, 0x93, 0xc1, 0x4a, 0x03, 0x31, 0x10, 0x86, 0xef, 0x7d, 0x0a, 0x8f, 0x6e, 0x89,
    0x4b, 0xf5, 0xe0, 0x61, 0xa1, 0x82, 0x8a, 0x27, 0xd1, 0xba, 0xa4, 0x9e, 0xc4, 0x43, 0xba, 0x3b,
    0xb6, 0x91, 0x30, 0x29, 0x93, 0xa9, 0x92, 0xb7, 0x77, 0x37, 0xb1, 0xb5, 0x6e, 0x6b, 0xd9, 0x40,
    0xc1, 0x53, 0x48, 0x26, 0xf3, 0xfd, 0xff, 0x4c, 0x26, 0x17, 0xc5, 0x93, 0x97, 0xba, 0x86, 0xcb,
    0xbc, 0x64, 0xc9, 0x8a, 0xe1, 0x41, 0x55, 0x0b, 0x8d, 0x90, 0x97, 0x52, 0xcf, 0x51, 0x99, 0x29,
    0x29, 0x74, 0x9a, 0xb5, 0xc5, 0x53, 0x07, 0xe6, 0x4d, 0xb8, 0x70, 0xda, 0x24, 0x4d, 0x66, 0xef,
    0x50, 0xb1, 0x70, 0x6d, 0xce, 0xdf, 0x8c, 0x76, 0x37, 0x1e, 0x89, 0x61, 0x71, 0x0f, 0xfe, 0xd3,
    0x52, 0x3d, 0x41, 0xe3, 0xc7, 0x8f, 0x16, 0x41, 0x38, 0xc0, 0x1a, 0x28, 0x52, 0x8a, 0x32, 0xae,
    0xdf, 0x91, 0x28, 0x51, 0xde, 0x78, 0x86, 0x6b, 0x22, 0x15, 0x13, 0xb2, 0xc1, 0x79, 0xaa, 0x55,
    0xbb, 0xa2, 0x0a, 0x64, 0x0f, 0x83, 0xb8, 0x32, 0x66, 0xc9, 0x74, 0x1c, 0x9b, 0xa3, 0x54, 0x9b,
    0x41, 0x61, 0x2b, 0xe9, 0xd6, 0x52, 0x73, 0x79, 0xdd, 0xdf, 0xa8, 0x52, 0x2d, 0x14, 0x0d, 0xff,
    0xab, 0xa2, 0xbe, 0xf5, 0xe4, 0xf0, 0x01, 0xc8, 0xb1, 0x2a, 0xd8, 0x29, 0xe8, 0xae, 0x0d, 0x66,
    0x67, 0x57, 0x33, 0x6b, 0x4d, 0x22, 0x72, 0x0a, 0x6e, 0x8d, 0x6d, 0xb7, 0x47, 0x42, 0x5b, 0xec,
    0x3e, 0xc5, 0x21, 0x7a, 0x7f, 0xee, 0x76, 0x83, 0x03, 0xb7, 0x71, 0xb6, 0xff, 0x75, 0x53, 0x98,
    0x2c, 0xbb, 0xd8, 0xc3, 0x93, 0x93, 0xa5, 0xc1, 0xc3, 0xd9, 0xaf, 0x2f, 0xce, 0x7e, 0xa9, 0x71,
    0x9e, 0x3f, 0x63, 0x73, 0xe5, 0xa5, 0xab, 0xb1, 0x19, 0x11, 0x71, 0x12, 0x46, 0xf3, 0x35, 0x45,
    0xee, 0x47, 0x6b, 0x4f, 0x67, 0x36, 0xe4, 0xc1, 0x17, 0x9e, 0x7a, 0xaf, 0xda
};
#endif

PyTypeObject *init_QSignalTransition(PyObject *module)
{
    if (SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX].type != nullptr)
        return SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX].type;

    Shiboken::AutoDecRef Sbk_QSignalTransition_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QAbstractTransition_IDX]))));

    _Sbk_QSignalTransition_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSignalTransition",
        "QSignalTransition*",
        &Sbk_QSignalTransition_spec,
        &Shiboken::callCppDestructor< QSignalTransition >,
        Sbk_QSignalTransition_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSignalTransition_TypeF(); // references _Sbk_QSignalTransition_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSignalTransition_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSignalTransition_SignatureBytes, QSignalTransition_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSignalTransition_PropertyStrings);
    SbkPySide6_QtStateMachineTypeStructs[SBK_QSignalTransition_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSignalTransition_PythonToCpp_QSignalTransition_PTR,
        is_QSignalTransition_PythonToCpp_QSignalTransition_PTR_Convertible,
        QSignalTransition_PTR_CppToPython_QSignalTransition);

    Shiboken::Conversions::registerConverterName(converter, "QSignalTransition");
    Shiboken::Conversions::registerConverterName(converter, "QSignalTransition*");
    Shiboken::Conversions::registerConverterName(converter, "QSignalTransition&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSignalTransition).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSignalTransitionWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSignalTransition_TypeF(), &Sbk_QSignalTransition_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QSignalTransition::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSignalTransition::staticMetaObject, sizeof(QSignalTransitionWrapper));

    return pyType;
}
