// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QUILOADERWRAPPER_H
#define SBK_QUILOADERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtUiTools/quiloader.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QUiLoaderWrapper : public QUiLoader
{
public:
    QUiLoaderWrapper(::QObject * parent = nullptr);
    QUiLoaderWrapper(const QUiLoaderWrapper &) = delete;
    QUiLoaderWrapper& operator=(const QUiLoaderWrapper &) = delete;
    QUiLoaderWrapper(QUiLoaderWrapper &&) = delete;
    QUiLoaderWrapper& operator=(QUiLoaderWrapper &&) = delete;
    ~QUiLoaderWrapper() override;

    void childEvent(::QChildEvent * event) override;
    static void sbk_o_childEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QChildEvent * event);
    void connectNotify(const ::QMetaMethod & signal) override;
    static void sbk_o_connectNotify(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMetaMethod & signal);
    ::QAction * createAction(::QObject * parent = nullptr, const ::QString & name = QString()) override;
    static ::QAction * sbk_o_createAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * parent = nullptr, const ::QString & name = QString());
    ::QActionGroup * createActionGroup(::QObject * parent = nullptr, const ::QString & name = QString()) override;
    static ::QActionGroup * sbk_o_createActionGroup(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * parent = nullptr, const ::QString & name = QString());
    ::QLayout * createLayout(const ::QString & className, ::QObject * parent = nullptr, const ::QString & name = QString()) override;
    static ::QLayout * sbk_o_createLayout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & className, ::QObject * parent = nullptr, const ::QString & name = QString());
    ::QWidget * createWidget(const ::QString & className, ::QWidget * parent = nullptr, const ::QString & name = QString()) override;
    static ::QWidget * sbk_o_createWidget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & className, ::QWidget * parent = nullptr, const ::QString & name = QString());
    void customEvent(::QEvent * event) override;
    static void sbk_o_customEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    static bool sbk_o_event(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    static bool sbk_o_eventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * watched, ::QEvent * event);
    void timerEvent(::QTimerEvent * event) override;
    static void sbk_o_timerEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTimerEvent * event);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[11] = {false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QUILOADERWRAPPER_H
