// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTITEMDELEGATEWRAPPER_H
#define SBK_QABSTRACTITEMDELEGATEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qabstractitemdelegate.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractItemDelegateWrapper : public QAbstractItemDelegate
{
public:
    QAbstractItemDelegateWrapper(::QObject * parent = nullptr);
    QAbstractItemDelegateWrapper(const QAbstractItemDelegateWrapper &) = delete;
    QAbstractItemDelegateWrapper& operator=(const QAbstractItemDelegateWrapper &) = delete;
    QAbstractItemDelegateWrapper(QAbstractItemDelegateWrapper &&) = delete;
    QAbstractItemDelegateWrapper& operator=(QAbstractItemDelegateWrapper &&) = delete;
    ~QAbstractItemDelegateWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QWidget * createEditor(::QWidget * parent, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static ::QWidget * sbk_o_createEditor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * parent, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    void customEvent(::QEvent * event) override;
    void destroyEditor(::QWidget * editor, const ::QModelIndex & index) const override;
    static void sbk_o_destroyEditor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, const ::QModelIndex & index);
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool editorEvent(::QEvent * event, ::QAbstractItemModel * model, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) override;
    static bool sbk_o_editorEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event, ::QAbstractItemModel * model, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool helpEvent(::QHelpEvent * event, ::QAbstractItemView * view, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) override;
    static bool sbk_o_helpEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QHelpEvent * event, ::QAbstractItemView * view, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    void paint(::QPainter * painter, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static void sbk_o_paint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    ::QList<int> paintingRoles() const override;
    static ::QList<int> sbk_o_paintingRoles(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setEditorData(::QWidget * editor, const ::QModelIndex & index) const override;
    void setModelData(::QWidget * editor, ::QAbstractItemModel * model, const ::QModelIndex & index) const override;
    static void sbk_o_setModelData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, ::QAbstractItemModel * model, const ::QModelIndex & index);
    ::QSize sizeHint(const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static ::QSize sbk_o_sizeHint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    void timerEvent(::QTimerEvent * event) override;
    void updateEditorGeometry(::QWidget * editor, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static void sbk_o_updateEditorGeometry(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[17] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTITEMDELEGATEWRAPPER_H
