// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qabstractspinbox_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qvalidator.h>
#include <QtWidgets/qabstractspinbox.h>
#include <QtWidgets/qlineedit.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractSpinBoxWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractSpinBoxWrapper::QAbstractSpinBoxWrapper(::QWidget * parent) : QAbstractSpinBox(parent)
{
}

void QAbstractSpinBoxWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::changeEvent(event);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::clear()
{
    static const char *funcName = "clear";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::clear();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QAbstractSpinBox", funcName, gil, pyOverride);
}

void QAbstractSpinBoxWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QAbstractSpinBox", funcName, gil, pyOverride, signal);
}

void QAbstractSpinBoxWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::contextMenuEvent(event);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

int QAbstractSpinBoxWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QAbstractSpinBox", funcName, gil, pyOverride);
}

void QAbstractSpinBoxWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QAbstractSpinBox", funcName, gil, pyOverride, signal);
}

void QAbstractSpinBoxWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

bool QAbstractSpinBoxWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

bool QAbstractSpinBoxWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QAbstractSpinBox", funcName, gil, pyOverride, watched, event);
}

void QAbstractSpinBoxWrapper::fixup(::QString & input) const
{
    static const char *funcName = "fixup";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::fixup(input);
    }
    sbk_o_fixup("QAbstractSpinBox", funcName, gil, pyOverride, input);
}

void QAbstractSpinBoxWrapper::sbk_o_fixup(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QString & input)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &input)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }

    // Begin code injection
    // TEMPLATE - return_QString_native - START
    if (Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult.object()))
        Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult.object(), &(input));
    else
        qWarning("QAbstractSpinBox::fixup: Argument is not convertible to unicode.");
    // TEMPLATE - return_QString_native - END
    // End of code injection

}

void QAbstractSpinBoxWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

bool QAbstractSpinBoxWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QAbstractSpinBox", funcName, gil, pyOverride, next);
}

void QAbstractSpinBoxWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

bool QAbstractSpinBoxWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QAbstractSpinBox", funcName, gil, pyOverride);
}

int QAbstractSpinBoxWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QAbstractSpinBox", funcName, gil, pyOverride, arg__1);
}

void QAbstractSpinBoxWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QAbstractSpinBox", funcName, gil, pyOverride, painter);
}

void QAbstractSpinBoxWrapper::initStyleOption(::QStyleOptionSpinBox * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::initStyleOption(option);
    }
    sbk_o_initStyleOption("QAbstractSpinBox", funcName, gil, pyOverride, option);
}

void QAbstractSpinBoxWrapper::sbk_o_initStyleOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyleOptionSpinBox * option)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), option)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), option)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractSpinBoxWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

::QVariant QAbstractSpinBoxWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QAbstractSpinBox", funcName, gil, pyOverride, arg__1);
}

void QAbstractSpinBoxWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

int QAbstractSpinBoxWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QAbstractSpinBox", funcName, gil, pyOverride, arg__1);
}

::QSize QAbstractSpinBoxWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QAbstractSpinBox", funcName, gil, pyOverride);
}

void QAbstractSpinBoxWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

bool QAbstractSpinBoxWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QAbstractSpinBox", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QAbstractSpinBoxWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QAbstractSpinBox", funcName, gil, pyOverride);
}

void QAbstractSpinBoxWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

::QPaintDevice * QAbstractSpinBoxWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QAbstractSpinBox", funcName, gil, pyOverride, offset);
}

void QAbstractSpinBoxWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QAbstractSpinBox", funcName, gil, pyOverride, visible);
}

::QPainter * QAbstractSpinBoxWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QAbstractSpinBox", funcName, gil, pyOverride);
}

void QAbstractSpinBoxWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

::QSize QAbstractSpinBoxWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QAbstractSpinBox", funcName, gil, pyOverride);
}

void QAbstractSpinBoxWrapper::stepBy(int steps)
{
    static const char *funcName = "stepBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::stepBy(steps);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QAbstractSpinBox", funcName, gil, pyOverride, steps);
}

::QFlags<QAbstractSpinBox::StepEnabledFlag> QAbstractSpinBoxWrapper::stepEnabled() const
{
    static const char *funcName = "stepEnabled";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::stepEnabled();
    }
    return sbk_o_stepEnabled("QAbstractSpinBox", funcName, gil, pyOverride);
}

::QFlags<QAbstractSpinBox::StepEnabledFlag> QAbstractSpinBoxWrapper::sbk_o_stepEnabled(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return QFlags<QAbstractSpinBox::StepEnabledFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractSpinBox_StepEnabledFlag_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QFlags<QAbstractSpinBox::StepEnabledFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QAbstractSpinBox::StepEnabledFlag>(0);
    }
    ::QFlags<QAbstractSpinBox::StepEnabledFlag> cppResult = QFlags<QAbstractSpinBox::StepEnabledFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractSpinBoxWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

void QAbstractSpinBoxWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

::QValidator::State QAbstractSpinBoxWrapper::validate(::QString & input, int & pos) const
{
    static const char *funcName = "validate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::validate(input, pos);
    }
    return sbk_o_validate("QAbstractSpinBox", funcName, gil, pyOverride, input, pos);
}

::QValidator::State QAbstractSpinBoxWrapper::sbk_o_validate(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QString & input, int & pos)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &input),
        pos
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return QValidator::Invalid;
    }
    // Begin code injection
    // TEMPLATE - validator_conversionrule - START
    QValidator::State cppResult;

    if (PySequence_Check(pyResult.object())) {
        Shiboken::AutoDecRef seq(PySequence_Fast(pyResult.object(), 0));
        const Py_ssize_t size = PySequence_Size(seq.object());

        if (size > 1) {
            Shiboken::AutoDecRef _obj1(PySequence_GetItem(seq.object(), 1));
            if (Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], _obj1))
                Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], _obj1, &(input));
            else
                qWarning("QAbstractSpinBox::validate: Second tuple element is not convertible to unicode.");
        }

        if (size > 2) {
            Shiboken::AutoDecRef _obj2(PySequence_GetItem(seq.object(), 2));
            if (Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), _obj2))
                Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), _obj2, &(pos));
            else
                qWarning("QAbstractSpinBox::validate: Second tuple element is not convertible to int.");
        }
        Shiboken::AutoDecRef _sobj(PySequence_GetItem(seq.object(), 0));

        pyResult.reset(_sobj);
        Py_INCREF(pyResult.object()); // we need to incref, because "pyResult.object() = ..." will decref the tuple and the tuple will be decrefed again at the end of this scope.
    }

    // check return value
    if (Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QValidator_State_IDX])))->converter, pyResult.object())) {
        Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QValidator_State_IDX])))->converter, pyResult.object(), &(cppResult));
    } else {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.",
                     "QValidator.validate",
                     "PySide6.QtGui.QValidator.State, (PySide6.QtGui.QValidator.State,), (PySide6.QtGui.QValidator.State, unicode) or (PySide6.QtGui.QValidator.State, unicode, int)",
                     Py_TYPE(pyResult)->tp_name);
        return QValidator::State();
    }
    // TEMPLATE - validator_conversionrule - END
    // End of code injection


    return cppResult;
}

void QAbstractSpinBoxWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::wheelEvent(event);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QAbstractSpinBox", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstractSpinBoxWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractSpinBox::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractSpinBoxWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractSpinBox::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractSpinBoxWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractSpinBoxWrapper *>(this));
    return QAbstractSpinBox::qt_metacast(_clname);
}

QAbstractSpinBoxWrapper::~QAbstractSpinBoxWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractSpinBox_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractSpinBox >()))
        return -1;

    QAbstractSpinBoxWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QAbstractSpinBox", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractSpinBox::QAbstractSpinBox(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractSpinBox(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractSpinBox(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractSpinBox(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAbstractSpinBoxWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAbstractSpinBoxWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractSpinBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAbstractSpinBoxFunc_alignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alignment()const
        QFlags<Qt::AlignmentFlag> cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->alignment();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_buttonSymbols(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buttonSymbols()const
        QAbstractSpinBox::ButtonSymbols cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->buttonSymbols();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_ButtonSymbols_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::changeEvent(cppArg0)
                : cppSelf->changeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractSpinBox::clear()
            : cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_closeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::closeEvent(QCloseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // closeEvent(QCloseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "closeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCloseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // closeEvent(QCloseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::closeEvent(cppArg0)
                : cppSelf->closeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_contextMenuEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::contextMenuEvent(QContextMenuEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), (pyArg)))) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contextMenuEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QContextMenuEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contextMenuEvent(QContextMenuEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::contextMenuEvent(cppArg0)
                : cppSelf->contextMenuEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_correctionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // correctionMode()const
        QAbstractSpinBox::CorrectionMode cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->correctionMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_CorrectionMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_fixup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::fixup(QString&)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fixup(QString&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fixup", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fixup(QString&)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractSpinBox *>(cppSelf)->::QAbstractSpinBox::fixup(cppArg0)
                : const_cast<const ::QAbstractSpinBox *>(cppSelf)->fixup(cppArg0);
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qstring-return)]
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg0);
            // END of custom code block [file: ../glue/qtcore.cpp (qstring-return)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_focusOutEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusOutEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusOutEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusOutEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::focusOutEvent(cppArg0)
                : cppSelf->focusOutEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_hasAcceptableInput(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasAcceptableInput()const
        bool cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->hasAcceptableInput();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_hasFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasFrame()const
        bool cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->hasFrame();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_hideEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::hideEvent(QHideEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hideEvent(QHideEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hideEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHideEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hideEvent(QHideEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::hideEvent(cppArg0)
                : cppSelf->hideEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_initStyleOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::initStyleOption(QStyleOptionSpinBox*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), (pyArg)))) {
        overloadId = 0; // initStyleOption(QStyleOptionSpinBox*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initStyleOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyleOptionSpinBox *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initStyleOption(QStyleOptionSpinBox*)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractSpinBox *>(cppSelf)->::QAbstractSpinBox::initStyleOption(cppArg0)
                : const_cast<const ::QAbstractSpinBox *>(cppSelf)->initStyleOption(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_inputMethodQuery(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::inputMethodQuery(Qt::InputMethodQuery)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodQuery", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractSpinBox *>(cppSelf)->::QAbstractSpinBox::inputMethodQuery(cppArg0)
                : const_cast<const ::QAbstractSpinBox *>(cppSelf)->inputMethodQuery(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_interpretText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // interpretText()
        cppSelf->interpretText();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_isAccelerated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAccelerated()const
        bool cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->isAccelerated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_isGroupSeparatorShown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isGroupSeparatorShown()const
        bool cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->isGroupSeparatorShown();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_isReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadOnly()const
        bool cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->isReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_keyReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyReleaseEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyReleaseEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::keyReleaseEvent(cppArg0)
                : cppSelf->keyReleaseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_keyboardTracking(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyboardTracking()const
        bool cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->keyboardTracking();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_lineEdit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineEdit()const
        QLineEdit * cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->lineEdit();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLineEdit_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_minimumSizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumSizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractSpinBox *>(cppSelf)->::QAbstractSpinBox::minimumSizeHint()
            : const_cast<const ::QAbstractSpinBox *>(cppSelf)->minimumSizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_mouseMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseMoveEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseMoveEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::mouseMoveEvent(cppArg0)
                : cppSelf->mouseMoveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseReleaseEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_selectAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectAll()
        cppSelf->selectAll();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setAccelerated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setAccelerated(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAccelerated(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAccelerated", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccelerated(bool)
            cppSelf->setAccelerated(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setAlignment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setAlignment(QFlags<Qt::AlignmentFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlignment", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::AlignmentFlag> cppArg0 = QFlags<Qt::AlignmentFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->setAlignment(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setButtonSymbols(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setButtonSymbols(QAbstractSpinBox::ButtonSymbols)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_ButtonSymbols_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setButtonSymbols(QAbstractSpinBox::ButtonSymbols)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setButtonSymbols", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        ::QAbstractSpinBox::ButtonSymbols cppArg0{QAbstractSpinBox::UpDownArrows};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setButtonSymbols(QAbstractSpinBox::ButtonSymbols)
            cppSelf->setButtonSymbols(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setCorrectionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setCorrectionMode(QAbstractSpinBox::CorrectionMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_CorrectionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCorrectionMode(QAbstractSpinBox::CorrectionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCorrectionMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        ::QAbstractSpinBox::CorrectionMode cppArg0{QAbstractSpinBox::CorrectToPreviousValue};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCorrectionMode(QAbstractSpinBox::CorrectionMode)
            cppSelf->setCorrectionMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setFrame(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFrame(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFrame", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFrame(bool)
            cppSelf->setFrame(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setGroupSeparatorShown(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setGroupSeparatorShown(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGroupSeparatorShown(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGroupSeparatorShown", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGroupSeparatorShown(bool)
            cppSelf->setGroupSeparatorShown(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setKeyboardTracking(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setKeyboardTracking(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setKeyboardTracking(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeyboardTracking", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeyboardTracking(bool)
            cppSelf->setKeyboardTracking(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setLineEdit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setLineEdit(QLineEdit*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLineEdit_IDX]), (pyArg)))) {
        overloadId = 0; // setLineEdit(QLineEdit*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLineEdit", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLineEdit *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineEdit(QLineEdit*)
            cppSelf->setLineEdit(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadOnly", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadOnly(bool)
            cppSelf->setReadOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setSpecialValueText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setSpecialValueText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSpecialValueText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpecialValueText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpecialValueText(QString)
            cppSelf->setSpecialValueText(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_setWrapping(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::setWrapping(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapping(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapping", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapping(bool)
            cppSelf->setWrapping(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_showEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::showEvent(QShowEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), (pyArg)))) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "showEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QShowEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showEvent(QShowEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::showEvent(cppArg0)
                : cppSelf->showEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractSpinBox *>(cppSelf)->::QAbstractSpinBox::sizeHint()
            : const_cast<const ::QAbstractSpinBox *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_specialValueText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // specialValueText()const
        QString cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->specialValueText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_stepBy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::stepBy(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // stepBy(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "stepBy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stepBy(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::stepBy(cppArg0)
                : cppSelf->stepBy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_stepDown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stepDown()
        cppSelf->stepDown();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_stepEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stepEnabled()const
        QFlags<QAbstractSpinBox::StepEnabledFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractSpinBox *>(cppSelf)->::QAbstractSpinBox::stepEnabled()
            : const_cast<const ::QAbstractSpinBox *>(cppSelf)->stepEnabled();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractSpinBox_StepEnabledFlag_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_stepUp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stepUp()
        cppSelf->stepUp();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_validate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "validate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSpinBox::validate(QString&,int&)const->PyObject
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // validate(QString&,int&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "validate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // validate(QString&,int&)const
            // Begin code injection
            // TEMPLATE - return_tuple_QValidator_QString_int - START
            ::QValidator::State retval_ = ::QValidator::State((Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QAbstractSpinBox::validate(cppArg0, cppArg1) : cppSelf->validate(cppArg0, cppArg1)));
            pyResult = PyTuple_New(3);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QValidator_State_IDX])))->converter, &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg0));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg1));
            // TEMPLATE - return_tuple_QValidator_QString_int - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSpinBoxFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSpinBox::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSpinBoxFunc_wrapping(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapping()const
        bool cppResult = const_cast<const ::QAbstractSpinBox *>(cppSelf)->wrapping();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QAbstractSpinBox_PropertyStrings[] = {
    "accelerated:isAccelerated:",
    "acceptableInput:hasAcceptableInput",
    "alignment::",
    "buttonSymbols::",
    "correctionMode::",
    "frame:hasFrame:",
    "keyboardTracking::",
    "readOnly:isReadOnly:",
    "showGroupSeparator:isGroupSeparatorShown:setGroupSeparatorShown",
    "specialValueText::",
    "text:",
    "wrapping::",
    nullptr // Sentinel
};

static const char *Sbk_QAbstractSpinBox_EnumFlagInfo[] = {
    "ButtonSymbols:Enum",
    "CorrectionMode:Enum",
    "StepEnabledFlag:Flag:StepEnabled",
    "StepType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractSpinBox_methods[] = {
    {"alignment", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_alignment), METH_NOARGS, nullptr},
    {"buttonSymbols", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_buttonSymbols), METH_NOARGS, nullptr},
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_changeEvent), METH_O, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_clear), METH_NOARGS, nullptr},
    {"closeEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_closeEvent), METH_O, nullptr},
    {"contextMenuEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_contextMenuEvent), METH_O, nullptr},
    {"correctionMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_correctionMode), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_event), METH_O, nullptr},
    {"fixup", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_fixup), METH_O, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_focusInEvent), METH_O, nullptr},
    {"focusOutEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_focusOutEvent), METH_O, nullptr},
    {"hasAcceptableInput", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_hasAcceptableInput), METH_NOARGS, nullptr},
    {"hasFrame", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_hasFrame), METH_NOARGS, nullptr},
    {"hideEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_hideEvent), METH_O, nullptr},
    {"initStyleOption", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_initStyleOption), METH_O, nullptr},
    {"inputMethodQuery", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_inputMethodQuery), METH_O, nullptr},
    {"interpretText", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_interpretText), METH_NOARGS, nullptr},
    {"isAccelerated", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_isAccelerated), METH_NOARGS, nullptr},
    {"isGroupSeparatorShown", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_isGroupSeparatorShown), METH_NOARGS, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_isReadOnly), METH_NOARGS, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_keyPressEvent), METH_O, nullptr},
    {"keyReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_keyReleaseEvent), METH_O, nullptr},
    {"keyboardTracking", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_keyboardTracking), METH_NOARGS, nullptr},
    {"lineEdit", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_lineEdit), METH_NOARGS, nullptr},
    {"minimumSizeHint", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_minimumSizeHint), METH_NOARGS, nullptr},
    {"mouseMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_mouseMoveEvent), METH_O, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_mousePressEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_mouseReleaseEvent), METH_O, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_paintEvent), METH_O, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_resizeEvent), METH_O, nullptr},
    {"selectAll", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_selectAll), METH_NOARGS, nullptr},
    {"setAccelerated", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setAccelerated), METH_O, nullptr},
    {"setAlignment", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setAlignment), METH_O, nullptr},
    {"setButtonSymbols", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setButtonSymbols), METH_O, nullptr},
    {"setCorrectionMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setCorrectionMode), METH_O, nullptr},
    {"setFrame", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setFrame), METH_O, nullptr},
    {"setGroupSeparatorShown", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setGroupSeparatorShown), METH_O, nullptr},
    {"setKeyboardTracking", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setKeyboardTracking), METH_O, nullptr},
    {"setLineEdit", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setLineEdit), METH_O, nullptr},
    {"setReadOnly", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setReadOnly), METH_O, nullptr},
    {"setSpecialValueText", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setSpecialValueText), METH_O, nullptr},
    {"setWrapping", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_setWrapping), METH_O, nullptr},
    {"showEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_showEvent), METH_O, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_sizeHint), METH_NOARGS, nullptr},
    {"specialValueText", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_specialValueText), METH_NOARGS, nullptr},
    {"stepBy", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_stepBy), METH_O, nullptr},
    {"stepDown", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_stepDown), METH_NOARGS, nullptr},
    {"stepEnabled", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_stepEnabled), METH_NOARGS, nullptr},
    {"stepUp", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_stepUp), METH_NOARGS, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_text), METH_NOARGS, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_timerEvent), METH_O, nullptr},
    {"validate", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_validate), METH_VARARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_wheelEvent), METH_O, nullptr},
    {"wrapping", reinterpret_cast<PyCFunction>(Sbk_QAbstractSpinBoxFunc_wrapping), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractSpinBox_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractSpinBoxWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractSpinBox_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractSpinBox_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QAbstractSpinBoxSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QAbstractSpinBox *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractSpinBox_Type = nullptr;
static PyTypeObject *Sbk_QAbstractSpinBox_TypeF(void)
{
    return _Sbk_QAbstractSpinBox_Type;
}

static PyType_Slot Sbk_QAbstractSpinBox_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractSpinBox_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractSpinBox_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractSpinBox_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractSpinBox_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractSpinBox_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractSpinBox_spec = {
    "2:PySide6.QtWidgets.QAbstractSpinBox",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractSpinBox_slots
};

} //extern "C"

static void *Sbk_QAbstractSpinBox_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QAbstractSpinBox *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractSpinBox *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QAbstractSpinBox *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractSpinBox_StepEnabledFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSpinBox::StepEnabledFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSpinBox::StepEnabledFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSpinBox_StepEnabledFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_StepEnabledFlag_IDX])))
        return Enum_PythonToCpp_QAbstractSpinBox_StepEnabledFlag;
    return {};
}

static PyObject *QAbstractSpinBox_StepEnabledFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSpinBox::StepEnabledFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSpinBox::StepEnabledFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_StepEnabledFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QAbstractSpinBox_StepEnabledFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QAbstractSpinBox::StepEnabledFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QAbstractSpinBox::StepEnabledFlag> *>(cppOut) = value;

}

static PyObject *QAbstractSpinBox_StepEnabledFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QAbstractSpinBox::StepEnabledFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_StepEnabledFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QAbstractSpinBox_ButtonSymbols(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSpinBox::ButtonSymbols>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSpinBox::ButtonSymbols *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSpinBox_ButtonSymbols_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_ButtonSymbols_IDX])))
        return Enum_PythonToCpp_QAbstractSpinBox_ButtonSymbols;
    return {};
}

static PyObject *QAbstractSpinBox_ButtonSymbols_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSpinBox::ButtonSymbols>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSpinBox::ButtonSymbols *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_ButtonSymbols_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSpinBox_CorrectionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSpinBox::CorrectionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSpinBox::CorrectionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSpinBox_CorrectionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_CorrectionMode_IDX])))
        return Enum_PythonToCpp_QAbstractSpinBox_CorrectionMode;
    return {};
}

static PyObject *QAbstractSpinBox_CorrectionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSpinBox::CorrectionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSpinBox::CorrectionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_CorrectionMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSpinBox_StepType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSpinBox::StepType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSpinBox::StepType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSpinBox_StepType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_StepType_IDX])))
        return Enum_PythonToCpp_QAbstractSpinBox_StepType;
    return {};
}

static PyObject *QAbstractSpinBox_StepType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSpinBox::StepType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSpinBox::StepType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_StepType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractSpinBox_PythonToCpp_QAbstractSpinBox_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractSpinBox_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractSpinBox_PythonToCpp_QAbstractSpinBox_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractSpinBox_TypeF()))
        return QAbstractSpinBox_PythonToCpp_QAbstractSpinBox_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractSpinBox_PTR_CppToPython_QAbstractSpinBox(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractSpinBox *>(const_cast<void *>(cppIn)), Sbk_QAbstractSpinBox_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractSpinBox_SignatureStrings[] = {
    "PySide6.QtWidgets.QAbstractSpinBox(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,wrapping:bool=None,frame:bool=None,alignment:PySide6.QtCore.Qt.AlignmentFlag=None,readOnly:bool=None,buttonSymbols:QAbstractSpinBox.ButtonSymbols=None,specialValueText:QString=None,text:QString=None,accelerated:bool=None,correctionMode:QAbstractSpinBox.CorrectionMode=None,acceptableInput:bool=None,keyboardTracking:bool=None,showGroupSeparator:bool=None)",
    "PySide6.QtWidgets.QAbstractSpinBox.alignment(self)->PySide6.QtCore.Qt.AlignmentFlag",
    "PySide6.QtWidgets.QAbstractSpinBox.buttonSymbols(self)->PySide6.QtWidgets.QAbstractSpinBox.ButtonSymbols",
    "PySide6.QtWidgets.QAbstractSpinBox.changeEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.clear(self)",
    "PySide6.QtWidgets.QAbstractSpinBox.closeEvent(self,event:PySide6.QtGui.QCloseEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.contextMenuEvent(self,event:PySide6.QtGui.QContextMenuEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.correctionMode(self)->PySide6.QtWidgets.QAbstractSpinBox.CorrectionMode",
    "PySide6.QtWidgets.QAbstractSpinBox.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QAbstractSpinBox.fixup(self,input:QString)->QString",
    "PySide6.QtWidgets.QAbstractSpinBox.focusInEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.focusOutEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.hasAcceptableInput(self)->bool",
    "PySide6.QtWidgets.QAbstractSpinBox.hasFrame(self)->bool",
    "PySide6.QtWidgets.QAbstractSpinBox.hideEvent(self,event:PySide6.QtGui.QHideEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.initStyleOption(self,option:PySide6.QtWidgets.QStyleOptionSpinBox)",
    "PySide6.QtWidgets.QAbstractSpinBox.inputMethodQuery(self,arg__1:PySide6.QtCore.Qt.InputMethodQuery)->QVariant",
    "PySide6.QtWidgets.QAbstractSpinBox.interpretText(self)",
    "PySide6.QtWidgets.QAbstractSpinBox.isAccelerated(self)->bool",
    "PySide6.QtWidgets.QAbstractSpinBox.isGroupSeparatorShown(self)->bool",
    "PySide6.QtWidgets.QAbstractSpinBox.isReadOnly(self)->bool",
    "PySide6.QtWidgets.QAbstractSpinBox.keyPressEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.keyReleaseEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.keyboardTracking(self)->bool",
    "PySide6.QtWidgets.QAbstractSpinBox.lineEdit(self)->PySide6.QtWidgets.QLineEdit",
    "PySide6.QtWidgets.QAbstractSpinBox.minimumSizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QAbstractSpinBox.mouseMoveEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.mousePressEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.mouseReleaseEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.paintEvent(self,event:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.resizeEvent(self,event:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.selectAll(self)",
    "PySide6.QtWidgets.QAbstractSpinBox.setAccelerated(self,on:bool)",
    "PySide6.QtWidgets.QAbstractSpinBox.setAlignment(self,flag:PySide6.QtCore.Qt.AlignmentFlag)",
    "PySide6.QtWidgets.QAbstractSpinBox.setButtonSymbols(self,bs:PySide6.QtWidgets.QAbstractSpinBox.ButtonSymbols)",
    "PySide6.QtWidgets.QAbstractSpinBox.setCorrectionMode(self,cm:PySide6.QtWidgets.QAbstractSpinBox.CorrectionMode)",
    "PySide6.QtWidgets.QAbstractSpinBox.setFrame(self,arg__1:bool)",
    "PySide6.QtWidgets.QAbstractSpinBox.setGroupSeparatorShown(self,shown:bool)",
    "PySide6.QtWidgets.QAbstractSpinBox.setKeyboardTracking(self,kt:bool)",
    "PySide6.QtWidgets.QAbstractSpinBox.setLineEdit(self,edit:PySide6.QtWidgets.QLineEdit)",
    "PySide6.QtWidgets.QAbstractSpinBox.setReadOnly(self,r:bool)",
    "PySide6.QtWidgets.QAbstractSpinBox.setSpecialValueText(self,txt:QString)",
    "PySide6.QtWidgets.QAbstractSpinBox.setWrapping(self,w:bool)",
    "PySide6.QtWidgets.QAbstractSpinBox.showEvent(self,event:PySide6.QtGui.QShowEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QAbstractSpinBox.specialValueText(self)->QString",
    "PySide6.QtWidgets.QAbstractSpinBox.stepBy(self,steps:int)",
    "PySide6.QtWidgets.QAbstractSpinBox.stepDown(self)",
    "PySide6.QtWidgets.QAbstractSpinBox.stepEnabled(self)->PySide6.QtWidgets.QAbstractSpinBox.StepEnabledFlag",
    "PySide6.QtWidgets.QAbstractSpinBox.stepUp(self)",
    "PySide6.QtWidgets.QAbstractSpinBox.text(self)->QString",
    "PySide6.QtWidgets.QAbstractSpinBox.timerEvent(self,event:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.validate(self,input:QString,pos:int)->PyObject",
    "PySide6.QtWidgets.QAbstractSpinBox.wheelEvent(self,event:PySide6.QtGui.QWheelEvent)",
    "PySide6.QtWidgets.QAbstractSpinBox.wrapping(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractSpinBox_SignatureByteSize = 819;
static constexpr uint8_t QAbstractSpinBox_SignatureBytes[819] = {
    0x78, 0xda, 0xad, 0x97, 0x4b, 0x6f, 0xe2, 0x30, 0x10, 0x80, 0xef, 0xfb, 0x4b, 0xb6, 0xab, 0x14,
    0x69, 0x2f, 0x7b, 0x88, 0xd4, 0x4a, 0xc0, 0xf6, 0xa5, 0x96, 0x05, 0x9a, 0x3e, 0x8e, 0x95, 0x93,
    0x0c, 0xe0, 0xad, 0x63, 0x5b, 0xf6, 0x04, 0xca, 0xfe, 0xfa, 0x75, 0x1e, 0x40, 0x02, 0xb4, 0x19,
    0x57, 0x3d, 0x61, 0xe2, 0xf1, 0x37, 0xf6, 0xcc, 0x78, 0x66, 0x3c, 0x59, 0x47, 0x3c, 0x85, 0x5f,
    0xbd, 0x29, 0x3e, 0xf3, 0x74, 0x0e, 0x68, 0x7b, 0xd3, 0x7e, 0x6c, 0xd1, 0xb0, 0x04, 0x23, 0xcd,
    0xe5, 0x40, 0xbd, 0x7d, 0xb7, 0x20, 0x66, 0x81, 0x66, 0x06, 0x24, 0x86, 0x93, 0x43, 0xf1, 0x6a,
    0x70, 0x26, 0x73, 0x21, 0x34, 0x9a, 0xe0, 0x47, 0x78, 0x0b, 0xeb, 0x95, 0x32, 0xe9, 0x58, 0x8a,
    0xf5, 0xd9, 0x1f, 0x25, 0x21, 0x58, 0x19, 0xa6, 0x1d, 0x6b, 0x1e, 0xc6, 0x4a, 0x89, 0xea, 0xd3,
    0xcc, 0xb0, 0x0c, 0x1a, 0xff, 0x99, 0xe0, 0x73, 0x99, 0xb5, 0x35, 0x0c, 0x95, 0x01, 0xf7, 0xd3,
    0xeb, 0x6f, 0xe6, 0x2e, 0x05, 0x9b, 0x57, 0xe2, 0x06, 0x58, 0xc9, 0x6f, 0x10, 0xe2, 0x1c, 0x51,
    0xc9, 0x68, 0x9d, 0xc5, 0x4a, 0xd8, 0x70, 0xff, 0x10, 0xbd, 0x41, 0x73, 0xba, 0x5a, 0x61, 0x35,
    0x24, 0x9c, 0x89, 0x27, 0x26, 0x72, 0x78, 0x80, 0x37, 0x0c, 0xa7, 0x11, 0x1a, 0xb7, 0xcd, 0x6a,
    0x16, 0x0f, 0xbe, 0xb0, 0x24, 0x01, 0x01, 0x86, 0x21, 0xa4, 0x0d, 0xbd, 0x89, 0x32, 0x06, 0x12,
    0xe4, 0x4a, 0x8e, 0x54, 0x0a, 0x87, 0x8a, 0x87, 0xad, 0xf9, 0x1d, 0x49, 0x23, 0x8b, 0x05, 0xdc,
    0x48, 0x9d, 0x63, 0x83, 0xf6, 0x0a, 0xeb, 0x58, 0x31, 0x93, 0x3e, 0x38, 0xc4, 0x6b, 0xdb, 0x64,
    0x76, 0xa1, 0x56, 0x57, 0x46, 0xe5, 0x3a, 0x02, 0xe7, 0x0c, 0x86, 0xca, 0xec, 0x26, 0x4f, 0xbe,
    0x4d, 0x3a, 0xfd, 0xd8, 0xdb, 0xda, 0xb8, 0xf4, 0xe8, 0xc9, 0xe9, 0x79, 0x87, 0xa9, 0x29, 0xcc,
    0x96, 0xd5, 0x0f, 0xb9, 0xef, 0xae, 0x6b, 0xb9, 0x83, 0xa2, 0x28, 0x59, 0x30, 0x39, 0x87, 0x8b,
    0xe5, 0x66, 0xfb, 0x01, 0x2c, 0x8f, 0x45, 0x4b, 0x29, 0x40, 0xb2, 0x46, 0x22, 0x80, 0x99, 0x6a,
    0xc7, 0x34, 0x71, 0x65, 0x3f, 0x52, 0x7f, 0x95, 0xf3, 0xde, 0x74, 0xb8, 0x15, 0xa2, 0x31, 0x95,
    0x2c, 0xa2, 0x6c, 0x04, 0x32, 0xef, 0x24, 0xef, 0x89, 0x12, 0xf9, 0xcd, 0xd0, 0xf3, 0xf0, 0x4e,
    0x3b, 0x66, 0x29, 0xaa, 0x80, 0xe6, 0x98, 0xd3, 0xf3, 0x22, 0x64, 0x29, 0xc0, 0x19, 0x7f, 0xcb,
    0x75, 0x05, 0xe4, 0xe5, 0x1d, 0xa9, 0xaf, 0xa2, 0x43, 0xd4, 0x23, 0x12, 0x45, 0x25, 0xb9, 0xbd,
    0x91, 0x5d, 0xd6, 0xbd, 0x2c, 0xc4, 0xe8, 0x76, 0x2d, 0xa9, 0xe3, 0x1c, 0xbf, 0x18, 0xbb, 0x60,
    0xb6, 0xdf, 0x4e, 0x0c, 0x1b, 0x97, 0x51, 0x8d, 0xe6, 0x08, 0x97, 0x45, 0x62, 0xf5, 0x5e, 0xe7,
    0x04, 0xba, 0x0e, 0x73, 0xbd, 0x91, 0x21, 0x9d, 0x85, 0x4b, 0x8e, 0x11, 0xae, 0x05, 0x8c, 0x75,
    0x11, 0x46, 0x15, 0x57, 0x95, 0xe3, 0x63, 0x35, 0xa4, 0x21, 0x5a, 0x13, 0x88, 0x5a, 0x9c, 0x91,
    0x46, 0x80, 0x0b, 0x95, 0x4e, 0x73, 0x30, 0xeb, 0x4a, 0x0d, 0x33, 0xf3, 0x97, 0x97, 0x9f, 0x47,
    0x0a, 0xc9, 0xcd, 0x9e, 0x78, 0x11, 0x4b, 0x4f, 0xcc, 0x70, 0x26, 0x91, 0xa6, 0x0d, 0xc1, 0x68,
    0x03, 0x58, 0x14, 0x0b, 0x7a, 0xe6, 0xe0, 0xa5, 0x57, 0xeb, 0xc2, 0xe1, 0xeb, 0x19, 0x6e, 0xdb,
    0x29, 0x3f, 0x72, 0x45, 0x40, 0xfa, 0x43, 0xee, 0xeb, 0x7a, 0xe9, 0xbb, 0xd2, 0x95, 0xa3, 0x89,
    0x01, 0x6b, 0xbb, 0x82, 0xc3, 0x95, 0x7c, 0x7a, 0x6c, 0x38, 0xe8, 0xbd, 0xb3, 0x07, 0xeb, 0xce,
    0xa7, 0xbe, 0xd8, 0x56, 0xe9, 0xf4, 0x3d, 0xab, 0xe0, 0x12, 0x2e, 0x52, 0x8e, 0x1f, 0xe4, 0xc9,
    0xbb, 0x5a, 0x84, 0x82, 0xcb, 0xdc, 0x15, 0xc8, 0xf2, 0x2c, 0xe2, 0xff, 0xe0, 0x9a, 0xbf, 0x5f,
    0x73, 0x8b, 0x79, 0x12, 0x4e, 0xe5, 0x16, 0x46, 0x6a, 0xd9, 0x69, 0xb3, 0x51, 0x21, 0x48, 0xb7,
    0x5a, 0xc9, 0x25, 0xf9, 0xf8, 0x33, 0x60, 0xa2, 0x9f, 0x3d, 0xd1, 0x9a, 0x39, 0x83, 0x76, 0x31,
    0x27, 0x5b, 0x21, 0x12, 0xd3, 0x59, 0xc0, 0x79, 0xa2, 0x0b, 0x7a, 0xbf, 0x93, 0x22, 0x51, 0x1d,
    0xc9, 0xd5, 0xd1, 0xbe, 0x10, 0xf4, 0x74, 0x61, 0x01, 0xf7, 0xf3, 0x45, 0xe0, 0x92, 0x66, 0x11,
    0xc5, 0xe4, 0xf5, 0xad, 0x46, 0x2f, 0x98, 0xb9, 0x5e, 0xae, 0xab, 0xad, 0xa6, 0xa2, 0x07, 0x07,
    0xfd, 0x5e, 0x10, 0xdb, 0xd0, 0xb7, 0xe1, 0xa3, 0x6a, 0x1b, 0x1e, 0x36, 0x30, 0x41, 0x92, 0x85,
    0xde, 0x1d, 0x0c, 0x55, 0xdf, 0xae, 0x78, 0x6e, 0x8a, 0x88, 0x8f, 0xd9, 0xdf, 0xcb, 0xd4, 0x65,
    0xe7, 0xee, 0xe7, 0xc1, 0xdb, 0x63, 0xb9, 0x2c, 0x78, 0x45, 0x2f, 0xc8, 0x5d, 0x33, 0xa1, 0x05,
    0xe0, 0x46, 0xe1, 0x07, 0x39, 0x8d, 0x4a, 0x6d, 0x95, 0x92, 0xc0, 0x78, 0xed, 0x28, 0xda, 0x7b,
    0x71, 0x55, 0x0c, 0xdc, 0x3d, 0xb4, 0xa8, 0xa0, 0xe7, 0xfa, 0x45, 0x59, 0x01, 0x56, 0x1e, 0x9b,
    0x70, 0xae, 0xe8, 0xba, 0xe4, 0xd1, 0x46, 0x86, 0x46, 0xfc, 0xa2, 0x04, 0x6f, 0x8f, 0xd9, 0xc6,
    0xaf, 0xdb, 0xb5, 0x08, 0x7a, 0x50, 0x3b, 0xa6, 0x18, 0xdb, 0x90, 0x53, 0x0f, 0xe1, 0xa4, 0x7f,
    0x6f, 0x3b, 0x0b, 0xea, 0x8a, 0x0b, 0x59, 0x74, 0xaa, 0xa9, 0xc7, 0xc3, 0x22, 0xda, 0xad, 0xa2,
    0xbe, 0x30, 0x0b, 0x45, 0x8f, 0x9a, 0xbe, 0x31, 0xfc, 0x9c, 0xed, 0x90, 0x67, 0x60, 0x3a, 0x9f,
    0x97, 0x0f, 0x5b, 0x29, 0xd2, 0x5e, 0x96, 0xee, 0xc9, 0x9d, 0xba, 0x34, 0x7e, 0xe4, 0x1d, 0x13,
    0x68, 0x55, 0xb9, 0xa7, 0xb0, 0xdb, 0x38, 0xfe, 0xeb, 0x92, 0x15, 0x85, 0xb8, 0x5a, 0x00, 0x88,
    0xae, 0x00, 0x7e, 0xde, 0x0a, 0x91, 0x76, 0xb9, 0x6a, 0x5e, 0xa6, 0x4d, 0xc3, 0xf4, 0x1f, 0x74,
    0xe7, 0xa9, 0x4f
};
#endif

PyTypeObject *init_QAbstractSpinBox(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractSpinBox_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QAbstractSpinBox_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractSpinBox",
        "QAbstractSpinBox*",
        &Sbk_QAbstractSpinBox_spec,
        &Shiboken::callCppDestructor< QAbstractSpinBox >,
        Sbk_QAbstractSpinBox_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QAbstractSpinBox_TypeF(); // references _Sbk_QAbstractSpinBox_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractSpinBox_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractSpinBox_SignatureBytes, QAbstractSpinBox_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractSpinBox_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractSpinBox_PythonToCpp_QAbstractSpinBox_PTR,
        is_QAbstractSpinBox_PythonToCpp_QAbstractSpinBox_PTR_Convertible,
        QAbstractSpinBox_PTR_CppToPython_QAbstractSpinBox);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractSpinBox");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractSpinBox*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractSpinBox&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractSpinBox).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractSpinBoxWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QAbstractSpinBox_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QAbstractSpinBox_TypeF(), &Sbk_QAbstractSpinBoxSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractSpinBox_TypeF(), &Sbk_QAbstractSpinBox_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractSpinBox_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StepEnabledFlag'.
    const char *StepEnabledFlag_Initializer[] = {
        "StepNone",
        "StepUpEnabled",
        "StepDownEnabled",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StepEnabledFlag_InitializerValues[] = {
        uint8_t(QAbstractSpinBox::StepEnabledFlag::StepNone),       //  0x00  0
        uint8_t(QAbstractSpinBox::StepEnabledFlag::StepUpEnabled),  //  0x01  1
        uint8_t(QAbstractSpinBox::StepEnabledFlag::StepDownEnabled) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSpinBox_TypeF(),
        "2:PySide6.QtWidgets.QAbstractSpinBox.StepEnabledFlag",
        StepEnabledFlag_Initializer, StepEnabledFlag_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_StepEnabledFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractSpinBox_StepEnabledFlag_IDX].type =
        EType;
    // Register converter for enum 'QAbstractSpinBox::StepEnabledFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSpinBox_StepEnabledFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSpinBox_StepEnabledFlag,
            is_Enum_PythonToCpp_QAbstractSpinBox_StepEnabledFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSpinBox::StepEnabledFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "StepEnabledFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QAbstractSpinBox_StepEnabledFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QAbstractSpinBox_StepEnabledFlag,
            is_Enum_PythonToCpp_QAbstractSpinBox_StepEnabledFlag_Convertible);
        // Register converter for flag 'QFlags<QAbstractSpinBox::StepEnabledFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QAbstractSpinBox::StepEnabledFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QAbstractSpinBox::StepEnabled");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'StepEnabledFlag' enum/flags.

    // Initialization of enum 'ButtonSymbols'.
    const char *ButtonSymbols_Initializer[] = {
        "UpDownArrows",
        "PlusMinus",
        "NoButtons",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ButtonSymbols_InitializerValues[] = {
        uint8_t(QAbstractSpinBox::ButtonSymbols::UpDownArrows), //  0x00  0
        uint8_t(QAbstractSpinBox::ButtonSymbols::PlusMinus),    //  0x01  1
        uint8_t(QAbstractSpinBox::ButtonSymbols::NoButtons)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSpinBox_TypeF(),
        "2:PySide6.QtWidgets.QAbstractSpinBox.ButtonSymbols",
        ButtonSymbols_Initializer, ButtonSymbols_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_ButtonSymbols_IDX].type = EType;
    // Register converter for enum 'QAbstractSpinBox::ButtonSymbols'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSpinBox_ButtonSymbols_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSpinBox_ButtonSymbols,
            is_Enum_PythonToCpp_QAbstractSpinBox_ButtonSymbols_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSpinBox::ButtonSymbols");
        Shiboken::Conversions::registerConverterAlias(converter, "ButtonSymbols");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ButtonSymbols' enum.

    // Initialization of enum 'CorrectionMode'.
    const char *CorrectionMode_Initializer[] = {
        "CorrectToPreviousValue",
        "CorrectToNearestValue",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CorrectionMode_InitializerValues[] = {
        uint8_t(QAbstractSpinBox::CorrectionMode::CorrectToPreviousValue), //  0x00  0
        uint8_t(QAbstractSpinBox::CorrectionMode::CorrectToNearestValue)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSpinBox_TypeF(),
        "2:PySide6.QtWidgets.QAbstractSpinBox.CorrectionMode",
        CorrectionMode_Initializer, CorrectionMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_CorrectionMode_IDX].type = EType;
    // Register converter for enum 'QAbstractSpinBox::CorrectionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSpinBox_CorrectionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSpinBox_CorrectionMode,
            is_Enum_PythonToCpp_QAbstractSpinBox_CorrectionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSpinBox::CorrectionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "CorrectionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CorrectionMode' enum.

    // Initialization of enum 'StepType'.
    const char *StepType_Initializer[] = {
        "DefaultStepType",
        "AdaptiveDecimalStepType",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StepType_InitializerValues[] = {
        uint8_t(QAbstractSpinBox::StepType::DefaultStepType),        //  0x00  0
        uint8_t(QAbstractSpinBox::StepType::AdaptiveDecimalStepType) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSpinBox_TypeF(),
        "2:PySide6.QtWidgets.QAbstractSpinBox.StepType",
        StepType_Initializer, StepType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_StepType_IDX].type = EType;
    // Register converter for enum 'QAbstractSpinBox::StepType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSpinBox_StepType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSpinBox_StepType,
            is_Enum_PythonToCpp_QAbstractSpinBox_StepType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSpinBox::StepType");
        Shiboken::Conversions::registerConverterAlias(converter, "StepType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StepType' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstractSpinBox::staticMetaObject);
    qRegisterMetaType< ::QAbstractSpinBox::StepEnabledFlag >("QAbstractSpinBox::StepEnabledFlag");
    qRegisterMetaType< ::QAbstractSpinBox::ButtonSymbols >("QAbstractSpinBox::ButtonSymbols");
    qRegisterMetaType< ::QAbstractSpinBox::CorrectionMode >("QAbstractSpinBox::CorrectionMode");
    qRegisterMetaType< ::QAbstractSpinBox::StepType >("QAbstractSpinBox::StepType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractSpinBox::staticMetaObject, sizeof(QAbstractSpinBoxWrapper));

    return pyType;
}
