// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qcalendarwidget_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"

// Extra includes
#include <QTextCharFormat>

// Argument includes
#include <QMap>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextformat.h>
#include <QtWidgets/qcalendarwidget.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcalendar.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QCalendarWidgetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QCalendarWidgetWrapper::QCalendarWidgetWrapper(::QWidget * parent) : QCalendarWidget(parent)
{
}

void QCalendarWidgetWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QCalendarWidget", funcName, gil, pyOverride, signal);
}

void QCalendarWidgetWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

int QCalendarWidgetWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QCalendarWidget", funcName, gil, pyOverride);
}

void QCalendarWidgetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QCalendarWidget", funcName, gil, pyOverride, signal);
}

void QCalendarWidgetWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

bool QCalendarWidgetWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QCalendarWidget", funcName, gil, pyOverride, event);
}

bool QCalendarWidgetWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QCalendarWidget", funcName, gil, pyOverride, watched, event);
}

void QCalendarWidgetWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

bool QCalendarWidgetWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QCalendarWidget", funcName, gil, pyOverride, next);
}

void QCalendarWidgetWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

bool QCalendarWidgetWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QCalendarWidget", funcName, gil, pyOverride);
}

int QCalendarWidgetWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QCalendarWidget", funcName, gil, pyOverride, arg__1);
}

void QCalendarWidgetWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QCalendarWidget", funcName, gil, pyOverride, painter);
}

void QCalendarWidgetWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

::QVariant QCalendarWidgetWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QCalendarWidget", funcName, gil, pyOverride, arg__1);
}

void QCalendarWidgetWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

int QCalendarWidgetWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QCalendarWidget", funcName, gil, pyOverride, arg__1);
}

::QSize QCalendarWidgetWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QCalendarWidget", funcName, gil, pyOverride);
}

void QCalendarWidgetWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

bool QCalendarWidgetWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QCalendarWidget", funcName, gil, pyOverride, eventType, message, result);
}

void QCalendarWidgetWrapper::paintCell(::QPainter * painter, const ::QRect & rect, ::QDate date) const
{
    static const char *funcName = "paintCell";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::paintCell(painter, rect, date);
    }
    sbk_o_paintCell("QCalendarWidget", funcName, gil, pyOverride, painter, rect, date);
}

void QCalendarWidgetWrapper::sbk_o_paintCell(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QRect & rect, ::QDate date)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QPaintEngine * QCalendarWidgetWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QCalendarWidget", funcName, gil, pyOverride);
}

void QCalendarWidgetWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

::QPaintDevice * QCalendarWidgetWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QCalendarWidget", funcName, gil, pyOverride, offset);
}

void QCalendarWidgetWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QCalendarWidget", funcName, gil, pyOverride, visible);
}

::QPainter * QCalendarWidgetWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QCalendarWidget", funcName, gil, pyOverride);
}

void QCalendarWidgetWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

::QSize QCalendarWidgetWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QCalendarWidget::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QCalendarWidget", funcName, gil, pyOverride);
}

void QCalendarWidgetWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

void QCalendarWidgetWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QCalendarWidget", funcName, gil, pyOverride, event);
}

const QMetaObject *QCalendarWidgetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QCalendarWidget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCalendarWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QCalendarWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCalendarWidgetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCalendarWidgetWrapper *>(this));
    return QCalendarWidget::qt_metacast(_clname);
}

QCalendarWidgetWrapper::~QCalendarWidgetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCalendarWidget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCalendarWidget >()))
        return -1;

    QCalendarWidgetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QCalendarWidget", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCalendarWidget::QCalendarWidget(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QCalendarWidget(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QCalendarWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCalendarWidget(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QCalendarWidgetWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QCalendarWidgetWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QCalendarWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QCalendarWidgetFunc_calendar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // calendar()const
        QCalendar cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->calendar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_clearMaximumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMaximumDate()
        cppSelf->clearMaximumDate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_clearMinimumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMinimumDate()
        cppSelf->clearMinimumDate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_dateEditAcceptDelay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dateEditAcceptDelay()const
        int cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->dateEditAcceptDelay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_dateTextFormat(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dateTextFormat", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::dateTextFormat()const->QMap<QDate,QTextCharFormat>
    // 1: QCalendarWidget::dateTextFormat(QDate)const->QTextCharFormat
    if (numArgs == 0) {
        overloadId = 0; // dateTextFormat()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))) {
        overloadId = 1; // dateTextFormat(QDate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dateTextFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // dateTextFormat() const
        {

            // dateTextFormat()const
            QMap<QDate,QTextCharFormat> cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->dateTextFormat();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QDate_QTextCharFormat_IDX], &cppResult);
            break;
        }
        case 1: // dateTextFormat(QDate date) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDate cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // dateTextFormat(QDate)const
                QTextCharFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->dateTextFormat(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eventFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_firstDayOfWeek(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstDayOfWeek()const
        Qt::DayOfWeek cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->firstDayOfWeek();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_headerTextFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // headerTextFormat()const
        QTextCharFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->headerTextFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_horizontalHeaderFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // horizontalHeaderFormat()const
        QCalendarWidget::HorizontalHeaderFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->horizontalHeaderFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_isDateEditEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDateEditEnabled()const
        bool cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->isDateEditEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_isGridVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isGridVisible()const
        bool cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->isGridVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_isNavigationBarVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNavigationBarVisible()const
        bool cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->isNavigationBarVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_maximumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumDate()const
        QDate cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->maximumDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_minimumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumDate()const
        QDate cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->minimumDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_minimumSizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumSizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QCalendarWidget *>(cppSelf)->::QCalendarWidget::minimumSizeHint()
            : const_cast<const ::QCalendarWidget *>(cppSelf)->minimumSizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_monthShown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // monthShown()const
        int cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->monthShown();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_paintCell(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "paintCell", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::paintCell(QPainter*,QRect,QDate)const
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[2])))) {
        overloadId = 0; // paintCell(QPainter*,QRect,QDate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "paintCell", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QDate cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintCell(QPainter*,QRect,QDate)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QCalendarWidget *>(cppSelf)->::QCalendarWidget::paintCell(cppArg0, *cppArg1, cppArg2)
                : const_cast<const ::QCalendarWidget *>(cppSelf)->paintCell(cppArg0, *cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_selectedDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedDate()const
        QDate cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->selectedDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_selectionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionMode()const
        QCalendarWidget::SelectionMode cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->selectionMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_setCalendar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setCalendar(QCalendar)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArg)))) {
        overloadId = 0; // setCalendar(QCalendar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCalendar", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCalendar cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCalendar(QCalendar)
            cppSelf->setCalendar(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setCurrentPage(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCurrentPage", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setCurrentPage(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setCurrentPage(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCurrentPage", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentPage(int,int)
            cppSelf->setCurrentPage(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateEditAcceptDelay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setDateEditAcceptDelay(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDateEditAcceptDelay(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDateEditAcceptDelay", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateEditAcceptDelay(int)
            cppSelf->setDateEditAcceptDelay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateEditEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setDateEditEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDateEditEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDateEditEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateEditEnabled(bool)
            cppSelf->setDateEditEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setDateRange(QDate,QDate)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setDateRange(QDate,QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateRange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDate cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateRange(QDate,QDate)
            cppSelf->setDateRange(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateTextFormat(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateTextFormat", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setDateTextFormat(QDate,QTextCharFormat)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setDateTextFormat(QDate,QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateTextFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTextCharFormat cppArg1_local;
        ::QTextCharFormat *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateTextFormat(QDate,QTextCharFormat)
            cppSelf->setDateTextFormat(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setFirstDayOfWeek(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setFirstDayOfWeek(Qt::DayOfWeek)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFirstDayOfWeek(Qt::DayOfWeek)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFirstDayOfWeek", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        ::Qt::DayOfWeek cppArg0 = static_cast< ::Qt::DayOfWeek>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstDayOfWeek(Qt::DayOfWeek)
            cppSelf->setFirstDayOfWeek(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setGridVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setGridVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGridVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGridVisible", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridVisible(bool)
            cppSelf->setGridVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setHeaderTextFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setHeaderTextFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setHeaderTextFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaderTextFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaderTextFormat(QTextCharFormat)
            cppSelf->setHeaderTextFormat(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setHorizontalHeaderFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setHorizontalHeaderFormat(QCalendarWidget::HorizontalHeaderFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHorizontalHeaderFormat(QCalendarWidget::HorizontalHeaderFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHorizontalHeaderFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        ::QCalendarWidget::HorizontalHeaderFormat cppArg0{QCalendarWidget::NoHorizontalHeader};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHorizontalHeaderFormat(QCalendarWidget::HorizontalHeaderFormat)
            cppSelf->setHorizontalHeaderFormat(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setMaximumDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setMaximumDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setMaximumDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumDate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumDate(QDate)
            cppSelf->setMaximumDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setMinimumDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setMinimumDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setMinimumDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumDate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumDate(QDate)
            cppSelf->setMinimumDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setNavigationBarVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setNavigationBarVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setNavigationBarVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNavigationBarVisible", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNavigationBarVisible(bool)
            cppSelf->setNavigationBarVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setSelectedDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setSelectedDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setSelectedDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectedDate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectedDate(QDate)
            cppSelf->setSelectedDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setSelectionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setSelectionMode(QCalendarWidget::SelectionMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSelectionMode(QCalendarWidget::SelectionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        ::QCalendarWidget::SelectionMode cppArg0{QCalendarWidget::NoSelection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionMode(QCalendarWidget::SelectionMode)
            cppSelf->setSelectionMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setVerticalHeaderFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setVerticalHeaderFormat(QCalendarWidget::VerticalHeaderFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVerticalHeaderFormat(QCalendarWidget::VerticalHeaderFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVerticalHeaderFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        ::QCalendarWidget::VerticalHeaderFormat cppArg0{QCalendarWidget::NoVerticalHeader};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVerticalHeaderFormat(QCalendarWidget::VerticalHeaderFormat)
            cppSelf->setVerticalHeaderFormat(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_setWeekdayTextFormat(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setWeekdayTextFormat", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setWeekdayTextFormat(Qt::DayOfWeek,QTextCharFormat)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setWeekdayTextFormat(Qt::DayOfWeek,QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setWeekdayTextFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        ::Qt::DayOfWeek cppArg0 = static_cast< ::Qt::DayOfWeek>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTextCharFormat cppArg1_local;
        ::QTextCharFormat *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setWeekdayTextFormat(Qt::DayOfWeek,QTextCharFormat)
            cppSelf->setWeekdayTextFormat(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_showNextMonth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showNextMonth()
        cppSelf->showNextMonth();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_showNextYear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showNextYear()
        cppSelf->showNextYear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_showPreviousMonth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showPreviousMonth()
        cppSelf->showPreviousMonth();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_showPreviousYear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showPreviousYear()
        cppSelf->showPreviousYear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_showSelectedDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showSelectedDate()
        cppSelf->showSelectedDate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_showToday(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showToday()
        cppSelf->showToday();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QCalendarWidget *>(cppSelf)->::QCalendarWidget::sizeHint()
            : const_cast<const ::QCalendarWidget *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_updateCell(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::updateCell(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // updateCell(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateCell", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateCell(QDate)
            cppSelf->updateCell(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_updateCells(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateCells()
        cppSelf->updateCells();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QCalendarWidgetFunc_verticalHeaderFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // verticalHeaderFormat()const
        QCalendarWidget::VerticalHeaderFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->verticalHeaderFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_weekdayTextFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::weekdayTextFormat(Qt::DayOfWeek)const->QTextCharFormat
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // weekdayTextFormat(Qt::DayOfWeek)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "weekdayTextFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);

    // Call function/method
    {
        ::Qt::DayOfWeek cppArg0 = static_cast< ::Qt::DayOfWeek>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // weekdayTextFormat(Qt::DayOfWeek)const
            QTextCharFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->weekdayTextFormat(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCalendarWidgetFunc_yearShown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yearShown()const
        int cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->yearShown();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QCalendarWidget_PropertyStrings[] = {
    "dateEditAcceptDelay::",
    "dateEditEnabled:isDateEditEnabled:",
    "firstDayOfWeek::",
    "gridVisible:isGridVisible:",
    "horizontalHeaderFormat::",
    "maximumDate::",
    "minimumDate::",
    "navigationBarVisible:isNavigationBarVisible:",
    "selectedDate::",
    "selectionMode::",
    "verticalHeaderFormat::",
    nullptr // Sentinel
};

static const char *Sbk_QCalendarWidget_EnumFlagInfo[] = {
    "HorizontalHeaderFormat:Enum",
    "SelectionMode:Enum",
    "VerticalHeaderFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCalendarWidget_methods[] = {
    {"calendar", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_calendar), METH_NOARGS, nullptr},
    {"clearMaximumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_clearMaximumDate), METH_NOARGS, nullptr},
    {"clearMinimumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_clearMinimumDate), METH_NOARGS, nullptr},
    {"dateEditAcceptDelay", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_dateEditAcceptDelay), METH_NOARGS, nullptr},
    {"dateTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_dateTextFormat), METH_VARARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_eventFilter), METH_VARARGS, nullptr},
    {"firstDayOfWeek", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_firstDayOfWeek), METH_NOARGS, nullptr},
    {"headerTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_headerTextFormat), METH_NOARGS, nullptr},
    {"horizontalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_horizontalHeaderFormat), METH_NOARGS, nullptr},
    {"isDateEditEnabled", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_isDateEditEnabled), METH_NOARGS, nullptr},
    {"isGridVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_isGridVisible), METH_NOARGS, nullptr},
    {"isNavigationBarVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_isNavigationBarVisible), METH_NOARGS, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_keyPressEvent), METH_O, nullptr},
    {"maximumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_maximumDate), METH_NOARGS, nullptr},
    {"minimumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_minimumDate), METH_NOARGS, nullptr},
    {"minimumSizeHint", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_minimumSizeHint), METH_NOARGS, nullptr},
    {"monthShown", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_monthShown), METH_NOARGS, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_mousePressEvent), METH_O, nullptr},
    {"paintCell", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_paintCell), METH_VARARGS, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_resizeEvent), METH_O, nullptr},
    {"selectedDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_selectedDate), METH_NOARGS, nullptr},
    {"selectionMode", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_selectionMode), METH_NOARGS, nullptr},
    {"setCalendar", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setCalendar), METH_O, nullptr},
    {"setCurrentPage", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setCurrentPage), METH_VARARGS, nullptr},
    {"setDateEditAcceptDelay", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateEditAcceptDelay), METH_O, nullptr},
    {"setDateEditEnabled", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateEditEnabled), METH_O, nullptr},
    {"setDateRange", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateRange), METH_VARARGS, nullptr},
    {"setDateTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateTextFormat), METH_VARARGS, nullptr},
    {"setFirstDayOfWeek", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setFirstDayOfWeek), METH_O, nullptr},
    {"setGridVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setGridVisible), METH_O, nullptr},
    {"setHeaderTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setHeaderTextFormat), METH_O, nullptr},
    {"setHorizontalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setHorizontalHeaderFormat), METH_O, nullptr},
    {"setMaximumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setMaximumDate), METH_O, nullptr},
    {"setMinimumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setMinimumDate), METH_O, nullptr},
    {"setNavigationBarVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setNavigationBarVisible), METH_O, nullptr},
    {"setSelectedDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setSelectedDate), METH_O, nullptr},
    {"setSelectionMode", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setSelectionMode), METH_O, nullptr},
    {"setVerticalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setVerticalHeaderFormat), METH_O, nullptr},
    {"setWeekdayTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setWeekdayTextFormat), METH_VARARGS, nullptr},
    {"showNextMonth", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showNextMonth), METH_NOARGS, nullptr},
    {"showNextYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showNextYear), METH_NOARGS, nullptr},
    {"showPreviousMonth", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showPreviousMonth), METH_NOARGS, nullptr},
    {"showPreviousYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showPreviousYear), METH_NOARGS, nullptr},
    {"showSelectedDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showSelectedDate), METH_NOARGS, nullptr},
    {"showToday", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showToday), METH_NOARGS, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_sizeHint), METH_NOARGS, nullptr},
    {"updateCell", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_updateCell), METH_O, nullptr},
    {"updateCells", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_updateCells), METH_NOARGS, nullptr},
    {"verticalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_verticalHeaderFormat), METH_NOARGS, nullptr},
    {"weekdayTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_weekdayTextFormat), METH_O, nullptr},
    {"yearShown", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_yearShown), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCalendarWidget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCalendarWidgetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QCalendarWidget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCalendarWidget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QCalendarWidgetSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QCalendarWidget *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCalendarWidget_Type = nullptr;
static PyTypeObject *Sbk_QCalendarWidget_TypeF(void)
{
    return _Sbk_QCalendarWidget_Type;
}

static PyType_Slot Sbk_QCalendarWidget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QCalendarWidget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCalendarWidget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCalendarWidget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCalendarWidget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCalendarWidget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCalendarWidget_spec = {
    "2:PySide6.QtWidgets.QCalendarWidget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCalendarWidget_slots
};

} //extern "C"

static void *Sbk_QCalendarWidget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QCalendarWidget *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QCalendarWidget *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QCalendarWidget *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCalendarWidget::HorizontalHeaderFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCalendarWidget::HorizontalHeaderFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX])))
        return Enum_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat;
    return {};
}

static PyObject *QCalendarWidget_HorizontalHeaderFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCalendarWidget::HorizontalHeaderFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCalendarWidget::HorizontalHeaderFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCalendarWidget_VerticalHeaderFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCalendarWidget::VerticalHeaderFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCalendarWidget::VerticalHeaderFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCalendarWidget_VerticalHeaderFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX])))
        return Enum_PythonToCpp_QCalendarWidget_VerticalHeaderFormat;
    return {};
}

static PyObject *QCalendarWidget_VerticalHeaderFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCalendarWidget::VerticalHeaderFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCalendarWidget::VerticalHeaderFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCalendarWidget_SelectionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCalendarWidget::SelectionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCalendarWidget::SelectionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCalendarWidget_SelectionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX])))
        return Enum_PythonToCpp_QCalendarWidget_SelectionMode;
    return {};
}

static PyObject *QCalendarWidget_SelectionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCalendarWidget::SelectionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCalendarWidget::SelectionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCalendarWidget_PythonToCpp_QCalendarWidget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCalendarWidget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCalendarWidget_PythonToCpp_QCalendarWidget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCalendarWidget_TypeF()))
        return QCalendarWidget_PythonToCpp_QCalendarWidget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCalendarWidget_PTR_CppToPython_QCalendarWidget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QCalendarWidget *>(const_cast<void *>(cppIn)), Sbk_QCalendarWidget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCalendarWidget_SignatureStrings[] = {
    "PySide6.QtWidgets.QCalendarWidget(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,selectedDate:QDate=None,minimumDate:QDate=None,maximumDate:QDate=None,firstDayOfWeek:Qt.DayOfWeek=None,gridVisible:bool=None,selectionMode:QCalendarWidget.SelectionMode=None,horizontalHeaderFormat:QCalendarWidget.HorizontalHeaderFormat=None,verticalHeaderFormat:QCalendarWidget.VerticalHeaderFormat=None,navigationBarVisible:bool=None,dateEditEnabled:bool=None,dateEditAcceptDelay:int=None)",
    "PySide6.QtWidgets.QCalendarWidget.calendar(self)->PySide6.QtCore.QCalendar",
    "PySide6.QtWidgets.QCalendarWidget.clearMaximumDate(self)",
    "PySide6.QtWidgets.QCalendarWidget.clearMinimumDate(self)",
    "PySide6.QtWidgets.QCalendarWidget.dateEditAcceptDelay(self)->int",
    "1:PySide6.QtWidgets.QCalendarWidget.dateTextFormat(self)->QMap[PySide6.QtCore.QDate, PySide6.QtGui.QTextCharFormat]",
    "0:PySide6.QtWidgets.QCalendarWidget.dateTextFormat(self,date:PySide6.QtCore.QDate)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtWidgets.QCalendarWidget.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QCalendarWidget.eventFilter(self,watched:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QCalendarWidget.firstDayOfWeek(self)->PySide6.QtCore.Qt.DayOfWeek",
    "PySide6.QtWidgets.QCalendarWidget.headerTextFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtWidgets.QCalendarWidget.horizontalHeaderFormat(self)->PySide6.QtWidgets.QCalendarWidget.HorizontalHeaderFormat",
    "PySide6.QtWidgets.QCalendarWidget.isDateEditEnabled(self)->bool",
    "PySide6.QtWidgets.QCalendarWidget.isGridVisible(self)->bool",
    "PySide6.QtWidgets.QCalendarWidget.isNavigationBarVisible(self)->bool",
    "PySide6.QtWidgets.QCalendarWidget.keyPressEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QCalendarWidget.maximumDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QCalendarWidget.minimumDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QCalendarWidget.minimumSizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QCalendarWidget.monthShown(self)->int",
    "PySide6.QtWidgets.QCalendarWidget.mousePressEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QCalendarWidget.paintCell(self,painter:PySide6.QtGui.QPainter,rect:PySide6.QtCore.QRect,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.resizeEvent(self,event:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QCalendarWidget.selectedDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QCalendarWidget.selectionMode(self)->PySide6.QtWidgets.QCalendarWidget.SelectionMode",
    "PySide6.QtWidgets.QCalendarWidget.setCalendar(self,calendar:PySide6.QtCore.QCalendar)",
    "PySide6.QtWidgets.QCalendarWidget.setCurrentPage(self,year:int,month:int)",
    "PySide6.QtWidgets.QCalendarWidget.setDateEditAcceptDelay(self,delay:int)",
    "PySide6.QtWidgets.QCalendarWidget.setDateEditEnabled(self,enable:bool)",
    "PySide6.QtWidgets.QCalendarWidget.setDateRange(self,min:PySide6.QtCore.QDate,max:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setDateTextFormat(self,date:PySide6.QtCore.QDate,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setFirstDayOfWeek(self,dayOfWeek:PySide6.QtCore.Qt.DayOfWeek)",
    "PySide6.QtWidgets.QCalendarWidget.setGridVisible(self,show:bool)",
    "PySide6.QtWidgets.QCalendarWidget.setHeaderTextFormat(self,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setHorizontalHeaderFormat(self,format:PySide6.QtWidgets.QCalendarWidget.HorizontalHeaderFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setMaximumDate(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setMinimumDate(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setNavigationBarVisible(self,visible:bool)",
    "PySide6.QtWidgets.QCalendarWidget.setSelectedDate(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setSelectionMode(self,mode:PySide6.QtWidgets.QCalendarWidget.SelectionMode)",
    "PySide6.QtWidgets.QCalendarWidget.setVerticalHeaderFormat(self,format:PySide6.QtWidgets.QCalendarWidget.VerticalHeaderFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setWeekdayTextFormat(self,dayOfWeek:PySide6.QtCore.Qt.DayOfWeek,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QCalendarWidget.showNextMonth(self)",
    "PySide6.QtWidgets.QCalendarWidget.showNextYear(self)",
    "PySide6.QtWidgets.QCalendarWidget.showPreviousMonth(self)",
    "PySide6.QtWidgets.QCalendarWidget.showPreviousYear(self)",
    "PySide6.QtWidgets.QCalendarWidget.showSelectedDate(self)",
    "PySide6.QtWidgets.QCalendarWidget.showToday(self)",
    "PySide6.QtWidgets.QCalendarWidget.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QCalendarWidget.updateCell(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.updateCells(self)",
    "PySide6.QtWidgets.QCalendarWidget.verticalHeaderFormat(self)->PySide6.QtWidgets.QCalendarWidget.VerticalHeaderFormat",
    "PySide6.QtWidgets.QCalendarWidget.weekdayTextFormat(self,dayOfWeek:PySide6.QtCore.Qt.DayOfWeek)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtWidgets.QCalendarWidget.yearShown(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QCalendarWidget_SignatureByteSize = 813;
static constexpr uint8_t QCalendarWidget_SignatureBytes[813] = {
    0x78, 0xda, 0xad, 0x57, 0x51, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xef, 0xaf, 0xd8, 0xe3, 0x3a, 0x79,
    0x68, 0x7b, 0xd9, 0x43, 0xa4, 0x4e, 0x5a, 0x81, 0x16, 0x69, 0xa2, 0x85, 0x52, 0xb5, 0x9a, 0xa6,
    0x3d, 0xb8, 0xf8, 0x00, 0xaf, 0xc1, 0x41, 0x8e, 0x81, 0xa6, 0xbf, 0x7e, 0xe7, 0xb8, 0x59, 0x42,
    0xec, 0xb4, 0x97, 0x86, 0x17, 0x44, 0x6c, 0xdf, 0xf7, 0xd9, 0xe7, 0xbb, 0xef, 0xce, 0x93, 0x6c,
    0x26, 0x05, 0x7c, 0xeb, 0x4d, 0xcd, 0xbd, 0x14, 0x4b, 0x30, 0x69, 0x6f, 0xda, 0xe7, 0x31, 0x28,
    0xc1, 0xb5, 0x1b, 0xf8, 0x98, 0x42, 0xbc, 0x60, 0x1b, 0xae, 0x41, 0x99, 0x68, 0xe2, 0xaf, 0x76,
    0x7f, 0xce, 0xd4, 0x36, 0x8e, 0x37, 0x46, 0xb3, 0x4f, 0xd1, 0x4f, 0xc8, 0xf6, 0x89, 0x16, 0xd7,
    0x2a, 0xce, 0xce, 0xae, 0x12, 0x05, 0x0c, 0x01, 0x60, 0x6e, 0x40, 0x0c, 0xb8, 0x81, 0x68, 0x6a,
    0x7f, 0xdd, 0xf8, 0x5a, 0x2a, 0xb9, 0xde, 0xae, 0xbd, 0x61, 0xfe, 0x14, 0x1a, 0x5e, 0x48, 0x9d,
    0x9a, 0x01, 0xcf, 0xae, 0x17, 0xf7, 0x00, 0x8f, 0xd1, 0xd4, 0xf4, 0xfe, 0x7f, 0xb8, 0x05, 0x4b,
    0x2d, 0xc5, 0x9d, 0x4c, 0xe5, 0x43, 0x0c, 0xd1, 0x43, 0x92, 0xc4, 0x55, 0x72, 0x99, 0xa8, 0x71,
    0x22, 0x10, 0xef, 0xf0, 0x6c, 0xbd, 0x59, 0x75, 0xd6, 0x19, 0xac, 0x12, 0x2d, 0x9f, 0x13, 0x65,
    0x78, 0x3c, 0x02, 0x2e, 0x40, 0x5f, 0x24, 0x7a, 0xcd, 0x8d, 0x67, 0x39, 0x0a, 0x2e, 0x73, 0x10,
    0x3b, 0xd0, 0x46, 0xce, 0xdf, 0x00, 0xb8, 0x0b, 0x2c, 0x72, 0xe6, 0x8a, 0xef, 0xe4, 0x92, 0xdb,
    0x5d, 0x9d, 0x73, 0xed, 0x9f, 0x48, 0xa0, 0x4b, 0x86, 0x42, 0x9a, 0xa1, 0xe2, 0x38, 0x21, 0x02,
    0x33, 0x3f, 0xe6, 0x73, 0xd8, 0x98, 0x01, 0xc4, 0x3c, 0x8b, 0xa4, 0x72, 0xa8, 0xa7, 0x27, 0x93,
    0xb7, 0x6e, 0xba, 0x37, 0x7f, 0xf9, 0xcc, 0xaf, 0xfc, 0xf4, 0xf3, 0xf7, 0xd2, 0xa2, 0x9f, 0x68,
    0x28, 0x97, 0x53, 0xa0, 0x62, 0xe0, 0x7a, 0x5c, 0xde, 0xa4, 0x83, 0x24, 0x1b, 0x96, 0x91, 0x41,
    0x36, 0x0c, 0x1c, 0xbe, 0x38, 0x07, 0xfa, 0xe0, 0xe4, 0x6b, 0x44, 0x83, 0xb8, 0x85, 0x27, 0xe3,
    0x2e, 0xa3, 0xb0, 0x9e, 0x8e, 0xf9, 0xe6, 0x77, 0xdd, 0x15, 0x76, 0x6b, 0xec, 0x43, 0x39, 0x7a,
    0xb9, 0x95, 0xbd, 0xa9, 0xb5, 0xed, 0xaf, 0xf8, 0xcb, 0x65, 0xfe, 0x39, 0xf9, 0xf2, 0x3e, 0xce,
    0xfc, 0x1e, 0xa3, 0x10, 0xe3, 0xc1, 0x9d, 0x04, 0x28, 0x09, 0x6e, 0x82, 0x1d, 0xe6, 0xb1, 0xa3,
    0xc9, 0xff, 0x7a, 0x3c, 0x43, 0x3b, 0x8a, 0x44, 0x36, 0xac, 0xa8, 0x78, 0x17, 0x32, 0x36, 0xe0,
    0xc2, 0x86, 0xed, 0xb9, 0x99, 0xaf, 0x30, 0x2c, 0xeb, 0xb8, 0xd7, 0x0f, 0x7f, 0x31, 0xd5, 0x8e,
    0x43, 0x7a, 0xa8, 0x05, 0x4d, 0xe1, 0x5a, 0x51, 0x08, 0x02, 0xe6, 0x2a, 0xcf, 0x43, 0xff, 0xfa,
    0xbb, 0x3a, 0x3c, 0xac, 0x27, 0x3e, 0x7a, 0x93, 0x7d, 0x58, 0x68, 0x08, 0xc4, 0x32, 0x1d, 0x1c,
    0x2a, 0x45, 0xc1, 0x49, 0x74, 0xb2, 0x4c, 0x2f, 0x4b, 0x45, 0x6d, 0x6d, 0x7b, 0x15, 0x10, 0xb1,
    0x96, 0x20, 0x8f, 0x90, 0x4d, 0x34, 0xa4, 0xe9, 0xb0, 0x39, 0x64, 0xf3, 0x2b, 0xc1, 0x82, 0xe3,
    0xe2, 0x87, 0x80, 0xb9, 0xae, 0x4b, 0x92, 0x1f, 0x36, 0x76, 0x8e, 0x82, 0x54, 0xd7, 0xa8, 0xae,
    0x48, 0x33, 0xf9, 0x0c, 0x23, 0xa9, 0x4c, 0x13, 0x9a, 0x9d, 0xa7, 0xa0, 0x61, 0xac, 0xac, 0x66,
    0xab, 0x64, 0xaf, 0xaa, 0xf2, 0x47, 0xb1, 0xdb, 0xa6, 0x40, 0xf2, 0xf7, 0xd8, 0xae, 0x24, 0x7b,
    0x7c, 0xc3, 0x91, 0xbf, 0x0f, 0x71, 0x5c, 0x34, 0x12, 0xf8, 0x09, 0xba, 0x8e, 0x39, 0x71, 0xc3,
    0x4c, 0xa3, 0x46, 0x78, 0xea, 0x70, 0x63, 0x85, 0xa3, 0x59, 0x14, 0x09, 0x9b, 0xc0, 0x63, 0xa1,
    0xf7, 0xde, 0x3a, 0xd8, 0x4d, 0xb9, 0x8a, 0x02, 0x5a, 0xed, 0x6b, 0x3a, 0x86, 0xc0, 0x41, 0x97,
    0x42, 0xd7, 0x86, 0x83, 0xf6, 0x85, 0x44, 0x63, 0xfa, 0xd5, 0x1a, 0xcf, 0x8a, 0x8a, 0x1f, 0x35,
    0x95, 0xfa, 0x53, 0x22, 0xea, 0x56, 0xdb, 0xfe, 0x70, 0xc2, 0x97, 0x6e, 0xf7, 0x2c, 0xc3, 0x2a,
    0x6e, 0x7b, 0x0f, 0x96, 0x87, 0xa3, 0xfd, 0x47, 0x44, 0x1a, 0x34, 0x94, 0x71, 0x26, 0x8a, 0x76,
    0xa6, 0x25, 0x50, 0x55, 0xfc, 0x18, 0xe4, 0x1f, 0x79, 0xcb, 0xd4, 0x02, 0xe6, 0x86, 0xab, 0xe2,
    0x5c, 0x98, 0xab, 0xc1, 0x20, 0xb4, 0x5d, 0xeb, 0xbb, 0xa3, 0xf3, 0x85, 0x86, 0xdc, 0x06, 0xb0,
    0x85, 0x6b, 0x29, 0x5f, 0x2d, 0x4d, 0x44, 0xe2, 0x0b, 0xbf, 0x94, 0x22, 0x71, 0xd1, 0x65, 0xbf,
    0x52, 0x52, 0x89, 0xf8, 0xf5, 0x1a, 0xc2, 0x52, 0x94, 0xa6, 0x36, 0x17, 0x30, 0x0a, 0xd5, 0xe5,
    0x63, 0x7a, 0x60, 0xd4, 0x5c, 0xa0, 0x7d, 0x9a, 0x76, 0x55, 0x9a, 0xb8, 0x83, 0x7a, 0x9f, 0xdc,
    0x4d, 0xeb, 0x2c, 0x60, 0xad, 0x36, 0x75, 0x06, 0x6c, 0xac, 0xe6, 0x6c, 0x57, 0x79, 0x9f, 0x10,
    0xc1, 0x66, 0x75, 0xdd, 0xec, 0xbc, 0xbd, 0x99, 0x27, 0x9f, 0xa8, 0x3b, 0x02, 0xa2, 0x96, 0x0a,
    0x4a, 0x64, 0x0b, 0xbd, 0xdc, 0x5a, 0x86, 0x4b, 0x08, 0x82, 0xc8, 0x6e, 0x73, 0x0f, 0x13, 0xd4,
    0x17, 0x0b, 0x42, 0xce, 0x1e, 0x2f, 0x6d, 0x30, 0x89, 0xaf, 0xd0, 0x6a, 0x6c, 0xd5, 0x9d, 0xfc,
    0x44, 0x2b, 0xac, 0x7e, 0x41, 0xf1, 0xc6, 0x24, 0x1a, 0x61, 0x5b, 0xb2, 0x93, 0xd8, 0x75, 0xb4,
    0xa7, 0x2b, 0x2c, 0x5b, 0x53, 0x7a, 0x41, 0x4a, 0x35, 0xbc, 0x4d, 0x44, 0xf1, 0xf2, 0xa4, 0x58,
    0x1c, 0xa7, 0xe9, 0xdb, 0x6e, 0x6c, 0x0a, 0x95, 0x5d, 0x56, 0xa7, 0x84, 0x2a, 0xc1, 0x52, 0xf2,
    0x39, 0x76, 0x4d, 0x39, 0x41, 0xea, 0x63, 0x42, 0xe9, 0x40, 0x20, 0xdd, 0x77, 0x48, 0x85, 0x23,
    0xbc, 0xec, 0x6c, 0x8f, 0xe3, 0x35, 0xda, 0xff, 0x00, 0xa6, 0x83, 0x0d, 0x4d
};
#endif

PyTypeObject *init_QCalendarWidget(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX].type;

    Shiboken::AutoDecRef Sbk_QCalendarWidget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QCalendarWidget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCalendarWidget",
        "QCalendarWidget*",
        &Sbk_QCalendarWidget_spec,
        &Shiboken::callCppDestructor< QCalendarWidget >,
        Sbk_QCalendarWidget_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QCalendarWidget_TypeF(); // references _Sbk_QCalendarWidget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCalendarWidget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCalendarWidget_SignatureBytes, QCalendarWidget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCalendarWidget_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCalendarWidget_PythonToCpp_QCalendarWidget_PTR,
        is_QCalendarWidget_PythonToCpp_QCalendarWidget_PTR_Convertible,
        QCalendarWidget_PTR_CppToPython_QCalendarWidget);

    Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget");
    Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget*");
    Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCalendarWidget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QCalendarWidgetWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QCalendarWidget_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QCalendarWidget_TypeF(), &Sbk_QCalendarWidgetSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QCalendarWidget_TypeF(), &Sbk_QCalendarWidget_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCalendarWidget_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HorizontalHeaderFormat'.
    const char *HorizontalHeaderFormat_Initializer[] = {
        "NoHorizontalHeader",
        "SingleLetterDayNames",
        "ShortDayNames",
        "LongDayNames",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HorizontalHeaderFormat_InitializerValues[] = {
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::NoHorizontalHeader),   //  0x00  0
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::SingleLetterDayNames), //  0x01  1
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::ShortDayNames),        //  0x02  2
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::LongDayNames)          //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCalendarWidget_TypeF(),
        "2:PySide6.QtWidgets.QCalendarWidget.HorizontalHeaderFormat",
        HorizontalHeaderFormat_Initializer, HorizontalHeaderFormat_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX].type = EType;
    // Register converter for enum 'QCalendarWidget::HorizontalHeaderFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCalendarWidget_HorizontalHeaderFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat,
            is_Enum_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget::HorizontalHeaderFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "HorizontalHeaderFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HorizontalHeaderFormat' enum.

    // Initialization of enum 'VerticalHeaderFormat'.
    const char *VerticalHeaderFormat_Initializer[] = {
        "NoVerticalHeader",
        "ISOWeekNumbers",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t VerticalHeaderFormat_InitializerValues[] = {
        uint8_t(QCalendarWidget::VerticalHeaderFormat::NoVerticalHeader), //  0x00  0
        uint8_t(QCalendarWidget::VerticalHeaderFormat::ISOWeekNumbers)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCalendarWidget_TypeF(),
        "2:PySide6.QtWidgets.QCalendarWidget.VerticalHeaderFormat",
        VerticalHeaderFormat_Initializer, VerticalHeaderFormat_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX].type = EType;
    // Register converter for enum 'QCalendarWidget::VerticalHeaderFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCalendarWidget_VerticalHeaderFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCalendarWidget_VerticalHeaderFormat,
            is_Enum_PythonToCpp_QCalendarWidget_VerticalHeaderFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget::VerticalHeaderFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "VerticalHeaderFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'VerticalHeaderFormat' enum.

    // Initialization of enum 'SelectionMode'.
    const char *SelectionMode_Initializer[] = {
        "NoSelection",
        "SingleSelection",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SelectionMode_InitializerValues[] = {
        uint8_t(QCalendarWidget::SelectionMode::NoSelection),    //  0x00  0
        uint8_t(QCalendarWidget::SelectionMode::SingleSelection) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCalendarWidget_TypeF(),
        "2:PySide6.QtWidgets.QCalendarWidget.SelectionMode",
        SelectionMode_Initializer, SelectionMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX].type = EType;
    // Register converter for enum 'QCalendarWidget::SelectionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCalendarWidget_SelectionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCalendarWidget_SelectionMode,
            is_Enum_PythonToCpp_QCalendarWidget_SelectionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget::SelectionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "SelectionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SelectionMode' enum.

    PySide::Signal::registerSignals(pyType, &::QCalendarWidget::staticMetaObject);
    qRegisterMetaType< ::QCalendarWidget::HorizontalHeaderFormat >("QCalendarWidget::HorizontalHeaderFormat");
    qRegisterMetaType< ::QCalendarWidget::VerticalHeaderFormat >("QCalendarWidget::VerticalHeaderFormat");
    qRegisterMetaType< ::QCalendarWidget::SelectionMode >("QCalendarWidget::SelectionMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QCalendarWidget::staticMetaObject, sizeof(QCalendarWidgetWrapper));

    return pyType;
}
