// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qdialogbuttonbox_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qabstractbutton.h>
#include <QtWidgets/qdialogbuttonbox.h>
#include <QtWidgets/qpushbutton.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDialogButtonBoxWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDialogButtonBoxWrapper::QDialogButtonBoxWrapper(::QFlags<QDialogButtonBox::StandardButton> buttons, ::QWidget * parent) : QDialogButtonBox(buttons, parent)
{
}

QDialogButtonBoxWrapper::QDialogButtonBoxWrapper(::QFlags<QDialogButtonBox::StandardButton> buttons, ::Qt::Orientation orientation, ::QWidget * parent) : QDialogButtonBox(buttons, orientation, parent)
{
}

QDialogButtonBoxWrapper::QDialogButtonBoxWrapper(::QWidget * parent) : QDialogButtonBox(parent)
{
}

QDialogButtonBoxWrapper::QDialogButtonBoxWrapper(::Qt::Orientation orientation, ::QWidget * parent) : QDialogButtonBox(orientation, parent)
{
}

void QDialogButtonBoxWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialogButtonBox::changeEvent(event);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QDialogButtonBox", funcName, gil, pyOverride, signal);
}

void QDialogButtonBoxWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

int QDialogButtonBoxWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QDialogButtonBox", funcName, gil, pyOverride);
}

void QDialogButtonBoxWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QDialogButtonBox", funcName, gil, pyOverride, signal);
}

void QDialogButtonBoxWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

bool QDialogButtonBoxWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialogButtonBox::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QDialogButtonBox", funcName, gil, pyOverride, event);
}

bool QDialogButtonBoxWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QDialogButtonBox", funcName, gil, pyOverride, watched, event);
}

void QDialogButtonBoxWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

bool QDialogButtonBoxWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QDialogButtonBox", funcName, gil, pyOverride, next);
}

void QDialogButtonBoxWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

bool QDialogButtonBoxWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QDialogButtonBox", funcName, gil, pyOverride);
}

int QDialogButtonBoxWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QDialogButtonBox", funcName, gil, pyOverride, arg__1);
}

void QDialogButtonBoxWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QDialogButtonBox", funcName, gil, pyOverride, painter);
}

void QDialogButtonBoxWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

::QVariant QDialogButtonBoxWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QDialogButtonBox", funcName, gil, pyOverride, arg__1);
}

void QDialogButtonBoxWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

int QDialogButtonBoxWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QDialogButtonBox", funcName, gil, pyOverride, arg__1);
}

::QSize QDialogButtonBoxWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QDialogButtonBox", funcName, gil, pyOverride);
}

void QDialogButtonBoxWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

bool QDialogButtonBoxWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QDialogButtonBox", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QDialogButtonBoxWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QDialogButtonBox", funcName, gil, pyOverride);
}

void QDialogButtonBoxWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

::QPaintDevice * QDialogButtonBoxWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QDialogButtonBox", funcName, gil, pyOverride, offset);
}

void QDialogButtonBoxWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QDialogButtonBox", funcName, gil, pyOverride, visible);
}

::QPainter * QDialogButtonBoxWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QDialogButtonBox", funcName, gil, pyOverride);
}

void QDialogButtonBoxWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

::QSize QDialogButtonBoxWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QDialogButtonBox", funcName, gil, pyOverride);
}

void QDialogButtonBoxWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

void QDialogButtonBoxWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QDialogButtonBox", funcName, gil, pyOverride, event);
}

const QMetaObject *QDialogButtonBoxWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDialogButtonBox::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDialogButtonBoxWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDialogButtonBox::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDialogButtonBoxWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDialogButtonBoxWrapper *>(this));
    return QDialogButtonBox::qt_metacast(_clname);
}

QDialogButtonBoxWrapper::~QDialogButtonBoxWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDialogButtonBox_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDialogButtonBox >()))
        return -1;

    QDialogButtonBoxWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QDialogButtonBox", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDialogButtonBox::QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,QWidget*=)
    // 1: QDialogButtonBox::QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,Qt::Orientation,QWidget*=)
    // 2: QDialogButtonBox::QDialogButtonBox(QWidget*=)
    // 3: QDialogButtonBox::QDialogButtonBox(Qt::Orientation,QWidget*=)
    if (numArgs == 0) {
        overloadId = 2; // QDialogButtonBox(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QDialogButtonBox(Qt::Orientation,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 3; // QDialogButtonBox(Qt::Orientation,QWidget*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QDialogButtonBox(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QDialogButtonBox_StandardButton_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,Qt::Orientation,QWidget*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
                overloadId = 1; // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,Qt::Orientation,QWidget*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton> buttons, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);
                }
            }
            ::QFlags<QDialogButtonBox::StandardButton> cppArg0 = QFlags<QDialogButtonBox::StandardButton>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDialogButtonBoxWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDialogButtonBoxWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton> buttons, Qt::Orientation orientation, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);
                }
            }
            ::QFlags<QDialogButtonBox::StandardButton> cppArg0 = QFlags<QDialogButtonBox::StandardButton>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Orientation cppArg1 = static_cast< ::Qt::Orientation>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QWidget *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDialogButtonBox(QFlags<QDialogButtonBox::StandardButton>,Qt::Orientation,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDialogButtonBoxWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDialogButtonBoxWrapper(cppArg0, cppArg1, cppArg2);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 2: // QDialogButtonBox(QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDialogButtonBox(QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDialogButtonBoxWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDialogButtonBoxWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 3: // QDialogButtonBox(Qt::Orientation orientation, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);
                }
            }
            ::Qt::Orientation cppArg0 = static_cast< ::Qt::Orientation>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDialogButtonBox(Qt::Orientation,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDialogButtonBoxWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDialogButtonBoxWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDialogButtonBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDialogButtonBoxFunc_addButton(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addButton", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDialogButtonBox::addButton(QAbstractButton*,QDialogButtonBox::ButtonRole)
    // 1: QDialogButtonBox::addButton(QDialogButtonBox::StandardButton)->QPushButton*
    // 2: QDialogButtonBox::addButton(QString,QDialogButtonBox::ButtonRole)->QPushButton*
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_StandardButton_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // addButton(QDialogButtonBox::StandardButton)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonRole_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // addButton(QAbstractButton*,QDialogButtonBox::ButtonRole)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonRole_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 2; // addButton(QString,QDialogButtonBox::ButtonRole)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addButton", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addButton(QAbstractButton *button, QDialogButtonBox::ButtonRole role)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QAbstractButton *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QDialogButtonBox::ButtonRole cppArg1{QDialogButtonBox::AcceptRole};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addButton(QAbstractButton*,QDialogButtonBox::ButtonRole)
                cppSelf->addButton(cppArg0, cppArg1);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArgs[0]);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // addButton(QDialogButtonBox::StandardButton button)
        {
            ::QDialogButtonBox::StandardButton cppArg0{QDialogButtonBox::NoButton};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addButton(QDialogButtonBox::StandardButton)
                QPushButton * cppResult = cppSelf->addButton(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPushButton_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 2: // addButton(const QString &text, QDialogButtonBox::ButtonRole role)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QDialogButtonBox::ButtonRole cppArg1{QDialogButtonBox::AcceptRole};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addButton(QString,QDialogButtonBox::ButtonRole)
                QPushButton * cppResult = cppSelf->addButton(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPushButton_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_button(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialogButtonBox::button(QDialogButtonBox::StandardButton)const->QPushButton*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_StandardButton_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // button(QDialogButtonBox::StandardButton)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "button", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        ::QDialogButtonBox::StandardButton cppArg0{QDialogButtonBox::NoButton};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // button(QDialogButtonBox::StandardButton)const
            QPushButton * cppResult = const_cast<const ::QDialogButtonBox *>(cppSelf)->button(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPushButton_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_buttonRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialogButtonBox::buttonRole(QAbstractButton*)const->QDialogButtonBox::ButtonRole
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), (pyArg)))) {
        overloadId = 0; // buttonRole(QAbstractButton*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "buttonRole", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractButton *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // buttonRole(QAbstractButton*)const
            QDialogButtonBox::ButtonRole cppResult = const_cast<const ::QDialogButtonBox *>(cppSelf)->buttonRole(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonRole_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_buttons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buttons()const
        QList<QAbstractButton*> cppResult = const_cast<const ::QDialogButtonBox *>(cppSelf)->buttons();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QAbstractButtonPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_centerButtons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // centerButtons()const
        bool cppResult = const_cast<const ::QDialogButtonBox *>(cppSelf)->centerButtons();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDialogButtonBox::changeEvent(cppArg0)
                : cppSelf->changeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDialogButtonBoxFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDialogButtonBoxFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDialogButtonBox::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_orientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // orientation()const
        Qt::Orientation cppResult = const_cast<const ::QDialogButtonBox *>(cppSelf)->orientation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_removeButton(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialogButtonBox::removeButton(QAbstractButton*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), (pyArg)))) {
        overloadId = 0; // removeButton(QAbstractButton*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeButton", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractButton *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeButton(QAbstractButton*)
            cppSelf->removeButton(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(Py_None, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDialogButtonBoxFunc_setCenterButtons(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialogButtonBox::setCenterButtons(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setCenterButtons(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCenterButtons", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCenterButtons(bool)
            cppSelf->setCenterButtons(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDialogButtonBoxFunc_setOrientation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialogButtonBox::setOrientation(Qt::Orientation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOrientation(Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOrientation", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        ::Qt::Orientation cppArg0 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOrientation(Qt::Orientation)
            cppSelf->setOrientation(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDialogButtonBoxFunc_setStandardButtons(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialogButtonBox::setStandardButtons(QFlags<QDialogButtonBox::StandardButton>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QDialogButtonBox_StandardButton_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setStandardButtons(QFlags<QDialogButtonBox::StandardButton>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStandardButtons", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        ::QFlags<QDialogButtonBox::StandardButton> cppArg0 = QFlags<QDialogButtonBox::StandardButton>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStandardButtons(QFlags<QDialogButtonBox::StandardButton>)
            cppSelf->setStandardButtons(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDialogButtonBoxFunc_standardButton(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialogButtonBox::standardButton(QAbstractButton*)const->QDialogButtonBox::StandardButton
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), (pyArg)))) {
        overloadId = 0; // standardButton(QAbstractButton*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "standardButton", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractButton *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standardButton(QAbstractButton*)const
            QDialogButtonBox::StandardButton cppResult = const_cast<const ::QDialogButtonBox *>(cppSelf)->standardButton(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_StandardButton_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDialogButtonBoxFunc_standardButtons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // standardButtons()const
        QFlags<QDialogButtonBox::StandardButton> cppResult = const_cast<const ::QDialogButtonBox *>(cppSelf)->standardButtons();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QDialogButtonBox_StandardButton_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QDialogButtonBox_PropertyStrings[] = {
    "centerButtons::",
    "orientation::",
    "standardButtons::",
    nullptr // Sentinel
};

static const char *Sbk_QDialogButtonBox_EnumFlagInfo[] = {
    "ButtonLayout:Enum",
    "ButtonRole:Enum",
    "StandardButton:Flag:StandardButtons",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDialogButtonBox_methods[] = {
    {"addButton", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_addButton), METH_VARARGS, nullptr},
    {"button", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_button), METH_O, nullptr},
    {"buttonRole", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_buttonRole), METH_O, nullptr},
    {"buttons", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_buttons), METH_NOARGS, nullptr},
    {"centerButtons", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_centerButtons), METH_NOARGS, nullptr},
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_changeEvent), METH_O, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_clear), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_event), METH_O, nullptr},
    {"orientation", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_orientation), METH_NOARGS, nullptr},
    {"removeButton", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_removeButton), METH_O, nullptr},
    {"setCenterButtons", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_setCenterButtons), METH_O, nullptr},
    {"setOrientation", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_setOrientation), METH_O, nullptr},
    {"setStandardButtons", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_setStandardButtons), METH_O, nullptr},
    {"standardButton", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_standardButton), METH_O, nullptr},
    {"standardButtons", reinterpret_cast<PyCFunction>(Sbk_QDialogButtonBoxFunc_standardButtons), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDialogButtonBox_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDialogButtonBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDialogButtonBoxWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDialogButtonBox_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDialogButtonBox_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QDialogButtonBoxSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QDialogButtonBox *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDialogButtonBox_Type = nullptr;
static PyTypeObject *Sbk_QDialogButtonBox_TypeF(void)
{
    return _Sbk_QDialogButtonBox_Type;
}

static PyType_Slot Sbk_QDialogButtonBox_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDialogButtonBox_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDialogButtonBox_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDialogButtonBox_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDialogButtonBox_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDialogButtonBox_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDialogButtonBox_spec = {
    "2:PySide6.QtWidgets.QDialogButtonBox",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDialogButtonBox_slots
};

} //extern "C"

static void *Sbk_QDialogButtonBox_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QDialogButtonBox *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDialogButtonBox *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QDialogButtonBox *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDialogButtonBox_ButtonRole(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDialogButtonBox::ButtonRole>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDialogButtonBox::ButtonRole *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDialogButtonBox_ButtonRole_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonRole_IDX])))
        return Enum_PythonToCpp_QDialogButtonBox_ButtonRole;
    return {};
}

static PyObject *QDialogButtonBox_ButtonRole_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDialogButtonBox::ButtonRole>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDialogButtonBox::ButtonRole *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonRole_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDialogButtonBox_StandardButton(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDialogButtonBox::StandardButton>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDialogButtonBox::StandardButton *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDialogButtonBox_StandardButton_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_StandardButton_IDX])))
        return Enum_PythonToCpp_QDialogButtonBox_StandardButton;
    return {};
}

static PyObject *QDialogButtonBox_StandardButton_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDialogButtonBox::StandardButton>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDialogButtonBox::StandardButton *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_StandardButton_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDialogButtonBox_StandardButton(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDialogButtonBox::StandardButton>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDialogButtonBox::StandardButton> *>(cppOut) = value;

}

static PyObject *QDialogButtonBox_StandardButton_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDialogButtonBox::StandardButton> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_StandardButton_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QDialogButtonBox_ButtonLayout(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDialogButtonBox::ButtonLayout>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDialogButtonBox::ButtonLayout *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDialogButtonBox_ButtonLayout_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonLayout_IDX])))
        return Enum_PythonToCpp_QDialogButtonBox_ButtonLayout;
    return {};
}

static PyObject *QDialogButtonBox_ButtonLayout_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDialogButtonBox::ButtonLayout>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDialogButtonBox::ButtonLayout *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonLayout_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDialogButtonBox_PythonToCpp_QDialogButtonBox_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDialogButtonBox_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDialogButtonBox_PythonToCpp_QDialogButtonBox_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDialogButtonBox_TypeF()))
        return QDialogButtonBox_PythonToCpp_QDialogButtonBox_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDialogButtonBox_PTR_CppToPython_QDialogButtonBox(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDialogButtonBox *>(const_cast<void *>(cppIn)), Sbk_QDialogButtonBox_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDialogButtonBox_SignatureStrings[] = {
    "3:PySide6.QtWidgets.QDialogButtonBox(self,buttons:PySide6.QtWidgets.QDialogButtonBox.StandardButton,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,orientation:Qt.Orientation=None,standardButtons:PySide6.QtWidgets.QDialogButtonBox.StandardButton=None,centerButtons:bool=None)",
    "2:PySide6.QtWidgets.QDialogButtonBox(self,buttons:PySide6.QtWidgets.QDialogButtonBox.StandardButton,orientation:PySide6.QtCore.Qt.Orientation,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,orientation:Qt.Orientation=None,standardButtons:PySide6.QtWidgets.QDialogButtonBox.StandardButton=None,centerButtons:bool=None)",
    "1:PySide6.QtWidgets.QDialogButtonBox(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,orientation:Qt.Orientation=None,standardButtons:PySide6.QtWidgets.QDialogButtonBox.StandardButton=None,centerButtons:bool=None)",
    "0:PySide6.QtWidgets.QDialogButtonBox(self,orientation:PySide6.QtCore.Qt.Orientation,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,orientation:Qt.Orientation=None,standardButtons:PySide6.QtWidgets.QDialogButtonBox.StandardButton=None,centerButtons:bool=None)",
    "2:PySide6.QtWidgets.QDialogButtonBox.addButton(self,button:PySide6.QtWidgets.QAbstractButton,role:PySide6.QtWidgets.QDialogButtonBox.ButtonRole)",
    "1:PySide6.QtWidgets.QDialogButtonBox.addButton(self,button:PySide6.QtWidgets.QDialogButtonBox.StandardButton)->PySide6.QtWidgets.QPushButton",
    "0:PySide6.QtWidgets.QDialogButtonBox.addButton(self,text:QString,role:PySide6.QtWidgets.QDialogButtonBox.ButtonRole)->PySide6.QtWidgets.QPushButton",
    "PySide6.QtWidgets.QDialogButtonBox.button(self,which:PySide6.QtWidgets.QDialogButtonBox.StandardButton)->PySide6.QtWidgets.QPushButton",
    "PySide6.QtWidgets.QDialogButtonBox.buttonRole(self,button:PySide6.QtWidgets.QAbstractButton)->PySide6.QtWidgets.QDialogButtonBox.ButtonRole",
    "PySide6.QtWidgets.QDialogButtonBox.buttons(self)->QList[PySide6.QtWidgets.QAbstractButton]",
    "PySide6.QtWidgets.QDialogButtonBox.centerButtons(self)->bool",
    "PySide6.QtWidgets.QDialogButtonBox.changeEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QDialogButtonBox.clear(self)",
    "PySide6.QtWidgets.QDialogButtonBox.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QDialogButtonBox.orientation(self)->PySide6.QtCore.Qt.Orientation",
    "PySide6.QtWidgets.QDialogButtonBox.removeButton(self,button:PySide6.QtWidgets.QAbstractButton)",
    "PySide6.QtWidgets.QDialogButtonBox.setCenterButtons(self,center:bool)",
    "PySide6.QtWidgets.QDialogButtonBox.setOrientation(self,orientation:PySide6.QtCore.Qt.Orientation)",
    "PySide6.QtWidgets.QDialogButtonBox.setStandardButtons(self,buttons:PySide6.QtWidgets.QDialogButtonBox.StandardButton)",
    "PySide6.QtWidgets.QDialogButtonBox.standardButton(self,button:PySide6.QtWidgets.QAbstractButton)->PySide6.QtWidgets.QDialogButtonBox.StandardButton",
    "PySide6.QtWidgets.QDialogButtonBox.standardButtons(self)->PySide6.QtWidgets.QDialogButtonBox.StandardButton",
    nullptr}; // Sentinel
#else
static constexpr size_t QDialogButtonBox_SignatureByteSize = 392;
static constexpr uint8_t QDialogButtonBox_SignatureBytes[392] = {
    0x78, 0xda, 0xe5, 0x56, 0x4b, 0x4f, 0xc3, 0x30, 0x0c, 0xbe, 0xf3, 0x4b, 0x28, 0x2a, 0x15, 0x0f,
    0x89, 0x43, 0xa5, 0x21, 0xb1, 0xc1, 0x09, 0xc4, 0x56, 0x76, 0xe0, 0x80, 0x38, 0xa4, 0xad, 0x69,
    0x23, 0x85, 0x64, 0x4a, 0xdc, 0x3d, 0xfe, 0x3d, 0x5d, 0xb3, 0x69, 0xcd, 0xd6, 0x6d, 0x5e, 0xd1,
    0x90, 0x26, 0x6e, 0x79, 0xd8, 0x9f, 0x3f, 0x7f, 0xb1, 0xdd, 0xde, 0x86, 0x83, 0xd9, 0x90, 0xa7,
    0x70, 0x17, 0x44, 0xf8, 0xce, 0xd3, 0x0c, 0xd0, 0x04, 0xd1, 0x23, 0x67, 0x42, 0x65, 0xdd, 0x02,
    0x51, 0xc9, 0xae, 0x9a, 0x9e, 0x1b, 0x10, 0x5f, 0x7e, 0x5c, 0x6d, 0x0d, 0xc1, 0x3e, 0x18, 0x22,
    0x93, 0x29, 0xd3, 0xa9, 0x3d, 0xf1, 0x47, 0x4c, 0x83, 0xc4, 0x26, 0x47, 0xbb, 0xe8, 0xc8, 0x42,
    0x88, 0x11, 0x6a, 0xff, 0x22, 0x7c, 0x86, 0xd9, 0x44, 0xe9, 0xb4, 0x2f, 0xc5, 0xac, 0xf3, 0xaa,
    0x24, 0xf8, 0x4a, 0xf3, 0xd2, 0x97, 0x21, 0x57, 0x32, 0x8c, 0x30, 0xe8, 0xaf, 0xb6, 0xf6, 0xde,
    0x38, 0xa1, 0x5a, 0xb0, 0xb3, 0x30, 0x49, 0x89, 0x0a, 0x7a, 0x09, 0x12, 0x2b, 0x25, 0xaa, 0x73,
    0xef, 0xec, 0xe6, 0x0f, 0xf4, 0xa9, 0xe7, 0xb8, 0xf2, 0xee, 0x29, 0x0d, 0x81, 0x9b, 0xf2, 0x49,
    0x2b, 0x79, 0x4d, 0x56, 0xf2, 0x94, 0xb3, 0xbc, 0x22, 0x67, 0xf9, 0x3f, 0x5e, 0x9d, 0xd2, 0x3f,
    0x01, 0x4b, 0x17, 0x60, 0xf5, 0x4e, 0x6a, 0x72, 0x7c, 0x88, 0x0d, 0x6a, 0x96, 0xe0, 0xa2, 0x71,
    0xb4, 0x12, 0x40, 0xc1, 0xb7, 0xab, 0xb7, 0xd2, 0x9a, 0x56, 0x86, 0x74, 0x42, 0xbb, 0xb5, 0xf1,
    0x2e, 0xef, 0x1b, 0x7c, 0x06, 0x85, 0xc9, 0xed, 0x3d, 0xa9, 0x5a, 0xd6, 0xc9, 0x20, 0x4c, 0x31,
    0x8c, 0x86, 0xa8, 0xb9, 0xcc, 0xda, 0x28, 0xb0, 0x8f, 0x13, 0x01, 0x2d, 0xae, 0xd1, 0x99, 0xe4,
    0x3c, 0xc9, 0x8f, 0x20, 0x0d, 0x99, 0xc6, 0x3c, 0xa9, 0xc3, 0xea, 0xa6, 0x39, 0xf6, 0x76, 0xc9,
    0xe8, 0x5c, 0x4c, 0x45, 0xa4, 0xc4, 0x8f, 0x5e, 0xb8, 0xc1, 0x8f, 0xbd, 0x4c, 0x3e, 0x29, 0xd0,
    0x4e, 0x6f, 0x2d, 0x03, 0xcc, 0x5b, 0x8c, 0xe4, 0x9c, 0x33, 0x99, 0xc1, 0xd3, 0xb8, 0xc4, 0xb0,
    0x22, 0xc1, 0xd8, 0x9d, 0x25, 0x76, 0xe0, 0x54, 0x06, 0x1e, 0x09, 0x50, 0x00, 0xd3, 0x96, 0x05,
    0xc5, 0x1c, 0x68, 0x91, 0xe9, 0x09, 0xd5, 0x06, 0xda, 0x52, 0x8b, 0x9d, 0xd3, 0x93, 0x82, 0xa9,
    0xe1, 0x5b, 0x8d, 0xa1, 0xcd, 0x08, 0x22, 0x69, 0x60, 0x00, 0x7b, 0x1b, 0x6f, 0xb8, 0x18, 0x99,
    0xd5, 0xac, 0xa4, 0xa2, 0xf4, 0xd7, 0x72, 0xa7, 0x7f, 0x43, 0xa8, 0x11, 0xdc, 0x26, 0x35, 0xbf,
    0xfc, 0xb3, 0xa1, 0x45, 0x75, 0x5c, 0x8e, 0xd1, 0xc9, 0x2e, 0xa9, 0xc3, 0x39, 0x99, 0xcd, 0x42,
    0xa3, 0xc6, 0xfa, 0x01, 0x45, 0x35, 0x3b, 0x69
};
#endif

PyTypeObject *init_QDialogButtonBox(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX].type;

    Shiboken::AutoDecRef Sbk_QDialogButtonBox_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QDialogButtonBox_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDialogButtonBox",
        "QDialogButtonBox*",
        &Sbk_QDialogButtonBox_spec,
        &Shiboken::callCppDestructor< QDialogButtonBox >,
        Sbk_QDialogButtonBox_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QDialogButtonBox_TypeF(); // references _Sbk_QDialogButtonBox_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDialogButtonBox_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDialogButtonBox_SignatureBytes, QDialogButtonBox_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDialogButtonBox_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDialogButtonBox_PythonToCpp_QDialogButtonBox_PTR,
        is_QDialogButtonBox_PythonToCpp_QDialogButtonBox_PTR_Convertible,
        QDialogButtonBox_PTR_CppToPython_QDialogButtonBox);

    Shiboken::Conversions::registerConverterName(converter, "QDialogButtonBox");
    Shiboken::Conversions::registerConverterName(converter, "QDialogButtonBox*");
    Shiboken::Conversions::registerConverterName(converter, "QDialogButtonBox&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDialogButtonBox).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDialogButtonBoxWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QDialogButtonBox_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QDialogButtonBox_TypeF(), &Sbk_QDialogButtonBoxSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDialogButtonBox_TypeF(), &Sbk_QDialogButtonBox_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDialogButtonBox_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ButtonRole'.
    const char *ButtonRole_Initializer[] = {
        "InvalidRole",
        "AcceptRole",
        "RejectRole",
        "DestructiveRole",
        "ActionRole",
        "HelpRole",
        "YesRole",
        "NoRole",
        "ResetRole",
        "ApplyRole",
        "NRoles",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ButtonRole_InitializerValues[] = {
        int8_t(QDialogButtonBox::ButtonRole::InvalidRole),     // -0x01 -1
        int8_t(QDialogButtonBox::ButtonRole::AcceptRole),      //  0x00  0
        int8_t(QDialogButtonBox::ButtonRole::RejectRole),      //  0x01  1
        int8_t(QDialogButtonBox::ButtonRole::DestructiveRole), //  0x02  2
        int8_t(QDialogButtonBox::ButtonRole::ActionRole),      //  0x03  3
        int8_t(QDialogButtonBox::ButtonRole::HelpRole),        //  0x04  4
        int8_t(QDialogButtonBox::ButtonRole::YesRole),         //  0x05  5
        int8_t(QDialogButtonBox::ButtonRole::NoRole),          //  0x06  6
        int8_t(QDialogButtonBox::ButtonRole::ResetRole),       //  0x07  7
        int8_t(QDialogButtonBox::ButtonRole::ApplyRole),       //  0x08  8
        int8_t(QDialogButtonBox::ButtonRole::NRoles)           //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDialogButtonBox_TypeF(),
        "2:PySide6.QtWidgets.QDialogButtonBox.ButtonRole",
        ButtonRole_Initializer, ButtonRole_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonRole_IDX].type = EType;
    // Register converter for enum 'QDialogButtonBox::ButtonRole'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDialogButtonBox_ButtonRole_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDialogButtonBox_ButtonRole,
            is_Enum_PythonToCpp_QDialogButtonBox_ButtonRole_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDialogButtonBox::ButtonRole");
        Shiboken::Conversions::registerConverterAlias(converter, "ButtonRole");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ButtonRole' enum.

    // Initialization of enum 'StandardButton'.
    const char *StandardButton_Initializer[] = {
        "NoButton",
        "Ok",
        "Save",
        "SaveAll",
        "Open",
        "Yes",
        "YesToAll",
        "No",
        "NoToAll",
        "Abort",
        "Retry",
        "Ignore",
        "Close",
        "Cancel",
        "Discard",
        "Help",
        "Apply",
        "Reset",
        "RestoreDefaults",
        "FirstButton",
        "LastButton",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StandardButton_InitializerValues[] = {
        uint32_t(QDialogButtonBox::StandardButton::NoButton),        //  0x00000000  0
        uint32_t(QDialogButtonBox::StandardButton::Ok),              //  0x00000400  1024
        uint32_t(QDialogButtonBox::StandardButton::Save),            //  0x00000800  2048
        uint32_t(QDialogButtonBox::StandardButton::SaveAll),         //  0x00001000  4096
        uint32_t(QDialogButtonBox::StandardButton::Open),            //  0x00002000  8192
        uint32_t(QDialogButtonBox::StandardButton::Yes),             //  0x00004000  16384
        uint32_t(QDialogButtonBox::StandardButton::YesToAll),        //  0x00008000  32768
        uint32_t(QDialogButtonBox::StandardButton::No),              //  0x00010000  65536
        uint32_t(QDialogButtonBox::StandardButton::NoToAll),         //  0x00020000  131072
        uint32_t(QDialogButtonBox::StandardButton::Abort),           //  0x00040000  262144
        uint32_t(QDialogButtonBox::StandardButton::Retry),           //  0x00080000  524288
        uint32_t(QDialogButtonBox::StandardButton::Ignore),          //  0x00100000  1048576
        uint32_t(QDialogButtonBox::StandardButton::Close),           //  0x00200000  2097152
        uint32_t(QDialogButtonBox::StandardButton::Cancel),          //  0x00400000  4194304
        uint32_t(QDialogButtonBox::StandardButton::Discard),         //  0x00800000  8388608
        uint32_t(QDialogButtonBox::StandardButton::Help),            //  0x01000000  16777216
        uint32_t(QDialogButtonBox::StandardButton::Apply),           //  0x02000000  33554432
        uint32_t(QDialogButtonBox::StandardButton::Reset),           //  0x04000000  67108864
        uint32_t(QDialogButtonBox::StandardButton::RestoreDefaults), //  0x08000000  134217728
        uint32_t(QDialogButtonBox::StandardButton::FirstButton),     //  0x00000400  1024
        uint32_t(QDialogButtonBox::StandardButton::LastButton)       //  0x08000000  134217728
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDialogButtonBox_TypeF(),
        "2:PySide6.QtWidgets.QDialogButtonBox.StandardButton",
        StandardButton_Initializer, StandardButton_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_StandardButton_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QDialogButtonBox_StandardButton_IDX].type =
        EType;
    // Register converter for enum 'QDialogButtonBox::StandardButton'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDialogButtonBox_StandardButton_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDialogButtonBox_StandardButton,
            is_Enum_PythonToCpp_QDialogButtonBox_StandardButton_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDialogButtonBox::StandardButton");
        Shiboken::Conversions::registerConverterAlias(converter, "StandardButton");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDialogButtonBox_StandardButton_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDialogButtonBox_StandardButton,
            is_Enum_PythonToCpp_QDialogButtonBox_StandardButton_Convertible);
        // Register converter for flag 'QFlags<QDialogButtonBox::StandardButton>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDialogButtonBox::StandardButton>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDialogButtonBox::StandardButtons");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'StandardButton' enum/flags.

    // Initialization of enum 'ButtonLayout'.
    const char *ButtonLayout_Initializer[] = {
        "WinLayout",
        "MacLayout",
        "KdeLayout",
        "GnomeLayout",
        "AndroidLayout",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ButtonLayout_InitializerValues[] = {
        uint8_t(QDialogButtonBox::ButtonLayout::WinLayout),    //  0x00  0
        uint8_t(QDialogButtonBox::ButtonLayout::MacLayout),    //  0x01  1
        uint8_t(QDialogButtonBox::ButtonLayout::KdeLayout),    //  0x02  2
        uint8_t(QDialogButtonBox::ButtonLayout::GnomeLayout),  //  0x03  3
        uint8_t(QDialogButtonBox::ButtonLayout::AndroidLayout) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDialogButtonBox_TypeF(),
        "2:PySide6.QtWidgets.QDialogButtonBox.ButtonLayout",
        ButtonLayout_Initializer, ButtonLayout_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_ButtonLayout_IDX].type = EType;
    // Register converter for enum 'QDialogButtonBox::ButtonLayout'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDialogButtonBox_ButtonLayout_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDialogButtonBox_ButtonLayout,
            is_Enum_PythonToCpp_QDialogButtonBox_ButtonLayout_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDialogButtonBox::ButtonLayout");
        Shiboken::Conversions::registerConverterAlias(converter, "ButtonLayout");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ButtonLayout' enum.

    PySide::Signal::registerSignals(pyType, &::QDialogButtonBox::staticMetaObject);
    qRegisterMetaType< ::QDialogButtonBox::ButtonRole >("QDialogButtonBox::ButtonRole");
    qRegisterMetaType< ::QDialogButtonBox::StandardButton >("QDialogButtonBox::StandardButton");
    qRegisterMetaType< ::QDialogButtonBox::ButtonLayout >("QDialogButtonBox::ButtonLayout");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDialogButtonBox::staticMetaObject, sizeof(QDialogButtonBoxWrapper));

    return pyType;
}
