// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicsanchor_wrapper.h"

// Wrappers providing overrides
#include "qwidget_wrapper.h"

// Argument includes
#include <QtWidgets/qsizepolicy.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsAnchorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QGraphicsAnchorWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QGraphicsAnchor", funcName, gil, pyOverride, event);
}

void QGraphicsAnchorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QGraphicsAnchor", funcName, gil, pyOverride, signal);
}

void QGraphicsAnchorWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QGraphicsAnchor", funcName, gil, pyOverride, event);
}

void QGraphicsAnchorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QGraphicsAnchor", funcName, gil, pyOverride, signal);
}

bool QGraphicsAnchorWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QGraphicsAnchor", funcName, gil, pyOverride, event);
}

bool QGraphicsAnchorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QGraphicsAnchor", funcName, gil, pyOverride, watched, event);
}

void QGraphicsAnchorWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QGraphicsAnchor", funcName, gil, pyOverride, event);
}

const QMetaObject *QGraphicsAnchorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGraphicsAnchor::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGraphicsAnchorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGraphicsAnchor::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGraphicsAnchorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGraphicsAnchorWrapper *>(this));
    return QGraphicsAnchor::qt_metacast(_clname);
}

QGraphicsAnchorWrapper::~QGraphicsAnchorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QGraphicsAnchor_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QGraphicsAnchor");
    return -1;
}

static PyObject *Sbk_QGraphicsAnchorFunc_setSizePolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsAnchor::setSizePolicy(QSizePolicy::Policy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSizePolicy(QSizePolicy::Policy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSizePolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]);

    // Call function/method
    {
        ::QSizePolicy::Policy cppArg0{QSizePolicy::Fixed};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSizePolicy(QSizePolicy::Policy)
            cppSelf->setSizePolicy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorFunc_setSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsAnchor::setSpacing(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpacing", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpacing(qreal)
            cppSelf->setSpacing(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorFunc_sizePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizePolicy()const
        QSizePolicy::Policy cppResult = const_cast<const ::QGraphicsAnchor *>(cppSelf)->sizePolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorFunc_spacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // spacing()const
        qreal cppResult = const_cast<const ::QGraphicsAnchor *>(cppSelf)->spacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorFunc_unsetSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetSpacing()
        cppSelf->unsetSpacing();
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QGraphicsAnchor_PropertyStrings[] = {
    "sizePolicy::",
    "spacing::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsAnchor_methods[] = {
    {"setSizePolicy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorFunc_setSizePolicy), METH_O, nullptr},
    {"setSpacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorFunc_setSpacing), METH_O, nullptr},
    {"sizePolicy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorFunc_sizePolicy), METH_NOARGS, nullptr},
    {"spacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorFunc_spacing), METH_NOARGS, nullptr},
    {"unsetSpacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorFunc_unsetSpacing), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsAnchor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsAnchor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsAnchorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsAnchor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsAnchor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsAnchor_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsAnchor_TypeF(void)
{
    return _Sbk_QGraphicsAnchor_Type;
}

static PyType_Slot Sbk_QGraphicsAnchor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsAnchor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsAnchor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsAnchor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsAnchor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsAnchor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsAnchor_spec = {
    "2:PySide6.QtWidgets.QGraphicsAnchor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsAnchor_slots
};

} //extern "C"

static void *Sbk_QGraphicsAnchor_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGraphicsAnchor *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsAnchor_PythonToCpp_QGraphicsAnchor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsAnchor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsAnchor_PythonToCpp_QGraphicsAnchor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsAnchor_TypeF()))
        return QGraphicsAnchor_PythonToCpp_QGraphicsAnchor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsAnchor_PTR_CppToPython_QGraphicsAnchor(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGraphicsAnchor *>(const_cast<void *>(cppIn)), Sbk_QGraphicsAnchor_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsAnchor_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsAnchor.setSizePolicy(self,policy:PySide6.QtWidgets.QSizePolicy.Policy)",
    "PySide6.QtWidgets.QGraphicsAnchor.setSpacing(self,spacing:qreal)",
    "PySide6.QtWidgets.QGraphicsAnchor.sizePolicy(self)->PySide6.QtWidgets.QSizePolicy.Policy",
    "PySide6.QtWidgets.QGraphicsAnchor.spacing(self)->qreal",
    "PySide6.QtWidgets.QGraphicsAnchor.unsetSpacing(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsAnchor_SignatureByteSize = 123;
static constexpr uint8_t QGraphicsAnchor_SignatureBytes[123] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf, 0x4c, 0x49,
    0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x74, 0x2f, 0x4a, 0x2c, 0xc8, 0xc8, 0x4c, 0x2e, 0x76, 0xcc, 0x4b,
    0xce, 0xc8, 0x2f, 0xd2, 0x2b, 0x4e, 0x2d, 0x09, 0xce, 0xac, 0x4a, 0x0d, 0xc8, 0xcf, 0xc9, 0x4c,
    0xae, 0xd4, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x00, 0xb3, 0xad, 0x02, 0x30, 0xf5, 0x22, 0x54,
    0xea, 0x41, 0x28, 0x4d, 0xae, 0x00, 0xa2, 0x6c, 0x28, 0x48, 0x4c, 0xce, 0xcc, 0x4b, 0x87, 0x18,
    0x5f, 0x0c, 0xe1, 0x58, 0x15, 0x16, 0xa5, 0x26, 0xe6, 0x10, 0x65, 0x00, 0xaa, 0xfb, 0x34, 0x75,
    0xed, 0x88, 0x71, 0x1a, 0x31, 0x06, 0x23, 0x39, 0x0b, 0x68, 0x2a, 0xd8, 0x41, 0x44, 0x68, 0x2b,
    0xcd, 0x43, 0xf3, 0x92, 0x26, 0x17, 0x00, 0xc3, 0x05, 0x84, 0x56
};
#endif

PyTypeObject *init_QGraphicsAnchor(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsAnchor_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QGraphicsAnchor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsAnchor",
        "QGraphicsAnchor*",
        &Sbk_QGraphicsAnchor_spec,
        &Shiboken::callCppDestructor< QGraphicsAnchor >,
        Sbk_QGraphicsAnchor_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsAnchor_TypeF(); // references _Sbk_QGraphicsAnchor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsAnchor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsAnchor_SignatureBytes, QGraphicsAnchor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsAnchor_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsAnchor_PythonToCpp_QGraphicsAnchor_PTR,
        is_QGraphicsAnchor_PythonToCpp_QGraphicsAnchor_PTR_Convertible,
        QGraphicsAnchor_PTR_CppToPython_QGraphicsAnchor);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsAnchor");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsAnchor*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsAnchor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsAnchor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsAnchorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsAnchor_TypeF(), &Sbk_QGraphicsAnchor_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGraphicsAnchor::staticMetaObject, sizeof(QGraphicsAnchorWrapper));

    return pyType;
}
