// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicsanchorlayout_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qgraphicslayoutitem_wrapper.h"
#include "qgraphicslinearlayout_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QtWidgets/qgraphicsanchorlayout.h>
#include <QtWidgets/qgraphicslayoutitem.h>
#include <qcoreevent.h>
#include <qnamespace.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsAnchorLayoutWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsAnchorLayoutWrapper::QGraphicsAnchorLayoutWrapper(::QGraphicsLayoutItem * parent) : QGraphicsAnchorLayout(parent)
{
}

int QGraphicsAnchorLayoutWrapper::count() const
{
    static const char *funcName = "count";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsAnchorLayout::count();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QGraphicsAnchorLayout", funcName, gil, pyOverride);
}

void QGraphicsAnchorLayoutWrapper::getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const
{
    static const char *funcName = "getContentsMargins";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayout::getContentsMargins(left, top, right, bottom);
    }
    QGraphicsLayoutWrapper::sbk_o_getContentsMargins("QGraphicsAnchorLayout", funcName, gil, pyOverride, left, top, right, bottom);
}

void QGraphicsAnchorLayoutWrapper::invalidate()
{
    static const char *funcName = "invalidate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsAnchorLayout::invalidate();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QGraphicsAnchorLayout", funcName, gil, pyOverride);
}

bool QGraphicsAnchorLayoutWrapper::isEmpty() const
{
    static const char *funcName = "isEmpty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayoutItem::isEmpty();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QGraphicsAnchorLayout", funcName, gil, pyOverride);
}

::QGraphicsLayoutItem * QGraphicsAnchorLayoutWrapper::itemAt(int index) const
{
    static const char *funcName = "itemAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsAnchorLayout::itemAt(index);
    }
    return QGraphicsLayoutWrapper::sbk_o_itemAt("QGraphicsAnchorLayout", funcName, gil, pyOverride, index);
}

void QGraphicsAnchorLayoutWrapper::removeAt(int index)
{
    static const char *funcName = "removeAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsAnchorLayout::removeAt(index);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QGraphicsAnchorLayout", funcName, gil, pyOverride, index);
}

void QGraphicsAnchorLayoutWrapper::setGeometry(const ::QRectF & rect)
{
    static const char *funcName = "setGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsAnchorLayout::setGeometry(rect);
    }
    QGraphicsLayoutItemWrapper::sbk_o_setGeometry("QGraphicsAnchorLayout", funcName, gil, pyOverride, rect);
}

::QSizeF QGraphicsAnchorLayoutWrapper::sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint) const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsAnchorLayout::sizeHint(which, constraint);
    }
    return QGraphicsLayoutItemWrapper::sbk_o_sizeHint("QGraphicsAnchorLayout", funcName, gil, pyOverride, which, constraint);
}

void QGraphicsAnchorLayoutWrapper::updateGeometry()
{
    static const char *funcName = "updateGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayout::updateGeometry();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QGraphicsAnchorLayout", funcName, gil, pyOverride);
}

void QGraphicsAnchorLayoutWrapper::widgetEvent(::QEvent * e)
{
    static const char *funcName = "widgetEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayout::widgetEvent(e);
    }
    QGraphicsLinearLayoutWrapper::sbk_o_widgetEvent("QGraphicsAnchorLayout", funcName, gil, pyOverride, e);
}

QGraphicsAnchorLayoutWrapper::~QGraphicsAnchorLayoutWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsAnchorLayout_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsAnchorLayout >()))
        return -1;

    QGraphicsAnchorLayoutWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    if (PyArg_ParseTuple(args, "|O:QGraphicsAnchorLayout", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::QGraphicsAnchorLayout(QGraphicsLayoutItem*=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsAnchorLayout(QGraphicsLayoutItem*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGraphicsAnchorLayout(QGraphicsLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QGraphicsLayoutItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphicsAnchorLayout(QGraphicsLayoutItem*)
            cptr = new QGraphicsAnchorLayoutWrapper(cppArg0);
            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsAnchorLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_addAnchor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addAnchor", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::addAnchor(QGraphicsLayoutItem*,Qt::AnchorPoint,QGraphicsLayoutItem*,Qt::AnchorPoint)->QGraphicsAnchor*
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AnchorPoint_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AnchorPoint_IDX])))->converter, (pyArgs[3])))) {
        overloadId = 0; // addAnchor(QGraphicsLayoutItem*,Qt::AnchorPoint,QGraphicsLayoutItem*,Qt::AnchorPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addAnchor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsLayoutItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::AnchorPoint cppArg1{Qt::AnchorLeft};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QGraphicsLayoutItem *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::Qt::AnchorPoint cppArg3{Qt::AnchorLeft};
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAnchor(QGraphicsLayoutItem*,Qt::AnchorPoint,QGraphicsLayoutItem*,Qt::AnchorPoint)
            QGraphicsAnchor * cppResult = cppSelf->addAnchor(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_addAnchors(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addAnchors", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:addAnchors", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::addAnchors(QGraphicsLayoutItem*,QGraphicsLayoutItem*,QFlags<Qt::Orientation>=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // addAnchors(QGraphicsLayoutItem*,QGraphicsLayoutItem*,QFlags<Qt::Orientation>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_Orientation_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 0; // addAnchors(QGraphicsLayoutItem*,QGraphicsLayoutItem*,QFlags<Qt::Orientation>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addAnchors", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"orientations", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_Orientation_IDX])))->flagsConverter, (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addAnchors", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsLayoutItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGraphicsLayoutItem *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<Qt::Orientation> cppArg2(Qt::Horizontal | Qt::Vertical);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAnchors(QGraphicsLayoutItem*,QGraphicsLayoutItem*,QFlags<Qt::Orientation>)
            cppSelf->addAnchors(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_addCornerAnchors(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addCornerAnchors", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::addCornerAnchors(QGraphicsLayoutItem*,Qt::Corner,QGraphicsLayoutItem*,Qt::Corner)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Corner_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Corner_IDX])))->converter, (pyArgs[3])))) {
        overloadId = 0; // addCornerAnchors(QGraphicsLayoutItem*,Qt::Corner,QGraphicsLayoutItem*,Qt::Corner)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addCornerAnchors", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsLayoutItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::Corner cppArg1{Qt::TopLeftCorner};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QGraphicsLayoutItem *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::Qt::Corner cppArg3{Qt::TopLeftCorner};
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addCornerAnchors(QGraphicsLayoutItem*,Qt::Corner,QGraphicsLayoutItem*,Qt::Corner)
            cppSelf->addCornerAnchors(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_anchor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "anchor", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::anchor(QGraphicsLayoutItem*,Qt::AnchorPoint,QGraphicsLayoutItem*,Qt::AnchorPoint)->QGraphicsAnchor*
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AnchorPoint_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AnchorPoint_IDX])))->converter, (pyArgs[3])))) {
        overloadId = 0; // anchor(QGraphicsLayoutItem*,Qt::AnchorPoint,QGraphicsLayoutItem*,Qt::AnchorPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "anchor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsLayoutItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::AnchorPoint cppArg1{Qt::AnchorLeft};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QGraphicsLayoutItem *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::Qt::AnchorPoint cppArg3{Qt::AnchorLeft};
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // anchor(QGraphicsLayoutItem*,Qt::AnchorPoint,QGraphicsLayoutItem*,Qt::AnchorPoint)
            QGraphicsAnchor * cppResult = cppSelf->anchor(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->::QGraphicsAnchorLayout::count()
            : const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_horizontalSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // horizontalSpacing()const
        qreal cppResult = const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->horizontalSpacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_invalidate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidate()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphicsAnchorLayout::invalidate()
            : cppSelf->invalidate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_itemAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayout::itemAt(int)const->QGraphicsLayoutItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // itemAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemAt(int)const
            QGraphicsLayoutItem * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->::QGraphicsAnchorLayout::itemAt(cppArg0)
                : const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->itemAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayout::removeAt(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // removeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsAnchorLayout::removeAt(cppArg0)
                : cppSelf->removeAt(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_setGeometry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setGeometry(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // setGeometry(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeometry", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGeometry(QRectF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsAnchorLayout::setGeometry(*cppArg0)
                : cppSelf->setGeometry(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_setHorizontalSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::setHorizontalSpacing(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setHorizontalSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHorizontalSpacing", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHorizontalSpacing(qreal)
            cppSelf->setHorizontalSpacing(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_setSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::setSpacing(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpacing", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpacing(qreal)
            cppSelf->setSpacing(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_setVerticalSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsAnchorLayout::setVerticalSpacing(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setVerticalSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVerticalSpacing", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVerticalSpacing(qreal)
            cppSelf->setVerticalSpacing(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_sizeHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    if (PyArg_ParseTuple(args, "|OO:sizeHint", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::sizeHint(Qt::SizeHint,const QSizeF&=)const->QSizeF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1])))) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"constraint", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);
            }
        }
        ::Qt::SizeHint cppArg0{Qt::MinimumSize};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSizeF cppArg1_local = QSizeF();
        ::QSizeF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeHint(Qt::SizeHint,QSizeF)const
            QSizeF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->::QGraphicsAnchorLayout::sizeHint(cppArg0, *cppArg1)
                : const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->sizeHint(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsAnchorLayoutFunc_verticalSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // verticalSpacing()const
        qreal cppResult = const_cast<const ::QGraphicsAnchorLayout *>(cppSelf)->verticalSpacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QGraphicsAnchorLayout_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsAnchorLayout_methods[] = {
    {"addAnchor", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_addAnchor), METH_VARARGS, nullptr},
    {"addAnchors", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_addAnchors), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addCornerAnchors", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_addCornerAnchors), METH_VARARGS, nullptr},
    {"anchor", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_anchor), METH_VARARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_count), METH_NOARGS, nullptr},
    {"horizontalSpacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_horizontalSpacing), METH_NOARGS, nullptr},
    {"invalidate", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_invalidate), METH_NOARGS, nullptr},
    {"itemAt", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_itemAt), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_removeAt), METH_O, nullptr},
    {"setGeometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_setGeometry), METH_O, nullptr},
    {"setHorizontalSpacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_setHorizontalSpacing), METH_O, nullptr},
    {"setSpacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_setSpacing), METH_O, nullptr},
    {"setVerticalSpacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_setVerticalSpacing), METH_O, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_sizeHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"verticalSpacing", reinterpret_cast<PyCFunction>(Sbk_QGraphicsAnchorLayoutFunc_verticalSpacing), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsAnchorLayout_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsAnchorLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsAnchorLayoutWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsAnchorLayout_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsAnchorLayout_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsAnchorLayout_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsAnchorLayout_TypeF(void)
{
    return _Sbk_QGraphicsAnchorLayout_Type;
}

static PyType_Slot Sbk_QGraphicsAnchorLayout_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsAnchorLayout_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsAnchorLayout_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsAnchorLayout_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsAnchorLayout_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsAnchorLayout_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsAnchorLayout_spec = {
    "2:PySide6.QtWidgets.QGraphicsAnchorLayout",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsAnchorLayout_slots
};

} //extern "C"

static void *Sbk_QGraphicsAnchorLayout_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QGraphicsLayoutItem >())
        return dynamic_cast< ::QGraphicsAnchorLayout *>(reinterpret_cast< ::QGraphicsLayoutItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsAnchorLayout_PythonToCpp_QGraphicsAnchorLayout_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsAnchorLayout_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsAnchorLayout_PythonToCpp_QGraphicsAnchorLayout_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsAnchorLayout_TypeF()))
        return QGraphicsAnchorLayout_PythonToCpp_QGraphicsAnchorLayout_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsAnchorLayout_PTR_CppToPython_QGraphicsAnchorLayout(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QGraphicsAnchorLayout *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QGraphicsAnchorLayout_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsAnchorLayout_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsAnchorLayout(self,parent:PySide6.QtWidgets.QGraphicsLayoutItem=nullptr)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.addAnchor(self,firstItem:PySide6.QtWidgets.QGraphicsLayoutItem,firstEdge:PySide6.QtCore.Qt.AnchorPoint,secondItem:PySide6.QtWidgets.QGraphicsLayoutItem,secondEdge:PySide6.QtCore.Qt.AnchorPoint)->PySide6.QtWidgets.QGraphicsAnchor",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.addAnchors(self,firstItem:PySide6.QtWidgets.QGraphicsLayoutItem,secondItem:PySide6.QtWidgets.QGraphicsLayoutItem,orientations:PySide6.QtCore.Qt.Orientation=Qt.Horizontal | Qt.Vertical)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.addCornerAnchors(self,firstItem:PySide6.QtWidgets.QGraphicsLayoutItem,firstCorner:PySide6.QtCore.Qt.Corner,secondItem:PySide6.QtWidgets.QGraphicsLayoutItem,secondCorner:PySide6.QtCore.Qt.Corner)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.anchor(self,firstItem:PySide6.QtWidgets.QGraphicsLayoutItem,firstEdge:PySide6.QtCore.Qt.AnchorPoint,secondItem:PySide6.QtWidgets.QGraphicsLayoutItem,secondEdge:PySide6.QtCore.Qt.AnchorPoint)->PySide6.QtWidgets.QGraphicsAnchor",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.count(self)->int",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.horizontalSpacing(self)->qreal",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.invalidate(self)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.itemAt(self,index:int)->PySide6.QtWidgets.QGraphicsLayoutItem",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.removeAt(self,index:int)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.setGeometry(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.setHorizontalSpacing(self,spacing:qreal)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.setSpacing(self,spacing:qreal)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.setVerticalSpacing(self,spacing:qreal)",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.sizeHint(self,which:PySide6.QtCore.Qt.SizeHint,constraint:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize]=QSizeF())->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsAnchorLayout.verticalSpacing(self)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsAnchorLayout_SignatureByteSize = 383;
static constexpr uint8_t QGraphicsAnchorLayout_SignatureBytes[383] = {
    0x78, 0xda, 0xed, 0x54, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0xbd, 0xf3, 0x2b, 0x76, 0xdc, 0xa4, 0xd2,
    0x23, 0x87, 0x4a, 0x43, 0x9a, 0x10, 0x6c, 0x48, 0x48, 0x74, 0x4c, 0xc0, 0x01, 0xed, 0x10, 0x35,
    0xde, 0x1a, 0xa9, 0x4b, 0x4a, 0xe2, 0x0d, 0x3a, 0xf1, 0xe3, 0xf1, 0x96, 0xee, 0x0b, 0x02, 0x4d,
    0xc6, 0x8e, 0x9c, 0x5a, 0xc7, 0xf6, 0x73, 0xfc, 0x9e, 0x9d, 0xb4, 0x1a, 0x09, 0x0e, 0x17, 0xf1,
    0x10, 0x9f, 0x05, 0x9f, 0x02, 0x9a, 0x78, 0xd8, 0xd7, 0xac, 0xcc, 0x45, 0x66, 0x7a, 0x32, 0xcb,
    0x95, 0xbe, 0x63, 0x95, 0x9a, 0x63, 0xdb, 0x40, 0x31, 0x89, 0x4a, 0xa6, 0x41, 0x62, 0x92, 0xfe,
    0x9c, 0x63, 0xa3, 0x6f, 0x11, 0x66, 0x5d, 0x39, 0x2f, 0x8a, 0x12, 0x75, 0xe7, 0x2c, 0xf5, 0x2b,
    0x11, 0x33, 0xce, 0xad, 0x6d, 0x8b, 0x4d, 0x84, 0x36, 0x6b, 0x24, 0xbf, 0x7a, 0x36, 0xfe, 0x9a,
    0xfc, 0x7b, 0xf1, 0x57, 0x4a, 0x03, 0x7d, 0x62, 0x8b, 0x9b, 0x2a, 0x21, 0x31, 0x32, 0x90, 0x29,
    0xc9, 0x03, 0x80, 0x6d, 0x42, 0x33, 0x72, 0xe7, 0xfc, 0xb2, 0xb1, 0xd5, 0x70, 0x32, 0xcc, 0x71,
    0x6c, 0x04, 0x77, 0xa9, 0xb4, 0x20, 0x6d, 0x19, 0x0a, 0x25, 0x8d, 0xa3, 0xcf, 0xfb, 0x9d, 0xbb,
    0x4b, 0xe6, 0x80, 0xc2, 0x97, 0x8a, 0x0e, 0x8a, 0xd6, 0x47, 0x8b, 0xec, 0x27, 0xd0, 0x28, 0x32,
    0x56, 0x04, 0xa9, 0x4d, 0xd8, 0x12, 0xf4, 0x9f, 0xda, 0x5c, 0xc7, 0x5b, 0x1c, 0xc7, 0xa5, 0xad,
    0xe3, 0x58, 0xc5, 0x1b, 0x60, 0x03, 0x5a, 0xfd, 0x9f, 0xea, 0x9a, 0x89, 0x4c, 0xcd, 0xa5, 0x7d,
    0x4b, 0x08, 0x96, 0xc0, 0xbd, 0x13, 0xf3, 0xed, 0xbc, 0x8d, 0x4a, 0x96, 0x09, 0x39, 0xdd, 0x80,
    0xbc, 0x6a, 0x60, 0x85, 0x37, 0x8c, 0x90, 0x0b, 0x56, 0x08, 0xce, 0x10, 0x6c, 0xbe, 0x7f, 0x22,
    0x51, 0xd6, 0xab, 0x5f, 0x41, 0x21, 0x39, 0xbc, 0x27, 0x8d, 0xd4, 0xec, 0xb8, 0xf6, 0xae, 0xa2,
    0x61, 0xa6, 0x16, 0xf0, 0xbd, 0x8e, 0x37, 0x80, 0x01, 0xec, 0x83, 0x9a, 0x01, 0xea, 0xca, 0x62,
    0x68, 0xc8, 0x30, 0xc1, 0xaa, 0x24, 0xc6, 0xe2, 0x47, 0x49, 0xcb, 0xfb, 0xf2, 0x55, 0xec, 0x07,
    0x8a, 0xb8, 0x89, 0x5a, 0xae, 0xe3, 0x71, 0x50, 0xe1, 0x81, 0x53, 0xa2, 0xc8, 0x58, 0x23, 0x59,
    0x0b, 0x15, 0x04, 0x78, 0x22, 0x98, 0xcd, 0xd3, 0x74, 0x12, 0x38, 0xb1, 0x84, 0x81, 0xa8, 0x47,
    0x38, 0x7a, 0x23, 0x7f, 0xee, 0xd8, 0x9e, 0x51, 0x1d, 0x15, 0xd1, 0x86, 0x19, 0xd4, 0x8c, 0x7e,
    0x7f, 0xd7, 0x60, 0x95, 0xe0, 0xd0, 0x60, 0x75, 0x3c, 0xee, 0x5a, 0x6f, 0xbb, 0x73, 0x30, 0x6d,
    0x7b, 0x79, 0xde, 0x97, 0x5f, 0x38, 0x88, 0xd8, 0x6e, 0xd0, 0x27, 0x23, 0x0e, 0xf8, 0xf1
};
#endif

PyTypeObject *init_QGraphicsAnchorLayout(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsAnchorLayout_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]))));

    _Sbk_QGraphicsAnchorLayout_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsAnchorLayout",
        "QGraphicsAnchorLayout*",
        &Sbk_QGraphicsAnchorLayout_spec,
        &Shiboken::callCppDestructor< QGraphicsAnchorLayout >,
        Sbk_QGraphicsAnchorLayout_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsAnchorLayout_TypeF(); // references _Sbk_QGraphicsAnchorLayout_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsAnchorLayout_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsAnchorLayout_SignatureBytes, QGraphicsAnchorLayout_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsAnchorLayout_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsAnchorLayout_PythonToCpp_QGraphicsAnchorLayout_PTR,
        is_QGraphicsAnchorLayout_PythonToCpp_QGraphicsAnchorLayout_PTR_Convertible,
        QGraphicsAnchorLayout_PTR_CppToPython_QGraphicsAnchorLayout);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsAnchorLayout");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsAnchorLayout*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsAnchorLayout&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsAnchorLayout).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsAnchorLayoutWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsAnchorLayout_TypeF(), &Sbk_QGraphicsAnchorLayout_typeDiscovery);


    return pyType;
}
