// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGRAPHICSEFFECTWRAPPER_H
#define SBK_QGRAPHICSEFFECTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qgraphicseffect.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QGraphicsEffectWrapper : public QGraphicsEffect
{
public:
    QGraphicsEffectWrapper(::QObject * parent = nullptr);
    QGraphicsEffectWrapper(const QGraphicsEffectWrapper &) = delete;
    QGraphicsEffectWrapper& operator=(const QGraphicsEffectWrapper &) = delete;
    QGraphicsEffectWrapper(QGraphicsEffectWrapper &&) = delete;
    QGraphicsEffectWrapper& operator=(QGraphicsEffectWrapper &&) = delete;
    ~QGraphicsEffectWrapper() override;

    ::QRectF boundingRectFor(const ::QRectF & sourceRect) const override;
    static ::QRectF sbk_o_boundingRectFor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & sourceRect);
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void draw(::QPainter * painter) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void sourceChanged(::QFlags<QGraphicsEffect::ChangeFlag> flags) override;
    static void sbk_o_sourceChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QGraphicsEffect::ChangeFlag> flags);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[10] = {false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QGRAPHICSEFFECTWRAPPER_H
