// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicslayout_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qgraphicslayoutitem_wrapper.h"

// Argument includes
#include <QtWidgets/qgraphicslayoutitem.h>
#include <qcoreevent.h>
#include <qnamespace.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsLayoutWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsLayoutWrapper::QGraphicsLayoutWrapper(::QGraphicsLayoutItem * parent) : QGraphicsLayout(parent)
{
}

int QGraphicsLayoutWrapper::count() const
{
    static const char *funcName = "count";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayout.count");
        return 0;
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QGraphicsLayout", funcName, gil, pyOverride);
}

void QGraphicsLayoutWrapper::getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const
{
    static const char *funcName = "getContentsMargins";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayout::getContentsMargins(left, top, right, bottom);
    }
    sbk_o_getContentsMargins("QGraphicsLayout", funcName, gil, pyOverride, left, top, right, bottom);
}

void QGraphicsLayoutWrapper::sbk_o_getContentsMargins(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qreal * left, qreal * top, qreal * right, qreal * bottom)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }

    // Begin code injection
    // TEMPLATE - fix_native_return_number*,number*,number*,number* - START
    PyObject *obj = pyResult.object();
    bool ok = false;
    if (PySequence_Check(obj) != 0 && PySequence_Size(obj) == 4) {
        Shiboken::AutoDecRef m0(PySequence_GetItem(obj, 0));
        Shiboken::AutoDecRef m1(PySequence_GetItem(obj, 1));
        Shiboken::AutoDecRef m2(PySequence_GetItem(obj, 2));
        Shiboken::AutoDecRef m3(PySequence_GetItem(obj, 3));
        ok = PyNumber_Check(m0) != 0 && PyNumber_Check(m1) != 0
             && PyNumber_Check(m2) && PyNumber_Check(m3) != 0;
        if (ok) {
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), m0, (left));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), m1, (top));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), m2, (right));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), m3, (bottom));
        }
    }
    if (!ok) {
        PyErr_SetString(PyExc_TypeError, "Sequence of 4 numbers expected");
        left = top = right = bottom = 0;
    }
    // TEMPLATE - fix_native_return_number*,number*,number*,number* - END
    // End of code injection

}

void QGraphicsLayoutWrapper::invalidate()
{
    static const char *funcName = "invalidate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayout::invalidate();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QGraphicsLayout", funcName, gil, pyOverride);
}

bool QGraphicsLayoutWrapper::isEmpty() const
{
    static const char *funcName = "isEmpty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayoutItem::isEmpty();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QGraphicsLayout", funcName, gil, pyOverride);
}

::QGraphicsLayoutItem * QGraphicsLayoutWrapper::itemAt(int i) const
{
    static const char *funcName = "itemAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayout.itemAt");
        return nullptr;
    }
    return sbk_o_itemAt("QGraphicsLayout", funcName, gil, pyOverride, i);
}

::QGraphicsLayoutItem * QGraphicsLayoutWrapper::sbk_o_itemAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int i)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &i)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        i
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QGraphicsLayoutItem >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QGraphicsLayoutItem *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsLayoutWrapper::removeAt(int index)
{
    static const char *funcName = "removeAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayout.removeAt");
        return;
    }
    sbk_o_removeAt("QGraphicsLayout", funcName, gil, pyOverride, index);
}

void QGraphicsLayoutWrapper::sbk_o_removeAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        index
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsLayoutWrapper::setGeometry(const ::QRectF & rect)
{
    static const char *funcName = "setGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayoutItem::setGeometry(rect);
    }
    QGraphicsLayoutItemWrapper::sbk_o_setGeometry("QGraphicsLayout", funcName, gil, pyOverride, rect);
}

::QSizeF QGraphicsLayoutWrapper::sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint) const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayout.sizeHint");
        return {};
    }
    return QGraphicsLayoutItemWrapper::sbk_o_sizeHint("QGraphicsLayout", funcName, gil, pyOverride, which, constraint);
}

void QGraphicsLayoutWrapper::updateGeometry()
{
    static const char *funcName = "updateGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayout::updateGeometry();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QGraphicsLayout", funcName, gil, pyOverride);
}

void QGraphicsLayoutWrapper::widgetEvent(::QEvent * e)
{
    static const char *funcName = "widgetEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayout::widgetEvent(e);
    }
    sbk_o_widgetEvent("QGraphicsLayout", funcName, gil, pyOverride, e);
}

void QGraphicsLayoutWrapper::sbk_o_widgetEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * e)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

QGraphicsLayoutWrapper::~QGraphicsLayoutWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsLayout_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QGraphicsLayout");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsLayout >()))
        return -1;

    QGraphicsLayoutWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    if (PyArg_ParseTuple(args, "|O:QGraphicsLayout", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsLayout::QGraphicsLayout(QGraphicsLayoutItem*=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsLayout(QGraphicsLayoutItem*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGraphicsLayout(QGraphicsLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QGraphicsLayoutItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphicsLayout(QGraphicsLayoutItem*)
            cptr = new QGraphicsLayoutWrapper(cppArg0);
            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphicsLayoutFunc_activate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activate()
        cppSelf->activate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsLayoutFunc_addChildLayoutItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayout::addChildLayoutItem(QGraphicsLayoutItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArg)))) {
        overloadId = 0; // addChildLayoutItem(QGraphicsLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addChildLayoutItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsLayoutItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addChildLayoutItem(QGraphicsLayoutItem*)
            cppSelf->addChildLayoutItem(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsLayoutFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayout.count");
            return {};
        }
        int cppResult = const_cast<const ::QGraphicsLayout *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsLayoutFunc_getContentsMargins(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getContentsMargins(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            qreal a, b, c, d;
            cppSelf->::QGraphicsLayout::getContentsMargins(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsLayoutFunc_instantInvalidatePropagation(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // instantInvalidatePropagation()
        bool cppResult = ::QGraphicsLayout::instantInvalidatePropagation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsLayoutFunc_invalidate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidate()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphicsLayout::invalidate()
            : cppSelf->invalidate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsLayoutFunc_isActivated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActivated()const
        bool cppResult = const_cast<const ::QGraphicsLayout *>(cppSelf)->isActivated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsLayoutFunc_itemAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayout::itemAt(int)const->QGraphicsLayoutItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // itemAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemAt(int)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayout.itemAt");
                return {};
            }
            QGraphicsLayoutItem * cppResult = const_cast<const ::QGraphicsLayout *>(cppSelf)->itemAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsLayoutFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayout::removeAt(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // removeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(int)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayout.removeAt");
                return {};
            }
            cppSelf->removeAt(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsLayoutFunc_setContentsMargins(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setContentsMargins", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayout::setContentsMargins(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 0; // setContentsMargins(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContentsMargins", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        qreal cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        qreal cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContentsMargins(qreal,qreal,qreal,qreal)
            cppSelf->setContentsMargins(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsLayoutFunc_setInstantInvalidatePropagation(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGraphicsLayout::setInstantInvalidatePropagation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInstantInvalidatePropagation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInstantInvalidatePropagation", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInstantInvalidatePropagation(bool)
            ::QGraphicsLayout::setInstantInvalidatePropagation(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsLayoutFunc_updateGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateGeometry()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphicsLayout::updateGeometry()
            : cppSelf->updateGeometry();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsLayoutFunc_widgetEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayout::widgetEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // widgetEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "widgetEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // widgetEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsLayout::widgetEvent(cppArg0)
                : cppSelf->widgetEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QGraphicsLayout_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsLayout_methods[] = {
    {"activate", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_activate), METH_NOARGS, nullptr},
    {"addChildLayoutItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_addChildLayoutItem), METH_O, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_count), METH_NOARGS, nullptr},
    {"getContentsMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_getContentsMargins), METH_NOARGS, nullptr},
    {"instantInvalidatePropagation", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_instantInvalidatePropagation), METH_NOARGS|METH_STATIC, nullptr},
    {"invalidate", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_invalidate), METH_NOARGS, nullptr},
    {"isActivated", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_isActivated), METH_NOARGS, nullptr},
    {"itemAt", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_itemAt), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_removeAt), METH_O, nullptr},
    {"setContentsMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_setContentsMargins), METH_VARARGS, nullptr},
    {"setInstantInvalidatePropagation", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_setInstantInvalidatePropagation), METH_O|METH_STATIC, nullptr},
    {"updateGeometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_updateGeometry), METH_NOARGS, nullptr},
    {"widgetEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutFunc_widgetEvent), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsLayout_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsLayoutWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsLayout_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsLayout_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsLayout_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsLayout_TypeF(void)
{
    return _Sbk_QGraphicsLayout_Type;
}

static PyType_Slot Sbk_QGraphicsLayout_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsLayout_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsLayout_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsLayout_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsLayout_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsLayout_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsLayout_spec = {
    "2:PySide6.QtWidgets.QGraphicsLayout",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsLayout_slots
};

} //extern "C"

static void *Sbk_QGraphicsLayout_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QGraphicsLayoutItem >())
        return dynamic_cast< ::QGraphicsLayout *>(reinterpret_cast< ::QGraphicsLayoutItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsLayout_PythonToCpp_QGraphicsLayout_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsLayout_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsLayout_PythonToCpp_QGraphicsLayout_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsLayout_TypeF()))
        return QGraphicsLayout_PythonToCpp_QGraphicsLayout_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsLayout_PTR_CppToPython_QGraphicsLayout(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QGraphicsLayout *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QGraphicsLayout_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsLayout_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsLayout(self,parent:PySide6.QtWidgets.QGraphicsLayoutItem=nullptr)",
    "PySide6.QtWidgets.QGraphicsLayout.activate(self)",
    "PySide6.QtWidgets.QGraphicsLayout.addChildLayoutItem(self,layoutItem:PySide6.QtWidgets.QGraphicsLayoutItem)",
    "PySide6.QtWidgets.QGraphicsLayout.count(self)->int",
    "PySide6.QtWidgets.QGraphicsLayout.getContentsMargins(self)->PyObject",
    "PySide6.QtWidgets.QGraphicsLayout.instantInvalidatePropagation()->bool",
    "PySide6.QtWidgets.QGraphicsLayout.invalidate(self)",
    "PySide6.QtWidgets.QGraphicsLayout.isActivated(self)->bool",
    "PySide6.QtWidgets.QGraphicsLayout.itemAt(self,i:int)->PySide6.QtWidgets.QGraphicsLayoutItem",
    "PySide6.QtWidgets.QGraphicsLayout.removeAt(self,index:int)",
    "PySide6.QtWidgets.QGraphicsLayout.setContentsMargins(self,left:qreal,top:qreal,right:qreal,bottom:qreal)",
    "PySide6.QtWidgets.QGraphicsLayout.setInstantInvalidatePropagation(enable:bool)",
    "PySide6.QtWidgets.QGraphicsLayout.updateGeometry(self)",
    "PySide6.QtWidgets.QGraphicsLayout.widgetEvent(self,e:PySide6.QtCore.QEvent)",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsLayout_SignatureByteSize = 286;
static constexpr uint8_t QGraphicsLayout_SignatureBytes[286] = {
    0x78, 0xda, 0x8d, 0x53, 0x4d, 0x4f, 0x84, 0x30, 0x10, 0xbd, 0xef, 0x2f, 0x59, 0x12, 0xe4, 0xe8,
    0x81, 0x44, 0x93, 0x0d, 0x31, 0x1b, 0x12, 0x8d, 0x10, 0x0f, 0x9e, 0x07, 0x3a, 0x0b, 0xdd, 0x94,
    0x0e, 0xb6, 0x03, 0xca, 0xbf, 0xb7, 0xcb, 0xc7, 0xea, 0xc1, 0xb8, 0x73, 0xeb, 0x4c, 0xfb, 0xde,
    0x9b, 0xbe, 0xd7, 0x16, 0xd3, 0x9b, 0x56, 0x78, 0x9f, 0x94, 0xfc, 0xae, 0x55, 0x83, 0xec, 0x93,
    0xf2, 0xe8, 0xa0, 0x6f, 0x75, 0xed, 0x9f, 0x61, 0xa2, 0x81, 0xf7, 0x1e, 0xcd, 0x29, 0xee, 0xc1,
    0xa1, 0xe5, 0xb4, 0xb8, 0x75, 0x3a, 0x67, 0xec, 0x1e, 0xec, 0x60, 0x4c, 0xcf, 0x2e, 0xda, 0xdd,
    0x3c, 0x9e, 0x40, 0xcd, 0x7a, 0x04, 0xc6, 0x59, 0x45, 0x04, 0x50, 0x2a, 0x6b, 0xb5, 0x51, 0x3f,
    0x72, 0xcb, 0x80, 0xe6, 0x5a, 0xcb, 0x86, 0x94, 0x68, 0xd5, 0x34, 0xd8, 0xe5, 0xfe, 0xd1, 0xdd,
    0xa3, 0xb6, 0x2c, 0x80, 0x84, 0x66, 0x46, 0x96, 0x83, 0x57, 0xfe, 0x05, 0x5c, 0xa3, 0xad, 0xdf,
    0xf0, 0xc5, 0xf4, 0x5a, 0x9d, 0xb1, 0x96, 0x90, 0x04, 0x14, 0x83, 0xe5, 0xdc, 0x8e, 0x60, 0xb4,
    0x0a, 0xee, 0x14, 0x8e, 0x7a, 0x68, 0x80, 0x35, 0xd9, 0x7d, 0xa0, 0xaa, 0x88, 0x8c, 0x88, 0x66,
    0xc3, 0x8b, 0xdd, 0xd5, 0xfe, 0xb0, 0x06, 0xa2, 0xb6, 0xb9, 0xa5, 0x62, 0xc1, 0xd3, 0xc3, 0xfa,
    0x58, 0x74, 0x1a, 0xcc, 0x9a, 0xaf, 0x2c, 0x08, 0x42, 0xc0, 0xed, 0xb0, 0xa3, 0x11, 0xaf, 0xec,
    0x56, 0xe1, 0xd7, 0xac, 0x20, 0x80, 0xfa, 0xbf, 0xf3, 0x88, 0x0d, 0x9e, 0x38, 0xfd, 0x70, 0x08,
    0x26, 0x66, 0xea, 0xd7, 0x95, 0xd3, 0x4d, 0xbb, 0x75, 0x2b, 0x62, 0xa6, 0x6e, 0x29, 0x84, 0x42,
    0xf9, 0x7f, 0xb1, 0xa1, 0x85, 0xca, 0x60, 0x7a, 0x71, 0x53, 0x42, 0x37, 0xf4, 0x17, 0x82, 0x23,
    0x52, 0x87, 0xec, 0x26, 0x71, 0x7e, 0x9f, 0x73, 0xff, 0x69, 0xc4, 0xf5, 0xdd, 0xc6, 0xf8, 0xeb,
    0x37, 0x64, 0xe4, 0x30, 0x29, 0xe7, 0xcd, 0x68, 0xf7, 0x0d, 0xc4, 0xa2, 0x79, 0x29
};
#endif

PyTypeObject *init_QGraphicsLayout(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsLayout_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]))));

    _Sbk_QGraphicsLayout_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsLayout",
        "QGraphicsLayout*",
        &Sbk_QGraphicsLayout_spec,
        &Shiboken::callCppDestructor< QGraphicsLayout >,
        Sbk_QGraphicsLayout_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsLayout_TypeF(); // references _Sbk_QGraphicsLayout_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsLayout_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsLayout_SignatureBytes, QGraphicsLayout_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsLayout_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsLayout_PythonToCpp_QGraphicsLayout_PTR,
        is_QGraphicsLayout_PythonToCpp_QGraphicsLayout_PTR_Convertible,
        QGraphicsLayout_PTR_CppToPython_QGraphicsLayout);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsLayout");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsLayout*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsLayout&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsLayout).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsLayoutWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsLayout_TypeF(), &Sbk_QGraphicsLayout_typeDiscovery);


    return pyType;
}
