// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGRAPHICSPROXYWIDGETWRAPPER_H
#define SBK_QGRAPHICSPROXYWIDGETWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qgraphicsproxywidget.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QGraphicsProxyWidgetWrapper : public QGraphicsProxyWidget
{
public:
    QGraphicsProxyWidgetWrapper(::QGraphicsItem * parent = nullptr, ::QFlags<Qt::WindowType> wFlags = Qt::WindowFlags());
    QGraphicsProxyWidgetWrapper(const QGraphicsProxyWidgetWrapper &) = delete;
    QGraphicsProxyWidgetWrapper& operator=(const QGraphicsProxyWidgetWrapper &) = delete;
    QGraphicsProxyWidgetWrapper(QGraphicsProxyWidgetWrapper &&) = delete;
    QGraphicsProxyWidgetWrapper& operator=(QGraphicsProxyWidgetWrapper &&) = delete;
    ~QGraphicsProxyWidgetWrapper() override;

    void advance(int phase) override;
    ::QRectF boundingRect() const override;
    void changeEvent(::QEvent * event) override;
    static void sbk_o_changeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void childEvent(::QChildEvent * event) override;
    void closeEvent(::QCloseEvent * event) override;
    static void sbk_o_closeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QCloseEvent * event);
    bool collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    bool collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    void connectNotify(const ::QMetaMethod & signal) override;
    bool contains(const ::QPointF & point) const override;
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent * event) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent * event) override;
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent * event) override;
    void dragMoveEvent(::QGraphicsSceneDragDropEvent * event) override;
    void dropEvent(::QGraphicsSceneDragDropEvent * event) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * object, ::QEvent * event) override;
    ::QVariant extension(const ::QVariant & variant) const override;
    void focusInEvent(::QFocusEvent * event) override;
    bool focusNextPrevChild(bool next) override;
    void focusOutEvent(::QFocusEvent * event) override;
    void getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const override;
    void grabKeyboardEvent(::QEvent * event) override;
    static void sbk_o_grabKeyboardEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void grabMouseEvent(::QEvent * event) override;
    static void sbk_o_grabMouseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void hideEvent(::QHideEvent * event) override;
    static void sbk_o_hideEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QHideEvent * event);
    void hoverEnterEvent(::QGraphicsSceneHoverEvent * event) override;
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent * event) override;
    void hoverMoveEvent(::QGraphicsSceneHoverEvent * event) override;
    void initStyleOption(::QStyleOption * option) const override;
    void inputMethodEvent(::QInputMethodEvent * event) override;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery query) const override;
    bool isEmpty() const override;
    bool isObscuredBy(const ::QGraphicsItem * item) const override;
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value) override;
    void keyPressEvent(::QKeyEvent * event) override;
    void keyReleaseEvent(::QKeyEvent * event) override;
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event) override;
    void mouseMoveEvent(::QGraphicsSceneMouseEvent * event) override;
    void mousePressEvent(::QGraphicsSceneMouseEvent * event) override;
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent * event) override;
    void moveEvent(::QGraphicsSceneMoveEvent * event) override;
    static void sbk_o_moveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMoveEvent * event);
    ::QPainterPath opaqueArea() const override;
    void paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget) override;
    void paintWindowFrame(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr) override;
    static void sbk_o_paintWindowFrame(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr);
    void polishEvent() override;
    ::QVariant propertyChange(const ::QString & propertyName, const ::QVariant & value) override;
    void resizeEvent(::QGraphicsSceneResizeEvent * event) override;
    static void sbk_o_resizeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneResizeEvent * event);
    bool sceneEvent(::QEvent * event) override;
    bool sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event) override;
    void setGeometry(const ::QRectF & rect) override;
    ::QPainterPath shape() const override;
    void showEvent(::QShowEvent * event) override;
    static void sbk_o_showEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QShowEvent * event);
    ::QSizeF sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint = QSizeF()) const override;
    void timerEvent(::QTimerEvent * event) override;
    int type() const override;
    void ungrabKeyboardEvent(::QEvent * event) override;
    static void sbk_o_ungrabKeyboardEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void ungrabMouseEvent(::QEvent * event) override;
    static void sbk_o_ungrabMouseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void updateGeometry() override;
    void wheelEvent(::QGraphicsSceneWheelEvent * event) override;
    bool windowFrameEvent(::QEvent * e) override;
    static bool sbk_o_windowFrameEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * e);
    ::Qt::WindowFrameSection windowFrameSectionAt(const ::QPointF & pos) const override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[62] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QGRAPHICSPROXYWIDGETWRAPPER_H
