// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qlcdnumber_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qlineedit_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qlcdnumber.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QLCDNumberWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QLCDNumberWrapper::QLCDNumberWrapper(::QWidget * parent) : QLCDNumber(parent)
{
}

QLCDNumberWrapper::QLCDNumberWrapper(uint numDigits, ::QWidget * parent) : QLCDNumber(numDigits, parent)
{
}

void QLCDNumberWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::changeEvent(::QEvent * arg__1)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::changeEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QLCDNumber", funcName, gil, pyOverride, arg__1);
}

void QLCDNumberWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QLCDNumber", funcName, gil, pyOverride, signal);
}

void QLCDNumberWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

int QLCDNumberWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QLCDNumber", funcName, gil, pyOverride);
}

void QLCDNumberWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QLCDNumber", funcName, gil, pyOverride, signal);
}

void QLCDNumberWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

bool QLCDNumberWrapper::event(::QEvent * e)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLCDNumber::event(e);
    }
    return QWidgetWrapper::sbk_o_event("QLCDNumber", funcName, gil, pyOverride, e);
}

bool QLCDNumberWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QLCDNumber", funcName, gil, pyOverride, watched, event);
}

void QLCDNumberWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

bool QLCDNumberWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QLCDNumber", funcName, gil, pyOverride, next);
}

void QLCDNumberWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

bool QLCDNumberWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QLCDNumber", funcName, gil, pyOverride);
}

int QLCDNumberWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QLCDNumber", funcName, gil, pyOverride, arg__1);
}

void QLCDNumberWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QLCDNumber", funcName, gil, pyOverride, painter);
}

void QLCDNumberWrapper::initStyleOption(::QStyleOptionFrame * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::initStyleOption(option);
    }
    QLineEditWrapper::sbk_o_initStyleOption("QLCDNumber", funcName, gil, pyOverride, option);
}

void QLCDNumberWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

::QVariant QLCDNumberWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QLCDNumber", funcName, gil, pyOverride, arg__1);
}

void QLCDNumberWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

int QLCDNumberWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QLCDNumber", funcName, gil, pyOverride, arg__1);
}

::QSize QLCDNumberWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QLCDNumber", funcName, gil, pyOverride);
}

void QLCDNumberWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

bool QLCDNumberWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QLCDNumber", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QLCDNumberWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QLCDNumber", funcName, gil, pyOverride);
}

void QLCDNumberWrapper::paintEvent(::QPaintEvent * arg__1)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLCDNumber::paintEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QLCDNumber", funcName, gil, pyOverride, arg__1);
}

::QPaintDevice * QLCDNumberWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QLCDNumber", funcName, gil, pyOverride, offset);
}

void QLCDNumberWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QLCDNumber", funcName, gil, pyOverride, visible);
}

::QPainter * QLCDNumberWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QLCDNumber", funcName, gil, pyOverride);
}

void QLCDNumberWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

::QSize QLCDNumberWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLCDNumber::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QLCDNumber", funcName, gil, pyOverride);
}

void QLCDNumberWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

void QLCDNumberWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QLCDNumber", funcName, gil, pyOverride, event);
}

const QMetaObject *QLCDNumberWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QLCDNumber::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QLCDNumberWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QLCDNumber::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QLCDNumberWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QLCDNumberWrapper *>(this));
    return QLCDNumber::qt_metacast(_clname);
}

QLCDNumberWrapper::~QLCDNumberWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLCDNumber_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLCDNumber >()))
        return -1;

    QLCDNumberWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QLCDNumber", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLCDNumber::QLCDNumber(QWidget*=)
    // 1: QLCDNumber::QLCDNumber(uint,QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QLCDNumber(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QLCDNumber(uint,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QLCDNumber(uint,QWidget*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QLCDNumber(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLCDNumber(QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLCDNumber(QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QLCDNumberWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QLCDNumberWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QLCDNumber(uint numDigits, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);
                }
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLCDNumber(uint,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QLCDNumberWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QLCDNumberWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QLCDNumber >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QLCDNumberFunc_checkOverflow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLCDNumber::checkOverflow(double)const->bool
    // 1: QLCDNumber::checkOverflow(int)const->bool
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // checkOverflow(double)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // checkOverflow(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "checkOverflow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // checkOverflow(double num) const
        {
            double cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // checkOverflow(double)const
                bool cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->checkOverflow(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // checkOverflow(int num) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // checkOverflow(int)const
                bool cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->checkOverflow(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_digitCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // digitCount()const
        int cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->digitCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_display(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLCDNumber::display(QString)
    // 1: QLCDNumber::display(double)
    // 2: QLCDNumber::display(int)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 1; // display(double)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 2; // display(int)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // display(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "display", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // display(const QString &str)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // display(QString)
                cppSelf->display(cppArg0);
            }
            break;
        }
        case 1: // display(double num)
        {
            double cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // display(double)
                cppSelf->display(cppArg0);
            }
            break;
        }
        case 2: // display(int num)
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // display(int)
                cppSelf->display(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QLCDNumber::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_intValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // intValue()const
        int cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->intValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_mode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mode()const
        QLCDNumber::Mode cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->mode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_Mode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QLCDNumber::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_segmentStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segmentStyle()const
        QLCDNumber::SegmentStyle cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->segmentStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_SegmentStyle_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_setBinMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setBinMode()
        cppSelf->setBinMode();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_setDecMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setDecMode()
        cppSelf->setDecMode();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_setDigitCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLCDNumber::setDigitCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDigitCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDigitCount", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDigitCount(int)
            cppSelf->setDigitCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_setHexMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setHexMode()
        cppSelf->setHexMode();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_setMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLCDNumber::setMode(QLCDNumber::Mode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_Mode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMode(QLCDNumber::Mode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    {
        ::QLCDNumber::Mode cppArg0{QLCDNumber::Hex};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMode(QLCDNumber::Mode)
            cppSelf->setMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_setOctMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setOctMode()
        cppSelf->setOctMode();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_setSegmentStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLCDNumber::setSegmentStyle(QLCDNumber::SegmentStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_SegmentStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSegmentStyle(QLCDNumber::SegmentStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSegmentStyle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    {
        ::QLCDNumber::SegmentStyle cppArg0{QLCDNumber::Outline};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSegmentStyle(QLCDNumber::SegmentStyle)
            cppSelf->setSegmentStyle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_setSmallDecimalPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLCDNumber::setSmallDecimalPoint(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSmallDecimalPoint(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSmallDecimalPoint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSmallDecimalPoint(bool)
            cppSelf->setSmallDecimalPoint(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLCDNumberFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QLCDNumber *>(cppSelf)->::QLCDNumber::sizeHint()
            : const_cast<const ::QLCDNumber *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_smallDecimalPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // smallDecimalPoint()const
        bool cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->smallDecimalPoint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLCDNumberFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        double cppResult = const_cast<const ::QLCDNumber *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QLCDNumber_PropertyStrings[] = {
    "digitCount::",
    "intValue::display",
    "mode::",
    "segmentStyle::",
    "smallDecimalPoint::",
    "value::display",
    nullptr // Sentinel
};

static const char *Sbk_QLCDNumber_EnumFlagInfo[] = {
    "Mode:Enum",
    "SegmentStyle:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLCDNumber_methods[] = {
    {"checkOverflow", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_checkOverflow), METH_O, nullptr},
    {"digitCount", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_digitCount), METH_NOARGS, nullptr},
    {"display", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_display), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_event), METH_O, nullptr},
    {"intValue", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_intValue), METH_NOARGS, nullptr},
    {"mode", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_mode), METH_NOARGS, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_paintEvent), METH_O, nullptr},
    {"segmentStyle", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_segmentStyle), METH_NOARGS, nullptr},
    {"setBinMode", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setBinMode), METH_NOARGS, nullptr},
    {"setDecMode", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setDecMode), METH_NOARGS, nullptr},
    {"setDigitCount", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setDigitCount), METH_O, nullptr},
    {"setHexMode", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setHexMode), METH_NOARGS, nullptr},
    {"setMode", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setMode), METH_O, nullptr},
    {"setOctMode", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setOctMode), METH_NOARGS, nullptr},
    {"setSegmentStyle", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setSegmentStyle), METH_O, nullptr},
    {"setSmallDecimalPoint", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_setSmallDecimalPoint), METH_O, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_sizeHint), METH_NOARGS, nullptr},
    {"smallDecimalPoint", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_smallDecimalPoint), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QLCDNumberFunc_value), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QLCDNumber_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QLCDNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QLCDNumberWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QLCDNumber_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLCDNumber_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QLCDNumberSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QLCDNumber *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))
        return static_cast< ::QFrame *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLCDNumber_Type = nullptr;
static PyTypeObject *Sbk_QLCDNumber_TypeF(void)
{
    return _Sbk_QLCDNumber_Type;
}

static PyType_Slot Sbk_QLCDNumber_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QLCDNumber_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLCDNumber_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLCDNumber_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLCDNumber_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLCDNumber_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLCDNumber_spec = {
    "2:PySide6.QtWidgets.QLCDNumber",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLCDNumber_slots
};

} //extern "C"

static void *Sbk_QLCDNumber_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QLCDNumber *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QLCDNumber *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QLCDNumber *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLCDNumber_Mode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLCDNumber::Mode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLCDNumber::Mode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLCDNumber_Mode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_Mode_IDX])))
        return Enum_PythonToCpp_QLCDNumber_Mode;
    return {};
}

static PyObject *QLCDNumber_Mode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLCDNumber::Mode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLCDNumber::Mode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_Mode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLCDNumber_SegmentStyle(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLCDNumber::SegmentStyle>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLCDNumber::SegmentStyle *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLCDNumber_SegmentStyle_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_SegmentStyle_IDX])))
        return Enum_PythonToCpp_QLCDNumber_SegmentStyle;
    return {};
}

static PyObject *QLCDNumber_SegmentStyle_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLCDNumber::SegmentStyle>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLCDNumber::SegmentStyle *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_SegmentStyle_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLCDNumber_PythonToCpp_QLCDNumber_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLCDNumber_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLCDNumber_PythonToCpp_QLCDNumber_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLCDNumber_TypeF()))
        return QLCDNumber_PythonToCpp_QLCDNumber_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLCDNumber_PTR_CppToPython_QLCDNumber(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QLCDNumber *>(const_cast<void *>(cppIn)), Sbk_QLCDNumber_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLCDNumber_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QLCDNumber(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,smallDecimalPoint:bool=None,digitCount:int=None,mode:QLCDNumber.Mode=None,segmentStyle:QLCDNumber.SegmentStyle=None,value:double=None,intValue:int=None)",
    "0:PySide6.QtWidgets.QLCDNumber(self,numDigits:uint,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,smallDecimalPoint:bool=None,digitCount:int=None,mode:QLCDNumber.Mode=None,segmentStyle:QLCDNumber.SegmentStyle=None,value:double=None,intValue:int=None)",
    "1:PySide6.QtWidgets.QLCDNumber.checkOverflow(self,num:double)->bool",
    "0:PySide6.QtWidgets.QLCDNumber.checkOverflow(self,num:int)->bool",
    "PySide6.QtWidgets.QLCDNumber.digitCount(self)->int",
    "2:PySide6.QtWidgets.QLCDNumber.display(self,str:QString)",
    "1:PySide6.QtWidgets.QLCDNumber.display(self,num:double)",
    "0:PySide6.QtWidgets.QLCDNumber.display(self,num:int)",
    "PySide6.QtWidgets.QLCDNumber.event(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QLCDNumber.intValue(self)->int",
    "PySide6.QtWidgets.QLCDNumber.mode(self)->PySide6.QtWidgets.QLCDNumber.Mode",
    "PySide6.QtWidgets.QLCDNumber.paintEvent(self,arg__1:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QLCDNumber.segmentStyle(self)->PySide6.QtWidgets.QLCDNumber.SegmentStyle",
    "PySide6.QtWidgets.QLCDNumber.setBinMode(self)",
    "PySide6.QtWidgets.QLCDNumber.setDecMode(self)",
    "PySide6.QtWidgets.QLCDNumber.setDigitCount(self,nDigits:int)",
    "PySide6.QtWidgets.QLCDNumber.setHexMode(self)",
    "PySide6.QtWidgets.QLCDNumber.setMode(self,arg__1:PySide6.QtWidgets.QLCDNumber.Mode)",
    "PySide6.QtWidgets.QLCDNumber.setOctMode(self)",
    "PySide6.QtWidgets.QLCDNumber.setSegmentStyle(self,arg__1:PySide6.QtWidgets.QLCDNumber.SegmentStyle)",
    "PySide6.QtWidgets.QLCDNumber.setSmallDecimalPoint(self,arg__1:bool)",
    "PySide6.QtWidgets.QLCDNumber.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QLCDNumber.smallDecimalPoint(self)->bool",
    "PySide6.QtWidgets.QLCDNumber.value(self)->double",
    nullptr}; // Sentinel
#else
static constexpr size_t QLCDNumber_SignatureByteSize = 408;
static constexpr uint8_t QLCDNumber_SignatureBytes[408] = {
    0x78, 0xda, 0xdd, 0x54, 0xcb, 0x6e, 0x83, 0x30, 0x10, 0xbc, 0xe7, 0x4b, 0x9a, 0x8a, 0xa2, 0xa4,
    0x87, 0x1e, 0x2c, 0xa5, 0x87, 0x26, 0x51, 0x23, 0xb5, 0x79, 0x20, 0xa4, 0xf6, 0x18, 0x11, 0xd8,
    0x50, 0xab, 0xc6, 0x46, 0xc6, 0x26, 0xa5, 0x5f, 0x5f, 0x13, 0x5e, 0x26, 0x0f, 0x4c, 0xae, 0x3d,
    0x85, 0xac, 0x77, 0x66, 0x77, 0xc6, 0xbb, 0x1e, 0xa3, 0x4d, 0xe6, 0xe2, 0x00, 0x9e, 0x6c, 0x47,
    0x7c, 0xe2, 0x20, 0x04, 0x91, 0xd8, 0xce, 0xfb, 0x74, 0xb6, 0x92, 0xd1, 0x0e, 0xf8, 0x5d, 0x02,
    0x64, 0x6f, 0xc5, 0x1e, 0x07, 0x2a, 0x2e, 0x25, 0x16, 0x1f, 0x13, 0x2a, 0x09, 0x89, 0x05, 0xb7,
    0xee, 0xd1, 0x1b, 0x64, 0x07, 0xc6, 0x83, 0x35, 0x25, 0xd9, 0x64, 0xc5, 0x28, 0x58, 0x49, 0xe4,
    0x11, 0x32, 0x03, 0x1f, 0xab, 0xdf, 0x0d, 0xc3, 0x8a, 0x66, 0xc7, 0x18, 0x29, 0xce, 0x02, 0x1c,
    0x62, 0x31, 0x65, 0x52, 0x05, 0xd5, 0x41, 0x11, 0x8b, 0x58, 0x00, 0xa8, 0x69, 0xc0, 0x5e, 0xaa,
    0xff, 0x25, 0x13, 0x84, 0x91, 0x6a, 0xc3, 0x15, 0x19, 0x69, 0x65, 0xb8, 0x5a, 0xbc, 0xc8, 0x4c,
    0x3d, 0x22, 0x01, 0x05, 0x4c, 0xee, 0xaa, 0x88, 0xa2, 0xff, 0x38, 0x06, 0xab, 0x3a, 0xc3, 0xc1,
    0xa8, 0x87, 0x70, 0x2a, 0xa3, 0x59, 0xde, 0x63, 0x82, 0xa4, 0x02, 0xfe, 0x4f, 0x1f, 0xc6, 0x9d,
    0x3e, 0xd8, 0xfe, 0x17, 0xf8, 0xdf, 0xeb, 0x14, 0xf8, 0x9e, 0xb0, 0x43, 0xed, 0x4a, 0x49, 0x3a,
    0x7c, 0x78, 0xce, 0x55, 0x18, 0xbc, 0xbc, 0xc6, 0xa1, 0x7a, 0xa8, 0x08, 0x3a, 0xe1, 0x8d, 0x3d,
    0x47, 0xac, 0xc2, 0x28, 0xe4, 0xe0, 0x11, 0x19, 0x40, 0x49, 0x4c, 0xbc, 0xac, 0xa8, 0x96, 0x08,
    0x8e, 0x1c, 0x57, 0x70, 0x4c, 0x43, 0xa3, 0xe0, 0x16, 0x50, 0x93, 0x6a, 0x12, 0x79, 0x86, 0xcb,
    0xe5, 0x75, 0x0b, 0x83, 0x14, 0x4a, 0x4d, 0x16, 0x68, 0xe4, 0x53, 0xc6, 0xc1, 0x76, 0xe6, 0xf9,
    0x61, 0x2f, 0x7f, 0xaa, 0x4b, 0xd5, 0xdd, 0xe9, 0x04, 0xe4, 0xb3, 0x55, 0x25, 0x77, 0x26, 0xe6,
    0x43, 0xd7, 0x4d, 0x15, 0x7b, 0xaa, 0xda, 0xbc, 0xd1, 0xe1, 0xf1, 0x70, 0xbb, 0xd5, 0x1d, 0x7e,
    0x95, 0xd8, 0x76, 0x36, 0x75, 0x96, 0xc1, 0x11, 0x7d, 0xb6, 0x7b, 0x75, 0xa8, 0x0f, 0xbd, 0x89,
    0x5a, 0xbc, 0x60, 0xba, 0xac, 0xa5, 0x1b, 0xb3, 0xd5, 0xb2, 0xde, 0x92, 0xdd, 0x1e, 0x52, 0x8b,
    0x96, 0x0f, 0x07, 0xee, 0xa1, 0x59, 0x2c, 0xe0, 0xe7, 0x86, 0x52, 0x75, 0xea, 0xb9, 0xdb, 0x57,
    0xee, 0xd0, 0xcc, 0xb9, 0xf6, 0xc5, 0x0d, 0x1d, 0xb8, 0xa7, 0xd7, 0xd4, 0xab, 0x13, 0x1d, 0xd5,
    0xa3, 0xc6, 0xe9, 0x83, 0xd9, 0x2a, 0x94, 0x6f, 0x85, 0x89, 0x03, 0xff, 0xc2, 0x02, 0x37, 0x8f,
    0xc6, 0xe9, 0x82, 0xb9, 0xea, 0xdc, 0xc0, 0x70, 0xb1, 0x85, 0x5e, 0x3b, 0x99, 0xea, 0x0b, 0x59,
    0xbc, 0x20, 0x83, 0x3f, 0x50, 0x6e, 0xa7, 0xd7
};
#endif

PyTypeObject *init_QLCDNumber(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX].type;

    Shiboken::AutoDecRef Sbk_QLCDNumber_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))));

    _Sbk_QLCDNumber_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLCDNumber",
        "QLCDNumber*",
        &Sbk_QLCDNumber_spec,
        &Shiboken::callCppDestructor< QLCDNumber >,
        Sbk_QLCDNumber_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QLCDNumber_TypeF(); // references _Sbk_QLCDNumber_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLCDNumber_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLCDNumber_SignatureBytes, QLCDNumber_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLCDNumber_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLCDNumber_PythonToCpp_QLCDNumber_PTR,
        is_QLCDNumber_PythonToCpp_QLCDNumber_PTR_Convertible,
        QLCDNumber_PTR_CppToPython_QLCDNumber);

    Shiboken::Conversions::registerConverterName(converter, "QLCDNumber");
    Shiboken::Conversions::registerConverterName(converter, "QLCDNumber*");
    Shiboken::Conversions::registerConverterName(converter, "QLCDNumber&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLCDNumber).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QLCDNumberWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QLCDNumber_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QLCDNumber_TypeF(), &Sbk_QLCDNumberSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QLCDNumber_TypeF(), &Sbk_QLCDNumber_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLCDNumber_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Mode'.
    const char *Mode_Initializer[] = {
        "Hex",
        "Dec",
        "Oct",
        "Bin",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Mode_InitializerValues[] = {
        uint8_t(QLCDNumber::Mode::Hex), //  0x00  0
        uint8_t(QLCDNumber::Mode::Dec), //  0x01  1
        uint8_t(QLCDNumber::Mode::Oct), //  0x02  2
        uint8_t(QLCDNumber::Mode::Bin)  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLCDNumber_TypeF(),
        "2:PySide6.QtWidgets.QLCDNumber.Mode",
        Mode_Initializer, Mode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_Mode_IDX].type = EType;
    // Register converter for enum 'QLCDNumber::Mode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLCDNumber_Mode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLCDNumber_Mode,
            is_Enum_PythonToCpp_QLCDNumber_Mode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLCDNumber::Mode");
        Shiboken::Conversions::registerConverterAlias(converter, "Mode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Mode' enum.

    // Initialization of enum 'SegmentStyle'.
    const char *SegmentStyle_Initializer[] = {
        "Outline",
        "Filled",
        "Flat",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SegmentStyle_InitializerValues[] = {
        uint8_t(QLCDNumber::SegmentStyle::Outline), //  0x00  0
        uint8_t(QLCDNumber::SegmentStyle::Filled),  //  0x01  1
        uint8_t(QLCDNumber::SegmentStyle::Flat)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLCDNumber_TypeF(),
        "2:PySide6.QtWidgets.QLCDNumber.SegmentStyle",
        SegmentStyle_Initializer, SegmentStyle_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_SegmentStyle_IDX].type = EType;
    // Register converter for enum 'QLCDNumber::SegmentStyle'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLCDNumber_SegmentStyle_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLCDNumber_SegmentStyle,
            is_Enum_PythonToCpp_QLCDNumber_SegmentStyle_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLCDNumber::SegmentStyle");
        Shiboken::Conversions::registerConverterAlias(converter, "SegmentStyle");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SegmentStyle' enum.

    PySide::Signal::registerSignals(pyType, &::QLCDNumber::staticMetaObject);
    qRegisterMetaType< ::QLCDNumber::Mode >("QLCDNumber::Mode");
    qRegisterMetaType< ::QLCDNumber::SegmentStyle >("QLCDNumber::SegmentStyle");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QLCDNumber::staticMetaObject, sizeof(QLCDNumberWrapper));

    return pyType;
}
