// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QLISTWIDGETITEMWRAPPER_H
#define SBK_QLISTWIDGETITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qlistwidget.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QListWidgetItemWrapper : public QListWidgetItem
{
public:
    QListWidgetItemWrapper(::QListWidget * listview = nullptr, int type = QListWidgetItem::ItemType::Type);
    QListWidgetItemWrapper(const ::QIcon & icon, const ::QString & text, ::QListWidget * listview = nullptr, int type = QListWidgetItem::ItemType::Type);
    QListWidgetItemWrapper(const ::QString & text, ::QListWidget * listview = nullptr, int type = QListWidgetItem::ItemType::Type);
    QListWidgetItemWrapper(const QListWidgetItemWrapper &) = delete;
    QListWidgetItemWrapper(const QListWidgetItem& self) : QListWidgetItem(self)
    {
    }
    QListWidgetItemWrapper& operator=(const QListWidgetItemWrapper &) = delete;
    QListWidgetItemWrapper(QListWidgetItemWrapper &&) = delete;
    QListWidgetItemWrapper& operator=(QListWidgetItemWrapper &&) = delete;
    ~QListWidgetItemWrapper() override;

    ::QListWidgetItem * clone() const override;
    static ::QListWidgetItem * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QVariant data(int role) const override;
    bool operator<(const ::QListWidgetItem & other) const override;
    static bool sbk_o_op_lt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QListWidgetItem & other);
    void read(::QDataStream & in) override;
    void setData(int role, const ::QVariant & value) override;
    void write(::QDataStream & out) const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QLISTWIDGETITEMWRAPPER_H
