// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qmainwindow_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qdockwidget.h>
#include <QtWidgets/qmenu.h>
#include <QtWidgets/qmenubar.h>
#include <QtWidgets/qstatusbar.h>
#include <QtWidgets/qtabwidget.h>
#include <QtWidgets/qtoolbar.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QMainWindowWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QMainWindowWrapper::QMainWindowWrapper(::QWidget * parent, ::QFlags<Qt::WindowType> flags) : QMainWindow(parent, flags)
{
}

void QMainWindowWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QMainWindow", funcName, gil, pyOverride, signal);
}

void QMainWindowWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMainWindow::contextMenuEvent(event);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QMainWindow", funcName, gil, pyOverride, event);
}

::QMenu * QMainWindowWrapper::createPopupMenu()
{
    static const char *funcName = "createPopupMenu";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMainWindow::createPopupMenu();
    }
    return sbk_o_createPopupMenu("QMainWindow", funcName, gil, pyOverride);
}

::QMenu * QMainWindowWrapper::sbk_o_createPopupMenu(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMenu_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QMenu >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QMenu *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QMainWindowWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QMainWindow", funcName, gil, pyOverride, event);
}

int QMainWindowWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QMainWindow", funcName, gil, pyOverride);
}

void QMainWindowWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QMainWindow", funcName, gil, pyOverride, signal);
}

void QMainWindowWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QMainWindow", funcName, gil, pyOverride, event);
}

bool QMainWindowWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMainWindow::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QMainWindow", funcName, gil, pyOverride, event);
}

bool QMainWindowWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QMainWindow", funcName, gil, pyOverride, watched, event);
}

void QMainWindowWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QMainWindow", funcName, gil, pyOverride, event);
}

bool QMainWindowWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QMainWindow", funcName, gil, pyOverride, next);
}

void QMainWindowWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QMainWindow", funcName, gil, pyOverride, event);
}

bool QMainWindowWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QMainWindow", funcName, gil, pyOverride);
}

int QMainWindowWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QMainWindow", funcName, gil, pyOverride, arg__1);
}

void QMainWindowWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QMainWindow", funcName, gil, pyOverride, painter);
}

void QMainWindowWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QMainWindow", funcName, gil, pyOverride, event);
}

::QVariant QMainWindowWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QMainWindow", funcName, gil, pyOverride, arg__1);
}

void QMainWindowWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QMainWindow", funcName, gil, pyOverride, event);
}

int QMainWindowWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QMainWindow", funcName, gil, pyOverride, arg__1);
}

::QSize QMainWindowWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QMainWindow", funcName, gil, pyOverride);
}

void QMainWindowWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QMainWindow", funcName, gil, pyOverride, event);
}

bool QMainWindowWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QMainWindow", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QMainWindowWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QMainWindow", funcName, gil, pyOverride);
}

void QMainWindowWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QMainWindow", funcName, gil, pyOverride, event);
}

::QPaintDevice * QMainWindowWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QMainWindow", funcName, gil, pyOverride, offset);
}

void QMainWindowWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QMainWindow", funcName, gil, pyOverride, visible);
}

::QPainter * QMainWindowWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QMainWindow", funcName, gil, pyOverride);
}

void QMainWindowWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QMainWindow", funcName, gil, pyOverride, event);
}

::QSize QMainWindowWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QMainWindow", funcName, gil, pyOverride);
}

void QMainWindowWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QMainWindow", funcName, gil, pyOverride, event);
}

void QMainWindowWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QMainWindow", funcName, gil, pyOverride, event);
}

const QMetaObject *QMainWindowWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QMainWindow::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QMainWindowWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QMainWindow::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QMainWindowWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QMainWindowWrapper *>(this));
    return QMainWindow::qt_metacast(_clname);
}

QMainWindowWrapper::~QMainWindowWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMainWindow_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMainWindow >()))
        return -1;

    QMainWindowWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QMainWindow", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMainWindow::QMainWindow(QWidget*=,QFlags<Qt::WindowType>=)
    if (numArgs == 0) {
        overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"parent", 0}, {"flags", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QMainWindowWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QMainWindowWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QMainWindow >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QMainWindowFunc_addDockWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addDockWidget", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::addDockWidget(Qt::DockWidgetArea,QDockWidget*)
    // 1: QMainWindow::addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DockWidgetArea_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 1; // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addDockWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addDockWidget(Qt::DockWidgetArea area, QDockWidget *dockwidget)
        {
            ::Qt::DockWidgetArea cppArg0{Qt::NoDockWidgetArea};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDockWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
                cppSelf->addDockWidget(cppArg0, cppArg1);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArgs[1]);
            }
            break;
        }
        case 1: // addDockWidget(Qt::DockWidgetArea area, QDockWidget *dockwidget, Qt::Orientation orientation)
        {
            ::Qt::DockWidgetArea cppArg0{Qt::NoDockWidgetArea};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDockWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Orientation cppArg2 = static_cast< ::Qt::Orientation>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
                cppSelf->addDockWidget(cppArg0, cppArg1, cppArg2);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArgs[1]);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_addToolBar(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addToolBar", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::addToolBar(QToolBar*)
    // 1: QMainWindow::addToolBar(Qt::ToolBarArea,QToolBar*)
    // 2: QMainWindow::addToolBar(QString)->QToolBar*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolBarArea_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArgs[1])))) {
        overloadId = 1; // addToolBar(Qt::ToolBarArea,QToolBar*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArgs[0])))) {
        overloadId = 0; // addToolBar(QToolBar*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 2; // addToolBar(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addToolBar", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addToolBar(QToolBar *toolbar)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QToolBar *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addToolBar(QToolBar*)
                cppSelf->addToolBar(cppArg0);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArgs[0]);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // addToolBar(Qt::ToolBarArea area, QToolBar *toolbar)
        {
            ::Qt::ToolBarArea cppArg0{Qt::NoToolBarArea};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QToolBar *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addToolBar(Qt::ToolBarArea,QToolBar*)
                cppSelf->addToolBar(cppArg0, cppArg1);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArgs[1]);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 2: // addToolBar(const QString &title)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addToolBar(QString)
                QToolBar * cppResult = cppSelf->addToolBar(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_addToolBarBreak(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addToolBarBreak", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    if (PyArg_ParseTuple(args, "|O:addToolBarBreak", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::addToolBarBreak(Qt::ToolBarArea=)
    if (numArgs == 0) {
        overloadId = 0; // addToolBarBreak(Qt::ToolBarArea)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolBarArea_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // addToolBarBreak(Qt::ToolBarArea)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addToolBarBreak", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"area", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolBarArea_IDX])))->converter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addToolBarBreak", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);
            }
        }
        ::Qt::ToolBarArea cppArg0(Qt::TopToolBarArea);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addToolBarBreak(Qt::ToolBarArea)
            cppSelf->addToolBarBreak(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_centralWidget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // centralWidget()const
        QWidget * cppResult = const_cast<const ::QMainWindow *>(cppSelf)->centralWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_contextMenuEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::contextMenuEvent(QContextMenuEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), (pyArg)))) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contextMenuEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QContextMenuEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contextMenuEvent(QContextMenuEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMainWindow::contextMenuEvent(cppArg0)
                : cppSelf->contextMenuEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_corner(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::corner(Qt::Corner)const->Qt::DockWidgetArea
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Corner_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // corner(Qt::Corner)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "corner", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::Qt::Corner cppArg0{Qt::TopLeftCorner};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // corner(Qt::Corner)const
            Qt::DockWidgetArea cppResult = const_cast<const ::QMainWindow *>(cppSelf)->corner(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DockWidgetArea_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_createPopupMenu(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createPopupMenu()
        QMenu * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QMainWindow::createPopupMenu()
            : cppSelf->createPopupMenu();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMenu_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_dockOptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dockOptions()const
        QFlags<QMainWindow::DockOption> cppResult = const_cast<const ::QMainWindow *>(cppSelf)->dockOptions();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QMainWindow_DockOption_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_dockWidgetArea(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::dockWidgetArea(QDockWidget*)const->Qt::DockWidgetArea
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArg)))) {
        overloadId = 0; // dockWidgetArea(QDockWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dockWidgetArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDockWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dockWidgetArea(QDockWidget*)const
            Qt::DockWidgetArea cppResult = const_cast<const ::QMainWindow *>(cppSelf)->dockWidgetArea(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DockWidgetArea_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_documentMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentMode()const
        bool cppResult = const_cast<const ::QMainWindow *>(cppSelf)->documentMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMainWindow::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_iconSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iconSize()const
        QSize cppResult = const_cast<const ::QMainWindow *>(cppSelf)->iconSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_insertToolBar(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertToolBar", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::insertToolBar(QToolBar*,QToolBar*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertToolBar(QToolBar*,QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertToolBar", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QToolBar *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QToolBar *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertToolBar(QToolBar*,QToolBar*)
            cppSelf->insertToolBar(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_insertToolBarBreak(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::insertToolBarBreak(QToolBar*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArg)))) {
        overloadId = 0; // insertToolBarBreak(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertToolBarBreak", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QToolBar *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertToolBarBreak(QToolBar*)
            cppSelf->insertToolBarBreak(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_isAnimated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAnimated()const
        bool cppResult = const_cast<const ::QMainWindow *>(cppSelf)->isAnimated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_isDockNestingEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDockNestingEnabled()const
        bool cppResult = const_cast<const ::QMainWindow *>(cppSelf)->isDockNestingEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_isSeparator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::isSeparator(QPoint)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // isSeparator(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSeparator", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isSeparator(QPoint)const
            bool cppResult = const_cast<const ::QMainWindow *>(cppSelf)->isSeparator(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_menuBar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // menuBar()const
        QMenuBar * cppResult = const_cast<const ::QMainWindow *>(cppSelf)->menuBar();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMenuBar_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_menuWidget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // menuWidget()const
        QWidget * cppResult = const_cast<const ::QMainWindow *>(cppSelf)->menuWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_removeDockWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::removeDockWidget(QDockWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArg)))) {
        overloadId = 0; // removeDockWidget(QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeDockWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDockWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeDockWidget(QDockWidget*)
            cppSelf->removeDockWidget(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(Py_None, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_removeToolBar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::removeToolBar(QToolBar*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArg)))) {
        overloadId = 0; // removeToolBar(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeToolBar", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QToolBar *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeToolBar(QToolBar*)
            cppSelf->removeToolBar(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(Py_None, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_removeToolBarBreak(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::removeToolBarBreak(QToolBar*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArg)))) {
        overloadId = 0; // removeToolBarBreak(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeToolBarBreak", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QToolBar *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeToolBarBreak(QToolBar*)
            cppSelf->removeToolBarBreak(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_resizeDocks(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resizeDocks", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::resizeDocks(QList<QDockWidget*>,QList<int>,Qt::Orientation)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QDockWidgetPTR_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // resizeDocks(QList<QDockWidget*>,QList<int>,Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resizeDocks", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::QList<QDockWidget*> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<int> cppArg1_local;
        ::QList<int> *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::Qt::Orientation cppArg2 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeDocks(QList<QDockWidget*>,QList<int>,Qt::Orientation)
            cppSelf->resizeDocks(cppArg0, *cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_restoreDockWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::restoreDockWidget(QDockWidget*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArg)))) {
        overloadId = 0; // restoreDockWidget(QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "restoreDockWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDockWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // restoreDockWidget(QDockWidget*)
            bool cppResult = cppSelf->restoreDockWidget(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_restoreState(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "restoreState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    if (PyArg_ParseTuple(args, "|OO:restoreState", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::restoreState(QByteArray,int=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // restoreState(QByteArray,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // restoreState(QByteArray,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "restoreState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"version", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "restoreState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // restoreState(QByteArray,int)
            bool cppResult = cppSelf->restoreState(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_saveState(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "saveState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    if (PyArg_ParseTuple(args, "|O:saveState", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::saveState(int=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // saveState(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // saveState(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "saveState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"version", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "saveState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // saveState(int)const
            QByteArray cppResult = const_cast<const ::QMainWindow *>(cppSelf)->saveState(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_setAnimated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setAnimated(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAnimated(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnimated", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnimated(bool)
            cppSelf->setAnimated(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setCentralWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setCentralWidget(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setCentralWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCentralWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCentralWidget(QWidget*)
            // Begin code injection
            // TEMPLATE - replace_child - START
            QWidget* oldChild = cppSelf->centralWidget();
            if (oldChild != nullptr && oldChild != cppArg0) {
                Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), oldChild));
                Shiboken::Object::setParent(nullptr, pyChild);
                Shiboken::Object::releaseOwnership(pyChild);
            }
            Shiboken::Object::setParent(self, pyArg);
            // TEMPLATE - replace_child - END
            // End of code injection

            cppSelf->setCentralWidget(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setCorner(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCorner", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::setCorner(Qt::Corner,Qt::DockWidgetArea)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Corner_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DockWidgetArea_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setCorner(Qt::Corner,Qt::DockWidgetArea)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCorner", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::Qt::Corner cppArg0{Qt::TopLeftCorner};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::DockWidgetArea cppArg1{Qt::NoDockWidgetArea};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCorner(Qt::Corner,Qt::DockWidgetArea)
            cppSelf->setCorner(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setDockNestingEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setDockNestingEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDockNestingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDockNestingEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDockNestingEnabled(bool)
            cppSelf->setDockNestingEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setDockOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setDockOptions(QFlags<QMainWindow::DockOption>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QMainWindow_DockOption_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setDockOptions(QFlags<QMainWindow::DockOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDockOptions", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::QFlags<QMainWindow::DockOption> cppArg0 = QFlags<QMainWindow::DockOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDockOptions(QFlags<QMainWindow::DockOption>)
            cppSelf->setDockOptions(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setDocumentMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setDocumentMode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDocumentMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocumentMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocumentMode(bool)
            cppSelf->setDocumentMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setIconSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setIconSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setIconSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIconSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIconSize(QSize)
            cppSelf->setIconSize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setMenuBar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setMenuBar(QMenuBar*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMenuBar_IDX]), (pyArg)))) {
        overloadId = 0; // setMenuBar(QMenuBar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMenuBar", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMenuBar *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMenuBar(QMenuBar*)
            // Begin code injection
            // TEMPLATE - replace_child - START
            QMenuBar* oldChild = cppSelf->menuBar();
            if (oldChild != nullptr && oldChild != cppArg0) {
                Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMenuBar_IDX]), oldChild));
                Shiboken::Object::setParent(nullptr, pyChild);
                Shiboken::Object::releaseOwnership(pyChild);
            }
            Shiboken::Object::setParent(self, pyArg);
            // TEMPLATE - replace_child - END
            // End of code injection

            cppSelf->setMenuBar(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setMenuWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setMenuWidget(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setMenuWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMenuWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMenuWidget(QWidget*)
            // Begin code injection
            // TEMPLATE - replace_child - START
            QWidget* oldChild = cppSelf->menuWidget();
            if (oldChild != nullptr && oldChild != cppArg0) {
                Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), oldChild));
                Shiboken::Object::setParent(nullptr, pyChild);
                Shiboken::Object::releaseOwnership(pyChild);
            }
            Shiboken::Object::setParent(self, pyArg);
            // TEMPLATE - replace_child - END
            // End of code injection

            cppSelf->setMenuWidget(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setStatusBar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setStatusBar(QStatusBar*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStatusBar_IDX]), (pyArg)))) {
        overloadId = 0; // setStatusBar(QStatusBar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStatusBar", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStatusBar *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStatusBar(QStatusBar*)
            // Begin code injection
            // TEMPLATE - replace_child - START
            QStatusBar* oldChild = cppSelf->statusBar();
            if (oldChild != nullptr && oldChild != cppArg0) {
                Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStatusBar_IDX]), oldChild));
                Shiboken::Object::setParent(nullptr, pyChild);
                Shiboken::Object::releaseOwnership(pyChild);
            }
            Shiboken::Object::setParent(self, pyArg);
            // TEMPLATE - replace_child - END
            // End of code injection

            cppSelf->setStatusBar(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setTabPosition(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTabPosition", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DockWidgetArea_IDX])))->flagsConverter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabPosition_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTabPosition", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::DockWidgetArea> cppArg0 = QFlags<Qt::DockWidgetArea>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QTabWidget::TabPosition cppArg1{QTabWidget::North};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
            cppSelf->setTabPosition(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setTabShape(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setTabShape(QTabWidget::TabShape)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabShape_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTabShape(QTabWidget::TabShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabShape", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::QTabWidget::TabShape cppArg0{QTabWidget::Rounded};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabShape(QTabWidget::TabShape)
            cppSelf->setTabShape(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setToolButtonStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setToolButtonStyle(Qt::ToolButtonStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolButtonStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setToolButtonStyle(Qt::ToolButtonStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setToolButtonStyle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::Qt::ToolButtonStyle cppArg0{Qt::ToolButtonIconOnly};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setToolButtonStyle(Qt::ToolButtonStyle)
            cppSelf->setToolButtonStyle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_setUnifiedTitleAndToolBarOnMac(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::setUnifiedTitleAndToolBarOnMac(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUnifiedTitleAndToolBarOnMac(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUnifiedTitleAndToolBarOnMac", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUnifiedTitleAndToolBarOnMac(bool)
            cppSelf->setUnifiedTitleAndToolBarOnMac(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_splitDockWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "splitDockWidget", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "splitDockWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDockWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDockWidget *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::Qt::Orientation cppArg2 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
            cppSelf->splitDockWidget(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_statusBar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // statusBar()const
        QStatusBar * cppResult = const_cast<const ::QMainWindow *>(cppSelf)->statusBar();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStatusBar_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_tabPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::tabPosition(Qt::DockWidgetArea)const->QTabWidget::TabPosition
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DockWidgetArea_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // tabPosition(Qt::DockWidgetArea)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tabPosition", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        ::Qt::DockWidgetArea cppArg0{Qt::NoDockWidgetArea};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tabPosition(Qt::DockWidgetArea)const
            QTabWidget::TabPosition cppResult = const_cast<const ::QMainWindow *>(cppSelf)->tabPosition(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabPosition_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_tabShape(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabShape()const
        QTabWidget::TabShape cppResult = const_cast<const ::QMainWindow *>(cppSelf)->tabShape();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabShape_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_tabifiedDockWidgets(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::tabifiedDockWidgets(QDockWidget*)const->QList<QDockWidget*>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArg)))) {
        overloadId = 0; // tabifiedDockWidgets(QDockWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tabifiedDockWidgets", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDockWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tabifiedDockWidgets(QDockWidget*)const
            QList<QDockWidget*> cppResult = const_cast<const ::QMainWindow *>(cppSelf)->tabifiedDockWidgets(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QDockWidgetPTR_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_tabifyDockWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "tabifyDockWidget", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMainWindow::tabifyDockWidget(QDockWidget*,QDockWidget*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), (pyArgs[1])))) {
        overloadId = 0; // tabifyDockWidget(QDockWidget*,QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tabifyDockWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDockWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDockWidget *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tabifyDockWidget(QDockWidget*,QDockWidget*)
            cppSelf->tabifyDockWidget(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMainWindowFunc_takeCentralWidget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // takeCentralWidget()
        QWidget * cppResult = cppSelf->takeCentralWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_toolBarArea(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::toolBarArea(const QToolBar*)const->Qt::ToolBarArea
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArg)))) {
        overloadId = 0; // toolBarArea(const QToolBar*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "toolBarArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QToolBar *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toolBarArea(const QToolBar*)const
            Qt::ToolBarArea cppResult = const_cast<const ::QMainWindow *>(cppSelf)->toolBarArea(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolBarArea_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_toolBarBreak(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMainWindow::toolBarBreak(QToolBar*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]), (pyArg)))) {
        overloadId = 0; // toolBarBreak(QToolBar*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "toolBarBreak", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QToolBar *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toolBarBreak(QToolBar*)const
            bool cppResult = const_cast<const ::QMainWindow *>(cppSelf)->toolBarBreak(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_toolButtonStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toolButtonStyle()const
        Qt::ToolButtonStyle cppResult = const_cast<const ::QMainWindow *>(cppSelf)->toolButtonStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolButtonStyle_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMainWindowFunc_unifiedTitleAndToolBarOnMac(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unifiedTitleAndToolBarOnMac()const
        bool cppResult = const_cast<const ::QMainWindow *>(cppSelf)->unifiedTitleAndToolBarOnMac();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QMainWindow_PropertyStrings[] = {
    "animated:isAnimated:",
    "dockNestingEnabled:isDockNestingEnabled:",
    "dockOptions::",
    "documentMode::",
    "iconSize::",
    "tabShape::",
    "toolButtonStyle::",
    "unifiedTitleAndToolBarOnMac::",
    nullptr // Sentinel
};

static const char *Sbk_QMainWindow_EnumFlagInfo[] = {
    "DockOption:Flag:DockOptions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMainWindow_methods[] = {
    {"addDockWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_addDockWidget), METH_VARARGS, nullptr},
    {"addToolBar", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_addToolBar), METH_VARARGS, nullptr},
    {"addToolBarBreak", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_addToolBarBreak), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"centralWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_centralWidget), METH_NOARGS, nullptr},
    {"contextMenuEvent", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_contextMenuEvent), METH_O, nullptr},
    {"corner", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_corner), METH_O, nullptr},
    {"createPopupMenu", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_createPopupMenu), METH_NOARGS, nullptr},
    {"dockOptions", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_dockOptions), METH_NOARGS, nullptr},
    {"dockWidgetArea", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_dockWidgetArea), METH_O, nullptr},
    {"documentMode", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_documentMode), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_event), METH_O, nullptr},
    {"iconSize", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_iconSize), METH_NOARGS, nullptr},
    {"insertToolBar", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_insertToolBar), METH_VARARGS, nullptr},
    {"insertToolBarBreak", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_insertToolBarBreak), METH_O, nullptr},
    {"isAnimated", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_isAnimated), METH_NOARGS, nullptr},
    {"isDockNestingEnabled", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_isDockNestingEnabled), METH_NOARGS, nullptr},
    {"isSeparator", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_isSeparator), METH_O, nullptr},
    {"menuBar", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_menuBar), METH_NOARGS, nullptr},
    {"menuWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_menuWidget), METH_NOARGS, nullptr},
    {"removeDockWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_removeDockWidget), METH_O, nullptr},
    {"removeToolBar", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_removeToolBar), METH_O, nullptr},
    {"removeToolBarBreak", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_removeToolBarBreak), METH_O, nullptr},
    {"resizeDocks", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_resizeDocks), METH_VARARGS, nullptr},
    {"restoreDockWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_restoreDockWidget), METH_O, nullptr},
    {"restoreState", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_restoreState), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"saveState", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_saveState), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAnimated", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setAnimated), METH_O, nullptr},
    {"setCentralWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setCentralWidget), METH_O, nullptr},
    {"setCorner", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setCorner), METH_VARARGS, nullptr},
    {"setDockNestingEnabled", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setDockNestingEnabled), METH_O, nullptr},
    {"setDockOptions", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setDockOptions), METH_O, nullptr},
    {"setDocumentMode", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setDocumentMode), METH_O, nullptr},
    {"setIconSize", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setIconSize), METH_O, nullptr},
    {"setMenuBar", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setMenuBar), METH_O, nullptr},
    {"setMenuWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setMenuWidget), METH_O, nullptr},
    {"setStatusBar", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setStatusBar), METH_O, nullptr},
    {"setTabPosition", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setTabPosition), METH_VARARGS, nullptr},
    {"setTabShape", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setTabShape), METH_O, nullptr},
    {"setToolButtonStyle", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setToolButtonStyle), METH_O, nullptr},
    {"setUnifiedTitleAndToolBarOnMac", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_setUnifiedTitleAndToolBarOnMac), METH_O, nullptr},
    {"splitDockWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_splitDockWidget), METH_VARARGS, nullptr},
    {"statusBar", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_statusBar), METH_NOARGS, nullptr},
    {"tabPosition", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_tabPosition), METH_O, nullptr},
    {"tabShape", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_tabShape), METH_NOARGS, nullptr},
    {"tabifiedDockWidgets", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_tabifiedDockWidgets), METH_O, nullptr},
    {"tabifyDockWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_tabifyDockWidget), METH_VARARGS, nullptr},
    {"takeCentralWidget", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_takeCentralWidget), METH_NOARGS, nullptr},
    {"toolBarArea", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_toolBarArea), METH_O, nullptr},
    {"toolBarBreak", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_toolBarBreak), METH_O, nullptr},
    {"toolButtonStyle", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_toolButtonStyle), METH_NOARGS, nullptr},
    {"unifiedTitleAndToolBarOnMac", reinterpret_cast<PyCFunction>(Sbk_QMainWindowFunc_unifiedTitleAndToolBarOnMac), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QMainWindow_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QMainWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QMainWindowWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QMainWindow_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMainWindow_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QMainWindowSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QMainWindow *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMainWindow_Type = nullptr;
static PyTypeObject *Sbk_QMainWindow_TypeF(void)
{
    return _Sbk_QMainWindow_Type;
}

static PyType_Slot Sbk_QMainWindow_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QMainWindow_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMainWindow_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMainWindow_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMainWindow_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMainWindow_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMainWindow_spec = {
    "2:PySide6.QtWidgets.QMainWindow",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMainWindow_slots
};

} //extern "C"

static void *Sbk_QMainWindow_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QMainWindow *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QMainWindow *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QMainWindow *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QMainWindow_DockOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMainWindow::DockOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMainWindow::DockOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMainWindow_DockOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_DockOption_IDX])))
        return Enum_PythonToCpp_QMainWindow_DockOption;
    return {};
}

static PyObject *QMainWindow_DockOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMainWindow::DockOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMainWindow::DockOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_DockOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QMainWindow_DockOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QMainWindow::DockOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QMainWindow::DockOption> *>(cppOut) = value;

}

static PyObject *QMainWindow_DockOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QMainWindow::DockOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_DockOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMainWindow_PythonToCpp_QMainWindow_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMainWindow_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMainWindow_PythonToCpp_QMainWindow_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMainWindow_TypeF()))
        return QMainWindow_PythonToCpp_QMainWindow_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMainWindow_PTR_CppToPython_QMainWindow(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QMainWindow *>(const_cast<void *>(cppIn)), Sbk_QMainWindow_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMainWindow_SignatureStrings[] = {
    "PySide6.QtWidgets.QMainWindow(self,parent:PySide6.QtWidgets.QWidget=nullptr,flags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags(),*:KeywordOnly=None,iconSize:QSize=None,toolButtonStyle:Qt.ToolButtonStyle=None,animated:bool=None,documentMode:bool=None,tabShape:QTabWidget.TabShape=None,dockNestingEnabled:bool=None,dockOptions:PySide6.QtWidgets.QMainWindow.DockOption=None,unifiedTitleAndToolBarOnMac:bool=None)",
    "1:PySide6.QtWidgets.QMainWindow.addDockWidget(self,area:PySide6.QtCore.Qt.DockWidgetArea,dockwidget:PySide6.QtWidgets.QDockWidget)",
    "0:PySide6.QtWidgets.QMainWindow.addDockWidget(self,area:PySide6.QtCore.Qt.DockWidgetArea,dockwidget:PySide6.QtWidgets.QDockWidget,orientation:PySide6.QtCore.Qt.Orientation)",
    "2:PySide6.QtWidgets.QMainWindow.addToolBar(self,toolbar:PySide6.QtWidgets.QToolBar)",
    "1:PySide6.QtWidgets.QMainWindow.addToolBar(self,area:PySide6.QtCore.Qt.ToolBarArea,toolbar:PySide6.QtWidgets.QToolBar)",
    "0:PySide6.QtWidgets.QMainWindow.addToolBar(self,title:QString)->PySide6.QtWidgets.QToolBar",
    "PySide6.QtWidgets.QMainWindow.addToolBarBreak(self,area:PySide6.QtCore.Qt.ToolBarArea=Qt.TopToolBarArea)",
    "PySide6.QtWidgets.QMainWindow.centralWidget(self)->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QMainWindow.contextMenuEvent(self,event:PySide6.QtGui.QContextMenuEvent)",
    "PySide6.QtWidgets.QMainWindow.corner(self,corner:PySide6.QtCore.Qt.Corner)->PySide6.QtCore.Qt.DockWidgetArea",
    "PySide6.QtWidgets.QMainWindow.createPopupMenu(self)->PySide6.QtWidgets.QMenu",
    "PySide6.QtWidgets.QMainWindow.dockOptions(self)->PySide6.QtWidgets.QMainWindow.DockOption",
    "PySide6.QtWidgets.QMainWindow.dockWidgetArea(self,dockwidget:PySide6.QtWidgets.QDockWidget)->PySide6.QtCore.Qt.DockWidgetArea",
    "PySide6.QtWidgets.QMainWindow.documentMode(self)->bool",
    "PySide6.QtWidgets.QMainWindow.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QMainWindow.iconSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QMainWindow.insertToolBar(self,before:PySide6.QtWidgets.QToolBar,toolbar:PySide6.QtWidgets.QToolBar)",
    "PySide6.QtWidgets.QMainWindow.insertToolBarBreak(self,before:PySide6.QtWidgets.QToolBar)",
    "PySide6.QtWidgets.QMainWindow.isAnimated(self)->bool",
    "PySide6.QtWidgets.QMainWindow.isDockNestingEnabled(self)->bool",
    "PySide6.QtWidgets.QMainWindow.isSeparator(self,pos:PySide6.QtCore.QPoint)->bool",
    "PySide6.QtWidgets.QMainWindow.menuBar(self)->PySide6.QtWidgets.QMenuBar",
    "PySide6.QtWidgets.QMainWindow.menuWidget(self)->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QMainWindow.removeDockWidget(self,dockwidget:PySide6.QtWidgets.QDockWidget)",
    "PySide6.QtWidgets.QMainWindow.removeToolBar(self,toolbar:PySide6.QtWidgets.QToolBar)",
    "PySide6.QtWidgets.QMainWindow.removeToolBarBreak(self,before:PySide6.QtWidgets.QToolBar)",
    "PySide6.QtWidgets.QMainWindow.resizeDocks(self,docks:QList[PySide6.QtWidgets.QDockWidget],sizes:QList[int],orientation:PySide6.QtCore.Qt.Orientation)",
    "PySide6.QtWidgets.QMainWindow.restoreDockWidget(self,dockwidget:PySide6.QtWidgets.QDockWidget)->bool",
    "PySide6.QtWidgets.QMainWindow.restoreState(self,state:typing.Union[PySide6.QtCore.QByteArray, char*],version:int=0)->bool",
    "PySide6.QtWidgets.QMainWindow.saveState(self,version:int=0)->PySide6.QtCore.QByteArray",
    "PySide6.QtWidgets.QMainWindow.setAnimated(self,enabled:bool)",
    "PySide6.QtWidgets.QMainWindow.setCentralWidget(self,widget:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QMainWindow.setCorner(self,corner:PySide6.QtCore.Qt.Corner,area:PySide6.QtCore.Qt.DockWidgetArea)",
    "PySide6.QtWidgets.QMainWindow.setDockNestingEnabled(self,enabled:bool)",
    "PySide6.QtWidgets.QMainWindow.setDockOptions(self,options:PySide6.QtWidgets.QMainWindow.DockOption)",
    "PySide6.QtWidgets.QMainWindow.setDocumentMode(self,enabled:bool)",
    "PySide6.QtWidgets.QMainWindow.setIconSize(self,iconSize:PySide6.QtCore.QSize)",
    "PySide6.QtWidgets.QMainWindow.setMenuBar(self,menubar:PySide6.QtWidgets.QMenuBar)",
    "PySide6.QtWidgets.QMainWindow.setMenuWidget(self,menubar:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QMainWindow.setStatusBar(self,statusbar:PySide6.QtWidgets.QStatusBar)",
    "PySide6.QtWidgets.QMainWindow.setTabPosition(self,areas:PySide6.QtCore.Qt.DockWidgetArea,tabPosition:PySide6.QtWidgets.QTabWidget.TabPosition)",
    "PySide6.QtWidgets.QMainWindow.setTabShape(self,tabShape:PySide6.QtWidgets.QTabWidget.TabShape)",
    "PySide6.QtWidgets.QMainWindow.setToolButtonStyle(self,toolButtonStyle:PySide6.QtCore.Qt.ToolButtonStyle)",
    "PySide6.QtWidgets.QMainWindow.setUnifiedTitleAndToolBarOnMac(self,set:bool)",
    "PySide6.QtWidgets.QMainWindow.splitDockWidget(self,after:PySide6.QtWidgets.QDockWidget,dockwidget:PySide6.QtWidgets.QDockWidget,orientation:PySide6.QtCore.Qt.Orientation)",
    "PySide6.QtWidgets.QMainWindow.statusBar(self)->PySide6.QtWidgets.QStatusBar",
    "PySide6.QtWidgets.QMainWindow.tabPosition(self,area:PySide6.QtCore.Qt.DockWidgetArea)->PySide6.QtWidgets.QTabWidget.TabPosition",
    "PySide6.QtWidgets.QMainWindow.tabShape(self)->PySide6.QtWidgets.QTabWidget.TabShape",
    "PySide6.QtWidgets.QMainWindow.tabifiedDockWidgets(self,dockwidget:PySide6.QtWidgets.QDockWidget)->QList[PySide6.QtWidgets.QDockWidget]",
    "PySide6.QtWidgets.QMainWindow.tabifyDockWidget(self,first:PySide6.QtWidgets.QDockWidget,second:PySide6.QtWidgets.QDockWidget)",
    "PySide6.QtWidgets.QMainWindow.takeCentralWidget(self)->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QMainWindow.toolBarArea(self,toolbar:PySide6.QtWidgets.QToolBar)->PySide6.QtCore.Qt.ToolBarArea",
    "PySide6.QtWidgets.QMainWindow.toolBarBreak(self,toolbar:PySide6.QtWidgets.QToolBar)->bool",
    "PySide6.QtWidgets.QMainWindow.toolButtonStyle(self)->PySide6.QtCore.Qt.ToolButtonStyle",
    "PySide6.QtWidgets.QMainWindow.unifiedTitleAndToolBarOnMac(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMainWindow_SignatureByteSize = 938;
static constexpr uint8_t QMainWindow_SignatureBytes[938] = {
    0x78, 0xda, 0xc5, 0x58, 0xcd, 0x6f, 0xda, 0x30, 0x14, 0xbf, 0xf7, 0xaf, 0xd8, 0xb1, 0x54, 0x59,
    0xd4, 0xed, 0xb0, 0x03, 0x12, 0x93, 0x28, 0xed, 0xa6, 0x69, 0xa3, 0x80, 0xa0, 0xea, 0xa1, 0xea,
    0xc1, 0x90, 0x47, 0x6b, 0x91, 0xda, 0x91, 0xed, 0xd0, 0x65, 0x7f, 0xfd, 0xec, 0x38, 0x10, 0x07,
    0x1c, 0xfc, 0xb2, 0x75, 0xda, 0xa5, 0x4d, 0xe2, 0xe7, 0xdf, 0xfb, 0xf0, 0xcf, 0xef, 0x83, 0x69,
    0x31, 0xa7, 0x09, 0x7c, 0x8a, 0x67, 0xea, 0x9e, 0x26, 0x4f, 0xa0, 0x64, 0x3c, 0x1b, 0x13, 0xca,
    0xee, 0x29, 0x4b, 0xf8, 0xeb, 0xb9, 0x84, 0x74, 0x1d, 0x65, 0x44, 0x00, 0x53, 0xfd, 0xe9, 0xb1,
    0xa4, 0x7d, 0x18, 0xb0, 0x3c, 0x4d, 0x33, 0x25, 0xa2, 0x75, 0x4a, 0x9e, 0xa4, 0x23, 0x37, 0xe2,
    0x02, 0xf4, 0xbf, 0xd8, 0x82, 0x2d, 0x8a, 0x0c, 0x06, 0xfb, 0xb7, 0x2f, 0x46, 0xf6, 0xbc, 0x17,
    0x5d, 0xf4, 0xbf, 0x43, 0xf1, 0xca, 0x45, 0x32, 0x61, 0x69, 0x31, 0xb8, 0xe5, 0x0c, 0x22, 0xba,
    0xe2, 0x6c, 0x4e, 0x7f, 0x41, 0x7f, 0x66, 0xfe, 0xda, 0x6f, 0x8a, 0xf3, 0xf4, 0x2a, 0x57, 0x4a,
    0xaf, 0xa8, 0x22, 0xd5, 0x4b, 0x2a, 0x5e, 0x34, 0x3f, 0x59, 0x39, 0xc2, 0xe8, 0x0b, 0x51, 0x90,
    0xf4, 0x97, 0x7a, 0xd5, 0x7e, 0x4a, 0xf8, 0x2a, 0x7f, 0xd1, 0x0e, 0x8c, 0x79, 0x02, 0xce, 0x67,
    0x45, 0x96, 0xf3, 0x67, 0x92, 0x69, 0xa8, 0x05, 0x59, 0x5a, 0x47, 0xe2, 0x45, 0xf5, 0x6d, 0xbf,
    0x71, 0x73, 0x0b, 0x52, 0x51, 0xf6, 0x74, 0xc3, 0xc8, 0x32, 0x3d, 0x44, 0xdd, 0x4c, 0x32, 0x45,
    0x39, 0x93, 0xbe, 0xc8, 0xd4, 0x31, 0x8c, 0xaf, 0xf7, 0x92, 0x76, 0x67, 0xce, 0xe8, 0x9a, 0x42,
    0xb2, 0xa0, 0x2a, 0x85, 0x21, 0x4b, 0x4a, 0x37, 0x88, 0x98, 0xb0, 0x31, 0x59, 0xd5, 0xf8, 0xbd,
    0xb3, 0x0f, 0x01, 0x58, 0x92, 0x24, 0x06, 0xd9, 0x2e, 0xd9, 0x83, 0xd2, 0xe7, 0x44, 0x3c, 0xe1,
    0xaf, 0xc5, 0x86, 0x5a, 0xa0, 0xb4, 0xfc, 0xb5, 0x7c, 0xf5, 0x69, 0xa8, 0x85, 0x7b, 0x67, 0x97,
    0xff, 0xdb, 0x84, 0x88, 0x0b, 0xaa, 0x4f, 0x8e, 0x98, 0xe0, 0x79, 0x50, 0x27, 0xf5, 0x6a, 0xef,
    0xec, 0x63, 0xd8, 0xd8, 0x2a, 0xd4, 0xd6, 0x52, 0xc3, 0xa8, 0x25, 0x11, 0xbe, 0x5d, 0x95, 0x1c,
    0xea, 0x0c, 0x1a, 0x98, 0x2d, 0xde, 0x57, 0x32, 0xa5, 0xeb, 0x18, 0xb5, 0x97, 0x5d, 0x5d, 0x31,
    0x54, 0xd2, 0xb7, 0x45, 0x09, 0x4d, 0xd5, 0xde, 0xfb, 0xcf, 0xed, 0xd8, 0x67, 0x58, 0xe0, 0x2b,
    0x6d, 0xeb, 0x06, 0xeb, 0xd4, 0xa0, 0x7c, 0xcd, 0x9c, 0x2f, 0xbd, 0x80, 0xa2, 0x95, 0x3e, 0x37,
    0x41, 0x52, 0x87, 0x39, 0x7e, 0xb3, 0xed, 0x43, 0x08, 0x8c, 0x33, 0x05, 0x3f, 0xd5, 0x18, 0x58,
    0x7e, 0xb3, 0xd5, 0xc0, 0xd6, 0x6c, 0xd8, 0x36, 0x93, 0xd6, 0xd7, 0x9c, 0xc6, 0xb3, 0xd1, 0x81,
    0x68, 0xd0, 0x4e, 0x2e, 0x18, 0x54, 0x51, 0xb6, 0xcf, 0x9e, 0x48, 0x8c, 0xca, 0x85, 0x86, 0x03,
    0x7e, 0xde, 0x87, 0x94, 0x69, 0x11, 0x05, 0x53, 0x9e, 0xe5, 0x99, 0x31, 0xf0, 0x44, 0x58, 0xcc,
    0x72, 0x00, 0xcc, 0xc9, 0x4f, 0xa7, 0x80, 0x7c, 0x69, 0x0a, 0x81, 0x5c, 0xfb, 0x64, 0x63, 0x83,
    0xce, 0x29, 0x7f, 0x1d, 0x24, 0x37, 0x9b, 0xef, 0x1c, 0x33, 0x59, 0x33, 0xb0, 0x0d, 0xda, 0x89,
    0x61, 0xcd, 0xb0, 0x74, 0x40, 0x61, 0xed, 0xea, 0xd3, 0x71, 0x5c, 0x2d, 0x94, 0x59, 0x0b, 0x41,
    0x30, 0x09, 0x42, 0x35, 0x2e, 0xf1, 0x12, 0xd6, 0x7a, 0xf7, 0x89, 0xbc, 0x80, 0x4a, 0x1d, 0x1d,
    0xd4, 0x3a, 0x57, 0x3c, 0xa8, 0x3b, 0x08, 0x2c, 0x87, 0x55, 0xe1, 0xed, 0x70, 0x26, 0x54, 0x5e,
    0x1f, 0x55, 0xd8, 0x4e, 0xdb, 0xe7, 0xa0, 0x5b, 0x13, 0xa2, 0x78, 0x15, 0xc1, 0x8c, 0x1f, 0x37,
    0x1f, 0x53, 0x4e, 0xb1, 0xc7, 0xaa, 0x59, 0x95, 0xef, 0x4e, 0xa3, 0xfd, 0xda, 0x85, 0x93, 0xa8,
    0xc1, 0x79, 0x9b, 0xc4, 0x26, 0xe0, 0x85, 0x6f, 0xe1, 0xb0, 0xc4, 0xe2, 0xeb, 0x37, 0x06, 0xbd,
    0x73, 0x4d, 0xec, 0x00, 0xfa, 0x96, 0x0c, 0x13, 0x20, 0xf5, 0xb5, 0x32, 0xde, 0xc9, 0x3a, 0x0c,
    0xb2, 0x3f, 0xfb, 0x41, 0xa5, 0x7a, 0x38, 0x19, 0x87, 0xc7, 0xc8, 0xec, 0xdc, 0x89, 0x6a, 0x3a,
    0x3c, 0x76, 0x69, 0x2b, 0x82, 0x56, 0x69, 0xfa, 0xfd, 0xf9, 0x11, 0xa1, 0x88, 0x59, 0x29, 0x99,
    0x6b, 0x93, 0x6c, 0xce, 0x89, 0xa4, 0x79, 0xec, 0xab, 0x22, 0xd3, 0x17, 0x27, 0xbe, 0x63, 0xda,
    0xd0, 0x87, 0x43, 0x37, 0xae, 0x0a, 0x05, 0x43, 0x21, 0x48, 0x11, 0xbd, 0x5b, 0x3d, 0x13, 0x71,
    0xf1, 0x18, 0x6d, 0x41, 0x48, 0xe3, 0xb0, 0x8e, 0xc0, 0xe0, 0x12, 0xa7, 0x59, 0x92, 0xad, 0xab,
    0xf6, 0x10, 0xa1, 0x55, 0x67, 0x08, 0x56, 0x67, 0x7a, 0x37, 0x5d, 0x44, 0xe0, 0xb4, 0xd7, 0xbd,
    0xf0, 0xe6, 0xd1, 0x51, 0xf7, 0x10, 0xb5, 0x47, 0x1b, 0x77, 0x19, 0x0c, 0x2a, 0xbe, 0xd6, 0xe3,
    0xda, 0x5c, 0x84, 0xce, 0x96, 0x04, 0xd8, 0x35, 0x20, 0xd7, 0x07, 0xc5, 0x3e, 0xe2, 0x1d, 0x27,
    0x13, 0x9c, 0x8e, 0x66, 0xe1, 0xed, 0x6a, 0xe4, 0x37, 0xb7, 0x6c, 0xd6, 0x43, 0x9e, 0xaf, 0x7a,
    0x22, 0xd0, 0xc6, 0x4e, 0xb6, 0x8e, 0x4c, 0xca, 0x6d, 0xc9, 0x5b, 0x95, 0x1c, 0x12, 0xd1, 0xa5,
    0xd4, 0x09, 0x50, 0x34, 0xa7, 0xcc, 0xe5, 0xc9, 0xe5, 0xde, 0x4e, 0x59, 0xbe, 0xb6, 0x80, 0xee,
    0x65, 0x11, 0xb8, 0x7a, 0x50, 0x9d, 0x72, 0x49, 0xcd, 0xd1, 0xd5, 0x4d, 0xba, 0x0c, 0x0f, 0x5e,
    0xaa, 0xde, 0xe7, 0xcd, 0xc5, 0xee, 0x24, 0xbc, 0x13, 0xc4, 0x99, 0x53, 0xce, 0xcd, 0x55, 0x15,
    0xd9, 0x4d, 0xd6, 0x21, 0x0d, 0xa5, 0x14, 0x06, 0xbe, 0x39, 0xe9, 0xd7, 0xb5, 0xca, 0xfd, 0x45,
    0xa0, 0x65, 0x42, 0xa9, 0x25, 0x10, 0x8a, 0xee, 0xda, 0x47, 0xf3, 0xea, 0x00, 0x75, 0x8e, 0x41,
    0xd1, 0x3d, 0x4b, 0xa9, 0x3a, 0x9a, 0x8d, 0xd7, 0x0a, 0x44, 0x60, 0xe0, 0xfd, 0x17, 0x93, 0x71,
    0xc0, 0xd4, 0x06, 0x45, 0xfd, 0xdd, 0xca, 0x9e, 0x9a, 0x01, 0x2c, 0xe5, 0xa3, 0x65, 0x38, 0x4f,
    0xfa, 0x27, 0x56, 0x1f, 0x17, 0xc3, 0xfa, 0x6b, 0x1e, 0x22, 0x60, 0x4b, 0xe1, 0x30, 0x66, 0x49,
    0x8a, 0xda, 0x66, 0xd9, 0xb9, 0xc8, 0x63, 0xba, 0x14, 0x8c, 0x19, 0xc5, 0x21, 0xa5, 0xd6, 0x54,
    0xc8, 0x10, 0x53, 0x24, 0xe8, 0x54, 0x9b, 0xfc, 0x5d, 0xaf, 0xa8, 0xc8, 0x06, 0x46, 0x6f, 0x39,
    0xb3, 0xab, 0xfa, 0xb7, 0x02, 0x74, 0xeb, 0xe9, 0x9b, 0x1d, 0x9d, 0xdf, 0x1c, 0x70, 0x1a, 0x9d,
    0x9e, 0x14, 0xa5, 0x12, 0xd1, 0x25, 0x29, 0x4f, 0x7a, 0x6a, 0x37, 0xb6, 0x16, 0x0c, 0xc0, 0xe6,
    0x81, 0x64, 0xb4, 0x33, 0xee, 0x37, 0xd1, 0x36, 0xee, 0xb6
};
#endif

PyTypeObject *init_QMainWindow(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX].type;

    Shiboken::AutoDecRef Sbk_QMainWindow_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QMainWindow_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMainWindow",
        "QMainWindow*",
        &Sbk_QMainWindow_spec,
        &Shiboken::callCppDestructor< QMainWindow >,
        Sbk_QMainWindow_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QMainWindow_TypeF(); // references _Sbk_QMainWindow_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMainWindow_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMainWindow_SignatureBytes, QMainWindow_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMainWindow_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMainWindow_PythonToCpp_QMainWindow_PTR,
        is_QMainWindow_PythonToCpp_QMainWindow_PTR_Convertible,
        QMainWindow_PTR_CppToPython_QMainWindow);

    Shiboken::Conversions::registerConverterName(converter, "QMainWindow");
    Shiboken::Conversions::registerConverterName(converter, "QMainWindow*");
    Shiboken::Conversions::registerConverterName(converter, "QMainWindow&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMainWindow).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QMainWindowWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QMainWindow_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QMainWindow_TypeF(), &Sbk_QMainWindowSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QMainWindow_TypeF(), &Sbk_QMainWindow_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMainWindow_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DockOption'.
    const char *DockOption_Initializer[] = {
        "AnimatedDocks",
        "AllowNestedDocks",
        "AllowTabbedDocks",
        "ForceTabbedDocks",
        "VerticalTabs",
        "GroupedDragging",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DockOption_InitializerValues[] = {
        uint8_t(QMainWindow::DockOption::AnimatedDocks),    //  0x01  1
        uint8_t(QMainWindow::DockOption::AllowNestedDocks), //  0x02  2
        uint8_t(QMainWindow::DockOption::AllowTabbedDocks), //  0x04  4
        uint8_t(QMainWindow::DockOption::ForceTabbedDocks), //  0x08  8
        uint8_t(QMainWindow::DockOption::VerticalTabs),     //  0x10  16
        uint8_t(QMainWindow::DockOption::GroupedDragging)   //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMainWindow_TypeF(),
        "2:PySide6.QtWidgets.QMainWindow.DockOption",
        DockOption_Initializer, DockOption_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_DockOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QMainWindow_DockOption_IDX].type =
        EType;
    // Register converter for enum 'QMainWindow::DockOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMainWindow_DockOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMainWindow_DockOption,
            is_Enum_PythonToCpp_QMainWindow_DockOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMainWindow::DockOption");
        Shiboken::Conversions::registerConverterAlias(converter, "DockOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QMainWindow_DockOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QMainWindow_DockOption,
            is_Enum_PythonToCpp_QMainWindow_DockOption_Convertible);
        // Register converter for flag 'QFlags<QMainWindow::DockOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QMainWindow::DockOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QMainWindow::DockOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'DockOption' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QMainWindow::staticMetaObject);
    qRegisterMetaType< ::QMainWindow::DockOption >("QMainWindow::DockOption");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QMainWindow::staticMetaObject, sizeof(QMainWindowWrapper));

    return pyType;
}
