// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicswidget_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qgraphicspixmapitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qgraphicslayoutitem_wrapper.h"
#include "qwidget_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qfocusframe_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qaction.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicslayout.h>
#include <QtWidgets/qgraphicssceneevent.h>
#include <QtWidgets/qgraphicswidget.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qmargins.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsWidgetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsWidgetWrapper::QGraphicsWidgetWrapper(::QGraphicsItem * parent, ::QFlags<Qt::WindowType> wFlags) : QGraphicsWidget(parent, wFlags)
{
}

void QGraphicsWidgetWrapper::advance(int phase)
{
    static const char *funcName = "advance";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::advance(phase);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QGraphicsWidget", funcName, gil, pyOverride, phase);
}

::QRectF QGraphicsWidgetWrapper::boundingRect() const
{
    static const char *funcName = "boundingRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::boundingRect();
    }
    return QGraphicsItemWrapper::sbk_o_boundingRect("QGraphicsWidget", funcName, gil, pyOverride);
}

void QGraphicsWidgetWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::changeEvent(event);
    }
    sbk_o_changeEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_changeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsWidgetWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::closeEvent(event);
    }
    sbk_o_closeEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_closeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QCloseEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

bool QGraphicsWidgetWrapper::collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithItem(other, mode);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_collidesWithItem("QGraphicsWidget", funcName, gil, pyOverride, other, mode);
}

bool QGraphicsWidgetWrapper::collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithPath";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithPath(path, mode);
    }
    return QGraphicsItemWrapper::sbk_o_collidesWithPath("QGraphicsWidget", funcName, gil, pyOverride, path, mode);
}

void QGraphicsWidgetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QGraphicsWidget", funcName, gil, pyOverride, signal);
}

bool QGraphicsWidgetWrapper::contains(const ::QPointF & point) const
{
    static const char *funcName = "contains";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contains(point);
    }
    return QGraphicsItemWrapper::sbk_o_contains("QGraphicsWidget", funcName, gil, pyOverride, point);
}

void QGraphicsWidgetWrapper::contextMenuEvent(::QGraphicsSceneContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contextMenuEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_contextMenuEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QGraphicsWidget", funcName, gil, pyOverride, signal);
}

void QGraphicsWidgetWrapper::dragEnterEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragEnterEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragEnterEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::dragLeaveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragLeaveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragLeaveEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::dragMoveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragMoveEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::dropEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dropEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dropEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

bool QGraphicsWidgetWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QGraphicsWidget", funcName, gil, pyOverride, event);
}

bool QGraphicsWidgetWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QGraphicsWidget", funcName, gil, pyOverride, watched, event);
}

::QVariant QGraphicsWidgetWrapper::extension(const ::QVariant & variant) const
{
    static const char *funcName = "extension";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::extension(variant);
    }
    return QGraphicsItemWrapper::sbk_o_extension("QGraphicsWidget", funcName, gil, pyOverride, variant);
}

void QGraphicsWidgetWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusInEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_focusInEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

bool QGraphicsWidgetWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QGraphicsWidget", funcName, gil, pyOverride, next);
}

void QGraphicsWidgetWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusOutEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_focusOutEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const
{
    static const char *funcName = "getContentsMargins";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::getContentsMargins(left, top, right, bottom);
    }
    QGraphicsLayoutWrapper::sbk_o_getContentsMargins("QGraphicsWidget", funcName, gil, pyOverride, left, top, right, bottom);
}

void QGraphicsWidgetWrapper::grabKeyboardEvent(::QEvent * event)
{
    static const char *funcName = "grabKeyboardEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::grabKeyboardEvent(event);
    }
    sbk_o_grabKeyboardEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_grabKeyboardEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsWidgetWrapper::grabMouseEvent(::QEvent * event)
{
    static const char *funcName = "grabMouseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::grabMouseEvent(event);
    }
    sbk_o_grabMouseEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_grabMouseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsWidgetWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hideEvent(event);
    }
    sbk_o_hideEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_hideEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QHideEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsWidgetWrapper::hoverEnterEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverEnterEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverEnterEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::hoverLeaveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hoverLeaveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverLeaveEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::hoverMoveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hoverMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverMoveEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::initStyleOption(::QStyleOption * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::initStyleOption(option);
    }
    QFocusFrameWrapper::sbk_o_initStyleOption("QGraphicsWidget", funcName, gil, pyOverride, option);
}

void QGraphicsWidgetWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_inputMethodEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

::QVariant QGraphicsWidgetWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodQuery(query);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QGraphicsWidget", funcName, gil, pyOverride, query);
}

bool QGraphicsWidgetWrapper::isEmpty() const
{
    static const char *funcName = "isEmpty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayoutItem::isEmpty();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QGraphicsWidget", funcName, gil, pyOverride);
}

bool QGraphicsWidgetWrapper::isObscuredBy(const ::QGraphicsItem * item) const
{
    static const char *funcName = "isObscuredBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::isObscuredBy(item);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_isObscuredBy("QGraphicsWidget", funcName, gil, pyOverride, item);
}

::QVariant QGraphicsWidgetWrapper::itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value)
{
    static const char *funcName = "itemChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::itemChange(change, value);
    }
    return QGraphicsItemWrapper::sbk_o_itemChange("QGraphicsWidget", funcName, gil, pyOverride, change, value);
}

void QGraphicsWidgetWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyPressEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_keyPressEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyReleaseEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_keyReleaseEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseDoubleClickEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseDoubleClickEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::mouseMoveEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseMoveEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::mousePressEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mousePressEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mousePressEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::mouseReleaseEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseReleaseEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseReleaseEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::moveEvent(::QGraphicsSceneMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::moveEvent(event);
    }
    sbk_o_moveEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_moveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMoveEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMoveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMoveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QPainterPath QGraphicsWidgetWrapper::opaqueArea() const
{
    static const char *funcName = "opaqueArea";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::opaqueArea();
    }
    return QGraphicsItemWrapper::sbk_o_opaqueArea("QGraphicsWidget", funcName, gil, pyOverride);
}

void QGraphicsWidgetWrapper::paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::paint(painter, option, widget);
    }
    QGraphicsPixmapItemWrapper::sbk_o_paint("QGraphicsWidget", funcName, gil, pyOverride, painter, option, widget);
}

void QGraphicsWidgetWrapper::paintWindowFrame(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paintWindowFrame";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::paintWindowFrame(painter, option, widget);
    }
    sbk_o_paintWindowFrame("QGraphicsWidget", funcName, gil, pyOverride, painter, option, widget);
}

void QGraphicsWidgetWrapper::sbk_o_paintWindowFrame(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsWidgetWrapper::polishEvent()
{
    static const char *funcName = "polishEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::polishEvent();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QGraphicsWidget", funcName, gil, pyOverride);
}

::QVariant QGraphicsWidgetWrapper::propertyChange(const ::QString & propertyName, const ::QVariant & value)
{
    static const char *funcName = "propertyChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::propertyChange(propertyName, value);
    }
    return sbk_o_propertyChange("QGraphicsWidget", funcName, gil, pyOverride, propertyName, value);
}

::QVariant QGraphicsWidgetWrapper::sbk_o_propertyChange(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & propertyName, const ::QVariant & value)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &propertyName),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &propertyName),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsWidgetWrapper::resizeEvent(::QGraphicsSceneResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::resizeEvent(event);
    }
    sbk_o_resizeEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_resizeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneResizeEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

bool QGraphicsWidgetWrapper::sceneEvent(::QEvent * event)
{
    static const char *funcName = "sceneEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::sceneEvent(event);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_sceneEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

bool QGraphicsWidgetWrapper::sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event)
{
    static const char *funcName = "sceneEventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::sceneEventFilter(watched, event);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_sceneEventFilter("QGraphicsWidget", funcName, gil, pyOverride, watched, event);
}

void QGraphicsWidgetWrapper::setGeometry(const ::QRectF & rect)
{
    // This method belongs to a property.
    static const char *funcName = "2:setGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::setGeometry(rect);
    }
    QGraphicsLayoutItemWrapper::sbk_o_setGeometry("QGraphicsWidget", funcName, gil, pyOverride, rect);
}

::QPainterPath QGraphicsWidgetWrapper::shape() const
{
    static const char *funcName = "shape";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::shape();
    }
    return QGraphicsItemWrapper::sbk_o_opaqueArea("QGraphicsWidget", funcName, gil, pyOverride);
}

void QGraphicsWidgetWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::showEvent(event);
    }
    sbk_o_showEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_showEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QShowEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QSizeF QGraphicsWidgetWrapper::sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint) const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::sizeHint(which, constraint);
    }
    return QGraphicsLayoutItemWrapper::sbk_o_sizeHint("QGraphicsWidget", funcName, gil, pyOverride, which, constraint);
}

void QGraphicsWidgetWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

int QGraphicsWidgetWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::type();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QGraphicsWidget", funcName, gil, pyOverride);
}

void QGraphicsWidgetWrapper::ungrabKeyboardEvent(::QEvent * event)
{
    static const char *funcName = "ungrabKeyboardEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::ungrabKeyboardEvent(event);
    }
    sbk_o_ungrabKeyboardEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_ungrabKeyboardEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsWidgetWrapper::ungrabMouseEvent(::QEvent * event)
{
    static const char *funcName = "ungrabMouseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::ungrabMouseEvent(event);
    }
    sbk_o_ungrabMouseEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

void QGraphicsWidgetWrapper::sbk_o_ungrabMouseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QGraphicsWidgetWrapper::updateGeometry()
{
    static const char *funcName = "updateGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::updateGeometry();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QGraphicsWidget", funcName, gil, pyOverride);
}

void QGraphicsWidgetWrapper::wheelEvent(::QGraphicsSceneWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[59], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::wheelEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_wheelEvent("QGraphicsWidget", funcName, gil, pyOverride, event);
}

bool QGraphicsWidgetWrapper::windowFrameEvent(::QEvent * e)
{
    static const char *funcName = "windowFrameEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[60], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::windowFrameEvent(e);
    }
    return sbk_o_windowFrameEvent("QGraphicsWidget", funcName, gil, pyOverride, e);
}

bool QGraphicsWidgetWrapper::sbk_o_windowFrameEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * e)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::Qt::WindowFrameSection QGraphicsWidgetWrapper::windowFrameSectionAt(const ::QPointF & pos) const
{
    static const char *funcName = "windowFrameSectionAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[61], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::windowFrameSectionAt(pos);
    }
    return sbk_o_windowFrameSectionAt("QGraphicsWidget", funcName, gil, pyOverride, pos);
}

::Qt::WindowFrameSection QGraphicsWidgetWrapper::sbk_o_windowFrameSectionAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF & pos)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &pos)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &pos)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return Qt::NoSection;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_WindowFrameSection_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< Qt::WindowFrameSection >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return Qt::NoSection;
    }
    ::Qt::WindowFrameSection cppResult{Qt::NoSection};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QGraphicsWidgetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGraphicsWidget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGraphicsWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGraphicsWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGraphicsWidgetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGraphicsWidgetWrapper *>(this));
    return QGraphicsWidget::qt_metacast(_clname);
}

QGraphicsWidgetWrapper::~QGraphicsWidgetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsWidget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
    if (type != myType)
        Shiboken::ObjectType::copyMultipleInheritance(type, myType);

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsWidget >()))
        return -1;

    QGraphicsWidgetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QGraphicsWidget", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsWidget::QGraphicsWidget(QGraphicsItem*=,QFlags<Qt::WindowType>=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsWidget(QGraphicsItem*,QFlags<Qt::WindowType>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QGraphicsWidget(QGraphicsItem*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QGraphicsWidget(QGraphicsItem*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"parent", 0}, {"wFlags", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QGraphicsItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphicsWidget(QGraphicsItem*,QFlags<Qt::WindowType>)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QGraphicsWidgetWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QGraphicsWidgetWrapper(cppArg0, cppArg1);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QGraphicsWidgetFunc_actions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actions()const
        QList<QAction*> cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->actions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QActionPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_addAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::addAction(QAction*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), (pyArg)))) {
        overloadId = 0; // addAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAction *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAction(QAction*)
            cppSelf->addAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_addActions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::addActions(QList<QAction*>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QActionPTR_IDX], (pyArg)))) {
        overloadId = 0; // addActions(QList<QAction*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addActions", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::QList<QAction*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addActions(QList<QAction*>)
            cppSelf->addActions(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_adjustSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // adjustSize()
        cppSelf->adjustSize();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_autoFillBackground(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoFillBackground()const
        bool cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->autoFillBackground();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_boundingRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundingRect()const
        QRectF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsWidget *>(cppSelf)->::QGraphicsWidget::boundingRect()
            : const_cast<const ::QGraphicsWidget *>(cppSelf)->boundingRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::changeEvent(cppArg0)
                : cppSelf->changeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        bool cppResult = cppSelf->close();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_closeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::closeEvent(QCloseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // closeEvent(QCloseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "closeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCloseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // closeEvent(QCloseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::closeEvent(cppArg0)
                : cppSelf->closeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_focusNextPrevChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::focusNextPrevChild(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusNextPrevChild", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusNextPrevChild(bool)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::focusNextPrevChild(cppArg0)
                : cppSelf->focusNextPrevChild(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_focusOutEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::focusOutEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusOutEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusOutEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::focusOutEvent(cppArg0)
                : cppSelf->focusOutEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_focusPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusPolicy()const
        Qt::FocusPolicy cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->focusPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusPolicy_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_focusWidget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusWidget()const
        QGraphicsWidget * cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->focusWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // font()const
        QFont cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->font();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_getContentsMargins(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getContentsMargins(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            qreal a, b, c, d;
            cppSelf->::QGraphicsWidget::getContentsMargins(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_getWindowFrameMargins(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getWindowFrameMargins(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            qreal a, b, c, d;
            cppSelf->::QGraphicsWidget::getWindowFrameMargins(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_grabKeyboardEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::grabKeyboardEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // grabKeyboardEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "grabKeyboardEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // grabKeyboardEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::grabKeyboardEvent(cppArg0)
                : cppSelf->grabKeyboardEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_grabMouseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::grabMouseEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // grabMouseEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "grabMouseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // grabMouseEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::grabMouseEvent(cppArg0)
                : cppSelf->grabMouseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_grabShortcut(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "grabShortcut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:grabShortcut", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::grabShortcut(QKeySequence,Qt::ShortcutContext=)->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // grabShortcut(QKeySequence,Qt::ShortcutContext)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ShortcutContext_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // grabShortcut(QKeySequence,Qt::ShortcutContext)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "grabShortcut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"context", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ShortcutContext_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "grabShortcut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QKeySequence cppArg0_local;
        ::QKeySequence *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::Qt::ShortcutContext cppArg1(Qt::WindowShortcut);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // grabShortcut(QKeySequence,Qt::ShortcutContext)
            int cppResult = cppSelf->grabShortcut(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_hideEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::hideEvent(QHideEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hideEvent(QHideEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hideEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHideEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hideEvent(QHideEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::hideEvent(cppArg0)
                : cppSelf->hideEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_hoverLeaveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::hoverLeaveEvent(QGraphicsSceneHoverEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneHoverEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hoverLeaveEvent(QGraphicsSceneHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hoverLeaveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneHoverEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hoverLeaveEvent(QGraphicsSceneHoverEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::hoverLeaveEvent(cppArg0)
                : cppSelf->hoverLeaveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_hoverMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::hoverMoveEvent(QGraphicsSceneHoverEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneHoverEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hoverMoveEvent(QGraphicsSceneHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hoverMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneHoverEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hoverMoveEvent(QGraphicsSceneHoverEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::hoverMoveEvent(cppArg0)
                : cppSelf->hoverMoveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_initStyleOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::initStyleOption(QStyleOption*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArg)))) {
        overloadId = 0; // initStyleOption(QStyleOption*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initStyleOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyleOption *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initStyleOption(QStyleOption*)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsWidget *>(cppSelf)->::QGraphicsWidget::initStyleOption(cppArg0)
                : const_cast<const ::QGraphicsWidget *>(cppSelf)->initStyleOption(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_insertAction(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertAction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::insertAction(QAction*,QAction*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertAction(QAction*,QAction*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAction *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAction *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertAction(QAction*,QAction*)
            cppSelf->insertAction(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_insertActions(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertActions", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::insertActions(QAction*,QList<QAction*>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QActionPTR_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertActions(QAction*,QList<QAction*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertActions", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAction *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<QAction*> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertActions(QAction*,QList<QAction*>)
            cppSelf->insertActions(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_isActiveWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActiveWindow()const
        bool cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->isActiveWindow();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_itemChange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemChange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsItem::itemChange(QGraphicsItem::GraphicsItemChange,QVariant)->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_GraphicsItemChange_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "itemChange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::QGraphicsItem::GraphicsItemChange cppArg0{QGraphicsItem::ItemPositionChange};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::itemChange(cppArg0, cppArg1)
                : cppSelf->itemChange(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_layout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layout()const
        QGraphicsLayout * cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->layout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_layoutDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layoutDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->layoutDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_moveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::moveEvent(QGraphicsSceneMoveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMoveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // moveEvent(QGraphicsSceneMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "moveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneMoveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // moveEvent(QGraphicsSceneMoveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::moveEvent(cppArg0)
                : cppSelf->moveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_paint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:paint", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsItem::paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"widget", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionGraphicsItem *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::paint(cppArg0, cppArg1, cppArg2)
                : cppSelf->paint(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_paintWindowFrame(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "paintWindowFrame", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:paintWindowFrame", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::paintWindowFrame(QPainter*,const QStyleOptionGraphicsItem*,QWidget*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // paintWindowFrame(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 0; // paintWindowFrame(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "paintWindowFrame", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"widget", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "paintWindowFrame", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionGraphicsItem *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintWindowFrame(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::paintWindowFrame(cppArg0, cppArg1, cppArg2)
                : cppSelf->paintWindowFrame(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_palette(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // palette()const
        QPalette cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->palette();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_polishEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // polishEvent()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphicsWidget::polishEvent()
            : cppSelf->polishEvent();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_propertyChange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "propertyChange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::propertyChange(QString,QVariant)->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // propertyChange(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "propertyChange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // propertyChange(QString,QVariant)
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::propertyChange(cppArg0, cppArg1)
                : cppSelf->propertyChange(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        QRectF cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_releaseShortcut(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::releaseShortcut(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // releaseShortcut(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "releaseShortcut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseShortcut(int)
            cppSelf->releaseShortcut(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_removeAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::removeAction(QAction*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), (pyArg)))) {
        overloadId = 0; // removeAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAction *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAction(QAction*)
            cppSelf->removeAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_resize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resize", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::resize(QSizeF)
    // 1: QGraphicsWidget::resize(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // resize(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // resize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // resize(const QSizeF &size)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // resize(QSizeF)
                cppSelf->resize(*cppArg0);
            }
            break;
        }
        case 1: // resize(qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resize(qreal,qreal)
                cppSelf->resize(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::resizeEvent(QGraphicsSceneResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QGraphicsSceneResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QGraphicsSceneResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_sceneEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::sceneEvent(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // sceneEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sceneEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sceneEvent(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::sceneEvent(cppArg0)
                : cppSelf->sceneEvent(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_setAttribute(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setAttribute", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setAttribute", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::setAttribute(Qt::WidgetAttribute,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_WidgetAttribute_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setAttribute(Qt::WidgetAttribute,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setAttribute(Qt::WidgetAttribute,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAttribute", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"on", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setAttribute", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        ::Qt::WidgetAttribute cppArg0{Qt::WA_Disabled};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttribute(Qt::WidgetAttribute,bool)
            cppSelf->setAttribute(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setAutoFillBackground(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setAutoFillBackground(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoFillBackground(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoFillBackground", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoFillBackground(bool)
            cppSelf->setAutoFillBackground(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setContentsMargins(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setContentsMargins", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_UnpackTuple(args, "setContentsMargins", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::setContentsMargins(QMarginsF)
    // 1: QGraphicsWidget::setContentsMargins(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setContentsMargins(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setContentsMargins(QMarginsF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContentsMargins", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setContentsMargins(QMarginsF margins)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMarginsF cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContentsMargins(QMarginsF)
                cppSelf->setContentsMargins(cppArg0);
            }
            break;
        }
        case 1: // setContentsMargins(qreal left, qreal top, qreal right, qreal bottom)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContentsMargins(qreal,qreal,qreal,qreal)
                cppSelf->setContentsMargins(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setFocusPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setFocusPolicy(Qt::FocusPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFocusPolicy(Qt::FocusPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFocusPolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::Qt::FocusPolicy cppArg0{Qt::NoFocus};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFocusPolicy(Qt::FocusPolicy)
            cppSelf->setFocusPolicy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont)
            cppSelf->setFont(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setGeometry(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setGeometry", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_UnpackTuple(args, "setGeometry", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setGeometry(QRectF)
    // 1: QGraphicsWidget::setGeometry(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setGeometry(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setGeometry(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setGeometry", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setGeometry(const QRectF &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setGeometry(QRectF)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QGraphicsWidget::setGeometry(*cppArg0)
                    : cppSelf->setGeometry(*cppArg0);
            }
            break;
        }
        case 1: // setGeometry(qreal x, qreal y, qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setGeometry(qreal,qreal,qreal,qreal)
                cppSelf->setGeometry(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setLayout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setLayout(QGraphicsLayout*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]), (pyArg)))) {
        overloadId = 0; // setLayout(QGraphicsLayout*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayout", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsLayout *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayout(QGraphicsLayout*)
            cppSelf->setLayout(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setLayoutDirection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setLayoutDirection(Qt::LayoutDirection)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayoutDirection", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutDirection(Qt::LayoutDirection)
            cppSelf->setLayoutDirection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setPalette(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setPalette(QPalette)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArg)))) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPalette cppArg0_local;
        ::QPalette *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPalette(QPalette)
            cppSelf->setPalette(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setShortcutAutoRepeat(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setShortcutAutoRepeat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setShortcutAutoRepeat", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::setShortcutAutoRepeat(int,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setShortcutAutoRepeat(int,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setShortcutAutoRepeat(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setShortcutAutoRepeat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"enabled", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setShortcutAutoRepeat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShortcutAutoRepeat(int,bool)
            cppSelf->setShortcutAutoRepeat(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setShortcutEnabled(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setShortcutEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setShortcutEnabled", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::setShortcutEnabled(int,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setShortcutEnabled(int,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setShortcutEnabled(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setShortcutEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"enabled", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setShortcutEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShortcutEnabled(int,bool)
            cppSelf->setShortcutEnabled(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setStyle(QStyle*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), (pyArg)))) {
        overloadId = 0; // setStyle(QStyle*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyle *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyle(QStyle*)
            cppSelf->setStyle(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setTabOrder(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTabOrder", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QGraphicsWidget::setTabOrder(QGraphicsWidget*,QGraphicsWidget*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setTabOrder(QGraphicsWidget*,QGraphicsWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTabOrder", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGraphicsWidget *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabOrder(QGraphicsWidget*,QGraphicsWidget*)
            ::QGraphicsWidget::setTabOrder(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setWindowFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setWindowFlags(QFlags<Qt::WindowType>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setWindowFlags(QFlags<Qt::WindowType>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWindowFlags", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::WindowType> cppArg0 = QFlags<Qt::WindowType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWindowFlags(QFlags<Qt::WindowType>)
            cppSelf->setWindowFlags(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setWindowFrameMargins(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setWindowFrameMargins", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_UnpackTuple(args, "setWindowFrameMargins", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsWidget::setWindowFrameMargins(QMarginsF)
    // 1: QGraphicsWidget::setWindowFrameMargins(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setWindowFrameMargins(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setWindowFrameMargins(QMarginsF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setWindowFrameMargins", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setWindowFrameMargins(QMarginsF margins)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMarginsF cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setWindowFrameMargins(QMarginsF)
                cppSelf->setWindowFrameMargins(cppArg0);
            }
            break;
        }
        case 1: // setWindowFrameMargins(qreal left, qreal top, qreal right, qreal bottom)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setWindowFrameMargins(qreal,qreal,qreal,qreal)
                cppSelf->setWindowFrameMargins(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_setWindowTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::setWindowTitle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setWindowTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWindowTitle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWindowTitle(QString)
            cppSelf->setWindowTitle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_shape(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shape()const
        QPainterPath cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsWidget *>(cppSelf)->::QGraphicsWidget::shape()
            : const_cast<const ::QGraphicsWidget *>(cppSelf)->shape();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_showEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::showEvent(QShowEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), (pyArg)))) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "showEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QShowEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showEvent(QShowEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::showEvent(cppArg0)
                : cppSelf->showEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSizeF cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_sizeHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:sizeHint", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::sizeHint(Qt::SizeHint,const QSizeF&=)const->QSizeF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1])))) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"constraint", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
            }
        }
        ::Qt::SizeHint cppArg0{Qt::MinimumSize};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSizeF cppArg1_local = QSizeF();
        ::QSizeF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeHint(Qt::SizeHint,QSizeF)const
            QSizeF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsWidget *>(cppSelf)->::QGraphicsWidget::sizeHint(cppArg0, *cppArg1)
                : const_cast<const ::QGraphicsWidget *>(cppSelf)->sizeHint(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_style(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()const
        QStyle * cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->style();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_testAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::testAttribute(Qt::WidgetAttribute)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_WidgetAttribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testAttribute(Qt::WidgetAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "testAttribute", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        ::Qt::WidgetAttribute cppArg0{Qt::WA_Disabled};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testAttribute(Qt::WidgetAttribute)const
            bool cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->testAttribute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsWidget *>(cppSelf)->::QGraphicsWidget::type()
            : const_cast<const ::QGraphicsWidget *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_ungrabKeyboardEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::ungrabKeyboardEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // ungrabKeyboardEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ungrabKeyboardEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ungrabKeyboardEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::ungrabKeyboardEvent(cppArg0)
                : cppSelf->ungrabKeyboardEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_ungrabMouseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::ungrabMouseEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // ungrabMouseEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ungrabMouseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ungrabMouseEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::ungrabMouseEvent(cppArg0)
                : cppSelf->ungrabMouseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_unsetLayoutDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetLayoutDirection()
        cppSelf->unsetLayoutDirection();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_unsetWindowFrameMargins(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetWindowFrameMargins()
        cppSelf->unsetWindowFrameMargins();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_updateGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateGeometry()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphicsWidget::updateGeometry()
            : cppSelf->updateGeometry();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsWidgetFunc_windowFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // windowFlags()const
        QFlags<Qt::WindowType> cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->windowFlags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_windowFrameEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::windowFrameEvent(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // windowFrameEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "windowFrameEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // windowFrameEvent(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsWidget::windowFrameEvent(cppArg0)
                : cppSelf->windowFrameEvent(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_windowFrameGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // windowFrameGeometry()const
        QRectF cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->windowFrameGeometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_windowFrameRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // windowFrameRect()const
        QRectF cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->windowFrameRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_windowFrameSectionAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsWidget::windowFrameSectionAt(QPointF)const->Qt::WindowFrameSection
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // windowFrameSectionAt(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "windowFrameSectionAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // windowFrameSectionAt(QPointF)const
            Qt::WindowFrameSection cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsWidget *>(cppSelf)->::QGraphicsWidget::windowFrameSectionAt(*cppArg0)
                : const_cast<const ::QGraphicsWidget *>(cppSelf)->windowFrameSectionAt(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_WindowFrameSection_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_windowTitle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // windowTitle()const
        QString cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->windowTitle();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsWidgetFunc_windowType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // windowType()const
        Qt::WindowType cppResult = const_cast<const ::QGraphicsWidget *>(cppSelf)->windowType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_WindowType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QGraphicsWidget_PropertyStrings[] = {
    "autoFillBackground::",
    "focusPolicy::",
    "font::",
    "geometry::",
    "layout::",
    "layoutDirection::",
    "maximumSize::",
    "minimumSize::",
    "palette::",
    "preferredSize::",
    "size::resize",
    "sizePolicy::",
    "windowFlags::",
    "windowTitle::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsWidget_methods[] = {
    {"actions", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_actions), METH_NOARGS, nullptr},
    {"addAction", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_addAction), METH_O, nullptr},
    {"addActions", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_addActions), METH_O, nullptr},
    {"adjustSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_adjustSize), METH_NOARGS, nullptr},
    {"autoFillBackground", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_autoFillBackground), METH_NOARGS, nullptr},
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_boundingRect), METH_NOARGS, nullptr},
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_changeEvent), METH_O, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_close), METH_NOARGS, nullptr},
    {"closeEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_closeEvent), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_event), METH_O, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_focusInEvent), METH_O, nullptr},
    {"focusNextPrevChild", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_focusNextPrevChild), METH_O, nullptr},
    {"focusOutEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_focusOutEvent), METH_O, nullptr},
    {"focusPolicy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_focusPolicy), METH_NOARGS, nullptr},
    {"focusWidget", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_focusWidget), METH_NOARGS, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_font), METH_NOARGS, nullptr},
    {"getContentsMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_getContentsMargins), METH_NOARGS, nullptr},
    {"getWindowFrameMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_getWindowFrameMargins), METH_NOARGS, nullptr},
    {"grabKeyboardEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_grabKeyboardEvent), METH_O, nullptr},
    {"grabMouseEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_grabMouseEvent), METH_O, nullptr},
    {"grabShortcut", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_grabShortcut), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hideEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_hideEvent), METH_O, nullptr},
    {"hoverLeaveEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_hoverLeaveEvent), METH_O, nullptr},
    {"hoverMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_hoverMoveEvent), METH_O, nullptr},
    {"initStyleOption", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_initStyleOption), METH_O, nullptr},
    {"insertAction", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_insertAction), METH_VARARGS, nullptr},
    {"insertActions", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_insertActions), METH_VARARGS, nullptr},
    {"isActiveWindow", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_isActiveWindow), METH_NOARGS, nullptr},
    {"itemChange", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_itemChange), METH_VARARGS, nullptr},
    {"layout", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_layout), METH_NOARGS, nullptr},
    {"layoutDirection", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_layoutDirection), METH_NOARGS, nullptr},
    {"moveEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_moveEvent), METH_O, nullptr},
    {"paint", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_paint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"paintWindowFrame", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_paintWindowFrame), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"palette", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_palette), METH_NOARGS, nullptr},
    {"polishEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_polishEvent), METH_NOARGS, nullptr},
    {"propertyChange", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_propertyChange), METH_VARARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_rect), METH_NOARGS, nullptr},
    {"releaseShortcut", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_releaseShortcut), METH_O, nullptr},
    {"removeAction", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_removeAction), METH_O, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_resize), METH_VARARGS, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_resizeEvent), METH_O, nullptr},
    {"sceneEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_sceneEvent), METH_O, nullptr},
    {"setAttribute", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setAttribute), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAutoFillBackground", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setAutoFillBackground), METH_O, nullptr},
    {"setContentsMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setContentsMargins), METH_VARARGS, nullptr},
    {"setFocusPolicy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setFocusPolicy), METH_O, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setFont), METH_O, nullptr},
    {"setGeometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setGeometry), METH_VARARGS, nullptr},
    {"setLayout", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setLayout), METH_O, nullptr},
    {"setLayoutDirection", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setLayoutDirection), METH_O, nullptr},
    {"setPalette", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setPalette), METH_O, nullptr},
    {"setShortcutAutoRepeat", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setShortcutAutoRepeat), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setShortcutEnabled", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setShortcutEnabled), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setStyle", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setStyle), METH_O, nullptr},
    {"setTabOrder", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setTabOrder), METH_VARARGS|METH_STATIC, nullptr},
    {"setWindowFlags", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setWindowFlags), METH_O, nullptr},
    {"setWindowFrameMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setWindowFrameMargins), METH_VARARGS, nullptr},
    {"setWindowTitle", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_setWindowTitle), METH_O, nullptr},
    {"shape", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_shape), METH_NOARGS, nullptr},
    {"showEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_showEvent), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_size), METH_NOARGS, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_sizeHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_style), METH_NOARGS, nullptr},
    {"testAttribute", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_testAttribute), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_type), METH_NOARGS, nullptr},
    {"ungrabKeyboardEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_ungrabKeyboardEvent), METH_O, nullptr},
    {"ungrabMouseEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_ungrabMouseEvent), METH_O, nullptr},
    {"unsetLayoutDirection", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_unsetLayoutDirection), METH_NOARGS, nullptr},
    {"unsetWindowFrameMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_unsetWindowFrameMargins), METH_NOARGS, nullptr},
    {"updateGeometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_updateGeometry), METH_NOARGS, nullptr},
    {"windowFlags", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_windowFlags), METH_NOARGS, nullptr},
    {"windowFrameEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_windowFrameEvent), METH_O, nullptr},
    {"windowFrameGeometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_windowFrameGeometry), METH_NOARGS, nullptr},
    {"windowFrameRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_windowFrameRect), METH_NOARGS, nullptr},
    {"windowFrameSectionAt", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_windowFrameSectionAt), METH_O, nullptr},
    {"windowTitle", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_windowTitle), METH_NOARGS, nullptr},
    {"windowType", reinterpret_cast<PyCFunction>(Sbk_QGraphicsWidgetFunc_windowType), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsWidget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsWidgetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsWidget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsWidget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_QGraphicsWidget_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QGraphicsWidget *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QGraphicsObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QGraphicsObject *>(static_cast<const QGraphicsWidget *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QGraphicsLayoutItem *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QGraphicsLayoutItem *>(static_cast<const QGraphicsWidget *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QGraphicsItem *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QGraphicsItem *>(static_cast<const QGraphicsObject *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QGraphicsObject *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QGraphicsWidgetSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QGraphicsWidget *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX]))
        return static_cast< ::QGraphicsObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]))
        return static_cast< ::QGraphicsItem *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]))
        return static_cast< ::QGraphicsLayoutItem *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsWidget_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsWidget_TypeF(void)
{
    return _Sbk_QGraphicsWidget_Type;
}

static PyType_Slot Sbk_QGraphicsWidget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsWidget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsWidget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsWidget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsWidget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsWidget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsWidget_spec = {
    "2:PySide6.QtWidgets.QGraphicsWidget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsWidget_slots
};

} //extern "C"

static void *Sbk_QGraphicsWidget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QGraphicsItem >())
        return dynamic_cast< ::QGraphicsWidget *>(reinterpret_cast< ::QGraphicsItem *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGraphicsWidget *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QGraphicsLayoutItem >())
        return dynamic_cast< ::QGraphicsWidget *>(reinterpret_cast< ::QGraphicsLayoutItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsWidget_PythonToCpp_QGraphicsWidget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsWidget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsWidget_PythonToCpp_QGraphicsWidget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsWidget_TypeF()))
        return QGraphicsWidget_PythonToCpp_QGraphicsWidget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsWidget_PTR_CppToPython_QGraphicsWidget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGraphicsWidget *>(const_cast<void *>(cppIn)), Sbk_QGraphicsWidget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsWidget_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsWidget(self,parent:PySide6.QtWidgets.QGraphicsItem=nullptr,wFlags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags(),*:KeywordOnly=None,palette:QPalette=None,font:QFont=None,layoutDirection:Qt.LayoutDirection=None,size:QSizeF=None,minimumSize:QSizeF=None,preferredSize:QSizeF=None,maximumSize:QSizeF=None,sizePolicy:QSizePolicy=None,focusPolicy:Qt.FocusPolicy=None,windowFlags:PySide6.QtCore.Qt.WindowType=None,windowTitle:QString=None,geometry:QRectF=None,autoFillBackground:bool=None,layout:QGraphicsLayout=None)",
    "PySide6.QtWidgets.QGraphicsWidget.actions(self)->QList[PySide6.QtGui.QAction]",
    "PySide6.QtWidgets.QGraphicsWidget.addAction(self,action:PySide6.QtGui.QAction)",
    "PySide6.QtWidgets.QGraphicsWidget.addActions(self,actions:QList[PySide6.QtGui.QAction])",
    "PySide6.QtWidgets.QGraphicsWidget.adjustSize(self)",
    "PySide6.QtWidgets.QGraphicsWidget.autoFillBackground(self)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.boundingRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsWidget.changeEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.close(self)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.closeEvent(self,event:PySide6.QtGui.QCloseEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.focusInEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.focusNextPrevChild(self,next:bool)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.focusOutEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.focusPolicy(self)->PySide6.QtCore.Qt.FocusPolicy",
    "PySide6.QtWidgets.QGraphicsWidget.focusWidget(self)->PySide6.QtWidgets.QGraphicsWidget",
    "PySide6.QtWidgets.QGraphicsWidget.font(self)->PySide6.QtGui.QFont",
    "PySide6.QtWidgets.QGraphicsWidget.getContentsMargins(self)->PyObject",
    "PySide6.QtWidgets.QGraphicsWidget.getWindowFrameMargins(self)->PyObject",
    "PySide6.QtWidgets.QGraphicsWidget.grabKeyboardEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.grabMouseEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.grabShortcut(self,sequence:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int],context:PySide6.QtCore.Qt.ShortcutContext=Qt.WindowShortcut)->int",
    "PySide6.QtWidgets.QGraphicsWidget.hideEvent(self,event:PySide6.QtGui.QHideEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.hoverLeaveEvent(self,event:PySide6.QtWidgets.QGraphicsSceneHoverEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.hoverMoveEvent(self,event:PySide6.QtWidgets.QGraphicsSceneHoverEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.initStyleOption(self,option:PySide6.QtWidgets.QStyleOption)",
    "PySide6.QtWidgets.QGraphicsWidget.insertAction(self,before:PySide6.QtGui.QAction,action:PySide6.QtGui.QAction)",
    "PySide6.QtWidgets.QGraphicsWidget.insertActions(self,before:PySide6.QtGui.QAction,actions:QList[PySide6.QtGui.QAction])",
    "PySide6.QtWidgets.QGraphicsWidget.isActiveWindow(self)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.itemChange(self,change:PySide6.QtWidgets.QGraphicsItem.GraphicsItemChange,value:QVariant)->QVariant",
    "PySide6.QtWidgets.QGraphicsWidget.layout(self)->PySide6.QtWidgets.QGraphicsLayout",
    "PySide6.QtWidgets.QGraphicsWidget.layoutDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtWidgets.QGraphicsWidget.moveEvent(self,event:PySide6.QtWidgets.QGraphicsSceneMoveEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.paint(self,painter:PySide6.QtGui.QPainter,option:PySide6.QtWidgets.QStyleOptionGraphicsItem,widget:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QGraphicsWidget.paintWindowFrame(self,painter:PySide6.QtGui.QPainter,option:PySide6.QtWidgets.QStyleOptionGraphicsItem,widget:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QGraphicsWidget.palette(self)->PySide6.QtGui.QPalette",
    "PySide6.QtWidgets.QGraphicsWidget.polishEvent(self)",
    "PySide6.QtWidgets.QGraphicsWidget.propertyChange(self,propertyName:QString,value:QVariant)->QVariant",
    "PySide6.QtWidgets.QGraphicsWidget.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsWidget.releaseShortcut(self,id:int)",
    "PySide6.QtWidgets.QGraphicsWidget.removeAction(self,action:PySide6.QtGui.QAction)",
    "1:PySide6.QtWidgets.QGraphicsWidget.resize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "0:PySide6.QtWidgets.QGraphicsWidget.resize(self,w:qreal,h:qreal)",
    "PySide6.QtWidgets.QGraphicsWidget.resizeEvent(self,event:PySide6.QtWidgets.QGraphicsSceneResizeEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.sceneEvent(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.setAttribute(self,attribute:PySide6.QtCore.Qt.WidgetAttribute,on:bool=true)",
    "PySide6.QtWidgets.QGraphicsWidget.setAutoFillBackground(self,enabled:bool)",
    "1:PySide6.QtWidgets.QGraphicsWidget.setContentsMargins(self,margins:typing.Union[PySide6.QtCore.QMarginsF, PySide6.QtCore.QMargins])",
    "0:PySide6.QtWidgets.QGraphicsWidget.setContentsMargins(self,left:qreal,top:qreal,right:qreal,bottom:qreal)",
    "PySide6.QtWidgets.QGraphicsWidget.setFocusPolicy(self,policy:PySide6.QtCore.Qt.FocusPolicy)",
    "PySide6.QtWidgets.QGraphicsWidget.setFont(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "1:PySide6.QtWidgets.QGraphicsWidget.setGeometry(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtWidgets.QGraphicsWidget.setGeometry(self,x:qreal,y:qreal,w:qreal,h:qreal)",
    "PySide6.QtWidgets.QGraphicsWidget.setLayout(self,layout:PySide6.QtWidgets.QGraphicsLayout)",
    "PySide6.QtWidgets.QGraphicsWidget.setLayoutDirection(self,direction:PySide6.QtCore.Qt.LayoutDirection)",
    "PySide6.QtWidgets.QGraphicsWidget.setPalette(self,palette:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor])",
    "PySide6.QtWidgets.QGraphicsWidget.setShortcutAutoRepeat(self,id:int,enabled:bool=true)",
    "PySide6.QtWidgets.QGraphicsWidget.setShortcutEnabled(self,id:int,enabled:bool=true)",
    "PySide6.QtWidgets.QGraphicsWidget.setStyle(self,style:PySide6.QtWidgets.QStyle)",
    "PySide6.QtWidgets.QGraphicsWidget.setTabOrder(first:PySide6.QtWidgets.QGraphicsWidget,second:PySide6.QtWidgets.QGraphicsWidget)",
    "PySide6.QtWidgets.QGraphicsWidget.setWindowFlags(self,wFlags:PySide6.QtCore.Qt.WindowType)",
    "1:PySide6.QtWidgets.QGraphicsWidget.setWindowFrameMargins(self,margins:typing.Union[PySide6.QtCore.QMarginsF, PySide6.QtCore.QMargins])",
    "0:PySide6.QtWidgets.QGraphicsWidget.setWindowFrameMargins(self,left:qreal,top:qreal,right:qreal,bottom:qreal)",
    "PySide6.QtWidgets.QGraphicsWidget.setWindowTitle(self,title:QString)",
    "PySide6.QtWidgets.QGraphicsWidget.shape(self)->PySide6.QtGui.QPainterPath",
    "PySide6.QtWidgets.QGraphicsWidget.showEvent(self,event:PySide6.QtGui.QShowEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.size(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsWidget.sizeHint(self,which:PySide6.QtCore.Qt.SizeHint,constraint:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize]=QSizeF())->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsWidget.style(self)->PySide6.QtWidgets.QStyle",
    "PySide6.QtWidgets.QGraphicsWidget.testAttribute(self,attribute:PySide6.QtCore.Qt.WidgetAttribute)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.type(self)->int",
    "PySide6.QtWidgets.QGraphicsWidget.ungrabKeyboardEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.ungrabMouseEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QGraphicsWidget.unsetLayoutDirection(self)",
    "PySide6.QtWidgets.QGraphicsWidget.unsetWindowFrameMargins(self)",
    "PySide6.QtWidgets.QGraphicsWidget.updateGeometry(self)",
    "PySide6.QtWidgets.QGraphicsWidget.windowFlags(self)->PySide6.QtCore.Qt.WindowType",
    "PySide6.QtWidgets.QGraphicsWidget.windowFrameEvent(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QGraphicsWidget.windowFrameGeometry(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsWidget.windowFrameRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsWidget.windowFrameSectionAt(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.Qt.WindowFrameSection",
    "PySide6.QtWidgets.QGraphicsWidget.windowTitle(self)->QString",
    "PySide6.QtWidgets.QGraphicsWidget.windowType(self)->PySide6.QtCore.Qt.WindowType",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsWidget_SignatureByteSize = 1386;
static constexpr uint8_t QGraphicsWidget_SignatureBytes[1386] = {
    0x78, 0xda, 0xd5, 0x59, 0x4b, 0x6f, 0xe3, 0x36, 0x10, 0xbe, 0xf7, 0x57, 0xe4, 0x18, 0x17, 0xaa,
    0xd1, 0x5e, 0x7a, 0x10, 0x90, 0x02, 0xa9, 0x1b, 0x27, 0x8b, 0xe6, 0x61, 0xc7, 0x69, 0x73, 0x28,
    0x72, 0xa0, 0xac, 0xb1, 0xc5, 0x2d, 0x45, 0x6a, 0x49, 0xca, 0x8e, 0xfa, 0xeb, 0xcb, 0x87, 0x5e,
    0xb6, 0x25, 0x7b, 0x1c, 0x3b, 0x05, 0x7a, 0xd8, 0x98, 0x22, 0x39, 0x1f, 0x87, 0x9c, 0xf7, 0xec,
    0xa4, 0x98, 0xd1, 0x18, 0x7e, 0x1e, 0x4e, 0xf5, 0x2b, 0x8d, 0x97, 0xa0, 0xd5, 0x70, 0x7a, 0x2b,
    0x49, 0x96, 0xd0, 0xb9, 0xf2, 0x13, 0x97, 0x0a, 0xd8, 0x22, 0xc8, 0x88, 0x04, 0xae, 0xc3, 0x49,
    0xff, 0xee, 0x2f, 0x1a, 0xd2, 0x2b, 0x9e, 0x33, 0x96, 0x69, 0x19, 0xac, 0xc7, 0x8c, 0x2c, 0x55,
    0x6b, 0xfb, 0x48, 0x48, 0x30, 0x3f, 0xc3, 0x57, 0xca, 0x63, 0xb1, 0x7e, 0x29, 0x32, 0xb8, 0xaa,
    0xbf, 0xdc, 0xde, 0xcb, 0x41, 0xf0, 0x7d, 0xf8, 0x3b, 0x14, 0x6b, 0x21, 0xe3, 0x27, 0xce, 0x8a,
    0xab, 0x47, 0xc1, 0xc1, 0x1c, 0xcb, 0x40, 0x6b, 0x08, 0xa7, 0x13, 0x3f, 0xf0, 0xb3, 0x0b, 0x61,
    0x58, 0x99, 0x8e, 0xcd, 0x5f, 0xff, 0xcd, 0x48, 0x21, 0x72, 0xfd, 0x1b, 0x95, 0x30, 0xd7, 0x54,
    0xf0, 0xd0, 0x20, 0xdf, 0x6f, 0x4e, 0xf9, 0x7d, 0x8a, 0xfe, 0x63, 0xa0, 0x66, 0xe6, 0xef, 0xd8,
    0x4f, 0xa4, 0x94, 0xd3, 0x34, 0x4f, 0x67, 0xdb, 0xf3, 0x99, 0x84, 0x05, 0x48, 0x09, 0xf1, 0xce,
    0x4a, 0x4a, 0xde, 0x3b, 0x29, 0x2c, 0xf4, 0x44, 0x30, 0x3a, 0x2f, 0xfc, 0xb4, 0x1f, 0x57, 0xec,
    0xce, 0x73, 0x55, 0x2d, 0xea, 0xe1, 0xb8, 0xf9, 0xf4, 0xeb, 0xeb, 0xe6, 0x15, 0xf6, 0xbf, 0x58,
    0x6b, 0xf7, 0x0b, 0xd5, 0xcc, 0x72, 0xa0, 0x25, 0xe5, 0x4b, 0xbf, 0xb0, 0x04, 0x91, 0x82, 0x96,
    0xe6, 0x8c, 0x67, 0x73, 0xe9, 0x92, 0x2f, 0x92, 0x6b, 0x31, 0xa6, 0x8c, 0xfd, 0x4a, 0xe6, 0x7f,
    0x2f, 0xa5, 0xc8, 0x79, 0x1c, 0x46, 0x42, 0xb0, 0xf6, 0xbb, 0x85, 0xb5, 0x08, 0xfd, 0xa3, 0xb9,
    0xb5, 0xc1, 0x77, 0x93, 0x43, 0x8a, 0x31, 0x24, 0xee, 0x69, 0x95, 0x53, 0x90, 0xc1, 0x0f, 0xbf,
    0x4c, 0xef, 0xa9, 0xd2, 0x7f, 0x35, 0x64, 0xb7, 0x39, 0x1d, 0x4e, 0xaf, 0xdd, 0x9e, 0x37, 0x0c,
    0x5a, 0x1c, 0xfb, 0xcd, 0x5e, 0xe1, 0x3c, 0x78, 0xd8, 0x09, 0x37, 0x38, 0x06, 0x4e, 0xb5, 0xf1,
    0x54, 0xb8, 0x8f, 0x4b, 0x1c, 0xee, 0xd7, 0x5c, 0x69, 0x2b, 0x62, 0x7f, 0x6f, 0x0c, 0xc9, 0x8e,
    0x0c, 0xaa, 0x27, 0xb3, 0xa2, 0x40, 0x00, 0x44, 0x96, 0xc6, 0xc8, 0xd9, 0xca, 0xb5, 0x22, 0xdd,
    0x56, 0x14, 0x27, 0x73, 0x04, 0xd6, 0x3c, 0x21, 0x7c, 0x09, 0x37, 0x2b, 0x63, 0xcd, 0xfe, 0x61,
    0x60, 0xb5, 0x69, 0xd8, 0x1e, 0xce, 0x6d, 0xc0, 0x5c, 0x6e, 0xce, 0x84, 0x82, 0x23, 0xef, 0xe3,
    0x68, 0xf6, 0xb0, 0xe0, 0x64, 0x32, 0xaa, 0x37, 0x61, 0xd8, 0x00, 0xdc, 0x85, 0xd0, 0x2c, 0x3a,
    0x9b, 0xfd, 0xc2, 0x0f, 0x31, 0xe9, 0x6c, 0x19, 0xcd, 0xa4, 0x03, 0x7d, 0x84, 0x77, 0x3d, 0x91,
    0xb0, 0x1a, 0x25, 0x94, 0x79, 0x45, 0x08, 0xb8, 0x99, 0x72, 0x66, 0x79, 0x24, 0x7f, 0x4f, 0xb9,
    0xfe, 0x04, 0x06, 0xbd, 0x6b, 0xea, 0xd3, 0xb3, 0x0d, 0xff, 0x85, 0x85, 0x6c, 0x45, 0x92, 0x0d,
    0xc8, 0x1e, 0x22, 0x14, 0x2c, 0xef, 0xc0, 0x2b, 0xaf, 0xcc, 0x31, 0x08, 0xe6, 0xdf, 0xc8, 0xec,
    0x34, 0x2f, 0xa3, 0x1e, 0x88, 0x5c, 0xd2, 0xc6, 0x91, 0x4d, 0x8a, 0xa7, 0xe8, 0xab, 0x31, 0x27,
    0x1c, 0x48, 0x19, 0xc3, 0x24, 0x49, 0xe1, 0x04, 0x1c, 0x49, 0x22, 0x13, 0xfc, 0x22, 0x41, 0x64,
    0x7c, 0x3e, 0xdb, 0xb4, 0xa8, 0x0f, 0x22, 0x57, 0x70, 0x5e, 0xc8, 0x59, 0x22, 0xa4, 0x9e, 0xe7,
    0x25, 0xa0, 0x82, 0x6f, 0x39, 0xf0, 0x39, 0x84, 0xba, 0xc8, 0x8c, 0x8f, 0x1a, 0xfe, 0xc1, 0x8d,
    0x2b, 0xdd, 0x76, 0xb0, 0xe6, 0x6e, 0xb3, 0x72, 0x5f, 0x70, 0xb1, 0x7d, 0xb8, 0x59, 0x1c, 0x89,
    0x34, 0xa2, 0x9c, 0x58, 0x2f, 0xdc, 0x5e, 0xdf, 0xa6, 0x1d, 0xce, 0x34, 0xe1, 0xb1, 0x79, 0x23,
    0x33, 0x17, 0x5c, 0x94, 0xd1, 0x2f, 0xb8, 0xa0, 0x5c, 0xbf, 0x05, 0x73, 0x2b, 0xcc, 0x77, 0xdd,
    0x11, 0x41, 0x2b, 0x7e, 0x47, 0x7e, 0x47, 0x93, 0x78, 0x54, 0x0b, 0x46, 0x56, 0x14, 0xa5, 0x33,
    0x89, 0x59, 0x3f, 0x64, 0x71, 0x77, 0xd5, 0x1e, 0xcc, 0x73, 0x26, 0x62, 0x05, 0xf2, 0x1e, 0xc8,
    0x6a, 0x1f, 0xec, 0x0e, 0xf1, 0x6c, 0x0e, 0x1c, 0xee, 0x2c, 0xe9, 0x71, 0x07, 0x3d, 0x88, 0x4f,
    0x3f, 0xc7, 0x24, 0x54, 0x7a, 0xa6, 0x0b, 0x06, 0x4f, 0x59, 0x13, 0xcb, 0x45, 0xb6, 0x15, 0xcb,
    0x6b, 0xea, 0xd6, 0x56, 0x1c, 0xba, 0x02, 0xa9, 0xdb, 0x69, 0x42, 0x04, 0x0b, 0x23, 0xe5, 0xee,
    0x34, 0xe1, 0xe4, 0x1c, 0xa2, 0x7d, 0x9c, 0x42, 0x9f, 0x77, 0x7a, 0x8e, 0x41, 0x95, 0xdd, 0xbc,
    0x02, 0xaf, 0xa5, 0x47, 0x06, 0x57, 0x6a, 0xf2, 0xf0, 0x91, 0x0b, 0xf2, 0x9e, 0x63, 0x1f, 0xf0,
    0x0f, 0x65, 0xee, 0xc3, 0xf6, 0x87, 0x27, 0x0f, 0x56, 0x84, 0xe5, 0x26, 0xc7, 0xfc, 0x93, 0x48,
    0x4a, 0x5c, 0xec, 0xac, 0x86, 0x08, 0x2e, 0x7c, 0x6a, 0x89, 0xf0, 0xf8, 0x3e, 0xe7, 0x44, 0x23,
    0xd6, 0x19, 0x7d, 0x7f, 0x7c, 0xda, 0x4a, 0xfd, 0x11, 0xd0, 0xe9, 0x47, 0xec, 0xa2, 0x36, 0x26,
    0x8c, 0x44, 0x33, 0x42, 0x79, 0x5d, 0x49, 0x99, 0x21, 0xc8, 0x6d, 0x15, 0x9a, 0xf8, 0x69, 0x9c,
    0xad, 0xb4, 0x85, 0x65, 0x0a, 0x02, 0xbb, 0xa1, 0x8b, 0xc2, 0x0f, 0xaa, 0xa2, 0x0c, 0xcd, 0x67,
    0x2b, 0xa2, 0xfd, 0x2f, 0x58, 0x76, 0x95, 0x61, 0x4f, 0x32, 0x50, 0xd6, 0x8d, 0x18, 0x1c, 0x93,
    0xd1, 0xa8, 0xa4, 0x51, 0x03, 0xd4, 0xd9, 0x52, 0x64, 0xc6, 0x43, 0x14, 0x6d, 0x7b, 0xab, 0xe6,
    0x1e, 0xcd, 0xf3, 0x55, 0x05, 0xda, 0x49, 0xa6, 0x24, 0xcf, 0x90, 0xf5, 0x4b, 0x60, 0x40, 0x14,
    0x6c, 0x46, 0x6e, 0x1a, 0x87, 0x14, 0xa7, 0xbe, 0x12, 0xac, 0x89, 0xe0, 0xcb, 0xb3, 0x9f, 0x42,
    0x0c, 0xa6, 0xaa, 0x8a, 0x28, 0x5f, 0x98, 0xf7, 0xe4, 0x0f, 0xfe, 0xa2, 0xae, 0xd4, 0xde, 0x4d,
    0x1d, 0xec, 0xb4, 0x71, 0xa9, 0x3f, 0x1e, 0x79, 0xde, 0x3a, 0xfc, 0x26, 0x81, 0xb0, 0x20, 0xf1,
    0xbf, 0xb8, 0x27, 0xb0, 0xe4, 0x47, 0x7b, 0x89, 0xe7, 0x86, 0x0c, 0x73, 0x8a, 0xb2, 0x34, 0x37,
    0x67, 0xae, 0x65, 0x14, 0xe8, 0x6b, 0x6d, 0xf4, 0x30, 0xca, 0x4b, 0x33, 0x09, 0x48, 0xf5, 0xd9,
    0xd9, 0x6f, 0xb0, 0x44, 0x35, 0x41, 0x60, 0xa4, 0xec, 0x3a, 0x06, 0x5a, 0xe6, 0xa8, 0xae, 0x80,
    0x3d, 0xad, 0xbb, 0xe0, 0x0d, 0x80, 0x93, 0x88, 0x81, 0xef, 0x40, 0xe0, 0x94, 0x44, 0x75, 0x27,
    0xe9, 0x41, 0xea, 0x3f, 0xf6, 0xeb, 0x4c, 0x49, 0xd1, 0xa1, 0x36, 0xe5, 0x0a, 0x52, 0x73, 0xfa,
    0x98, 0x60, 0xb0, 0xd0, 0xa5, 0x22, 0x69, 0x91, 0x95, 0x23, 0x49, 0x97, 0x49, 0x35, 0x1b, 0x09,
    0xad, 0x45, 0x8a, 0xd7, 0x31, 0x73, 0xd0, 0x78, 0xab, 0x02, 0x0b, 0x32, 0xdf, 0x37, 0xda, 0x5b,
    0x86, 0xa1, 0xb1, 0x2b, 0xb5, 0x72, 0x0d, 0xb4, 0x7d, 0xf9, 0xba, 0xdd, 0xda, 0x4a, 0xb0, 0xcb,
    0x81, 0x4d, 0x6b, 0xde, 0xd0, 0x82, 0xbb, 0x2d, 0xfb, 0x51, 0xfe, 0x48, 0xeb, 0xc5, 0xf6, 0x8b,
    0xcb, 0xf9, 0xb2, 0x5d, 0x59, 0xd9, 0x69, 0xbc, 0xa0, 0x36, 0x0f, 0x7d, 0x2f, 0x05, 0x51, 0x94,
    0xbf, 0x1f, 0xb0, 0x7b, 0x83, 0x79, 0xdf, 0xe4, 0x32, 0x55, 0xcb, 0xec, 0x60, 0x42, 0x73, 0x14,
    0xf4, 0x66, 0x52, 0x13, 0xc4, 0x75, 0x23, 0xf3, 0x60, 0x72, 0x83, 0x3c, 0x66, 0xd2, 0x8a, 0x91,
    0x75, 0x4f, 0x75, 0x9f, 0xfc, 0x4b, 0x82, 0x5d, 0x69, 0xe8, 0xe1, 0x2d, 0x13, 0x11, 0x61, 0x23,
    0xc1, 0x84, 0xdc, 0x29, 0xd5, 0xdc, 0xec, 0x1b, 0x92, 0xa9, 0x2a, 0x18, 0x59, 0x6f, 0xf1, 0x0c,
    0x19, 0x90, 0x8d, 0xb0, 0xb4, 0xe1, 0x2c, 0x8e, 0x71, 0x3e, 0x15, 0xec, 0x8d, 0xa7, 0x3f, 0x0f,
    0xa6, 0xcd, 0x63, 0xca, 0x50, 0x65, 0x87, 0xbd, 0xb9, 0x0e, 0x12, 0xef, 0x85, 0x44, 0x4f, 0x32,
    0x06, 0x79, 0xb9, 0xa0, 0x52, 0xe9, 0xc3, 0x9a, 0x6d, 0x8a, 0x6c, 0x53, 0xde, 0xc6, 0x87, 0x37,
    0x22, 0xcf, 0x6f, 0xf7, 0xdd, 0x7d, 0x40, 0x3c, 0xdc, 0x7d, 0x46, 0xdb, 0x7d, 0x4f, 0x43, 0xe4,
    0x3f, 0xf7, 0xd9, 0x7d, 0x7c, 0x7c, 0x86, 0xdb, 0x7e, 0x6d, 0x9a, 0xf2, 0xfe, 0x10, 0xdd, 0xee,
    0xcf, 0xa3, 0x40, 0x12, 0x92, 0xf5, 0x27, 0xb1, 0x2e, 0xd1, 0x9e, 0x10, 0x9d, 0xa0, 0x90, 0xc4,
    0xfa, 0x50, 0x93, 0x62, 0x56, 0xed, 0x41, 0xb1, 0x56, 0x37, 0xbb, 0x77, 0x13, 0x50, 0x97, 0x97,
    0x21, 0x31, 0xee, 0xea, 0x1a, 0x68, 0x6d, 0x56, 0x92, 0xae, 0x4e, 0x4d, 0xb9, 0xcb, 0x36, 0x73,
    0x94, 0x96, 0xf6, 0xda, 0x1f, 0x4f, 0x0b, 0xaf, 0xfc, 0xea, 0xe5, 0xe0, 0x14, 0xb6, 0x6b, 0xc3,
    0xef, 0xae, 0x62, 0x9d, 0xd1, 0x23, 0x70, 0x34, 0xa8, 0x13, 0x72, 0x30, 0x7c, 0xaa, 0x67, 0x1e,
    0xab, 0x66, 0x17, 0xd7, 0xd2, 0xca, 0xf9, 0xe7, 0xf4, 0x1e, 0x3d, 0xee, 0x99, 0xbb, 0x8f, 0x39,
    0xef, 0x89, 0x99, 0x68, 0xe2, 0xbe, 0x6e, 0x2d, 0x86, 0x3e, 0x8b, 0x89, 0x86, 0x8d, 0x04, 0x03,
    0x43, 0xb6, 0xde, 0xf2, 0xb5, 0x9d, 0x3d, 0x8b, 0xc6, 0xcd, 0xe2, 0x11, 0xed, 0x1d, 0xda, 0x4f,
    0x7b, 0x6a, 0x99, 0xd0, 0x82, 0xdd, 0xbc, 0xe4, 0xc7, 0xcb, 0xce, 0x16, 0xe4, 0x39, 0xfe, 0xef,
    0xaa, 0x05, 0x37, 0xf3, 0xc2, 0xbf, 0xae, 0x9a, 0x2a, 0xe2, 0x40, 0x5c, 0x99, 0x08, 0x63, 0x0e,
    0x1d, 0x9e, 0xc2, 0xcd, 0xef, 0xe4, 0x31, 0x2d, 0x87, 0x3b, 0xbc, 0x61, 0x90, 0x9a, 0x77, 0x7c,
    0xdb, 0x23, 0xb7, 0x36, 0x47, 0xe8, 0x6b, 0x34, 0xc1, 0xc2, 0xb6, 0x03, 0x7c, 0xa0, 0xc0, 0x13,
    0x17, 0x19, 0xa0, 0xb4, 0xe9, 0x5f, 0xee, 0x8e, 0xaf, 0x71
};
#endif

PyTypeObject *init_QGraphicsWidget(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsWidget_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]))));

    _Sbk_QGraphicsWidget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsWidget",
        "QGraphicsWidget*",
        &Sbk_QGraphicsWidget_spec,
        &Shiboken::callCppDestructor< QGraphicsWidget >,
        Sbk_QGraphicsWidget_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsWidget_TypeF(); // references _Sbk_QGraphicsWidget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsWidget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsWidget_SignatureBytes, QGraphicsWidget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsWidget_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsWidget_PythonToCpp_QGraphicsWidget_PTR,
        is_QGraphicsWidget_PythonToCpp_QGraphicsWidget_PTR_Convertible,
        QGraphicsWidget_PTR_CppToPython_QGraphicsWidget);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsWidget");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsWidget*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsWidget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsWidget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsWidgetWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QGraphicsWidget_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QGraphicsWidget_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QGraphicsWidget_TypeF(), &Sbk_QGraphicsWidgetSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsWidget_TypeF(), &Sbk_QGraphicsWidget_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QGraphicsWidget::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGraphicsWidget::staticMetaObject, sizeof(QGraphicsWidgetWrapper));

    return pyType;
}
